(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1251282,      31472]*)
(*NotebookOutlinePosition[   1295361,      33037]*)
(*  CellTagsIndexPosition[   1294893,      33019]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Angoli orientati e definizione delle funzioni goniometriche", "Title"],

Cell["Lorenzo Roi", "Author"],

Cell[TextData[{
  "Copyright 2006",
  ButtonBox[" www.lorenzoroi.net",
    ButtonData:>{
      URL[ "http://www.lorenzoroi.net"], None},
    ButtonStyle->"Hyperlink"]
}], "Copyright",
  CellMargins->{{Inherited, Inherited}, {10, Inherited}},
  TextAlignment->Right],

Cell[CellGroupData[{

Cell["Presentazione", "Subsection"],

Cell["\<\
In questo notebook intendiamo dapprima introdurre la misura di un angolo \
orientato estendendola all'insieme dei reali e successivamente definiamo le \
funzioni goniometriche del seno, coseno e tangente studiandone i grafici e le \
periodicit\[AGrave].\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Funzioni e comandi utilizzati", "Subsection"],

Cell["\<\
Le istruzioni seguenti vanno caricate prima di procedere al calcolo delle \
celle di input di questo notebook.\
\>", "Text"],

Cell[BoxData[{
    \(<< Graphics`Arrow`\), "\[IndentingNewLine]", 
    \(\(stileVet = 
        Sequence[HeadLength \[Rule] 0.03, 
          HeadCenter \[Rule]  .9];\)\), "\[IndentingNewLine]", 
    \(\(intervalloValori[inf_, sup_, incr_] := 
        Table[t, {t, inf, sup, incr}];\)\), "\[IndentingNewLine]", 
    \(\(colBlu = RGBColor[0, \ 0, 1];\)\), "\n", 
    \(\(colRosso = RGBColor[1, 0, 0];\)\), "\[IndentingNewLine]", 
    \(\(colGiallo = RGBColor[1, \ 1, \ 0];\)\), "\[IndentingNewLine]", 
    \(\(colVerde = RGBColor[0, 1, 0];\)\), "\[IndentingNewLine]", 
    \(\(stileTesto = {FontSize \[Rule] 9, FontFamily \[Rule] Helvetica, 
          FontWeight -> "\<Bold\>"};\)\), "\[IndentingNewLine]", 
    \(\($TextStyle = {FontFamily \[Rule] Helvetica, 
          FontSize \[Rule] 8};\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Estensione delle ampiezze di un angolo", "Section"],

Cell[TextData[{
  "La misura dell'ampiezza di un angolo \[EGrave] comunemente espressa da un \
numero reale compreso nell'intervallo ",
  Cell[BoxData[
      FormBox[
        RowBox[{\([0, 2  \[Pi]]\), Cell[""]}], TraditionalForm]]],
  "se espresso in radianti oppure, se intesa in gradi, la misura appartiene \
all'intervallo ",
  Cell[BoxData[
      \(TraditionalForm\`\([0  \[Degree], 360  \[Degree]]\)\)]],
  ". Come per i segmenti anche per gli angoli \[EGrave] comunque possibile \
introdurre una orientazione o verso e quindi assegnare valori positivi o \
negativi all'ampiezza corrispondente. \nIdentificato quindi un lato \
dell'angolo (che \[EGrave] una semiretta) con il semiasse positivo delle ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " di un sistema cartesiano isometrico di origine ",
  Cell[BoxData[
      \(TraditionalForm\`O\)]],
  ", potremo assegnare un verso all'angolo appena sia dato il secondo lato. \
Difatti, partendo dal semiasse positivo e muovendoci in verso antiorario fino \
ad incontrare l'altro lato, introduciamo la convenzione che associa \
all'ampiezza di quest'angolo un valore positivo. Se invece, sempre a partire \
dal semiasse positivo ci muoviamo in verso orario fino ad incontrare il \
secondo lato, l'ampiezza corrispondente dell'angolo in tal modo individuato \
verr\[AGrave] espressa da un valore negativo. Allora, per esempio, il ",
  ButtonBox["seguente",
    ButtonData:>"figura1",
    ButtonStyle->"Hyperlink"],
  " angolo \[EGrave] positivo "
}], "Text",
  CellTags->"intervalli"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[
    \(\(\(Show[
            ParametricPlot[{Sign[t] t\ Cos[t], Sign[t]\ t\ Sin[t]}/
                  200  \[Pi], {t, Sign[#] 2  \[Pi], Sign[#] 2\ \[Pi] + #}, 
              Axes \[Rule] False, DisplayFunction \[Rule] Identity, 
              PlotStyle \[Rule] {AbsoluteThickness[3], colBlu}], 
            Graphics[{Circle[{0, 0}, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
                Line[{{0, \(-1.2\)}, {0, 1.2}}], 
                Line[{{Cos[#], Sin[#]}, {0, 0}}]}], 
            Graphics[{AbsolutePointSize[6], Point[{Cos[#], Sin[#]}]}], 
            Epilog \[Rule] {{Text["\<ampiezza = \>" <> 
                      ToString[N[#]/\[Pi]] <> "\< \[Pi]\>", {1.1, 
                      0.5}, {\(-1\), 0}, 
                    TextStyle \[Rule] 
                      stileTesto]}}, \[IndentingNewLine]AspectRatio \[Rule] 
              Automatic, Axes \[Rule] True, 
            DisplayFunction \[Rule] $DisplayFunction, 
            PlotRange \[Rule] {{\(-1.26\), 2}, {\(-1.26\), 1.26}}, 
            ImageSize \[Rule] {450, 300}] &\) /@ {2  \[Pi]/10};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77301 
%%ImageSize: 450 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.386503 0.306748 0.386503 0.306748 [
[.07975 .374 -6.96875 -10.9375 ]
[.07975 .374 6.96875 0 ]
[.23313 .374 -10.3125 -10.9375 ]
[.23313 .374 10.3125 0 ]
[.53988 .374 -7.5625 -10.9375 ]
[.53988 .374 7.5625 0 ]
[.69325 .374 -4.21875 -10.9375 ]
[.69325 .374 4.21875 0 ]
[.84663 .374 -7.5625 -10.9375 ]
[.84663 .374 7.5625 0 ]
[1 .374 -4.21875 -10.9375 ]
[1 .374 4.21875 0 ]
[.374 .07975 -13.9375 -5.46875 ]
[.374 .07975 0 5.46875 ]
[.374 .23313 -20.625 -5.46875 ]
[.374 .23313 0 5.46875 ]
[.374 .53988 -15.125 -5.46875 ]
[.374 .53988 0 5.46875 ]
[.374 .69325 -8.4375 -5.46875 ]
[.374 .69325 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .77301 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07975 .3865 m
.07975 .39275 L
s
gsave
.07975 .374 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.23313 .3865 m
.23313 .39275 L
s
gsave
.23313 .374 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.53988 .3865 m
.53988 .39275 L
s
gsave
.53988 .374 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69325 .3865 m
.69325 .39275 L
s
gsave
.69325 .374 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84663 .3865 m
.84663 .39275 L
s
gsave
.84663 .374 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
1 .3865 m
1 .39275 L
s
gsave
1 .374 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.11043 .3865 m
.11043 .39025 L
s
.1411 .3865 m
.1411 .39025 L
s
.17178 .3865 m
.17178 .39025 L
s
.20245 .3865 m
.20245 .39025 L
s
.2638 .3865 m
.2638 .39025 L
s
.29448 .3865 m
.29448 .39025 L
s
.32515 .3865 m
.32515 .39025 L
s
.35583 .3865 m
.35583 .39025 L
s
.41718 .3865 m
.41718 .39025 L
s
.44785 .3865 m
.44785 .39025 L
s
.47853 .3865 m
.47853 .39025 L
s
.5092 .3865 m
.5092 .39025 L
s
.57055 .3865 m
.57055 .39025 L
s
.60123 .3865 m
.60123 .39025 L
s
.6319 .3865 m
.6319 .39025 L
s
.66258 .3865 m
.66258 .39025 L
s
.72393 .3865 m
.72393 .39025 L
s
.7546 .3865 m
.7546 .39025 L
s
.78528 .3865 m
.78528 .39025 L
s
.81595 .3865 m
.81595 .39025 L
s
.8773 .3865 m
.8773 .39025 L
s
.90798 .3865 m
.90798 .39025 L
s
.93865 .3865 m
.93865 .39025 L
s
.96933 .3865 m
.96933 .39025 L
s
.04908 .3865 m
.04908 .39025 L
s
.0184 .3865 m
.0184 .39025 L
s
.25 Mabswid
0 .3865 m
1 .3865 L
s
.3865 .07975 m
.39275 .07975 L
s
gsave
.374 .07975 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.3865 .23313 m
.39275 .23313 L
s
gsave
.374 .23313 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.3865 .53988 m
.39275 .53988 L
s
gsave
.374 .53988 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.3865 .69325 m
.39275 .69325 L
s
gsave
.374 .69325 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.3865 .11043 m
.39025 .11043 L
s
.3865 .1411 m
.39025 .1411 L
s
.3865 .17178 m
.39025 .17178 L
s
.3865 .20245 m
.39025 .20245 L
s
.3865 .2638 m
.39025 .2638 L
s
.3865 .29448 m
.39025 .29448 L
s
.3865 .32515 m
.39025 .32515 L
s
.3865 .35583 m
.39025 .35583 L
s
.3865 .41718 m
.39025 .41718 L
s
.3865 .44785 m
.39025 .44785 L
s
.3865 .47853 m
.39025 .47853 L
s
.3865 .5092 m
.39025 .5092 L
s
.3865 .57055 m
.39025 .57055 L
s
.3865 .60123 m
.39025 .60123 L
s
.3865 .6319 m
.39025 .6319 L
s
.3865 .66258 m
.39025 .66258 L
s
.3865 .04908 m
.39025 .04908 L
s
.3865 .0184 m
.39025 .0184 L
s
.3865 .72393 m
.39025 .72393 L
s
.3865 .7546 m
.39025 .7546 L
s
.25 Mabswid
.3865 0 m
.3865 .77301 L
s
0 0 m
1 0 L
1 .77301 L
0 .77301 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
.41678 .3865 m
.41689 .38728 L
.41699 .38813 L
.41706 .38893 L
.41709 .38934 L
.41711 .38971 L
.41713 .39012 L
.41714 .39034 L
.41714 .39055 L
.41715 .39075 L
.41715 .39085 L
.41715 .39096 L
.41715 .39105 L
.41715 .39111 L
.41715 .39113 L
.41715 .39116 L
.41715 .39118 L
.41715 .3912 L
.41715 .39123 L
.41715 .39125 L
.41715 .39127 L
.41715 .3913 L
.41715 .39132 L
.41715 .39134 L
.41715 .39137 L
.41715 .39139 L
.41715 .39144 L
.41715 .39149 L
.41715 .39154 L
.41715 .39164 L
.41715 .39173 L
.41715 .39194 L
.41714 .39216 L
.41713 .39257 L
.41711 .39295 L
.41705 .39375 L
.41697 .39461 L
.41687 .39544 L
.41675 .39624 L
.4166 .39709 L
.41643 .39791 L
.41623 .39877 L
.41601 .3996 L
.41578 .4004 L
.41551 .40124 L
.41523 .40205 L
.41494 .40283 L
.4146 .40364 L
.41426 .40442 L
.41387 .40525 L
Mistroke
.41347 .40603 L
.41345 .40608 L
Mfstroke
0 g
.5 Mabswid
newpath
.3865 .3865 .30675 0 365.73 arc
s
.0184 .3865 m
.7546 .3865 L
s
.3865 .0184 m
.3865 .7546 L
s
.63467 .56681 m
.3865 .3865 L
s
6 Mabswid
.63467 .56681 Mdot
gsave
.72393 .53988 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ampiezza) show
105.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
114.250 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
129.250 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
134.250 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{449.875, 299.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000dB000`400?l00000o`00003oO03oool0
0`000000oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?ooo`2k0?ooo`00O03oool00`000000
oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?oo
o`2k0?ooo`00O03oool200000;`0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`03
0000003oool0oooo0;/0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`030000003o
ool0oooo0;/0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`030000003oool0oooo
0;/0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`800000_03oool007`0oooo00<0
00000?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<000000?oo
o`3oool0^`3oool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3oool0
^`3oool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3oool0^`3oool0
0740oooo0`0000000`3oool000000000000=00000;H0oooo001^0?ooo`P000001P3oool00`000000
oooo0?ooo`050?ooo`P00000[P3oool006X0oooo100000070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03@3oool400000:X0oooo001V0?ooo`@000004P3oool00`000000oooo0?oo
o`0A0?ooo`@00000YP3oool00680oooo1000000F0?ooo`030000003oool0oooo01D0oooo1000002R
0?ooo`00H03oool2000001X0oooo00<000000?ooo`3oool06@3oool200000:00oooo001N0?ooo`80
0000703oool00`000000oooo0?ooo`0K0?ooo`800000WP3oool005`0oooo0P00000N0?ooo`030000
003oool0oooo01d0oooo0P00002L0?ooo`00F03oool400000200oooo0P00000P0?ooo`<00000V@3o
ool005H0oooo0P00000T0?ooo`030000003oool0oooo0280oooo0P00002G0?ooo`00E@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo0P00002E0?ooo`00D`3oool2000002L0
oooo00<000000?ooo`3oool09P3oool2000009<0oooo001A0?ooo`800000:@3oool00`000000oooo
0?ooo`0X0?ooo`800000T@3oool004l0oooo0P00000[0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0SP3oool004h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo08d0oooo001>0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`2<0?ooo`00C03oool2000002h0oooo00<000000?ooo`3o
ool0;@3oool2000008`0oooo001:0?ooo`800000<03oool200000300oooo00<000000?ooo`3oool0
R@3oool004T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`800000R@3o
ool004P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo08H0oooo00170?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`250?ooo`00A@3oool2000003D0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`240?ooo`00A03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0P`3oool004<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo0880oooo00120?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`210?ooo`00@@3oool00`000000oooo0?ooo`0h0?oo
o`800000>@3oool00`000000oooo0?ooo`200?ooo`00@@3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0O`3oool00400oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo07h0oooo000n0?ooo`800000?03o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo07d0oooo000m0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1l0?ooo`00?@3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0N`3oool003/0
oooo0P00000o0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0NP3oool003X0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo07X0oooo
000j0?ooo`030000003oool0oooo03l0oooo0P0000100?ooo`030000003oool0oooo07T0oooo000i
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1h
0?ooo`00>@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0M`3oool003P0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo07H0oooo000g0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`1f0?ooo`00=`3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0M@3oool003H0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo07D0oooo000f0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1d0?ooo`00=@3oool00`000000
oooo0?ooo`0h0?ooo`<0000000<0oooo0000000000000P0000040?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0M03oool003D0oooo00<000000?ooo`3oool0=03oool3000000040?oo
o`000000oooo000000@0oooo00<000000?ooo`3oool00P3oool3000004D0oooo00<000000?ooo`3o
ool0L`3oool003@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo000000020?ooo`<00000
103oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0780oooo000c0?ooo`030000003o
ool0oooo03X0oooo0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo0780oooo000c0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`1a0?ooo`00<P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0L@3oool00380oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0700oooo000a0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1`0?ooo`00<@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0K`3oool00300oooo00<00000
0?ooo`3oool0B@3oool2000004X0oooo00<000000?ooo`3oool0K`3oool00300oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo06h0oooo000_0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1^0?ooo`00
;`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
KP3oool002h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo06h0oooo000^0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`1]0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0K@3oool002h0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo06`0oooo000]0?ooo`030000003oool0oooo04`0oooo
0P00001=0?ooo`030000003oool0oooo06`0oooo000]0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`1[0?ooo`00;@3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0J`3oool002d0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo06/0oooo000/0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1[0?ooo`00
;03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
JP3oool002/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo06X0oooo000[0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`1Z0?ooo`00:`3oool00`000000oooo0?ooo`1>0?ooo`800000C`3oool00`00
0000oooo0?ooo`1Z0?ooo`00:`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0J@3oool002/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo06T0oooo000[0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`1Y0?ooo`00:P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0J@3oool002X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo06T0oooo000Z0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1Y0?ooo`00
:P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
J03oool002X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo06P0oooo000Z0?ooo`030000003oool0oooo02@0oooo0`0000000`3oool0000000000002
000002<0oooo0P00000T0?ooo`<0000000<0oooo0000000000000P00000U0?ooo`030000003oool0
oooo02L0oooo1000000S0?ooo`<000005`3oool002H0oooo0`0000000`3oool000000000000Q0?oo
o`<0000000@0oooo0000003oool00000103oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo01H0oooo000Z0?ooo`8000009@3oool00`000000oooo000000020?ooo`<000008`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool000000080oooo0`00000U0?ooo`030000003oool0oooo
02@0oooo00@000000?ooo`3oool0oooo0`00000U0?ooo`030000003oool0oooo01D0oooo000Z0?oo
o`8000009@3oool300000080oooo0P00000T0?ooo`030000003oool0oooo02<0oooo0`0000020?oo
o`8000009P3oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo0?ooo`800000903oool3
000001L0oooo000Z0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0D03oool00`00
0000oooo0?ooo`1X0?ooo`00:@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool0J03oool002T0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo06P0oooo000Y0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`1X0?ooo`00503ooooo0000010000005`3oool0
01T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo0`0000050?ooo`80003o1`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`00:@3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00@000000?ooo`3oool000001@3oool00`00
0?l0oooo0?ooo`0N0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo01D0oooo000Y0?ooo`030000003oool0oooo0500
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000o`3oool0oooo04P0oooo00<000000?oo
o`3oool0J03oool002X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`020?ooo`80
000000<0oooo0000o`3oool0B@3oool00`000000oooo0?ooo`1X0?ooo`00:P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00@0oooo00<000000000o`3oool0B@3oool00`000000oooo
0?ooo`1X0?ooo`00:P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`1X0?ooo`00:P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo00H0oooo0P0000180?ooo`030000003oool0oooo06P0oooo000Z0?oo
o`030000003oool0oooo04l0oooo0P0000090?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool0J03oool002X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool0J03oool002X0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0:0?ooo`800000A03oool00`000000oooo0?ooo`1X0?ooo`00:P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`1Y0?ooo`00:P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo00d0oooo0P0000100?ooo`030000003oool0oooo06T0oooo000Z0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
06T0oooo000[0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo06T0oooo000[0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool04@3oool2000003`0oooo00<000000?ooo`3oool0J@3oool002/0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0J@3oool002/0oooo00<000000?ooo`3oool0CP3oool2000001D0oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`1Y0?ooo`00:`3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo01D0oooo0P00000g0?ooo`030000003oool0oooo06X0oooo000[0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo06X0oooo000/0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
603oool2000003@0oooo00<000000?ooo`3oool0JP3oool002`0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0JP3o
ool002d0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0J`3oool002d0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0L0?ooo`800000;`3oool00`000000oooo0?ooo`1[0?ooo`00;@3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`1/0?ooo`00;@3oool00`000000oooo0?ooo`1<0?ooo`800000803oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo06`0oooo000^0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0803oool2000002X0oooo00<000000?ooo`3oool0K03oool002h0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0K@3oool002h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0K@3oool002h0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`0T0?ooo`800000903oool00`000000oooo0?ooo`1^0?ooo`00
;`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`1^0?ooo`00;`3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo02L0oooo0P00000Q0?ooo`030000003oool0oooo06h0oooo000`0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo06h0oooo000`0?ooo`030000003oool0oooo04T0oooo0P00000[0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0K`3oool00340oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0[0?ooo`800000703oool00`000000oooo0?ooo`1_0?ooo`00<@3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`1`0?ooo`00<P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`1`0?ooo`00<P3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo02l0oooo0P00000F0?ooo`030000003oool0oooo0740oooo000c0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0740oooo000c0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0<P3oool200000180oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1F0?ooo`00
<`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0A0?ooo`@0000000<0oooo0000003oool0100000000`3oool00000
0?ooo`0<000000/0oooo0`000000103oool000000000000000020?ooo`<00000<03oool003@0oooo
0P00000j0?ooo`<0000000<0oooo0000000000000P0000040?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`@0000000<0oooo0000003oool0
0P0000030?ooo`030000003oool000000080000000H0oooo0000003oool0oooo0000003oool30000
00@0oooo100000020?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool000000300oooo000e0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`<00000=P3oool2000000d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo00000003000000030?ooo`00000000000080000000D0oooo0000003oool000000?oo
o`08000000030?ooo`000000oooo00<0oooo100000020?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00`00000`0?ooo`00=P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
00000080oooo0`0000040?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool000000080oooo00<000000?ooo`000000=@3oool0
03H0oooo00<000000?ooo`3oool0=`3oool300000080oooo0P0000050?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1e0?ooo`00=`3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo03X0oooo0P0000070?ooo`030000003oool0oooo07D0
oooo000g0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo07H0oooo000h0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`03000007P0oooo000i0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0?P3oool5000007P0oooo000i0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0?`3oool4000007P0oooo000j0?ooo`030000003oool0oooo03l0
oooo0P0000100?ooo`<00000N@3oool003X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo07X0oooo000k0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`1j0?ooo`00?03oool2000003h0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`1k0?ooo`00?@3oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0O03oool003h0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo07d0oooo000o0?ooo`800000
>`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo07h0oooo00110?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1o0?ooo`00@@3oool0
0`000000oooo0?ooo`0h0?ooo`800000>@3oool00`000000oooo0?ooo`200?ooo`00@P3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0P@3oool004<0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0880
oooo00140?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`230?ooo`00A@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0Q03oool004H0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo08D0oooo00170?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`250?ooo`00B03oool200000380oooo00<000000?ooo`3o
ool0<@3oool2000008P0oooo001:0?ooo`030000003oool0oooo02l0oooo0P00000`0?ooo`800000
RP3oool004/0oooo0P00000_0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0RP3o
ool004d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo08/0oooo001>0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`2<0?ooo`00C`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo02X0
oooo0P00002?0?ooo`00D03oool2000002X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`2?0?ooo`00DP3oool2000002P0oooo00<000000?ooo`3oool09`3oool200000980oooo001D
0?ooo`8000009P3oool00`000000oooo0?ooo`0U0?ooo`800000U03oool005H0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`800000UP3oool005L0oooo0P00000S0?ooo`80
00008P3oool2000009P0oooo001I0?ooo`@000007`3oool00`000000oooo0?ooo`0M0?ooo`@00000
VP3oool005d0oooo0P00000M0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0W03o
ool005l0oooo0P00000K0?ooo`030000003oool0oooo01X0oooo0P00002O0?ooo`00H@3oool40000
01L0oooo00<000000?ooo`3oool05P3oool400000:40oooo001U0?ooo`@000004`3oool00`000000
oooo0?ooo`0B0?ooo`@00000Y@3oool006T0oooo1000000?0?ooo`030000003oool0oooo00h0oooo
1000002Y0?ooo`00K@3oool6000000T0oooo00<000000?ooo`3oool0203oool600000:d0oooo001c
0?oooa@00000/`3oool007D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2k0?oo
o`00M@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0;/0oooo001l0?ooo`030000
003oool0oooo0;/0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`030000003oool0
oooo0;/0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`030000003oool0oooo0;/0
oooo001l0?ooo`800000_03oool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<00000
0?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3o
ool0^`3oool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3oool0^`3o
ool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3oool0^`3oool007`0
oooo0P00002l0?ooo`00O03oool00`000000oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?oo
o`2k0?ooo`00O03oool00`000000oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?ooo`2k0?oo
o`00\
\>"],
  ImageRangeCache->{{{100.063, 413.938}, {449.125, 240.25}} -> {-2.71285, \
1.63856, 0.00844538, 0.00844538}},
  CellTags->"figura1"],

Cell[TextData[{
  "mentre quello rappresentato in ",
  ButtonBox["fig. 2",
    ButtonData:>"figura2",
    ButtonStyle->"Hyperlink"],
  " \[EGrave] identificato da una misura dell'ampiezza di segno negativo: in \
termini geometrici tradizionali (cio\[EGrave] con ampiezze appartenenti agli \
intervalli ricordati ",
  ButtonBox["sopra",
    ButtonData:>"intervalli",
    ButtonStyle->"Hyperlink"],
  ") la loro somma fornisce invece l'angolo giro cio\[EGrave] un'ampiezza di \
",
  Cell[BoxData[
      \(TraditionalForm\`360  \[Degree]\)]],
  " oppure ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[
    \(\(\(Show[
            ParametricPlot[{Sign[t] t\ Cos[t], Sign[t]\ t\ Sin[t]}/
                  200  \[Pi], {t, Sign[#] 2  \[Pi], Sign[#] 2\ \[Pi] + #}, 
              Axes \[Rule] False, DisplayFunction \[Rule] Identity, 
              PlotStyle \[Rule] {AbsoluteThickness[3], colBlu}], 
            Graphics[{Circle[{0, 0}, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
                Line[{{0, \(-1.2\)}, {0, 1.2}}], 
                Line[{{Cos[#], Sin[#]}, {0, 0}}]}], 
            Graphics[{AbsolutePointSize[6], Point[{Cos[#], Sin[#]}]}], 
            Epilog \[Rule] {{Text["\<ampiezza = \>" <> 
                      ToString[N[#]/\[Pi]] <> "\< \[Pi]\>", {1.1, 
                      0.5}, {\(-1\), 0}, 
                    TextStyle \[Rule] 
                      stileTesto]}}, \[IndentingNewLine]AspectRatio \[Rule] 
              Automatic, Axes \[Rule] True, 
            DisplayFunction \[Rule] $DisplayFunction, 
            PlotRange \[Rule] {{\(-1.26\), 2}, {\(-1.26\), 1.26}}, 
            ImageSize \[Rule] {450, 300}] &\) /@ {\(-18\) \[Pi]/
              10};\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77301 
%%ImageSize: 450 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.386503 0.306748 0.386503 0.306748 [
[.07975 .374 -6.96875 -10.9375 ]
[.07975 .374 6.96875 0 ]
[.23313 .374 -10.3125 -10.9375 ]
[.23313 .374 10.3125 0 ]
[.53988 .374 -7.5625 -10.9375 ]
[.53988 .374 7.5625 0 ]
[.69325 .374 -4.21875 -10.9375 ]
[.69325 .374 4.21875 0 ]
[.84663 .374 -7.5625 -10.9375 ]
[.84663 .374 7.5625 0 ]
[1 .374 -4.21875 -10.9375 ]
[1 .374 4.21875 0 ]
[.374 .07975 -13.9375 -5.46875 ]
[.374 .07975 0 5.46875 ]
[.374 .23313 -20.625 -5.46875 ]
[.374 .23313 0 5.46875 ]
[.374 .53988 -15.125 -5.46875 ]
[.374 .53988 0 5.46875 ]
[.374 .69325 -8.4375 -5.46875 ]
[.374 .69325 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .77301 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07975 .3865 m
.07975 .39275 L
s
gsave
.07975 .374 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.23313 .3865 m
.23313 .39275 L
s
gsave
.23313 .374 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.53988 .3865 m
.53988 .39275 L
s
gsave
.53988 .374 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69325 .3865 m
.69325 .39275 L
s
gsave
.69325 .374 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84663 .3865 m
.84663 .39275 L
s
gsave
.84663 .374 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
1 .3865 m
1 .39275 L
s
gsave
1 .374 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.11043 .3865 m
.11043 .39025 L
s
.1411 .3865 m
.1411 .39025 L
s
.17178 .3865 m
.17178 .39025 L
s
.20245 .3865 m
.20245 .39025 L
s
.2638 .3865 m
.2638 .39025 L
s
.29448 .3865 m
.29448 .39025 L
s
.32515 .3865 m
.32515 .39025 L
s
.35583 .3865 m
.35583 .39025 L
s
.41718 .3865 m
.41718 .39025 L
s
.44785 .3865 m
.44785 .39025 L
s
.47853 .3865 m
.47853 .39025 L
s
.5092 .3865 m
.5092 .39025 L
s
.57055 .3865 m
.57055 .39025 L
s
.60123 .3865 m
.60123 .39025 L
s
.6319 .3865 m
.6319 .39025 L
s
.66258 .3865 m
.66258 .39025 L
s
.72393 .3865 m
.72393 .39025 L
s
.7546 .3865 m
.7546 .39025 L
s
.78528 .3865 m
.78528 .39025 L
s
.81595 .3865 m
.81595 .39025 L
s
.8773 .3865 m
.8773 .39025 L
s
.90798 .3865 m
.90798 .39025 L
s
.93865 .3865 m
.93865 .39025 L
s
.96933 .3865 m
.96933 .39025 L
s
.04908 .3865 m
.04908 .39025 L
s
.0184 .3865 m
.0184 .39025 L
s
.25 Mabswid
0 .3865 m
1 .3865 L
s
.3865 .07975 m
.39275 .07975 L
s
gsave
.374 .07975 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.3865 .23313 m
.39275 .23313 L
s
gsave
.374 .23313 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.3865 .53988 m
.39275 .53988 L
s
gsave
.374 .53988 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.3865 .69325 m
.39275 .69325 L
s
gsave
.374 .69325 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.3865 .11043 m
.39025 .11043 L
s
.3865 .1411 m
.39025 .1411 L
s
.3865 .17178 m
.39025 .17178 L
s
.3865 .20245 m
.39025 .20245 L
s
.3865 .2638 m
.39025 .2638 L
s
.3865 .29448 m
.39025 .29448 L
s
.3865 .32515 m
.39025 .32515 L
s
.3865 .35583 m
.39025 .35583 L
s
.3865 .41718 m
.39025 .41718 L
s
.3865 .44785 m
.39025 .44785 L
s
.3865 .47853 m
.39025 .47853 L
s
.3865 .5092 m
.39025 .5092 L
s
.3865 .57055 m
.39025 .57055 L
s
.3865 .60123 m
.39025 .60123 L
s
.3865 .6319 m
.39025 .6319 L
s
.3865 .66258 m
.39025 .66258 L
s
.3865 .04908 m
.39025 .04908 L
s
.3865 .0184 m
.39025 .0184 L
s
.3865 .72393 m
.39025 .72393 L
s
.3865 .7546 m
.39025 .7546 L
s
.25 Mabswid
.3865 0 m
.3865 .77301 L
s
0 0 m
1 0 L
1 .77301 L
0 .77301 L
closepath
clip
newpath
0 0 1 r
3 Mabswid
.43304 .42031 m
.42858 .42493 L
.42341 .42917 L
.41774 .43279 L
.41434 .43453 L
.41116 .4359 L
.40826 .43695 L
.40507 .4379 L
.40167 .43869 L
.39999 .43899 L
.39842 .43922 L
.39685 .43941 L
.39541 .43954 L
.39459 .4396 L
.39381 .43964 L
.39341 .43966 L
.39298 .43967 L
.39274 .43968 L
.39252 .43969 L
.39231 .43969 L
.39209 .4397 L
.39167 .4397 L
.39144 .4397 L
.39122 .4397 L
.39084 .4397 L
.39043 .43969 L
.3902 .43969 L
.38995 .43968 L
.3895 .43967 L
.38864 .43964 L
.38783 .43959 L
.38697 .43952 L
.38543 .43938 L
.3839 .43918 L
.38251 .43897 L
.37941 .43835 L
.37673 .43765 L
.37397 .43677 L
.36837 .43443 L
.3635 .4317 L
.35852 .4281 L
.35446 .42435 L
.35076 .42009 L
.34738 .41508 L
.34478 .41 L
.3437 .40732 L
.34273 .40439 L
.34201 .4016 L
.3415 .39904 L
.3413 .3978 L
Mistroke
.34113 .39645 L
.341 .39518 L
.34092 .394 L
.3409 .39364 L
.34088 .39327 L
.34087 .39294 L
.34086 .3926 L
.34085 .3924 L
.34085 .39222 L
.34084 .39188 L
.34084 .39168 L
.34084 .39147 L
.34084 .39127 L
.34084 .39109 L
.34084 .39076 L
.34085 .39046 L
.34085 .39012 L
.34086 .38976 L
.34089 .38903 L
.34093 .38837 L
.34102 .38719 L
.34116 .38591 L
.34154 .38336 L
.3421 .38066 L
.34276 .37825 L
.34469 .37307 L
.347 .36862 L
.35001 .3642 L
.35334 .3604 L
.35728 .3569 L
.36126 .35415 L
.3652 .35204 L
.36752 .35105 L
.36975 .35026 L
.37176 .34967 L
.374 .34914 L
.37623 .34875 L
.37746 .3486 L
.37802 .34854 L
.37861 .34848 L
.37912 .34845 L
.37967 .34841 L
.38018 .34839 L
.38065 .34837 L
.38094 .34837 L
.38121 .34836 L
.38145 .34836 L
.38172 .34836 L
.382 .34836 L
.38231 .34836 L
Mistroke
.38257 .34837 L
.38285 .34837 L
.38315 .34838 L
.38342 .3484 L
.38404 .34843 L
.38459 .34847 L
.38516 .34851 L
.38626 .34863 L
.38725 .34876 L
.38963 .34919 L
.39183 .34974 L
.39602 .35119 L
.39963 .35293 L
.40305 .35509 L
.40643 .35783 L
.40925 .36075 L
.41181 .36416 L
.41392 .36787 L
.41471 .36963 L
.41544 .37153 L
.41598 .37329 L
.41647 .37525 L
.41664 .37611 L
.41679 .37704 L
.41691 .37785 L
.417 .37872 L
.41705 .37921 L
.41708 .37965 L
.41711 .38011 L
.41713 .38052 L
.41714 .38076 L
.41714 .381 L
.41715 .38113 L
.41715 .38125 L
.41715 .3814 L
.41715 .38153 L
.41715 .38165 L
.41715 .38178 L
.41715 .38202 L
.41715 .38226 L
.41714 .38248 L
.41714 .38272 L
.41713 .38299 L
.4171 .38347 L
.41707 .38393 L
.41704 .38436 L
.41694 .38533 L
.4168 .38634 L
.41678 .3865 L
Mfstroke
0 g
.5 Mabswid
newpath
.3865 .3865 .30675 0 365.73 arc
s
.0184 .3865 m
.7546 .3865 L
s
.3865 .0184 m
.3865 .7546 L
s
.63467 .56681 m
.3865 .3865 L
s
6 Mabswid
.63467 .56681 Mdot
gsave
.72393 .53988 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ampiezza) show
105.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
114.250 13.375 moveto
(-) show
120.375 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
135.375 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
140.375 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{449.875, 299.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000dB000`400?l00000o`00003oO03oool0
0`000000oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?ooo`2k0?ooo`00O03oool00`000000
oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?oo
o`2k0?ooo`00O03oool200000;`0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`03
0000003oool0oooo0;/0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`030000003o
ool0oooo0;/0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`030000003oool0oooo
0;/0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`800000_03oool007`0oooo00<0
00000?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<000000?oo
o`3oool0^`3oool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3oool0
^`3oool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3oool0^`3oool0
0740oooo0`0000000`3oool000000000000=00000;H0oooo001^0?ooo`P000001P3oool00`000000
oooo0?ooo`050?ooo`P00000[P3oool006X0oooo100000070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03@3oool400000:X0oooo001V0?ooo`@000004P3oool00`000000oooo0?oo
o`0A0?ooo`@00000YP3oool00680oooo1000000F0?ooo`030000003oool0oooo01D0oooo1000002R
0?ooo`00H03oool2000001X0oooo00<000000?ooo`3oool06@3oool200000:00oooo001N0?ooo`80
0000703oool00`000000oooo0?ooo`0K0?ooo`800000WP3oool005`0oooo0P00000N0?ooo`030000
003oool0oooo01d0oooo0P00002L0?ooo`00F03oool400000200oooo0P00000P0?ooo`<00000V@3o
ool005H0oooo0P00000T0?ooo`030000003oool0oooo0280oooo0P00002G0?ooo`00E@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo0P00002E0?ooo`00D`3oool2000002L0
oooo00<000000?ooo`3oool09P3oool2000009<0oooo001A0?ooo`800000:@3oool00`000000oooo
0?ooo`0X0?ooo`800000T@3oool004l0oooo0P00000[0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0SP3oool004h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo08d0oooo001>0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`2<0?ooo`00C03oool2000002h0oooo00<000000?ooo`3o
ool0;@3oool2000008`0oooo001:0?ooo`800000<03oool200000300oooo00<000000?ooo`3oool0
R@3oool004T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0`0?ooo`800000R@3o
ool004P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo08H0oooo00170?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`250?ooo`00A@3oool2000003D0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`240?ooo`00A03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0P`3oool004<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo0880oooo00120?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`210?ooo`00@@3oool00`000000oooo0?ooo`0h0?oo
o`800000>@3oool00`000000oooo0?ooo`200?ooo`00@@3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0O`3oool00400oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo07h0oooo000n0?ooo`800000?03o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo07d0oooo000m0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1l0?ooo`00?@3oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0N`3oool003/0
oooo0P00000o0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0NP3oool003X0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo07X0oooo
000j0?ooo`030000003oool0oooo03l0oooo0P0000100?ooo`030000003oool0oooo07T0oooo000i
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1h
0?ooo`00>@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0M`3oool003P0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo07H0oooo000g0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`1f0?ooo`00=`3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0M@3oool003H0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo07D0oooo000f0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1d0?ooo`00=@3oool00`000000
oooo0?ooo`0h0?ooo`<0000000<0oooo0000000000000P0000040?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0M03oool003D0oooo00<000000?ooo`3oool0=03oool3000000040?oo
o`000000oooo000000@0oooo00<000000?ooo`3oool00P3oool3000004D0oooo00<000000?ooo`3o
ool0L`3oool003@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo000000020?ooo`<00000
103oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0780oooo000c0?ooo`030000003o
ool0oooo03X0oooo0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo0780oooo000c0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`1a0?ooo`00<P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0L@3oool00380oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0700oooo000a0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1`0?ooo`00<@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0K`3oool00300oooo00<00000
0?ooo`3oool0B@3oool2000004X0oooo00<000000?ooo`3oool0K`3oool00300oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo06h0oooo000_0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1^0?ooo`00
;`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
KP3oool002h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo06h0oooo000^0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`1]0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0K@3oool002h0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo06`0oooo000]0?ooo`030000003oool0oooo04`0oooo
0P00001=0?ooo`030000003oool0oooo06`0oooo000]0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`1[0?ooo`00;@3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0J`3oool002d0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo06/0oooo000/0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1[0?ooo`00
;03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
JP3oool002/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo06X0oooo000[0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`1Z0?ooo`00:`3oool00`000000oooo0?ooo`1>0?ooo`800000C`3oool00`00
0000oooo0?ooo`1Z0?ooo`00:`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0J@3oool002/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo06T0oooo000[0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`1Y0?ooo`00:P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0J@3oool002X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo06T0oooo000Z0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1Y0?ooo`00
:P3oool00`000000oooo0?ooo`190?ooo`H0003o00@000000000o`000?l0003oC`3oool00`000000
oooo0?ooo`1X0?ooo`00:P3oool00`000000oooo0?ooo`170?ooo`P0003o00<000000000o`000?l0
0`000?m=0?ooo`030000003oool0oooo06P0oooo000Z0?ooo`030000003oool0oooo02@0oooo0`00
00000`3oool0000000000002000001X0oooo1@000?l40?ooo`80000000<0oooo0000o`000?l00P00
0?lO0?ooo`<0000000<0oooo0000000000000P00000U0?ooo`030000003oool0oooo02L0oooo1000
000S0?ooo`<000005`3oool002H0oooo0`0000000`3oool000000000000Q0?ooo`<0000000@0oooo
0000003oool00000103oool00`000000oooo0?ooo`0G0?ooo`<0003o1`3oool00`000000oooo0?oo
o`020?ooo`<0003o7P3oool00`000000oooo000000040?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool05P3oool002X0oooo0P00000U0?ooo`030000003oool000000080oooo0`00000H
0?ooo`<0003o203oool00`000000oooo0?ooo`030?ooo`<0003o7@3oool00`000000oooo00000002
0?ooo`<000009@3oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo0?ooo`<000009@3o
ool00`000000oooo0?ooo`0E0?ooo`00:P3oool2000002D0oooo0`0000020?ooo`8000006@3oool2
0000o`T0oooo00<000000?ooo`3oool0103oool20000oad0oooo0`0000020?ooo`8000009P3oool0
0`000000oooo0?ooo`0T0?ooo`040000003oool0oooo0?ooo`800000903oool3000001L0oooo000Z
0?ooo`030000003oool0oooo04@0oooo0P000?l90?ooo`030000003oool0oooo00@0oooo0P000?m:
0?ooo`030000003oool0oooo06P0oooo000Y0?ooo`030000003oool0oooo04@0oooo0P000?l:0?oo
o`030000003oool0oooo00@0oooo0P000?m:0?ooo`030000003oool0oooo06P0oooo000Y0?ooo`03
0000003oool0oooo04@0oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`<0
003oB@3oool00`000000oooo0?ooo`1X0?ooo`00:@3oool00`000000oooo0?ooo`130?ooo`80003o
2`3oool00`000000oooo0?ooo`040?ooo`<0003oB@3oool00`000000oooo0?ooo`1X0?ooo`00503o
oooo0000010000005`3oool001T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0000o`<0oooo00<000000?ooo`3oool01@3oool3000000@0oooo0`000?l70?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01D0oooo000Y0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool06@3oool20000
o`/0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0E0?ooo`00:@3oool00`00
0000oooo0?ooo`130?ooo`80003o2`3oool01@000000oooo0?ooo`3oool0000004h0oooo00<00000
0?ooo`3oool0J03oool002X0oooo00<000000?ooo`3oool0@P3oool20000o`/0oooo00<000000?oo
o`3oool00P3oool2000004`0oooo00<000000?ooo`3oool0J03oool002X0oooo00<000000?ooo`3o
ool0@P3oool30000o`X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo06P0oooo000Z0?ooo`030000003oool0oooo04<0oooo0P000?l:0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1X0?ooo`00:P3o
ool00`000000oooo0?ooo`140?ooo`80003o2@3oool00`000000oooo0?ooo`060?ooo`800000B03o
ool00`000000oooo0?ooo`1X0?ooo`00:P3oool00`000000oooo0?ooo`150?ooo`80003o203oool2
000000T0oooo00<000000?ooo`000?l0A@3oool00`000000oooo0?ooo`1X0?ooo`00:P3oool00`00
0000oooo0?ooo`150?ooo`<0003o1`3oool00`000000oooo0?ooo`090?ooo`03000000000?l0003o
04@0oooo00<000000?ooo`3oool0J03oool002X0oooo00<000000?ooo`3oool0AP3oool30000o`H0
oooo00<000000?ooo`3oool0203oool20000o`800000A03oool00`000000oooo0?ooo`1X0?ooo`00
:P3oool00`000000oooo0?ooo`170?ooo`<0003o1@3oool00`000000oooo0?ooo`070?ooo`<0003o
0P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo06T0oooo000Z0?ooo`030000003o
ool0oooo04P0oooo0`000?l40?ooo`030000003oool0oooo00H0oooo0`000?l40?ooo`800000@03o
ool00`000000oooo0?ooo`1Y0?ooo`00:P3oool00`000000oooo0?ooo`190?ooo`@0003o0P3oool0
0`000000oooo0?ooo`030?ooo`D0003o1`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo06T0oooo000[0?ooo`030000003oool0oooo04T0oooo1@000?l00`000000003o0000o`070000
o`T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1Y0?ooo`00:`3oool00`000000
oooo0?ooo`1;0?ooo`<0003o00<000000000o`000?l010000?l=0?ooo`800000?03oool00`000000
oooo0?ooo`1Y0?ooo`00:`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1Y0?ooo`00:`3oool00`000000oooo0?oo
o`1>0?ooo`8000005@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo06T0oooo000[
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool05@3oool2000003L0oooo00<00000
0?ooo`3oool0JP3oool002/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0JP3oool002`0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`0H0?ooo`800000=03oool00`000000oooo0?ooo`1Z0?ooo`00
;03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`1Z0?ooo`00;@3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1[0?ooo`00;@3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo01`0oooo0P00000_0?ooo`030000003oool0
oooo06/0oooo000]0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo06`0oooo000]0?ooo`030000003oool0oooo04`0
oooo0P00000P0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0K03oool002h0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0P0?ooo`800000:P3oool00`000000oooo
0?ooo`1/0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`1]0?ooo`00;P3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1]
0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02@0oooo0P00000T0?oo
o`030000003oool0oooo06h0oooo000_0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo06h0oooo000_0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool09`3oool200000240oooo00<000000?ooo`3oool0
KP3oool00300oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0KP3oool00300oooo00<000000?ooo`3oool0B@3oool2
000002/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1_0?ooo`00<@3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo02/0oooo0P00000L0?ooo`030000003oool0oooo
06l0oooo000a0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo0700oooo000b0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0700oooo
000b0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0;`3oool2000001H0oooo00<0
00000?ooo`3oool0L@3oool003<0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0L@3oool003<0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0b0?ooo`8000004P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo05H0oooo000c0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo100000000`3oool0
00000?ooo`04000000030?ooo`000000oooo00`000004@3oool00`000000oooo00000002000000<0
oooo0`00000[0?ooo`00=03oool2000003X0oooo0`0000000`3oool0000000000002000000@0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo
100000000`3oool000000?ooo`02000000<0oooo00<000000?ooo`0000000P0000001P3oool00000
0?ooo`3oool000000?ooo`<00000103oool400000080oooo100000050?ooo`030000003oool00000
00<0oooo00<000000?ooo`000000:`3oool003D0oooo00<000000?ooo`3oool0>03oool00`000000
oooo000000040?ooo`030000003oool0oooo0080oooo0`00000f0?ooo`8000003@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0000000<0000000<0oooo0000000000000P0000001@3oool0
00000?ooo`000000oooo00P0000000<0oooo0000003oool00`3oool4000000H0oooo00<000000?oo
o`3oool00`3oool2000000<0oooo0`00000[0?ooo`00=P3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool000000080oooo0`0000040?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0l0?ooo`070000003oool0oooo0?ooo`000000oooo0000000a
0?ooo`00=P3oool00`000000oooo0?ooo`0g0?ooo`<000000P3oool2000000D0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07D0oooo000g0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0>P3oool2000000L0oooo00<000000?ooo`3o
ool0M@3oool003L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0MP3oool003P0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00<00000N03oool003T0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0n0?ooo`D00000N03oool003T0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0o0?ooo`@00000N03oool003X0oooo00<000000?ooo`3o
ool0?`3oool200000400oooo0`00001i0?ooo`00>P3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool0NP3oool003/0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo07X0oooo000l0?ooo`800000?P3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo07/0oooo000m0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1l0?ooo`00?P3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0O@3oool003l0oooo
0P00000k0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0OP3oool00440oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo07l0oooo0011
0?ooo`030000003oool0oooo03P0oooo0P00000i0?ooo`030000003oool0oooo0800oooo00120?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`210?oo
o`00@`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0PP3oool004@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo08<0oooo00150?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`240?ooo`00AP3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0Q@3oool004L0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo08D0oooo00180?ooo`800000<P3oool00`000000
oooo0?ooo`0a0?ooo`800000R03oool004X0oooo00<000000?ooo`3oool0;`3oool200000300oooo
0P00002:0?ooo`00B`3oool2000002l0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`2:0?ooo`00C@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0R`3oool004h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo08`0oooo001?0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0:P3oool2000008l0oooo001@0?ooo`800000:P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo08l0oooo001B0?ooo`800000:03oool00`000000oooo0?ooo`0W0?ooo`800000TP3o
ool005@0oooo0P00000V0?ooo`030000003oool0oooo02D0oooo0P00002D0?ooo`00EP3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo0P00002F0?ooo`00E`3oool2000002<0
oooo0P00000R0?ooo`800000V03oool005T0oooo1000000O0?ooo`030000003oool0oooo01d0oooo
1000002J0?ooo`00G@3oool2000001d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`2L0?ooo`00G`3oool2000001/0oooo00<000000?ooo`3oool06P3oool2000009l0oooo001Q0?oo
o`@000005`3oool00`000000oooo0?ooo`0F0?ooo`@00000X@3oool006D0oooo1000000C0?ooo`03
0000003oool0oooo0180oooo1000002U0?ooo`00J@3oool4000000l0oooo00<000000?ooo`3oool0
3P3oool400000:T0oooo001]0?ooo`H000002@3oool00`000000oooo0?ooo`080?ooo`H00000[@3o
ool007<0oooo5000002c0?ooo`00M@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0;/0oooo001e0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0^`3oool007`0oooo
00<000000?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<00000
0?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3oool0^`3oool007`0oooo00<000000?ooo`3o
ool0^`3oool007`0oooo0P00002l0?ooo`00O03oool00`000000oooo0?ooo`2k0?ooo`00O03oool0
0`000000oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?ooo`2k0?ooo`00O03oool00`000000
oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?oo
o`2k0?ooo`00O03oool00`000000oooo0?ooo`2k0?ooo`00O03oool00`000000oooo0?ooo`2k0?oo
o`00O03oool200000;`0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`030000003o
ool0oooo0;/0oooo001l0?ooo`030000003oool0oooo0;/0oooo001l0?ooo`030000003oool0oooo
0;/0oooo0000\
\>"],
  ImageRangeCache->{{{100.063, 413.938}, {309.813, 100.938}} -> {-2.71285, \
-0.0422204, 0.00844538, 0.00844538}},
  CellTags->"figura2"],

Cell[TextData[{
  "Come si vede, possiamo quindi individuare i due angoli nei quali viene \
suddiviso il piano, il primo (convesso in questo esempio) con una misura \
positiva, il secondo (nell'esempio, concavo) con una misura negativa. Poich\
\[EAcute] \[EGrave] possibile che il secondo lato dell'angolo ripassi pi\
\[UGrave] volte sul semiasse positivo delle ascisse ossia per il lato origine \
cio\[EGrave] \"ruoti\" attorno all'origine del sistema cartesiano, conveniamo \
di tener conto di tale eventualit\[AGrave] nell'esprimere la misura \
dell'angolo in tal modo percorso. L'ampiezza dell'angolo potr\[AGrave] \
pertanto assumere qualsiasi valore positivo cos\[IGrave] come qualsiasi \
valore negativo. Difatti, ad ogni giro completo del secondo lato attorno \
all'origine ",
  Cell[BoxData[
      \(TraditionalForm\`O\)]],
  " l'ampiezza dovr\[AGrave] aumentare di un valore pari a ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  " (o ",
  Cell[BoxData[
      \(TraditionalForm\`360  \[Degree]\)]],
  "). L'animazione successiva mostra appunto come si debbano considerare \
angoli la cui misura sia maggiore di ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  "  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(versoPositivo = intervalloValori[0, 4  \[Pi], \[Pi]/10];\)\), "\n", 
    \(\(\(Show[
            If[# \[NotEqual] 0, 
              ParametricPlot[{Sign[t] t\ Cos[t], Sign[t]\ t\ Sin[t]}/
                    200  \[Pi], {t, Sign[#] 2  \[Pi], Sign[#] 2\ \[Pi] + #}, 
                Axes \[Rule] False, DisplayFunction \[Rule] Identity, 
                PlotStyle \[Rule] {AbsoluteThickness[3], colBlu}], 
              Graphics[{Point[{Cos[#], Sin[#]}]}]], 
            Graphics[{Circle[{0, 0}, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
                Line[{{0, \(-1.2\)}, {0, 1.2}}], 
                Line[{{Cos[#], Sin[#]}, {0, 0}}]}], 
            Graphics[{AbsolutePointSize[6], Point[{Cos[#], Sin[#]}]}], 
            Epilog \[Rule] {{Text["\<ampiezza = \>" <> 
                      ToString[N[#]/\[Pi]] <> "\< \[Pi]\>", {1.1, 
                      0.5}, {\(-1\), 0}, 
                    TextStyle \[Rule] 
                      stileTesto]}}, \[IndentingNewLine]AspectRatio \[Rule] 
              Automatic, Axes \[Rule] True, 
            DisplayFunction \[Rule] $DisplayFunction, 
            PlotRange \[Rule] {{\(-1.26\), 2}, {\(-1.26\), 1.26}}, 
            ImageSize \[Rule] {450, 300}] &\) /@ versoPositivo;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77301 
%%ImageSize: 450 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.386503 0.306748 0.386503 0.306748 [
[.07975 .374 -6.96875 -10.9375 ]
[.07975 .374 6.96875 0 ]
[.23313 .374 -10.3125 -10.9375 ]
[.23313 .374 10.3125 0 ]
[.53988 .374 -7.5625 -10.9375 ]
[.53988 .374 7.5625 0 ]
[.69325 .374 -4.21875 -10.9375 ]
[.69325 .374 4.21875 0 ]
[.84663 .374 -7.5625 -10.9375 ]
[.84663 .374 7.5625 0 ]
[1 .374 -4.21875 -10.9375 ]
[1 .374 4.21875 0 ]
[.374 .07975 -13.9375 -5.46875 ]
[.374 .07975 0 5.46875 ]
[.374 .23313 -20.625 -5.46875 ]
[.374 .23313 0 5.46875 ]
[.374 .53988 -15.125 -5.46875 ]
[.374 .53988 0 5.46875 ]
[.374 .69325 -8.4375 -5.46875 ]
[.374 .69325 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .77301 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07975 .3865 m
.07975 .39275 L
s
gsave
.07975 .374 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.23313 .3865 m
.23313 .39275 L
s
gsave
.23313 .374 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.53988 .3865 m
.53988 .39275 L
s
gsave
.53988 .374 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69325 .3865 m
.69325 .39275 L
s
gsave
.69325 .374 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84663 .3865 m
.84663 .39275 L
s
gsave
.84663 .374 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
1 .3865 m
1 .39275 L
s
gsave
1 .374 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.11043 .3865 m
.11043 .39025 L
s
.1411 .3865 m
.1411 .39025 L
s
.17178 .3865 m
.17178 .39025 L
s
.20245 .3865 m
.20245 .39025 L
s
.2638 .3865 m
.2638 .39025 L
s
.29448 .3865 m
.29448 .39025 L
s
.32515 .3865 m
.32515 .39025 L
s
.35583 .3865 m
.35583 .39025 L
s
.41718 .3865 m
.41718 .39025 L
s
.44785 .3865 m
.44785 .39025 L
s
.47853 .3865 m
.47853 .39025 L
s
.5092 .3865 m
.5092 .39025 L
s
.57055 .3865 m
.57055 .39025 L
s
.60123 .3865 m
.60123 .39025 L
s
.6319 .3865 m
.6319 .39025 L
s
.66258 .3865 m
.66258 .39025 L
s
.72393 .3865 m
.72393 .39025 L
s
.7546 .3865 m
.7546 .39025 L
s
.78528 .3865 m
.78528 .39025 L
s
.81595 .3865 m
.81595 .39025 L
s
.8773 .3865 m
.8773 .39025 L
s
.90798 .3865 m
.90798 .39025 L
s
.93865 .3865 m
.93865 .39025 L
s
.96933 .3865 m
.96933 .39025 L
s
.04908 .3865 m
.04908 .39025 L
s
.0184 .3865 m
.0184 .39025 L
s
.25 Mabswid
0 .3865 m
1 .3865 L
s
.3865 .07975 m
.39275 .07975 L
s
gsave
.374 .07975 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.3865 .23313 m
.39275 .23313 L
s
gsave
.374 .23313 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.3865 .53988 m
.39275 .53988 L
s
gsave
.374 .53988 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.3865 .69325 m
.39275 .69325 L
s
gsave
.374 .69325 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.3865 .11043 m
.39025 .11043 L
s
.3865 .1411 m
.39025 .1411 L
s
.3865 .17178 m
.39025 .17178 L
s
.3865 .20245 m
.39025 .20245 L
s
.3865 .2638 m
.39025 .2638 L
s
.3865 .29448 m
.39025 .29448 L
s
.3865 .32515 m
.39025 .32515 L
s
.3865 .35583 m
.39025 .35583 L
s
.3865 .41718 m
.39025 .41718 L
s
.3865 .44785 m
.39025 .44785 L
s
.3865 .47853 m
.39025 .47853 L
s
.3865 .5092 m
.39025 .5092 L
s
.3865 .57055 m
.39025 .57055 L
s
.3865 .60123 m
.39025 .60123 L
s
.3865 .6319 m
.39025 .6319 L
s
.3865 .66258 m
.39025 .66258 L
s
.3865 .04908 m
.39025 .04908 L
s
.3865 .0184 m
.39025 .0184 L
s
.3865 .72393 m
.39025 .72393 L
s
.3865 .7546 m
.39025 .7546 L
s
.25 Mabswid
.3865 0 m
.3865 .77301 L
s
0 0 m
1 0 L
1 .77301 L
0 .77301 L
closepath
clip
newpath
0 0 1 r
3 Mabswid
.41678 .3865 m
.4169 .38731 L
.417 .38819 L
.41704 .38861 L
.41707 .38902 L
.41709 .38938 L
.41712 .38978 L
.41714 .39022 L
.41715 .39069 L
.41715 .39112 L
.41715 .39153 L
.41714 .39201 L
.41713 .39245 L
.41712 .3927 L
.41711 .39296 L
.41708 .39345 L
.41699 .39443 L
.41689 .39532 L
.41656 .39732 L
.41613 .39916 L
.41563 .40089 L
.41411 .40475 L
.41225 .40816 L
.40973 .41168 L
.40654 .41507 L
.40346 .41762 L
.39981 .41997 L
.39606 .4218 L
.39243 .42309 L
.39037 .42365 L
.38812 .4241 L
.38617 .42439 L
.38505 .4245 L
.38399 .42458 L
.38344 .42461 L
.38312 .42462 L
.38283 .42463 L
.38252 .42464 L
.38219 .42465 L
.3816 .42465 L
.38106 .42464 L
.38047 .42463 L
.37991 .42461 L
.37939 .42458 L
.37824 .42449 L
.37697 .42435 L
.37565 .42417 L
.37441 .42395 L
.37211 .42343 L
.36963 .42271 L
Mistroke
.36521 .42097 L
.36108 .41875 L
.35746 .41625 L
.35348 .41274 L
.35013 .40896 L
.34749 .4052 L
.34508 .40078 L
.3432 .39613 L
.34237 .39338 L
.34175 .39076 L
.34148 .38931 L
.34126 .38793 L
.34111 .38666 L
.34098 .38531 L
.34093 .38461 L
.34089 .38384 L
.34086 .38313 L
.34084 .38247 L
.34084 .38209 L
.34084 .38169 L
.34084 .38097 L
.34085 .38057 L
.34086 .3802 L
.34088 .37979 L
.3409 .37935 L
.34094 .37867 L
.34099 .37792 L
.34115 .37641 L
.34133 .375 L
.34154 .3737 L
.34216 .37076 L
.34304 .36764 L
.34521 .36205 L
.34783 .35717 L
.35113 .35244 L
.3547 .3484 L
.35916 .3444 L
.36444 .34072 L
.36948 .33806 L
.37225 .33687 L
.37527 .3358 L
.37798 .33501 L
.38101 .33432 L
.38235 .33407 L
.3838 .33384 L
.38506 .33367 L
.38644 .33353 L
.38723 .33346 L
.38807 .3334 L
.38854 .33338 L
Mistroke
.38897 .33336 L
.3894 .33334 L
.38981 .33333 L
.39057 .33331 L
.39141 .3333 L
.39214 .33331 L
.39293 .33333 L
.39341 .33335 L
.39385 .33337 L
.39485 .33342 L
.39572 .33349 L
.39665 .33357 L
.39826 .33376 L
.40002 .33402 L
.40322 .33465 L
.40661 .33554 L
.41261 .3377 L
.41865 .34073 L
.4248 .34487 L
.43012 .34955 L
.43452 .35448 L
.43836 .35992 L
.44139 .36545 L
.44403 .37191 L
.44519 .37569 L
.44602 .37923 L
.44661 .38258 L
.44686 .38447 L
.44703 .3862 L
.44709 .38699 L
.44714 .38782 L
.44719 .38874 L
.44722 .38958 L
.44724 .39037 L
.44724 .39111 L
.44724 .39193 L
.44723 .3928 L
.44721 .39329 L
.44719 .3938 L
.44715 .39473 L
.44707 .39584 L
.44699 .39684 L
.44678 .39882 L
.44652 .40067 L
.44589 .40411 L
.44498 .4078 L
.44269 .41451 L
.43928 .42159 L
.43478 .42852 L
.42975 .43446 L
Mistroke
.4238 .43996 L
.41753 .44447 L
.41143 .44789 L
.40784 .44953 L
.40438 .45088 L
.40065 .45209 L
.39716 .45301 L
.39322 .45381 L
.39102 .45415 L
.38891 .45441 L
.38688 .45459 L
.38574 .45467 L
.3847 .45473 L
.38373 .45476 L
.38267 .45478 L
.38168 .45479 L
.38076 .45478 L
.37969 .45476 L
.37868 .45472 L
.37758 .45467 L
.3764 .45459 L
.37399 .45436 L
.3718 .45407 L
.3679 .45339 L
.36379 .45242 L
.35653 .45003 L
.34902 .44657 L
.34119 .44172 L
.3345 .43631 L
.32893 .43062 L
.32354 .42367 L
.31877 .41564 L
.31539 .40795 L
.31388 .40347 L
.31275 .39931 L
.31191 .39536 L
.31155 .39325 L
.31124 .39101 L
.31102 .38904 L
.31092 .38799 L
.31084 .38686 L
.31078 .38582 L
.31073 .38487 L
.3107 .38391 L
.31067 .383 L
.31066 .38187 L
.31066 .38124 L
.31067 .38065 L
.31069 .37958 L
.31073 .37844 L
Mistroke
.31078 .37742 L
.31084 .37647 L
.31102 .3743 L
.31129 .37197 L
.31159 .36984 L
.3125 .36509 L
.31351 .36105 L
.31486 .35672 L
.31797 .34905 L
.32214 .34132 L
.32775 .33335 L
.33466 .32577 L
.34203 .31948 L
.3499 .31425 L
.35885 .30974 L
.36693 .30678 L
.37165 .30547 L
.37612 .30451 L
.38079 .30378 L
.38344 .30348 L
.38471 .30337 L
.3859 .30328 L
.38703 .30322 L
.38806 .30317 L
.38921 .30313 L
.39044 .30311 L
.39162 .30311 L
.39291 .30312 L
.39413 .30316 L
.39526 .3032 L
.39626 .30325 L
.39734 .30333 L
.3993 .30349 L
.40162 .30375 L
.40375 .30404 L
.40813 .30481 L
.4127 .30588 L
Mfstroke
0 g
.5 Mabswid
newpath
.3865 .3865 .30675 0 365.73 arc
s
.0184 .3865 m
.7546 .3865 L
s
.3865 .0184 m
.3865 .7546 L
s
.48129 .09477 m
.3865 .3865 L
s
6 Mabswid
.48129 .09477 Mdot
gsave
.72393 .53988 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ampiezza) show
105.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
114.250 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
129.250 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
134.250 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{450, 300},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008b0001Mb000`400?l00000o`00003og`3oool0
0`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0
oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo
003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA
0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0
ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool300000?l0ooooD@3o
ool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oo
oe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0
o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0
oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000
oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<0
00000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?oo
o`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00
g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`<00000o`3ooomA0?ooo`00g`3oool0
0`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0
oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo
003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA
0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0
ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?oo
o`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?oo
o`3oool0o`3ooomA0?ooo`00d`3oool00`3ooml0W4Qd0;ooo`090?ooo`030000003oool0oooo0?l0
ooooD@3oool00=<0oooo00<0oooO09a8M02oool02@3oool00`000000oooo0?ooo`3o0?oooe40oooo
003:0?ooo`030?noM000000000000080000000D004RL0=ooo`3oool0oooo0?oog`0E00000?l0oooo
BP3oool00<X0oooo2P0000000`2LB7@0_ooo0?ooo`080?ooo`030000003oool0oooo00L0oooo2`00
003o0?ooocl0oooo00350?ooo`D000001`3oool01@3ooml0W9bo0?oog`2LB7@0_ooo00T0oooo00<0
00000?ooo`3oool04P3oool600000?l0oooo>@3oool00<00oooo1@00000=0?ooo`040?noM0000000
001d0;ooo`T0oooo00<000000?ooo`3oool0603oool500000?l0oooo=03oool00;`0oooo1000000C
0?ooo`030?oo_`1d07@0_ooo00T0oooo00<000000?ooo`3oool07@3oool400000?l0oooo<03oool0
0;P0oooo1000000S0?ooo`030000003oool0oooo0240oooo0`0000050?ooo`<00000o`3ooolU0?oo
o`00]@3oool3000002L0oooo00<000000?ooo`3oool0903oool900000?l0oooo903oool00;40oooo
1000000Z0?ooo`030000003oool0oooo02L0oooo1`00003o0?ooob<0oooo002^0?ooo`<00000;P3o
ool00`000000oooo0?ooo`0W0?ooo`P00000o`3ooolR0?ooo`00[03oool200000340oooo00<00000
0?ooo`3oool09`3oool7000000030?ooo`000000oooo0?l0oooo803oool00:T0oooo0`00000c0?oo
o`030000003oool0oooo02P0oooo1@0000030?ooo`@00000o`3ooolM0?ooo`00Y`3oool2000003H0
oooo00<000000?ooo`3oool0:@3oool3000000P0oooo0P00003o0?oooa/0oooo002S0?ooo`@00000
>03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00X0oooo0`00003o0?oooaP0oooo
002R0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0=0?ooo`800000o`3ooolF0?ooo`00X03oool2000003d0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo4`3oool009h0oooo0P00000o0?oo
o`<00000:03oool00`000000oooo0?ooo`0A0?ooo`800000o`3ooolC0?ooo`00V`3oool300000440
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0C0?ooo`<00000o`3oool@0?ooo`00
V@3oool2000004@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0F0?ooo`800000
o`3oool>0?ooo`00V03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool06@3oool200000?l0oooo303oool009H0oooo0P0000170?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`3o0?ooo`T0oooo002E0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0L0?oo
o`800000o`3oool90?ooo`00T`3oool2000004X0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0O0?ooo`800000o`3oool70?ooo`00T@3oool2000004`0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0?l0oooo103oool00900oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0280oooo0P00
003o0?ooo`@0oooo002>0?ooo`800000C`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0o`3oool10?ooo`00S@3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool09P3oool200000?l0oooo0@3oool008/0
oooo0P00001B0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`3m0?ooo`00R@3oool2000005@0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0Z0?ooo`800000o@3oool008P0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0nP3oool008H0oooo0P00001G
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;@3oool200000?X0oooo00250?oo
o`030000003oool0oooo05L0oooo0`00000S0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0m`3oool008<0oooo0P00001J0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0<@3oool200000?L0oooo00220?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0?@0oooo00210?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0?<0oooo00200?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0?80oooo001o0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0?40oooo001n0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0h0?ooo`800000l@3oool007d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0kP3oool007`0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0k@3oool007/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0k03oool007X0oooo00<000000?oo
o`3oool0HP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0j`3oool007P0oooo0P00001U0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`3Z0?ooo`00M`3oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3Y0?ooo`00MP3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`3X0?ooo`00M@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`3W0?ooo`00M03oool00`00
0000oooo0?ooo`1X0?ooo`<000007`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
0>H0oooo001c0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo0>D0oooo001c0?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0>@0oooo
001b0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo0><0oooo001`0?ooo`800000K@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0hP3oool006l0oooo00<000000?oo
o`3oool0K@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0h@3oool006h0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0h03oool006h0oooo00<000000?ooo`3oool0
KP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
h03oool006d0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0g`3oool006`0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0gP3oool0
06`0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0g@3oool006/0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0g03oool006X0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool0f`3oool006T0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0f`3oool006P0oooo00<00000
0?ooo`3oool0M03oool3000001X0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`3J
0?ooo`00I`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`3I0?ooo`00I`3oool00`000000oooo0?ooo`1e0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`3I0?ooo`00
IP3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`3H0?ooo`00I@3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3G0?ooo`00I03oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`3G0?ooo`00I03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3F0?ooo`00H`3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`3E0?ooo`00HP3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3E0?ooo`00HP3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`3D0?ooo`00H@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`3D0?ooo`00H@3oool00`000000oooo0?ooo`1k0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3C0?oo
o`00H03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0HP3oool00`000000oooo0?ooo`3B0?ooo`00G`3oool00`000000oooo0?ooo`1W0?ooo`0:0;md
00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool01`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0dP3o
ool005l0oooo00<000000?ooo`3oool0IP3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo
00H0okmd04RLg`3oool0oooo0=nLB01d_ol80?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`3A0?ooo`00GP3oool00`000000oooo0?ooo`1P0?ooo`03
0?noM000000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0
okmd04RLg`3oool01`3oool4000001@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`3@0?ooo`00G@3oool00`000000oooo0?ooo`1X0?ooo`060=nLB01d_ol0oooo0?oog`2LB7@0_ooo
0`3oool01P3o_g@0001d0;ooo`3oool0gia807Boo`P0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo0=00oooo001M0?ooo`030000003oool0oooo06P0
oooo00H0gia804RLg`3oool0oono07@0M02oool30?ooo`050?oo_`1dB4P0B00000000000M;l02@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0c`3o
ool005`0oooo00<000000?ooo`3oool0J@3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo
00<0oooO09a8B02Lgol02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo06L0oooo
00<000000?ooo`3oool0c`3oool005`0oooo00<000000?ooo`3oool0JP3oool0102oM00000000000
B02Lgol50?ooo`050;md0000000000000000B02Lgol0203oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool0cP3oool005`0oooo00<000000?ooo`3oool0
P03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
c@3oool005/0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool0c@3oool005/0oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0c03oool0
05X0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
06`0oooo00<000000?ooo`3oool0b`3oool005T0oooo00<000000?ooo`3oool0P`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0b`3oool005T0oooo
00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo06d0oooo
00<000000?ooo`3oool0b`3oool005P0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0b`3oool005P0oooo00<00000
0?ooo`3oool0Q03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool0bP3oool005L0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0700oooo00<000000?ooo`3oool0b@3oool005L0oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0b@3oool005L0oooo00<000000?ooo`3oool0Q@3oool300000100oooo00<000000?ooo`3oool0
LP3oool00`000000oooo0?ooo`380?ooo`00EP3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`380?ooo`00EP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0LP3oool0
0`000000oooo0?ooo`380?ooo`00E@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`380?ooo`00E@3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`370?ooo`00E@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`360?ooo`00E03oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`360?ooo`00E03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`350?ooo`00D`3oool00`000000oooo0?ooo`290?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`350?oo
o`00D`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`350?ooo`00D`3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`350?ooo`00DP3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`340?ooo`00DP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`340?ooo`00D@3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`340?ooo`00D@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`330?ooo`00D@3oool00`000000oooo
0?ooo`2;0?ooo`<000002`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0<<0oooo
001A0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo0<80oooo001@0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0<80oooo001@0?oo
o`030000003oool0oooo08P0oooo10000?l00`000000003o0000o`050000o`D0oooo00<000000?oo
o`3oool0OP3oool00`000000oooo0?ooo`320?ooo`00D03oool00`000000oooo0?ooo`230?ooo`T0
003o00<000000000o`000?l02P000?l00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0<40
oooo001?0?ooo`030000003oool0oooo0840oooo30000?l00`000000003o0000o`0:0000o`030000
003oool0oooo07l0oooo00<000000?ooo`3oool0`@3oool004l0oooo00<000000?ooo`3oool0OP3o
ool<0000o`<0oooo00<000000?ooo`3oool0103oool50000o`03000000000?l0oooo0800oooo00<0
00000?ooo`3oool0`@3oool004l0oooo00<000000?ooo`3oool0O@3oool80000o`P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0<40oooo001?0?oo
o`030000003oool0oooo07`0oooo1@000?l<0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`300?ooo`00CP3oool00`000000oooo0?ooo`1k0?ooo`D0
003o3P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0880oooo00<000000?ooo`3o
ool0`03oool004h0oooo00<000000?ooo`3oool0N@3oool60000o`l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0<00oooo001>0?ooo`030000003o
ool0oooo07L0oooo1`000?l@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0PP3o
ool00`000000oooo0?ooo`300?ooo`00CP3oool00`000000oooo0?ooo`1f0?ooo`H0003o4P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0`03oool0
04h0oooo00<000000?ooo`3oool0M@3oool50000oa@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`240?ooo`030000003oool0oooo0;l0oooo001=0?ooo`030000003oool0oooo07D0
oooo10000?lF0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0Q03oool00`000000
oooo0?ooo`2o0?ooo`00C@3oool00`000000oooo0?ooo`1d0?ooo`@0003o5`3oool3000000H0oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`2o0?ooo`00C@3oool00`000000oooo0?oo
o`1c0?ooo`@0003o603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08D0oooo00<0
00000?ooo`3oool0_`3oool004d0oooo00<000000?ooo`3oool0LP3oool40000oaT0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0;h0oooo001=0?oo
o`030000003oool0oooo0740oooo10000?lF0?ooo`@0003o00<000000000o`000?l01@000?l00`00
0000oooo0?ooo`270?ooo`030000003oool0oooo0;h0oooo001=0?ooo`030000003oool0oooo0740
oooo0`000?lC0?ooo`P0003o00<000000000o`000?l01@000?l00`000000003o0000o`270?ooo`03
0000003oool0oooo0;h0oooo001<0?ooo`030000003oool0oooo0740oooo10000?lA0?ooo`X0003o
00<000000000o`000?l01@000?l00`000000003o0000o`030000oh@0oooo00<000000?ooo`3oool0
_P3oool004`0oooo00<000000?ooo`3oool0L@3oool30000oa00oooo2@000?l30?ooo`030000003o
ool0oooo00D0oooo00<000000000o`000?l01P000?n10?ooo`030000003oool0oooo0;h0oooo001<
0?ooo`030000003oool0oooo0700oooo10000?l?0?ooo`H0003o1`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00P0003oP03oool00`000000oooo0?ooo`2n0?ooo`00C03oool00`00
0000oooo0?ooo`1`0?ooo`<0003o3P3oool60000o`T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`H0003oO`3oool00`000000oooo0?ooo`2n0?ooo`00C03oool00`000000
oooo0?ooo`1_0?ooo`@0003o3@3oool50000o`/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`@0003oO`3oool00`000000oooo0?ooo`2m0?ooo`00B`3oool00`000000oooo
0?ooo`1_0?ooo`@0003o3@3oool50000o``0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`080?ooo`@0003oOP3oool00`000000oooo0?ooo`2m0?ooo`00B`3oool00`000000oooo0?oo
o`1_0?ooo`<0003o3P3oool30000o`h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`@0003oO@3oool00`000000oooo0?ooo`2m0?ooo`00B`3oool00`000000oooo0?ooo`1^
0?ooo`@0003o3@3oool40000o`h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:
0?ooo`@0003oO03oool00`000000oooo0?ooo`2m0?ooo`00B`3oool00`000000oooo0?ooo`1^0?oo
o`<0003o3@3oool40000o`l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?oo
o`@0003oN`3oool00`000000oooo0?ooo`2m0?ooo`00B`3oool01@000000oooo0?oog`2LB7@0_ooo
0480oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18W=l0
oooo0?ooo`0J0?ooo`@0003o303oool40000oa00oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0=0?ooo`@0003o:`3oool02P2oM00000000000B02Lgol0oooo0?oo_`1dB9`0gooo0?oo
o`2oM0020000000304RLg`3oool0oooo0400oooo00<0000009a8M02oool0@`3oool02@3ooml0W4Qd
0;ooo`3oool0oono07A8W03Oool0oooo0;md00020000000304RLg`3oool0oooo03l0oooo00<0_g@0
0000000000000P0000000`18W=l0oooo0?ooo`0U0?ooo`00B`3oool01@000000oooo0?oog`2LB7@0
_ooo0440oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`060?noM018W=l0oooo0?ooo`3O
W4P0M;oo6`3oool30000o`d0oooo0`000?lA0?ooo`<000000P3oool00`000000oooo0?ooo`0>0?oo
o`@0003o:@3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo
0=nLB01d_om10?ooo`030000002LB7@0_ooo04<0oooo00<0oooO09a8M02oool0103oool01P3o_g@0
B9cO0?ooo`3oool0gia807Bood00oooo00<0oooO09a8001d_ol0:P3oool004@0oooo00<0okmd0000
000000000P0000001`00B9`0gooo0000003oool0oooO09a8M02oool0>P3oool00`3o_g@000000000
0002000000080018W03Oool0gia804RLg`3oool0oono07@0M02oool70?ooo`030?noM018W=l0oooo
01T0oooo10000?l<0?ooo`@0003o4@3oool01@000000oooo0?ooo`3oool000000180oooo10000?lX
0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`100?ooo`030000
002LB7@0_ooo04<0oooo00<0oooO09a8M02oool0203oool00`3o_g@0B9cO0?ooo`110?ooo`030;md
0000M;l0oooo02P0oooo001;0?ooo`050000003oool0oooO09a8M02oool0@@3oool01P3OW4P0M;oo
0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_olJ0?ooo`<0003o3@3o
ool30000oa80oooo00D000000?ooo`3oool0oooo0000000C0?ooo`<0003o:03oool01P3OW4P0M;oo
0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_om10?ooo`030?oog`00
0000_ooo04<0oooo00<0oooO09a8M02oool0103oool01P3o_g@0001d0;ooo`3oool0gia807Bood<0
oooo00<0okmd001d_`3oool09`3oool004/0oooo00D0000009bL_`3ooml0W4Qd0;ooo`110?ooo`06
0=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo01/0oooo0`00
0?l=0?ooo`<0003o4P3oool01@000000oooo0?ooo`3oool0000001<0oooo10000?lW0?ooo`060=nL
B018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo0400oooo00D0oooO
09bL_`3ooml000000;ooo`110?ooo`050?oog`2LW;l0oooO09a8M02oool0103oool01@3ookl0M4Q8
04P00000000007Bo04D0oooo00<0gia807Boo`3oool09P3oool004/0oooo00D000000?noM0000000
001d0;ooo`110?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`0M
0?ooo`<0003o303oool40000oa80oooo00@000000?ooo`3oool000005@3oool30000obL0oooo00H0
okmd0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo04<0oooo00@0okmd00000000
0000_ooo@P3oool0103o_g@000000000M02oool40?ooo`030?oog`2LB4P0W=oo04<0oooo00H0okmd
001d_`3oool0oooo0;md001d_olW0?ooo`00B`3oool01@000000oooo0?oo_`1d07@0_ooo0480oooo
00@0_g@00000000004P0W=oo1@3oool01@2oM00000000000000004P0W=oo01T0oooo10000?l<0?oo
o`<0003o4`3oool010000000oooo0?ooo`00000E0?ooo`@0003o9`3oool0102oM00000000000B02L
gol50?ooo`050;md0000000000000000B02Lgol0@@3oool00`3ookl000000;ooo`130?ooo`030?oo
_`1d07@0_ooo00D0oooo00D0_g@0000000000000001809cOo`100?ooo`060?oog`2LB00000000000
0000B9`0gooo9`3oool004X0oooo00<000000?ooo`3oool0K03oool30000o``0oooo10000?lC0?oo
o`040000003oool0oooo000001H0oooo10000?mf0?ooo`030000003oool0oooo0;`0oooo001:0?oo
o`030000003oool0oooo06`0oooo0`000?l<0?ooo`<0003o503oool00`000000oooo0000000H0?oo
o`<0003oMP3oool00`000000oooo0?ooo`2l0?ooo`00BP3oool00`000000oooo0?ooo`1/0?ooo`<0
003o303oool30000oa@0oooo00<000000?ooo`000000603oool30000ogH0oooo00<000000?ooo`3o
ool0_03oool004X0oooo00<000000?ooo`3oool0K03oool30000o``0oooo0`000?lD0?ooo`030000
003oool0000001P0oooo0`000?mf0?ooo`030000003oool0oooo0;`0oooo001:0?ooo`030000003o
ool0oooo06`0oooo0`000?l<0?ooo`<0003o503oool2000001T0oooo0`000?mf0?ooo`030000003o
ool0oooo0;`0oooo001:0?ooo`030000003oool0oooo06`0oooo0`000?l<0?ooo`<0003o503oool2
000001T0oooo0`000?mf0?ooo`030000003oool0oooo0;`0oooo001:0?ooo`030000003oool0oooo
06`0oooo0`000?l<0?ooo`<0003o503oool2000001T0oooo10000?me0?ooo`030000003oool0oooo
0;`0oooo001:0?ooo`030000003oool0oooo06`0oooo0`000?l<0?ooo`<0003o503oool00`000000
oooo0?ooo`0:0?ooo`<0003o303oool30000ogD0oooo00<000000?ooo`3oool0_03oool002@0oooo
o`00003V000002T0oooo000]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo0`000?l50?ooo`030000003o
ool0oooo00@0oooo0`000?l50?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3o
ool40000o`/0oooo0`000?l=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0W0?ooo`00;@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`<0003o1@3oool0
0`000000oooo0?ooo`040?ooo`<0003o1@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00X0oooo10000?l;0?ooo`<0003o3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool09`3oool004X0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0R0?ooo`<0003o303oool30000oa@0oooo00<000000?ooo`3oool02P3oool40000
o`/0oooo0`000?l[0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo02L0oooo001:0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool08P3oool30000o``0oooo0`000?lD0?ooo`030000003oool0oooo00X0
oooo10000?l;0?ooo`<0003o:`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0W0?ooo`00BP3oool00`000000oooo
0?ooo`1/0?ooo`@0003o2`3oool40000oa<0oooo00<000000?ooo`3oool02P3oool40000o`/0oooo
0`000?me0?ooo`030000003oool0oooo0;`0oooo001:0?ooo`030000003oool0oooo06d0oooo0`00
0?l<0?ooo`@0003o4P3oool00`000000oooo0?ooo`0:0?ooo`<0003o303oool30000ogD0oooo00<0
00000?ooo`3oool0_03oool004X0oooo00<000000?ooo`3oool0K@3oool30000o`d0oooo0`000?lB
0?ooo`030000003oool0oooo00X0oooo0`000?l<0?ooo`<0003oM@3oool00`000000oooo0?ooo`2l
0?ooo`00BP3oool00`000000oooo0?ooo`1]0?ooo`@0003o303oool30000oa80oooo00<000000?oo
o`3oool02@3oool40000o`/0oooo10000?me0?ooo`030000003oool0oooo0;`0oooo001:0?ooo`03
0000003oool0oooo06h0oooo0`000?l<0?ooo`@0003o4@3oool00`000000oooo0?ooo`090?ooo`<0
003o303oool30000ogH0oooo00<000000?ooo`3oool0_03oool004/0oooo00<000000?ooo`3oool0
K@3oool30000o`d0oooo0`000?lA0?ooo`030000003oool0oooo00P0oooo10000?l<0?ooo`<0003o
MP3oool00`000000oooo0?ooo`2l0?ooo`00B`3oool00`000000oooo0?ooo`1]0?ooo`<0003o3@3o
ool40000oa00oooo00<000000?ooo`3oool0203oool30000o`d0oooo0`000?mf0?ooo`030000003o
ool0oooo0;`0oooo001;0?ooo`030000003oool0oooo06d0oooo10000?l=0?ooo`@0003o3`3oool0
0`000000oooo0?ooo`070?ooo`@0003o303oool40000ogH0oooo00<000000?ooo`3oool0_03oool0
04/0oooo00<000000?ooo`3oool0KP3oool30000o`h0oooo10000?l>0?ooo`030000003oool0oooo
00D0oooo1@000?l=0?ooo`<0003oM`3oool00`000000oooo0?ooo`2l0?ooo`00B`3oool00`000000
oooo0?ooo`1^0?ooo`@0003o3P3oool40000o`d0oooo00<000000?ooo`3oool01@3oool50000o`d0
oooo0`000?mf0?ooo`030000003oool0oooo0;d0oooo001;0?ooo`030000003oool0oooo06l0oooo
0`000?l?0?ooo`D0003o2`3oool3000000@0oooo10000?l>0?ooo`@0003oMP3oool00`000000oooo
0?ooo`2m0?ooo`00B`3oool00`000000oooo0?ooo`1_0?ooo`@0003o3`3oool60000o`T0oooo00<0
00000?ooo`3oool00P3oool50000o`h0oooo10000?mg0?ooo`030000003oool0oooo0;d0oooo001;
0?ooo`030000003oool0oooo0700oooo10000?l?0?ooo`P0003o1P3oool00`000000003o0000o`07
0000o`h0oooo0`000?mh0?ooo`030000003oool0oooo0;d0oooo001;0?ooo`030000003oool0oooo
0740oooo0`000?lA0?ooo``0003o00<000000000o`000?l01@000?l?0?ooo`@0003oN03oool00`00
0000oooo0?ooo`2m0?ooo`00B`3oool00`000000oooo0?ooo`1a0?ooo`@0003o4P3oool:0000o`03
000000000?l0003o00<0003o4@3oool30000ogT0oooo00<000000?ooo`3oool0_@3oool004/0oooo
00<000000?ooo`3oool0LP3oool40000oa@0oooo1`000?l00`000000003o0?ooo`0C0?ooo`@0003o
N@3oool00`000000oooo0?ooo`2m0?ooo`00C03oool00`000000oooo0?ooo`1b0?ooo`<0003o6`3o
ool00`000000oooo0?ooo`0C0?ooo`<0003oNP3oool00`000000oooo0?ooo`2m0?ooo`00C03oool0
0`000000oooo0?ooo`1c0?ooo`<0003o6P3oool00`000000oooo0?ooo`0B0?ooo`@0003oN@3oool0
0`000000oooo0?ooo`2n0?ooo`00C03oool00`000000oooo0?ooo`1c0?ooo`@0003o6@3oool00`00
0000oooo0?ooo`0A0?ooo`@0003oNP3oool00`000000oooo0?ooo`2n0?ooo`00C03oool00`000000
oooo0?ooo`1d0?ooo`D0003o5`3oool00`000000oooo0?ooo`0@0?ooo`@0003oN`3oool00`000000
oooo0?ooo`2n0?ooo`00C03oool00`000000oooo0?ooo`1e0?ooo`D0003o5P3oool00`000000oooo
0?ooo`0>0?ooo`H0003oN`3oool00`000000oooo0?ooo`2n0?ooo`00C@3oool00`000000oooo0?oo
o`1e0?ooo`H0003o503oool00`000000oooo0?ooo`0=0?ooo`D0003oO@3oool00`000000oooo0?oo
o`2n0?ooo`00C@3oool00`000000oooo0?ooo`1g0?ooo`D0003o4`3oool00`000000oooo0?ooo`0<
0?ooo`D0003oOP3oool00`000000oooo0?ooo`2n0?ooo`00C@3oool00`000000oooo0?ooo`1h0?oo
o`D0003o4P3oool00`000000oooo0?ooo`0:0?ooo`D0003oP03oool00`000000oooo0?ooo`2n0?oo
o`00C@3oool00`000000oooo0?ooo`1j0?ooo`D0003o403oool00`000000oooo0?ooo`080?ooo`H0
003oP03oool00`000000oooo0?ooo`2o0?ooo`00C@3oool00`000000oooo0?ooo`1k0?ooo`L0003o
3@3oool3000000H0oooo1`000?n10?ooo`030000003oool0oooo0;l0oooo001=0?ooo`030000003o
ool0oooo07`0oooo2P000?l90?ooo`030000003oool0oooo00<0oooo20000?n30?ooo`030000003o
ool0oooo0;l0oooo001>0?ooo`030000003oool0oooo07d0oooo3@000?l20?ooo`80003o00<00000
0000o`000?l02@000?n50?ooo`030000003oool0oooo0;l0oooo001>0?ooo`030000003oool0oooo
0840oooo3@000?l00`000000003o0000o`070000ohH0oooo00<000000?ooo`3oool0`03oool004h0
oooo00<000000?ooo`3oool0Q03oool:0000o`03000000000?l0003o00@0003oR@3oool00`000000
oooo0?ooo`300?ooo`00CP3oool00`000000oooo0?ooo`290?ooo`D0003o00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`300?ooo`00CP3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0`03oool004l0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0<00oooo001?0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`310?ooo`00C`3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0`@3oool004l0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0<40oooo
001@0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`310?ooo`00D03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool0`P3oool00500oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo0<80oooo001A0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`320?ooo`00D@3oool00`000000oooo0?ooo`2;0?ooo`<00000
RP3oool00`000000oooo0?ooo`330?ooo`00D@3oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0``3oool00540oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo0<@0oooo001B0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`340?ooo`00D`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0a03oool005<0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0<@0oooo
001C0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`350?ooo`00D`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0a@3oool005@0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0<D0oooo001D0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0Q`3oool00`000000oooo0?ooo`360?ooo`00E@3oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo08L0oooo00<000000?ooo`3oool0aP3oool005D0oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0<L0oooo001E0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`380?ooo`00EP3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0b03oool005H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0<P0
oooo001G0?ooo`030000003oool0oooo08D0oooo0`0000250?ooo`030000003oool0oooo0<P0oooo
001G0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`390?ooo`00E`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool0b@3oool005P0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`230?oo
o`030000003oool0oooo0<X0oooo001H0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`3;0?ooo`00F@3oool00`000000oooo0?ooo`230?ooo`030000
003oool0oooo0880oooo00<000000?ooo`3oool0b`3oool005T0oooo00<000000?ooo`3oool0P`3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0</0oooo001J0?ooo`030000003oool0
oooo0880oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3;0?ooo`00F`3oool00`00
0000oooo0?ooo`210?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0c03oool005/0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0<d0
oooo001K0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P03oool00`000000oooo
0?ooo`0`0?ooo`030?noM0000000M;oo09X0oooo001L0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`0a0?ooo`030?noM0000000M;oo09X0oooo001L
0?ooo`030000003oool0oooo06X0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3o
ool0_g@00P0000000`18W=l0oooo0?ooo`070?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool08@3oool0503ogi`0B00000000000M7@0M00004RLg`3ogi`0B00007Boo`3oool0okmd0000
B02Lgol0oooo0=nLB00004P0W=oo0?noM0000000M7Ad0P0000001`00M;l0oooo0?noM00004P0W=oo
0?ooo`3o_g@00`000000101d_ol0oooo0?oOW0180003000000030018W03Ogi`0B00000<0000000L0
04RL0=oOW01800000000001dM01d0000B9cO00d0oooo00/0oooO09a800000000000004RLg`3oool0
omnL04P0001d_ol0oooo0?noM0020000000;001d_`3oool0oooo0?ooo`3ookl0M00004RLg`3oool0
_g@00018W03Oool0E@3oool005d0oooo00<000000?ooo`3oool0J03oool01P3o_g@004RL0=ooo`3o
_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo0=nLB01d_ol80?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool08@3oool09P2oM000001d0;ooo`3OW4P0000007Boo`3ogi`0B000
07Boo`3oool0okmd0000B02Lgol0oooo0=nLB00004P0W=oo0?noM000000007Bo0?ooo`3ogi`0B000
07Boo`3o_g@0001809cOo`3ogi`0B000001d_`3oool0okmd0000B02Lgol0oooo0;md000007@0_ooo
0`3oool00`2oM000001d0;ooo`020?ooo`060;md000007@0_ooo0=nLB0000000M;oo0P3oool00`3o
_g@0000000000003000000030018W03Oool0oooo0080oooo00l0gia80000B02Lgol0okmd0000001d
_ol0omnL04P0001d_ol0omnL04P0B02Lgol0omnL04P0001d_ol00`3oool01@3ogi`0B01d0;oog`2L
B000M;oo05H0oooo001M0?ooo`030000003oool0oooo06P0oooo00H0gia804RLg`3oool0oono07@0
M02oool70?ooo`030?noM018W=l0oooo00L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo
0?ooo`0R0?ooo`0N0=nLB00004P0W=oo0?oOW0180000M;oo0?oOW0180000M;oo0?ooo`3o_g@00018
09cOo`3oool0gia80000B02Lgol0okmd0000001d_ol0oooo0?oog`2LB00007Bo0?noM00004P0W=oo
0=nLB00004P0W=oo1@3oool00`3ookl0M00004RLg`030?ooo`030?oo_`1d0000B9cO0080oooo00H0
gia80000B02Lgol0omnL04P0001d_ol@0?ooo`030?oo_`1d0000B9cO00<0oooo00H0gia80000M02o
ool0oono07@00000M;l40?ooo`040;md001d_ol0_gA809cOoeH0oooo001N0?ooo`030000003oool0
oooo06L0oooo00H0gia807Boo`3oool0oooO09a8M02oool30?ooo`060?noM00007@0_ooo0?ooo`3O
W4P0M;oo203oool4000007`0oooo00<000000?ooo`3oool08`3oool06`3ogi`0B000000000000000
M;oo0?oOW0180000M;oo0?ooo`3o_g@0000007Boo`3oool0gia80000B02Lgol0okmd0000001d_ol0
oooo0?oog`2LB00007Bo0?noM00004P0W=oo0=nLB0050000000604RLg`3oool0oooo0=nLB00004P0
W=oo0`3oool00`3OW4P0001809cOo`020?ooo`050?oOW018000000000000001d_ol0403oool00`3o
gi`0B00007Boo`030?ooo`060;md000004P0W=oo0?oOW0180000B9cO103oool0103o_g@007Bo0=nL
B01d_omF0?ooo`00G`3oool00`000000oooo0?ooo`1V0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0
_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00T0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`0S0?ooo`0R0?noM000B9`0gooo0?noM0000000M;oo0?oOW018000007Bo0?ooo`3O
W4P0000004RLg`3oool0gia80000M02oool0okmd00000000M;l0oooo0?noM0000000M;oo0?noM000
04P0W=oo0?oOW0180000M;oo0?ooo`3ogi`0B00007Boo`80oooo00<0oooO09a80000M;l00`3oool0
2P3ooml0W4P0001d_`3oool0okmd0018W03Oool0okmd0000001d_ol20?ooo`030?noM00000000000
00<0000000<004RL0=ooo`3oool0103oool00`3o_g@0001d0;ooo`040?ooo`050=nLB000B4P0B000
00000000M;l0103oool01@2oM7@0_ono07A8W03O_g@007Bo05H0oooo001O0?ooo`030000003oool0
oooo06H0oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo00/0oooo
00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0U0?ooo`080;md0000000000000018W03O
ool0omnL04P0001dM7@2000000090018W02LM000000000000018W=l0oooo0?noM0000000M7Ad0080
000000L007Bo0?ooo`3o_g@0001809cOo`3oool0okmd00<0000000@0B9cO0?ooo`3ogi`0B0000P00
0000100004P0W=oo0?oOW0180002000000040000B02Lgol0oooo0;md0080000000<004RL0=ooo`3o
ool03`3oool00`3OW4P0001d0;ooo`030?ooo`030=nLB00007@0_ooo00H0oooo00<0oono07@00000
00000P0000000`0007@0_ooo0?ooo`1C0?ooo`00H03oool00`000000oooo0?ooo`1V0?ooo`040;md
00000000001809cOo`D0oooo00D0_g@0000000000000001809cOo`080?ooo`030000003oool0oooo
07/0oooo00<000000?ooo`3oool0I@3oool01P3o_g@0000007Boo`3OW4P0001809cOo`<0oooo00H0
omnL04P0001d_ol0okmd0000001d_omN0?ooo`00H@3oool00`000000oooo0?ooo`1k0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0?@3oool00`3o_g@0001809cOo`0W0?ooo`040;md
00000000000004RLg`D0oooo00@0okmd00000000000007BoG`3oool00640oooo00<000000?ooo`3o
ool0N`3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0=@0oooo001R0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`3D0?ooo`00HP3o
ool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0e@3o
ool006<0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo0=D0oooo001T0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`3F0?ooo`00I@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0e`3oool006D0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo0=L0oooo001V0?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool0M@3oool00`000000oooo0?ooo`3H0?ooo`00I`3oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0f@3oool006L0oooo00<000000?oo
o`3oool0M@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0=T0oooo001X0?ooo`03
0000003oool0oooo07@0oooo0`00001c0?ooo`030000003oool0oooo0=X0oooo001Y0?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`3K0?ooo`00JP3o
ool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0f`3o
ool006/0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo0=`0oooo001/0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`3M0?ooo`00K03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo06l0
oooo00<000000?ooo`3oool0gP3oool006d0oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo0=l0oooo001^0?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`3P0?ooo`00KP3oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0h03oool006l0oooo00<000000?oo
o`3oool0K@3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0>40oooo001`0?ooo`80
0000K@3oool00`000000oooo0?ooo`1Z0?ooo`800000i03oool00780oooo00<000000?ooo`3oool0
JP3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0>@0oooo001c0?ooo`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`3U0?ooo`00L`3oool0
0`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0i@3oool0
07@0oooo00<000000?ooo`3oool0J03oool3000006L0oooo00<000000?ooo`3oool0iP3oool007D0
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0>L0
oooo001f0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`3X0?ooo`00M`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool0j@3oool007P0oooo0P00001U0?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool0jP3oool007X0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1R0?oo
o`030000003oool0oooo0>/0oooo001k0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`3/0?ooo`00N`3oool00`000000oooo0?ooo`1Q0?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool0k@3oool007`0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0>h0oooo001m0?ooo`800000H03oool0
0`000000oooo0?ooo`1M0?ooo`800000l@3oool007l0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo0?40oooo00200?ooo`030000003oool0oooo05`0
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`3b0?ooo`00P@3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0l`3oool00880oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0?@0oooo0023
0?ooo`800000FP3oool00`000000oooo0?ooo`1G0?ooo`800000m`3oool008D0oooo00<000000?oo
o`3oool0E`3oool3000005H0oooo00<000000?ooo`3oool0m`3oool008H0oooo0P00001G0?ooo`03
0000003oool0oooo05@0oooo0P00003j0?ooo`00R03oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool0nP3oool008T0oooo0P00001D0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0n`3oool008/0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`1@0?ooo`800000oP3oool008`0oooo0P00001A0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0oP3oool008h0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`1=0?ooo`800000o`3oool20?ooo`00S`3oool2000004h0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`3o0?ooo`80oooo002A0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0BP3oool200000?l0oooo1@3oool00980oooo0P00001;0?ooo`030000003oool0
oooo04P0oooo0P00003o0?ooo`L0oooo002D0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo002E0?ooo`800000B03oool00`000000
oooo0?ooo`150?ooo`800000o`3oool:0?ooo`00U`3oool2000004H0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`3o0?ooo`X0oooo002I0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool0@P3oool200000?l0oooo3@3oool009X0oooo100000110?ooo`030000003oool0
oooo03l0oooo0`00003o0?ooo`l0oooo002N0?ooo`030000003oool0oooo03h0oooo0`00000m0?oo
o`800000o`3ooolB0?ooo`00W`3oool2000003h0oooo00<000000?ooo`3oool0>`3oool200000?l0
oooo503oool00:40oooo0P00000l0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
o`3ooolD0?ooo`00X`3oool3000003T0oooo00<000000?ooo`3oool0=P3oool400000?l0oooo5`3o
ool00:H0oooo0P00000g0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0o`3ooolI
0?ooo`00Z03oool3000003@0oooo00<000000?ooo`3oool0<@3oool400000?l0oooo703oool00:/0
oooo0P00000b0?ooo`030000003oool0oooo02l0oooo0P00003o0?ooob00oooo002]0?ooo`<00000
;`3oool00`000000oooo0?ooo`0/0?ooo`<00000o`3ooolR0?ooo`00/03oool4000002/0oooo00<0
00000?ooo`3oool0:03oool400000?l0oooo9@3oool00;@0oooo0`00000X0?ooo`030000003oool0
oooo02D0oooo0`00003o0?ooobT0oooo002g0?ooo`@00000903oool00`000000oooo0?ooo`0Q0?oo
o`@00000o`3oool/0?ooo`00^`3oool400000200oooo00<000000?ooo`3oool07P3oool300000?l0
oooo<03oool00;l0oooo1@00000K0?ooo`030000003oool0oooo01P0oooo1P00003o0?oooc<0oooo
00340?ooo`H000002@3oool00`3ooml0W4Qd0;ooo`090?ooo`030000003oool0oooo01<0oooo1@00
003o0?ooocT0oooo003:0?ooo`/0000000<0_ooo0?ooo`3oool01`3oool00`000000oooo0?ooo`08
0?ooo`/00000o`3oooln0?ooo`00d`3oool00`3ooml0W4Qd0000000D00000?l0ooooB@3oool00=<0
oooo00<0oooO09a8M02oool02@3oool00`000000oooo0?ooo`3o0?oooe40oooo003A0?ooo`050?oo
g`2LW;l0oooO09a8M02oool02@3oool00`000000oooo0?ooo`3o0?oooe40oooo003B0?ooo`040?no
M0000000001d0;ooo`T0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00d`3oool00`3ookl0M01d
0;ooo`090?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3o
oomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo
0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo
0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<00000
0?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`03
0000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3o
ool300000?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`00
0000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo
00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O
0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?oo
o`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0oooo
D@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o
0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3o
ool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`<00000o`3o
oomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo
0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo
0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<00000
0?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`03
0000003oool0oooo0?l0ooooD@3oool00001\
\>"],
  ImageRangeCache->{{{94.4375, 408.375}, {309.875, 100.938}} -> {-2.64446, \
-0.0425847, 0.00844286, 0.00844286}}],

Cell[TextData[{
  "o minore di ",
  Cell[BoxData[
      \(TraditionalForm\`\(-2\) \[Pi]\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(versoNegativo = 
        intervalloValori[
          0, \(-4\) \[Pi], \(-\[Pi]\)/10];\)\), "\[IndentingNewLine]", 
    \(\(\(Show[
            If[# \[NotEqual] 0, 
              ParametricPlot[{Sign[t] t\ Cos[t], Sign[t]\ t\ Sin[t]}/
                    200  \[Pi], {t, Sign[#] 2  \[Pi], Sign[#] 2\ \[Pi] + #}, 
                Axes \[Rule] False, DisplayFunction \[Rule] Identity, 
                PlotStyle \[Rule] {AbsoluteThickness[3], colBlu}], 
              Graphics[{Point[{Cos[#], Sin[#]}]}]], 
            Graphics[{Circle[{0, 0}, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
                Line[{{0, \(-1.2\)}, {0, 1.2}}], 
                Line[{{Cos[#], Sin[#]}, {0, 0}}]}], 
            Graphics[{AbsolutePointSize[6], Point[{Cos[#], Sin[#]}]}], 
            Epilog \[Rule] {{Text["\<ampiezza = \>" <> 
                      ToString[N[#]/\[Pi]] <> "\< \[Pi]\>", {1.1, 
                      0.5}, {\(-1\), 0}, 
                    TextStyle \[Rule] 
                      stileTesto]}}, \[IndentingNewLine]AspectRatio \[Rule] 
              Automatic, Axes \[Rule] True, 
            DisplayFunction \[Rule] $DisplayFunction, 
            PlotRange \[Rule] {{\(-1.26\), 2}, {\(-1.26\), 1.26}}, 
            ImageSize \[Rule] {450, 300}] &\) /@ versoNegativo;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77301 
%%ImageSize: 450 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.386503 0.306748 0.386503 0.306748 [
[.07975 .374 -6.96875 -10.9375 ]
[.07975 .374 6.96875 0 ]
[.23313 .374 -10.3125 -10.9375 ]
[.23313 .374 10.3125 0 ]
[.53988 .374 -7.5625 -10.9375 ]
[.53988 .374 7.5625 0 ]
[.69325 .374 -4.21875 -10.9375 ]
[.69325 .374 4.21875 0 ]
[.84663 .374 -7.5625 -10.9375 ]
[.84663 .374 7.5625 0 ]
[1 .374 -4.21875 -10.9375 ]
[1 .374 4.21875 0 ]
[.374 .07975 -13.9375 -5.46875 ]
[.374 .07975 0 5.46875 ]
[.374 .23313 -20.625 -5.46875 ]
[.374 .23313 0 5.46875 ]
[.374 .53988 -15.125 -5.46875 ]
[.374 .53988 0 5.46875 ]
[.374 .69325 -8.4375 -5.46875 ]
[.374 .69325 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .77301 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07975 .3865 m
.07975 .39275 L
s
gsave
.07975 .374 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.23313 .3865 m
.23313 .39275 L
s
gsave
.23313 .374 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.53988 .3865 m
.53988 .39275 L
s
gsave
.53988 .374 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69325 .3865 m
.69325 .39275 L
s
gsave
.69325 .374 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.84663 .3865 m
.84663 .39275 L
s
gsave
.84663 .374 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
1 .3865 m
1 .39275 L
s
gsave
1 .374 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.11043 .3865 m
.11043 .39025 L
s
.1411 .3865 m
.1411 .39025 L
s
.17178 .3865 m
.17178 .39025 L
s
.20245 .3865 m
.20245 .39025 L
s
.2638 .3865 m
.2638 .39025 L
s
.29448 .3865 m
.29448 .39025 L
s
.32515 .3865 m
.32515 .39025 L
s
.35583 .3865 m
.35583 .39025 L
s
.41718 .3865 m
.41718 .39025 L
s
.44785 .3865 m
.44785 .39025 L
s
.47853 .3865 m
.47853 .39025 L
s
.5092 .3865 m
.5092 .39025 L
s
.57055 .3865 m
.57055 .39025 L
s
.60123 .3865 m
.60123 .39025 L
s
.6319 .3865 m
.6319 .39025 L
s
.66258 .3865 m
.66258 .39025 L
s
.72393 .3865 m
.72393 .39025 L
s
.7546 .3865 m
.7546 .39025 L
s
.78528 .3865 m
.78528 .39025 L
s
.81595 .3865 m
.81595 .39025 L
s
.8773 .3865 m
.8773 .39025 L
s
.90798 .3865 m
.90798 .39025 L
s
.93865 .3865 m
.93865 .39025 L
s
.96933 .3865 m
.96933 .39025 L
s
.04908 .3865 m
.04908 .39025 L
s
.0184 .3865 m
.0184 .39025 L
s
.25 Mabswid
0 .3865 m
1 .3865 L
s
.3865 .07975 m
.39275 .07975 L
s
gsave
.374 .07975 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.3865 .23313 m
.39275 .23313 L
s
gsave
.374 .23313 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.3865 .53988 m
.39275 .53988 L
s
gsave
.374 .53988 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.3865 .69325 m
.39275 .69325 L
s
gsave
.374 .69325 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.3865 .11043 m
.39025 .11043 L
s
.3865 .1411 m
.39025 .1411 L
s
.3865 .17178 m
.39025 .17178 L
s
.3865 .20245 m
.39025 .20245 L
s
.3865 .2638 m
.39025 .2638 L
s
.3865 .29448 m
.39025 .29448 L
s
.3865 .32515 m
.39025 .32515 L
s
.3865 .35583 m
.39025 .35583 L
s
.3865 .41718 m
.39025 .41718 L
s
.3865 .44785 m
.39025 .44785 L
s
.3865 .47853 m
.39025 .47853 L
s
.3865 .5092 m
.39025 .5092 L
s
.3865 .57055 m
.39025 .57055 L
s
.3865 .60123 m
.39025 .60123 L
s
.3865 .6319 m
.39025 .6319 L
s
.3865 .66258 m
.39025 .66258 L
s
.3865 .04908 m
.39025 .04908 L
s
.3865 .0184 m
.39025 .0184 L
s
.3865 .72393 m
.39025 .72393 L
s
.3865 .7546 m
.39025 .7546 L
s
.25 Mabswid
.3865 0 m
.3865 .77301 L
s
0 0 m
1 0 L
1 .77301 L
0 .77301 L
closepath
clip
newpath
0 0 1 r
3 Mabswid
.43722 .45631 m
.42902 .46098 L
.41958 .465 L
.41467 .46658 L
.40935 .46793 L
.40674 .46846 L
.40427 .46889 L
.40187 .46923 L
.39962 .46948 L
.39714 .46969 L
.39582 .46978 L
.3944 .46984 L
.3937 .46986 L
.39293 .46988 L
.3922 .46989 L
.39152 .4699 L
.39024 .46989 L
.38953 .46988 L
.38888 .46986 L
.38761 .46982 L
.38644 .46976 L
.38516 .46967 L
.38381 .46956 L
.38155 .46932 L
.37907 .46899 L
.37363 .46799 L
.36791 .46653 L
.36264 .46478 L
.35797 .46288 L
.34923 .45836 L
.34174 .4533 L
.33428 .44686 L
.32733 .43913 L
.32217 .43172 L
.31762 .42319 L
.3159 .41911 L
.31435 .41474 L
.31316 .41065 L
.31224 .40675 L
.31182 .40454 L
.31144 .40213 L
.31117 .40012 L
.31095 .3979 L
.31085 .39666 L
.31078 .3955 L
.31072 .39428 L
.3107 .39359 L
.31068 .39296 L
.31066 .39185 L
.31067 .39063 L
Mistroke
.31069 .38948 L
.31072 .38842 L
.31077 .38735 L
.31084 .3862 L
.31101 .38411 L
.31123 .38209 L
.31148 .38024 L
.31222 .37607 L
.31325 .37174 L
.31598 .36353 L
.31791 .35912 L
.31991 .35523 L
.32414 .34847 L
.32937 .34189 L
.3356 .33571 L
.34194 .33076 L
.34927 .3263 L
.3534 .32429 L
.35784 .32248 L
.36177 .32117 L
.36612 .32 L
.37012 .3192 L
.37191 .31892 L
.37386 .31867 L
.37505 .31854 L
.37614 .31844 L
.37717 .31836 L
.3783 .3183 L
.37931 .31826 L
.38026 .31823 L
.38126 .31822 L
.38233 .31822 L
.38293 .31823 L
.38349 .31824 L
.3841 .31826 L
.38475 .31828 L
.38583 .31834 L
.38703 .31842 L
.38922 .31863 L
.39127 .31889 L
.39509 .31955 L
.39921 .32051 L
.40341 .32179 L
.40723 .32322 L
.41378 .32633 L
.42031 .33039 L
.42666 .33551 L
.4327 .34185 L
.43753 .34848 L
.44116 .35503 L
Mistroke
.44261 .35831 L
.44396 .36191 L
.44494 .36507 L
.44581 .36856 L
.44624 .37069 L
.44657 .37267 L
.44682 .37457 L
.44693 .37554 L
.44703 .3766 L
.44711 .37763 L
.44716 .37859 L
.4472 .3795 L
.44723 .38046 L
.44724 .38133 L
.44724 .38213 L
.44723 .38301 L
.4472 .38395 L
.44716 .38486 L
.4471 .38586 L
.44693 .38787 L
.44671 .38972 L
.44645 .39145 L
.44569 .39529 L
.4446 .39934 L
.4419 .40645 L
.43868 .41256 L
.43471 .41829 L
.43047 .4231 L
.42527 .42776 L
.41921 .43194 L
.41299 .43514 L
.40936 .43658 L
.40594 .43766 L
.40292 .43843 L
.39956 .43906 L
.39787 .4393 L
.39694 .4394 L
.39605 .43949 L
.39522 .43956 L
.39433 .43962 L
.39351 .43966 L
.39276 .43968 L
.39191 .4397 L
.39148 .4397 L
.39102 .4397 L
.39019 .43969 L
.38942 .43967 L
.38896 .43965 L
.38852 .43963 L
.38769 .43958 L
Mistroke
.38585 .43942 L
.38425 .43923 L
.38279 .43901 L
.37951 .43837 L
.37684 .43768 L
.37397 .43677 L
.36839 .43443 L
.36289 .43131 L
.35829 .4279 L
.35356 .42341 L
.34969 .41865 L
.34666 .41382 L
.34525 .41105 L
.34411 .40837 L
.34319 .40583 L
.34236 .40305 L
.34177 .40049 L
.34135 .39812 L
.34116 .39673 L
.34103 .39546 L
.34097 .39476 L
.34092 .394 L
.34088 .39328 L
.34086 .39262 L
.34084 .39201 L
.34084 .39143 L
.34084 .39081 L
.34085 .39013 L
.34087 .38947 L
.34091 .38876 L
.34095 .38817 L
.34099 .38752 L
.34115 .38601 L
.34133 .38465 L
.34188 .38165 L
.34256 .37892 L
.34336 .37641 L
.3454 .37157 L
.34813 .36681 L
.35089 .36311 L
.35433 .35944 L
.35833 .35611 L
.36227 .35356 L
.36454 .35236 L
.36707 .35123 L
.36933 .35039 L
.37181 .34965 L
.37433 .34907 L
.37549 .34887 L
.37672 .34868 L
Mistroke
.37783 .34856 L
.37841 .3485 L
.37904 .34845 L
.37962 .34841 L
.38015 .34839 L
.38067 .34837 L
.38117 .34836 L
.38174 .34836 L
.38207 .34836 L
.38237 .34836 L
.38298 .34838 L
.38332 .34839 L
.38364 .34841 L
.38474 .34848 L
.38529 .34853 L
.38589 .34859 L
.38716 .34875 L
.38849 .34897 L
.39086 .34948 L
.39321 .35015 L
.39531 .3509 L
.3998 .35303 L
.40343 .35536 L
.40686 .35824 L
.40961 .36118 L
.41211 .36462 L
.41402 .36807 L
.41537 .37134 L
.41595 .37316 L
.41644 .37512 L
.41675 .37679 L
.41689 .37775 L
.417 .37865 L
.41708 .37962 L
.41711 .38011 L
.41712 .38039 L
.41713 .38065 L
.41715 .3811 L
.41715 .38159 L
.41715 .38204 L
.41714 .38247 L
.41713 .38296 L
.41712 .38321 L
.4171 .38349 L
.41704 .38442 L
.41698 .38494 L
.41692 .3855 L
.41678 .3865 L
Mfstroke
0 g
.5 Mabswid
newpath
.3865 .3865 .30675 0 365.73 arc
s
.0184 .3865 m
.7546 .3865 L
s
.3865 .0184 m
.3865 .7546 L
s
.56681 .63467 m
.3865 .3865 L
s
6 Mabswid
.56681 .63467 Mdot
gsave
.72393 .53988 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(ampiezza) show
105.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
114.250 13.375 moveto
(-) show
120.375 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.7) show
135.375 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
140.375 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{450, 300},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008b0001Mb000`400?l00000o`00003og`3oool0
0`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0
oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo
003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA
0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0
ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool300000?l0ooooD@3o
ool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oo
oe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0
o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0
oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000
oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<0
00000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?oo
o`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00
g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`<00000o`3ooomA0?ooo`00g`3oool0
0`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0
oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo
003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA
0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0
ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?oo
o`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?oo
o`3oool0o`3ooomA0?ooo`00d`3oool00`3ooml0W4Qd0;ooo`090?ooo`030000003oool0oooo0?l0
ooooD@3oool00=<0oooo00<0oooO09a8M02oool02@3oool00`000000oooo0?ooo`3o0?oooe40oooo
003:0?ooo`030?noM000000000000080000000D004RL0=ooo`3oool0oooo0?oog`0E00000?l0oooo
BP3oool00<X0oooo2P0000000`2LB7@0_ooo0?ooo`080?ooo`030000003oool0oooo00L0oooo2`00
003o0?ooocl0oooo00350?ooo`D000001`3oool01@3ooml0W9bo0?oog`2LB7@0_ooo00T0oooo00<0
00000?ooo`3oool04P3oool600000?l0oooo>@3oool00<00oooo1@00000=0?ooo`040?noM0000000
001d0;ooo`T0oooo00<000000?ooo`3oool0603oool500000?l0oooo=03oool00;`0oooo1000000C
0?ooo`030?oo_`1d07@0_ooo00T0oooo00<000000?ooo`3oool07@3oool400000?l0oooo<03oool0
0;P0oooo1000000S0?ooo`030000003oool0oooo0240oooo0`00003o0?ooobd0oooo002e0?ooo`<0
00009`3oool00`000000oooo0?ooo`0T0?ooo`@00000o`3ooolY0?ooo`00/@3oool4000002X0oooo
00<000000?ooo`3oool0:03oool300000?l0oooo9P3oool00:h0oooo0`00000^0?ooo`030000003o
ool0oooo02/0oooo1000003o0?ooob80oooo002/0?ooo`800000<@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo0?l0oooo7`3oool00:T0oooo0`00000c0?ooo`030000003oool0oooo
0300oooo1000003o0?oooad0oooo002W0?ooo`800000=P3oool00`000000oooo0?ooo`0d0?ooo`80
0000o`3ooolK0?ooo`00X`3oool4000003P0oooo00<000000?ooo`3oool0=P3oool300000?l0oooo
603oool00:80oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0i0?ooo`800000o`3o
oolF0?ooo`00X03oool2000003d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3o
0?oooa<0oooo002N0?ooo`800000?`3oool3000003`0oooo0P00003o0?oooa<0oooo002K0?ooo`<0
0000@@3oool00`000000oooo0?ooo`0n0?ooo`<00000o`3oool@0?ooo`00V@3oool2000004@0oooo
00<000000?ooo`3oool0@@3oool200000?l0oooo3P3oool009P0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`130?ooo`800000o`3oool<0?ooo`00UP3oool2000004L0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`3o0?ooo`T0oooo002E0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0AP3oool200000?l0oooo2@3oool009<0oooo0P00001:0?ooo`03
0000003oool0oooo04P0oooo0P00003o0?ooo`L0oooo002A0?ooo`800000C03oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0?l0oooo103oool00900oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`1;0?ooo`800000o`3oool40?ooo`00SP3oool2000004l0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`3o0?ooo`40oooo002=0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0CP3oool200000?l0oooo0@3oool008/0oooo0P00001B0?ooo`03
0000003oool0oooo0500oooo00<000000?ooo`3oool0o@3oool008T0oooo0P00001D0?ooo`030000
003oool0oooo0540oooo0P00003m0?ooo`00R03oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0nP3oool008H0oooo0P00001G0?ooo`030000003oool0
oooo05@0oooo0P00003j0?ooo`00Q@3oool00`000000oooo0?ooo`1G0?ooo`<00000EP3oool00`00
0000oooo0?ooo`3g0?ooo`00P`3oool2000005X0oooo00<000000?ooo`3oool0E`3oool200000?L0
oooo00220?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`3d0?ooo`00P@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0l`3oool00800oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1K
0?ooo`030000003oool0oooo0?80oooo001o0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`3a0?ooo`00OP3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo05d0oooo0P00003a0?ooo`00O@3oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool0kP3oool007`0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0>d0oooo001k0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`3/0?ooo`00NP3oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0j`3oool007P0
oooo0P00001U0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0jP3oool007L0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0>T0oooo
001f0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`3X0?ooo`00M@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool0i`3oool007@0oooo00<000000?ooo`3oool0J03oool3000006L0oooo00<000000?oo
o`3oool0iP3oool007<0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo0>D0oooo001c0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`3T0?ooo`00LP3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool0h`3oool00700oooo0P00001]0?ooo`030000003oool0
oooo06/0oooo00<000000?ooo`3oool0hP3oool006l0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`1/0?ooo`030000003oool0oooo0>40oooo001^0?ooo`030000003oool0oooo06h0
oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`3P0?ooo`00KP3oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0h03oool006d0oooo00<0
00000?ooo`3oool0K`3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0=l0oooo001/
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`3N
0?ooo`00K03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0g@3oool006/0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1a0?ooo`03
0000003oool0oooo0=`0oooo001Z0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0
LP3oool00`000000oooo0?ooo`3K0?ooo`00J@3oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool0f`3oool006P0oooo00<000000?ooo`3oool0M03oool3
000007<0oooo00<000000?ooo`3oool0fP3oool006L0oooo00<000000?ooo`3oool0M@3oool00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo0=T0oooo001W0?ooo`030000003oool0oooo07D0
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`3I0?ooo`00IP3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0f03oool006D0oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0=L0oooo001T
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`3G
0?ooo`00I03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0eP3oool006<0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo0=D0oooo001R0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`3E0?ooo`00HP3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0e03oool00640oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0=@0oooo001Q0?ooo`030000003oool0oooo
07/0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3C0?ooo`00H03oool00`000000
oooo0?ooo`1l0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0dP3oool005l0oooo
00<000000?ooo`3oool0I`3oool02P2oM00000000000B02Lgol0oooo0?oo_`1dB9`0gooo0?ooo`2o
M0020000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?oo
o`3B0?ooo`00G`3oool00`000000oooo0?ooo`1V0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo
0`3oool01P3o_g@0B9cO0?ooo`3oool0gia807Boo`P0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`3A0?ooo`00GP3oool00`000000oooo0?ooo`1P0?ooo`030?noM000000000000080
000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0okmd04RLg`3oool01`3o
ool4000007`0oooo00<000000?ooo`3oool0d03oool005d0oooo00<000000?ooo`3oool0J03oool0
1P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol80?oo
o`030000003oool0oooo07d0oooo00<000000?ooo`3oool0d03oool005d0oooo00<000000?ooo`3o
ool0J03oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`<0oooo00D0oono07A8B01800000000001d
_`090?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0c`3oool005`0oooo00<00000
0?ooo`3oool0J@3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol0
2`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0<l0oooo001L0?ooo`030000003o
ool0oooo06X0oooo00@0_g@00000000004P0W=oo1@3oool01@2oM00000000000000004P0W=oo00P0
oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`3>0?ooo`00G03oool00`000000oooo
0?ooo`200?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0c@3oool005/0oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0<d0oooo001K
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`3<
0?ooo`00FP3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0880oooo00<000000?oo
o`3oool0b`3oool005T0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo0</0oooo001I0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`3;0?ooo`00F03oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0b`3oool005P0oooo00<000000?ooo`3oool0Q03oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo0<X0oooo001G0?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`390?ooo`00E`3oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0b@3oool005L0oooo
00<000000?ooo`3oool0Q@3oool3000008D0oooo00<000000?ooo`3oool0b03oool005H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0<P0oooo001F
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`38
0?ooo`00E@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool0b03oool005D0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`260?ooo`03
0000003oool0oooo0<L0oooo001E0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`360?ooo`00E03oool00`000000oooo0?ooo`280?ooo`030000003o
ool0oooo08L0oooo00<000000?ooo`3oool0aP3oool005@0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo0<D0oooo001C0?ooo`030000003oool0oooo
08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`350?ooo`00D`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0a@3oool005<0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0<D0oooo
001B0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`340?ooo`00DP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool0a03oool00540oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`290?oo
o`030000003oool0oooo0<@0oooo001A0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`330?ooo`00D@3oool00`000000oooo0?ooo`2;0?ooo`<00000
RP3oool00`000000oooo0?ooo`330?ooo`00D@3oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool0`P3oool00500oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo0<80oooo001@0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`320?ooo`00D03oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0`@3oool004l0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0<40oooo
001?0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`310?ooo`00C`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0`@3oool004l0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo0<00oooo001>0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`300?ooo`00CP3oool00`000000oooo0?ooo`290?ooo`D0003o
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`300?ooo`00CP3oool00`000000oooo0?oo
o`230?ooo`/0003o00<000000000o`000?l00`000?n:0?ooo`030000003oool0oooo0<00oooo001>
0?ooo`030000003oool0oooo0840oooo3@000?l00`000000003o0000o`070000ohH0oooo00<00000
0?ooo`3oool0`03oool004h0oooo00<000000?ooo`3oool0O@3oool=0000o`80oooo0P000?l00`00
0000003o0000o`090000ohD0oooo00<000000?ooo`3oool0_`3oool004d0oooo00<000000?ooo`3o
ool0O03oool90000o`X0oooo00<000000?ooo`3oool00P3oool:0000oh80oooo00<000000?ooo`3o
ool0_`3oool004d0oooo00<000000?ooo`3oool0N`3oool80000o``0oooo0`0000060?ooo`L0003o
P@3oool00`000000oooo0?ooo`2o0?ooo`00C@3oool00`000000oooo0?ooo`1j0?ooo`D0003o403o
ool00`000000oooo0?ooo`080?ooo`H0003oP03oool00`000000oooo0?ooo`2o0?ooo`00C@3oool0
0`000000oooo0?ooo`1h0?ooo`D0003o4P3oool00`000000oooo0?ooo`0;0?ooo`@0003oP03oool0
0`000000oooo0?ooo`2n0?ooo`00C@3oool00`000000oooo0?ooo`1g0?ooo`D0003o4`3oool00`00
0000oooo0?ooo`0<0?ooo`@0003oO`3oool00`000000oooo0?ooo`2n0?ooo`00C@3oool00`000000
oooo0?ooo`1e0?ooo`H0003o503oool00`000000oooo0?ooo`0=0?ooo`@0003oOP3oool00`000000
oooo0?ooo`2n0?ooo`00C03oool00`000000oooo0?ooo`1e0?ooo`D0003o5P3oool00`000000oooo
0?ooo`0>0?ooo`@0003oO@3oool00`000000oooo0?ooo`2n0?ooo`00C03oool00`000000oooo0?oo
o`1d0?ooo`D0003o5`3oool00`000000oooo0?ooo`0?0?ooo`@0003oO03oool00`000000oooo0?oo
o`2n0?ooo`00C03oool00`000000oooo0?ooo`1c0?ooo`@0003o6@3oool00`000000oooo0?ooo`0@
0?ooo`@0003oN`3oool00`000000oooo0?ooo`2n0?ooo`00C03oool00`000000oooo0?ooo`1c0?oo
o`<0003o6P3oool00`000000oooo0?ooo`0A0?ooo`@0003oNP3oool00`000000oooo0?ooo`2n0?oo
o`00C03oool00`000000oooo0?ooo`1b0?ooo`@0003o6P3oool00`000000oooo0?ooo`0B0?ooo`@0
003oNP3oool00`000000oooo0?ooo`2m0?ooo`00B`3oool00`000000oooo0?ooo`1b0?ooo`@0003o
503oool70000o`03000000000?l0oooo01<0oooo10000?mi0?ooo`030000003oool0oooo0;d0oooo
001;0?ooo`030000003oool0oooo0740oooo10000?lA0?ooo`/0003o00<000000000o`000?l00`00
0?lA0?ooo`<0003oN@3oool00`000000oooo0?ooo`2m0?ooo`00B`3oool00`000000oooo0?ooo`1`
0?ooo`@0003o4@3oool<0000o`03000000000?l0003o00D0003o3`3oool40000ogP0oooo00<00000
0?ooo`3oool0_@3oool004/0oooo00<000000?ooo`3oool0K`3oool40000oa40oooo1`000?l60?oo
o`03000000000?l0003o00H0003o3`3oool40000ogL0oooo00<000000?ooo`3oool0_@3oool004/0
oooo00D000000?ooo`3ooml0W4Qd0;ooo`120?ooo`0:0;md00000000001809cOo`3oool0oono07A8
W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool0703oool30000oa00oooo1@000?l:0?ooo`03
0000003oool0oooo0080oooo1@000?l?0?ooo`<0003o:03oool02P2oM00000000000B02Lgol0oooo
0?oo_`1dB9`0gooo0?ooo`2oM0020000000304RLg`3oool0oooo0400oooo00<0000009a8M02oool0
@`3oool02@3ooml0W4Qd0;ooo`3oool0oono07A8W03Oool0oooo0;md00020000000304RLg`3oool0
oooo03l0oooo00<0_g@00000000000000P0000000`18W=l0oooo0?ooo`0U0?ooo`00B`3oool01@00
0000oooo0?oog`2LB7@0_ooo0440oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`060?no
M018W=l0oooo0?ooo`3OW4P0M;oo7@3oool30000o`h0oooo1P000?l;0?ooo`<00000103oool40000
o`h0oooo10000?lV0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool01P3o_g@0B9cO0?oo
o`3oool0gia807Bood40oooo00<0000009a8M02oool0@`3oool00`3ooml0W4Qd0;ooo`040?ooo`06
0?noM018W=l0oooo0?ooo`3OW4P0M;oo@03oool00`3ooml0W4P007Boo`0Z0?ooo`00A03oool00`3o
_g@0000000000002000000070018W03Oool000000?ooo`3ooml0W4Qd0;ooo`0j0?ooo`030?noM000
000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0okmd04RL
g`3oool0703oool30000o`d0oooo1P000?l<0?ooo`030000003oool0oooo00D0oooo10000?l>0?oo
o`<0003o9P3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0okmd04RLg`3oool0@03o
ool00`000000W4Qd0;ooo`130?ooo`030?oog`2LB7@0_ooo00P0oooo00<0okmd04RLg`3oool0@@3o
ool00`2oM00007Bo0?ooo`0X0?ooo`00B`3oool01@000000oooo0?oog`2LB7@0_ooo0440oooo00H0
gia807Boo`3oool0oooO09a8M02oool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo703oool4
0000o``0oooo1@000?l>0?ooo`030000003oool0oooo00H0oooo10000?l=0?ooo`@0003o9@3oool0
1P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_om10?oo
o`030?oog`000000_ooo04<0oooo00<0oooO09a8M02oool0103oool01P3o_g@0001d0;ooo`3oool0
gia807Bood<0oooo00<0okmd001d_`3oool09`3oool004/0oooo00D0000009bL_`3ooml0W4Qd0;oo
o`110?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo
01d0oooo0`000?l=0?ooo`<0003o403oool00`000000oooo0?ooo`070?ooo`@0003o3@3oool30000
obD0oooo00H0gia804RLg`3oool0oono07@0M02oool30?ooo`050?oo_`1dB4P0B00000000000M;l0
@03oool01@3ooml0W9bo0?oog`000000_ooo0440oooo00D0oooO09bL_`3ooml0W4Qd0;ooo`040?oo
o`050?oo_`1dB4P0B00000000000M;l0A@3oool00`3OW4P0M;oo0?ooo`0V0?ooo`00B`3oool01@00
0000okmd0000000007@0_ooo0440oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`030?oo
g`2LB4P0W=oo01h0oooo10000?l<0?ooo`@0003o403oool00`000000oooo0?ooo`080?ooo`<0003o
3@3oool30000obD0oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo
04<0oooo00@0okmd000000000000_ooo@P3oool0103o_g@000000000M02oool40?ooo`030?oog`2L
B4P0W=oo04<0oooo00H0okmd001d_`3oool0oooo0;md001d_olW0?ooo`00B`3oool01@000000oooo
0?oo_`1d07@0_ooo0480oooo00@0_g@00000000004P0W=oo1@3oool01@2oM00000000000000004P0
W=oo01/0oooo0`000?l=0?ooo`<0003o4@3oool00`000000oooo0?ooo`080?ooo`@0003o303oool3
0000obH0oooo00@0_g@00000000004P0W=oo1@3oool01@2oM00000000000000004P0W=oo0440oooo
00<0oono0000002oool0@`3oool00`3ookl0M01d0;ooo`050?ooo`050;md0000000000000000B02L
gol0@03oool01P3ooml0W4P000000000000004RL0=ooobL0oooo001:0?ooo`030000003oool0oooo
06d0oooo10000?l<0?ooo`@0003o4@3oool00`000000oooo0?ooo`090?ooo`<0003o303oool30000
ogH0oooo00<000000?ooo`3oool0_03oool004X0oooo00<000000?ooo`3oool0K@3oool30000o`d0
oooo0`000?lB0?ooo`030000003oool0oooo00T0oooo10000?l;0?ooo`@0003oM@3oool00`000000
oooo0?ooo`2l0?ooo`00BP3oool00`000000oooo0?ooo`1]0?ooo`<0003o303oool40000oa80oooo
00<000000?ooo`3oool02P3oool30000o``0oooo0`000?me0?ooo`030000003oool0oooo0;`0oooo
001:0?ooo`030000003oool0oooo06d0oooo0`000?l<0?ooo`<0003o4`3oool00`000000oooo0?oo
o`0:0?ooo`<0003o303oool30000ogD0oooo00<000000?ooo`3oool0_03oool004X0oooo00<00000
0?ooo`3oool0K03oool40000o`/0oooo10000?lC0?ooo`030000003oool0oooo00X0oooo10000?l;
0?ooo`<0003oM@3oool00`000000oooo0?ooo`2l0?ooo`00BP3oool00`000000oooo0?ooo`1/0?oo
o`<0003o303oool30000oa@0oooo00<000000?ooo`3oool02P3oool40000o`/0oooo0`000?me0?oo
o`030000003oool0oooo0;`0oooo001:0?ooo`030000003oool0oooo06`0oooo0`000?l<0?ooo`<0
003o503oool00`000000oooo0?ooo`0:0?ooo`@0003o2`3oool30000ogD0oooo00<000000?ooo`3o
ool0_03oool004X0oooo00<000000?ooo`3oool0K03oool30000o``0oooo0`000?lD0?ooo`030000
003oool0oooo00X0oooo10000?l;0?ooo`<0003oM@3oool00`000000oooo0?ooo`2l0?ooo`00903o
oooo00000>H00000:@3oool002d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool30000o`D0oooo00<00000
0?ooo`3oool0103oool30000o`D0oooo00<000000?ooo`3oool0303oool2000000/0oooo0`000?l<
0?ooo`<0003o3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool09`3oool002d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103oool30000o`D0oooo00<000000?oo
o`3oool0103oool30000o`D0oooo00<000000?ooo`3oool0303oool2000000d0oooo00<000000?oo
o`3oool02P3oool30000o`d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo02L0oooo001:0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool08P3oool30000o``0oooo0`000?lD0?ooo`030000003oool0000001T0oooo0`000?l[0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo02L0oooo001:0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
8P3oool30000o``0oooo0`000?lD0?ooo`040000003oool0oooo000001L0oooo10000?l[0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo02L0oooo001:0?ooo`030000003oool0oooo06`0oooo0`000?l<0?ooo`<0003o
503oool01@000000oooo0?ooo`3oool0000001H0oooo0`000?mf0?ooo`030000003oool0oooo0;`0
oooo001:0?ooo`030000003oool0oooo06`0oooo0`000?l<0?ooo`<0003o503oool01@000000oooo
0?ooo`3oool0000001H0oooo0`000?mf0?ooo`030000003oool0oooo0;`0oooo001:0?ooo`030000
003oool0oooo06`0oooo0`000?l<0?ooo`<0003o503oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01<0oooo0`000?mf0?ooo`030000003oool0oooo0;`0oooo001:0?ooo`030000003o
ool0oooo06`0oooo0`000?l<0?ooo`<0003o503oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0140oooo10000?mf0?ooo`030000003oool0oooo0;`0oooo001:0?ooo`030000003oool0
oooo06`0oooo10000?l;0?ooo`<0003o503oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0140oooo0`000?mg0?ooo`030000003oool0oooo0;`0oooo001;0?ooo`030000003oool0oooo
06`0oooo0`000?l;0?ooo`@0003o4`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0100oooo0`000?mg0?ooo`030000003oool0oooo0;`0oooo001;0?ooo`030000003oool0oooo06`0
oooo0`000?l<0?ooo`<0003o4`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0
oooo10000?mg0?ooo`030000003oool0oooo0;`0oooo001;0?ooo`030000003oool0oooo06`0oooo
0`000?l<0?ooo`@0003o4P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo
10000?mh0?ooo`030000003oool0oooo0;`0oooo001;0?ooo`030000003oool0oooo06`0oooo1000
0?l<0?ooo`<0003o4P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo0`00
0?mi0?ooo`030000003oool0oooo0;`0oooo001;0?ooo`030000003oool0oooo06d0oooo0`000?l<
0?ooo`<0003o4P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo10000?mh
0?ooo`030000003oool0oooo0;d0oooo001;0?ooo`030000003oool0oooo06d0oooo10000?l;0?oo
o`@0003o4@3oool3000000P0oooo00<000000?ooo`3oool0203oool40000ogT0oooo00<000000?oo
o`3oool0_@3oool004/0oooo00<000000?ooo`3oool0KP3oool30000o``0oooo10000?l@0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool40000ogX0oooo00<000000?ooo`3o
ool0_@3oool004/0oooo00<000000?ooo`3oool0KP3oool30000o`d0oooo10000?l?0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool40000og/0oooo00<000000?ooo`3oool0
_@3oool004/0oooo00<000000?ooo`3oool0KP3oool30000o`h0oooo10000?l>0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00`3oool40000og`0oooo00<000000?ooo`3oool0_@3o
ool004/0oooo00<000000?ooo`3oool0KP3oool40000o`h0oooo10000?l=0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool01@000?mm0?ooo`030000003oool0oooo0;d0oooo001;0?oo
o`030000003oool0oooo06l0oooo10000?l>0?ooo`@0003o303oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0003o00@0003oOP3oool00`000000oooo0?ooo`2m0?ooo`00C03oool00`000000
oooo0?ooo`1_0?ooo`<0003o3`3oool50000o`X0oooo00<000000?ooo`3oool0303oool00`000000
003o0000o`020000ogl0oooo00<000000?ooo`3oool0_@3oool004`0oooo00<000000?ooo`3oool0
L03oool30000o`h0oooo1P000?l90?ooo`030000003oool0oooo00/0oooo0P000?l00`000000003o
0?ooo`1o0?ooo`030000003oool0oooo0;h0oooo001<0?ooo`030000003oool0oooo0700oooo1000
0?l?0?ooo`H0003o1`3oool00`000000oooo0?ooo`090?ooo`D0003o00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`2n0?ooo`00C03oool00`000000oooo0?ooo`1a0?ooo`<0003o4@3oool7
0000o`@0oooo00<000000?ooo`3oool01@3oool80000o`030?ooo`000000oooo07l0oooo00<00000
0?ooo`3oool0_P3oool004`0oooo00<000000?ooo`3oool0L@3oool40000oa40oooo2P000?l00`00
0000003o0000o`0<0000o`<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2n0?oo
o`00C@3oool00`000000oooo0?ooo`1a0?ooo`<0003o4`3oool80000o`03000000000?l0003o00X0
003o1P3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0;h0oooo001=0?ooo`030000
003oool0oooo0740oooo10000?lE0?ooo`D0003o00<000000000o`000?l01P000?l:0?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool0_P3oool004d0oooo00<000000?ooo`3oool0LP3o
ool40000oaT0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1k0?ooo`030000003o
ool0oooo0;h0oooo001=0?ooo`030000003oool0oooo07<0oooo10000?lH0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`2o0?ooo`00C@3oool00`00
0000oooo0?ooo`1d0?ooo`@0003o5`3oool3000001<0oooo00<000000?ooo`3oool0N03oool00`00
0000oooo0?ooo`2o0?ooo`00C@3oool00`000000oooo0?ooo`1d0?ooo`D0003o5P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0_`3oool004h0oooo
00<000000?ooo`3oool0M@3oool50000oa@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo001>0?ooo`030000003oool0oooo07H0oooo1P00
0?lB0?ooo`030000003oool0oooo01@0oooo00<0003o000000000?l0MP3oool00`000000oooo0?oo
o`300?ooo`00CP3oool00`000000oooo0?ooo`1g0?ooo`L0003o403oool00`000000oooo0?ooo`0C
0?ooo`80003o00<000000000o`3oool0M@3oool00`000000oooo0?ooo`300?ooo`00CP3oool00`00
0000oooo0?ooo`1i0?ooo`L0003o3P3oool00`000000oooo0?ooo`0B0?ooo`@0003o00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`300?ooo`00CP3oool00`000000oooo0?ooo`1k0?ooo`L0
003o303oool00`000000oooo0?ooo`0?0?ooo`H0003o0P3oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo0<00oooo001?0?ooo`030000003oool0oooo07`0oooo1`000?l:0?ooo`030000
003oool0oooo00/0oooo2@000?l40?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0
`03oool004l0oooo00<000000?ooo`3oool0OP3oool80000o`L0oooo00<000000?ooo`3oool02@3o
ool:0000o`D0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`310?ooo`00C`3oool0
0`000000oooo0?ooo`200?ooo`X0003o0`3oool00`000000oooo0?ooo`040?ooo`/0003o2P3oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<40oooo001?0?ooo`030000003oool0oooo
0880oooo2`000?l00`000000003o0000o`0<0000o`h0oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`310?ooo`00D03oool00`000000oooo0?ooo`240?ooo`P0003o00<000000000o`00
0?l02P000?l@0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0`@3oool00500oooo
00<000000?ooo`3oool0R03oool40000o`03000000000?l0003o00D0003o5P3oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo0<80oooo001@0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0<80oooo001A
0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo0<80oooo001A0?ooo`030000003oool0oooo08/0oooo0`00000M0?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool0``3oool00540oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3o
ool0``3oool00540oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool0a03oool00580oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0a03o
ool005<0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0a03oool005<0oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0a03oool005<0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool0a@3oool005<0oooo00<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0a@3oool005@0oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0a@3oool005@0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0aP3oool005D0oooo00<000000?oo
o`3oool0Q`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo05l0oooo00<000000?oo
o`3oool0aP3oool005D0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool0a`3oool005D0oooo00<000000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
b03oool005H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo05/0oooo00<000000?ooo`3oool0b03oool005H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0b03oool0
05L0oooo00<000000?ooo`3oool0Q@3oool3000002P0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`380?ooo`00E`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`390?ooo`00E`3oool00`000000oooo
0?ooo`250?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`390?ooo`00F03oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`3:0?ooo`00F03oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3;
0?ooo`00F@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`3;0?ooo`00F@3oool00`000000oooo0?ooo`230?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3;0?ooo`00
FP3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`3;0?ooo`00F`3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`3<0?ooo`00F`3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`3=0?ooo`00F`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0`0?ooo`030?noM0000000M;oo
09X0oooo001L0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo0340oooo00<0okmd0000001d_ol0VP3oool005`0oooo
00<000000?ooo`3oool0JP3oool02P2oM00000000000B02Lgol0oooo0?oo_`1dB9`0gooo0?ooo`2o
M0020000000304RLg`3oool0oooo00L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo0240oooo01@0omnL04P00000000007Ad07@00018W=l0omnL04P0
001d_ol0oooo0?noM00004P0W=oo0?ooo`3OW4P0001809cOo`3o_g@0000007AdM080000000L007Bo
0?ooo`3o_g@0001809cOo`3oool0okmd00<0000000@0M;oo0?ooo`3ogi`0B0000`0000000`00B9`0
gmnL04P00003000000070018W03Ogi`0B00000000000M7@0M00004RLg`0D0?ooo`0=0?oog`2LB000
000000000018W=l0oooo0?oOW0180000M;oo0?ooo`2oM000001d0;ooo`050?ooo`070?oo_`1d0000
B9cO0?ooo`2oM00004RL0=ooo`1=0?ooo`00G@3oool00`000000oooo0?ooo`1X0?ooo`060?noM000
B9`0gooo0?noM000B9`0gooo0`3oool01P3o_g@0B9cO0?ooo`3oool0gia807Boo`P0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0240oooo02H0_g@0
0000M02oool0gia80000001d_ol0omnL04P0001d_ol0oooo0?noM00004P0W=oo0?ooo`3OW4P00018
09cOo`3o_g@00000001d_`3oool0omnL04P0001d_ol0okmd0000B02Lgol0omnL04P00000M;l0oooo
0?noM00004P0W=oo0?ooo`2oM000001d0;ooo`<0oooo00<0_g@00000M02oool00P3oool01P2oM000
001d0;ooo`3OW4P0000007Boo`80oooo00<0okmd0000000000000`0000000`00B9`0gooo0?ooo`09
0?ooo`0=0=nLB00004P0W=oo0?noM0000000M;oo0?oOW0180000M;oo0?ooo`3OW4P0001d0;ooo`06
0?ooo`050?oOW01807@0_ooO09a8001d_ol0CP3oool005d0oooo00<000000?ooo`3oool0J03oool0
1P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0okmd04RLg`3oool01`3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool08P3oool07P3OW4P00018
09cOo`3ogi`0B00007Boo`3ogi`0B00007Boo`3oool0okmd0000B02Lgol0oooo0=nLB00004P0W=oo
0?noM0000000M;oo0?ooo`3ooml0W4P0001d_`3o_g@0001809cOo`3OW4P0001809cOo`D0oooo00<0
oono07@00018W=l00`3oool00`3ookl0M00004RLg`020?ooo`060=nLB00004P0W=oo0?oOW0180000
M;oo3@3oool00`3o_g@0000000000003000000070018W03Oool0oooo0?ooo`3ookl0M00004RLg`04
0?ooo`030?noM0000000M;oo00L0oooo00@0_g@007Boo`2oM4P0W=ooCP3oool005h0oooo00<00000
0?ooo`3oool0I`3oool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0
oooo0=nLB01d_ol80?ooo`@00000<P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
02<0oooo01/0omnL04P000000000000007Boo`3ogi`0B00007Boo`3oool0okmd0000001d_ol0oooo
0=nLB00004P0W=oo0?noM0000000M;oo0?ooo`3ooml0W4P0001d_`3o_g@0001809cOo`3OW4P01@00
00001P18W=l0oooo0?ooo`3OW4P0001809cOo`<0oooo00<0gia80000B02Lgol00P3oool01@3ogi`0
B000000000000000M;oo01L0oooo00<0omnL04P0001d_ol0103oool00`3ookl0M00004RLg`070?oo
o`040?noM000M;l0gia807Boodh0oooo001O0?ooo`030000003oool0oooo06H0oooo00H0gia804RL
g`3oool0oono07@0M02oool30?ooo`050?oo_`1dB4P0B00000000000M;l02@3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool08`3oool08P3o_g@004RL
0=ooo`3o_g@0000007Boo`3ogi`0B000001d_`3oool0gia800000018W=l0oooo0=nLB00007@0_ooo
0?noM000000007Bo0?ooo`3o_g@0000007Boo`3o_g@0001809cOo`3ogi`0B00007Boo`3oool0omnL
04P0001d_ol20?ooo`030?oog`2LB00007Bo00<0oooo00X0oooO09a80000M;l0oooo0?noM000B9`0
gooo0?noM0000000M;oo0P3oool00`3o_g@0000000000003000000030018W03Oool0oooo00/0oooo
00<0okmd0000M02oool01P3oool00`2oM000001d0;ooo`050?ooo`050;mdM02ookl0M4RL0=noM000
M;l0CP3oool005l0oooo00<000000?ooo`3oool0IP3oool01P3o_g@004RL0=ooo`3o_g@004RL0=oo
o`<0oooo00<0oooO09a8B02Lgol02`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool09@3oool0202oM000000000000000B9`0gooo0?oOW0180000M7Ad
0P0000002@00B9`0W7@0000000000000B9cO0?ooo`3o_g@0000007AdM00200000007001d_`3oool0
okmd0000B02Lgol0oooo0?noM0030000000404RLg`3oool0omnL04P00080000000@0001809cOo`3o
gi`0B0000P000000100004P0W=oo0?ooo`2oM002000000030018W03Oool0oooo01H0oooo00<0gia8
0000M02oool01@3oool00`3ogi`0B00004RLg`050?ooo`030?oo_`1d000000000080000000<0001d
0;ooo`3oool0B`3oool00600oooo00<000000?ooo`3oool0IP3oool0102oM00000000000B02Lgol5
0?ooo`050;md0000000000000000B02Lgol0203oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0K03oool01P3o_g@0000007Boo`3OW4P0001809cOo`H0
oooo00<0gia80000B02Lgol0E`3oool00640oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0?@3oool00`3o_g@00018
09cOo`0^0?ooo`040;md00000000000004RLg`@0oooo00<0gia80000000000000P0000000`18W=l0
oooo0?ooo`1E0?ooo`00H@3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3D0?ooo`00HP3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`3D0?ooo`00HP3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`3E0?ooo`00H`3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3E0?oo
o`00I03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`3F0?ooo`00I@3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3G0?ooo`00I@3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`3G0?ooo`00IP3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`3H0?ooo`00I`3oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`3I0?ooo`00I`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`3I0?ooo`00J03oool00`000000oooo
0?ooo`1d0?ooo`<00000?P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0=X0oooo
001Y0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo0=/0oooo001Z0?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0=/0oooo001[0?oo
o`030000003oool0oooo0740oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0=`0oooo001/0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0=d0oooo001/0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0=h0oooo001]0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0=l0oooo001^0?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0>00oooo001^0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo0>00oooo001_0?ooo`030000003oool0oooo06d0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0>40
oooo001`0?ooo`800000K@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0280oooo
0P00003T0?ooo`00LP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`3T0?ooo`00L`3oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3U
0?ooo`00L`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`3U0?ooo`00M03oool00`000000oooo0?ooo`1X0?ooo`<0
0000B03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0>H0oooo001e0?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0>L0oooo001f0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0>P0oooo001g0?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo0>T0oooo001h0?ooo`800000I@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0jP3oool007X0oooo00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0j`3oool007/0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0k03oool007/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0k@3oool007`0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0kP3oool007d0oooo0P00001P0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0303oool200000?40oooo001o0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?40oooo00200?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0?80oooo00210?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?<0oooo00220?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0?@0oooo00230?ooo`800000FP3oool00`000000oooo0?ooo`1B0?ooo`@0000000<0oooo0000
00000000m`3oool008D0oooo00<000000?ooo`3oool0E`3oool300000580oooo1@00003i0?ooo`00
QP3oool2000005L0oooo00<000000?ooo`3oool0D@3oool700000?P0oooo00280?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0D@3oool700000?P0oooo00290?ooo`800000E03oool0
0`000000oooo0?ooo`1A0?ooo`L00000n03oool008/0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`1@0?ooo`L00000n@3oool008`0oooo0P00001A0?ooo`030000003oool0oooo04l0
oooo00@000000?ooo`3oool0oooo0`00003j0?ooo`00SP3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo04d0oooo0P00003o0?ooo`80oooo002?0?ooo`800000CP3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0?l0oooo0P3oool00940oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`1:0?ooo`800000o`3oool50?ooo`00TP3oool2000004/0oooo00<00000
0?ooo`3oool0B03oool200000?l0oooo1`3oool009@0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo1`3oool009D0oooo0P0000180?ooo`03
0000003oool0oooo04D0oooo0P00003o0?ooo`X0oooo002G0?ooo`800000AP3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0?l0oooo2P3oool009T0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`120?ooo`800000o`3oool=0?ooo`00VP3oool400000440oooo00<00000
0?ooo`3oool0?`3oool300000?l0oooo3`3oool009h0oooo00<000000?ooo`3oool0?P3oool30000
03d0oooo0P00003o0?oooa80oooo002O0?ooo`800000?P3oool00`000000oooo0?ooo`0k0?ooo`80
0000o`3ooolD0?ooo`00X@3oool2000003`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`3o0?oooa@0oooo002S0?ooo`<00000>@3oool00`000000oooo0?ooo`0f0?ooo`@00000o`3o
oolG0?ooo`00YP3oool2000003L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o
0?oooaT0oooo002X0?ooo`<00000=03oool00`000000oooo0?ooo`0a0?ooo`@00000o`3ooolL0?oo
o`00Z`3oool200000380oooo00<000000?ooo`3oool0;`3oool200000?l0oooo803oool00:d0oooo
0`00000_0?ooo`030000003oool0oooo02`0oooo0`00003o0?ooob80oooo002`0?ooo`@00000:`3o
ool00`000000oooo0?ooo`0X0?ooo`@00000o`3ooolU0?ooo`00]03oool3000002P0oooo00<00000
0?ooo`3oool09@3oool300000?l0oooo:@3oool00;L0oooo1000000T0?ooo`030000003oool0oooo
0240oooo1000003o0?ooob`0oooo002k0?ooo`@00000803oool00`000000oooo0?ooo`0N0?ooo`<0
0000o`3oool`0?ooo`00_`3oool5000001/0oooo00<000000?ooo`3oool0603oool600000?l0oooo
<`3oool00<@0oooo1P0000090?ooo`030?oog`2LB7@0_ooo00T0oooo00<000000?ooo`3oool04`3o
ool500000?l0oooo>@3oool00<X0oooo2`0000000`2oool0oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo2`00003o0?oooch0oooo003C0?ooo`030?oog`2LB7@0000001@00000o`3ooom90?oo
o`00d`3oool00`3ooml0W4Qd0;ooo`090?ooo`030000003oool0oooo0?l0ooooD@3oool00=40oooo
00D0oooO09bL_`3ooml0W4Qd0;ooo`090?ooo`030000003oool0oooo0?l0ooooD@3oool00=80oooo
00@0okmd0000000007@0_ooo2@3oool00`000000oooo0?ooo`3o0?oooe40oooo003C0?ooo`030?oo
_`1d07@0_ooo00T0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?oo
o`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?oo
o`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000
003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool0
0`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0
oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo
003O0?ooo`<00000o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?oo
o`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00
g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3o
ool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oo
oe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0
o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0
oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool00`000000
oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo0`00
003o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?oo
o`3oool0o`3ooomA0?ooo`00g`3oool00`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000
003oool0oooo0?l0ooooD@3oool00=l0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00g`3oool0
0`000000oooo0?ooo`3o0?oooe40oooo003O0?ooo`030000003oool0oooo0?l0ooooD@3oool00=l0
oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00\
\>"],
  ImageRangeCache->{{{94.4375, 408.375}, {736.5, 527.563}} -> {-2.64446, \
5.10303, 0.00844286, 0.00844286}}],

Cell[TextData[{
  "In definitiva, la convenzione appena introdotta ci permette di associare \
ad un qualsiasi numero reale \[Alpha] un angolo orientato ossia un angolo con \
lato origine sul semiasse positivo delle ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " di un sistema cartesiano e la cui ampiezza \[EGrave] espressa da un \
valore positivo o negativo a seconda che si debba ruotare in verso antiorario \
o orario per raggiungere il secondo lato ruotando, se necessario, anche pi\
\[UGrave] volte attorno all'origine. In termini un po' pi\[UGrave] formali \
abbiamo stabilito la funzione"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Alpha] \[Element] \[DoubleStruckCapitalR]\ \
\[LongRightArrow]\ angolo\ orientato\)]]], "Theorem"],

Cell[TextData[{
  "Se al sistema cartesiano associamo pure una circonferenza ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " di raggio ",
  StyleBox["qualsiasi",
    FontSlant->"Italic"],
  " dato e di centro nell'origine, il secondo lato determina un punto ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " (ed uno solo) di intersezione con ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " cosicch\[EAcute] in corrispondenza di un valore reale di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " esiste un solo ",
  Cell[BoxData[
      \(TraditionalForm\`P \[Element] \[Gamma]\)]],
  ". La corrispondenza qualitativa precedente si specifica quindi in "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[Cell[TextData[Cell[BoxData[
          \(TraditionalForm\`\[Alpha] \[Element] \[DoubleStruckCapitalR]\ \
\[LongRightArrow]\ P \[Element] \[Gamma]\)]]]], TraditionalForm]]]], "Theorem"],

Cell[TextData[{
  "\[CapitalEGrave] immediato notare che tale funzione non pu\[OGrave] essere \
iniettiva: difatti \[EGrave] sufficiente riprendere il primo esempio (",
  ButtonBox["fig.1",
    ButtonData:>"figura1",
    ButtonStyle->"Hyperlink"],
  " e ",
  ButtonBox["fig. 2",
    ButtonData:>"figura2",
    ButtonStyle->"Hyperlink"],
  ") per vedere come al medesimo punto ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " (nelle figure evidenziato dal cerchietto nero) si possano associare gi\
\[AGrave] due valori distinti di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ". Difatti in generale, se ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " individua un determinato angolo e quindi un punto ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  ", viceversa questo stesso punto pu\[OGrave] essere individuato \
dall'insieme (numerabile) di valori ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] + 2  k\ \[Pi]\)]],
  " con ",
  Cell[BoxData[
      \(TraditionalForm\`k \[Element] \[DoubleStruckCapitalZ]\)]],
  ": ciascuno di questi valori differisce da ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " per un multiplo (positivo o negativo) di ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  ", multiplo che descrive il numero di rotazioni complete attorno \
all'origine necessarie per \"raggiungere\" ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] + 2  k\ \[Pi]\)]],
  " a partire dallo stesso ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Definizione della funzione seno di un angolo", "Section"],

Cell[TextData[{
  "Ad un sistema cartesiano isometrico ",
  Cell[BoxData[
      FormBox[
        StyleBox["Oxy",
          FontSlant->"Italic"], TraditionalForm]]],
  " associamo quindi una circonferenza ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " di raggio ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " assegnato e sia ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " l'ampiezza di un angolo qualsiasi (nelle figure verr\[AGrave] considerato \
",
  Cell[BoxData[
      \(TraditionalForm\`r = 1\)]],
  ": in tal caso la circonferenza viene identificata come la ",
  StyleBox["circonferenza goniometrica",
    FontSlant->"Italic"],
  "). Come detto, il secondo lato di tale angolo individua un punto ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " su ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  ": sia ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  " la proiezione sull'asse delle ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " di ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " quella sull'asse delle ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ".\nDefiniamo seno dell'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " il valore del rapporto"
}], "Text"],

Cell[TextData[{
  "Definizione del seno di un angolo \[Alpha]\n\n",
  Cell[BoxData[
      \(TraditionalForm\`sen(\[Alpha]) = QP\/OP\)]]
}], "Definition"],

Cell[TextData[{
  "dove ",
  Cell[BoxData[
      FormBox[
        StyleBox["QP",
          FontSlant->"Italic"], TraditionalForm]]],
  " (",
  ButtonBox["fig. 3",
    ButtonData:>"figura3",
    ButtonStyle->"Hyperlink"],
  ") rappresenta la misura del ",
  StyleBox["segmento orientato",
    FontSlant->"Italic"],
  " di estremi ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " ed \[EGrave] pari all'ordinata del punto ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " (o anche alla componente del vettore ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontWeight->"Bold"], TraditionalForm]]],
  " sull'asse ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "): ",
  Cell[BoxData[
      FormBox[
        StyleBox["QP",
          FontSlant->"Italic"], TraditionalForm]]],
  " rappresenta quindi un valore che appartiene all'intervallo ",
  Cell[BoxData[
      \(TraditionalForm\`\([\(-r\), r]\)\)]],
  ". ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontSlant->"Italic"], TraditionalForm]]],
  " \[EGrave] invece la lunghezza del segmento di estremi ",
  Cell[BoxData[
      \(TraditionalForm\`O\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " oppure il modulo del vettore ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontWeight->"Bold"], TraditionalForm]]],
  " (oppure, come detto, il raggio ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " della circonferenza ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " cui appartiene il punto ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  "). ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontSlant->"Italic"], TraditionalForm]]],
  " \[EGrave] espresso pertanto da un numero positivo (",
  Cell[BoxData[
      \(TraditionalForm\`r > 0\)]],
  ") ed al variare di ",
  Cell[BoxData[
      FormBox[
        StyleBox["P",
          FontSlant->"Italic"], TraditionalForm]]],
  " su ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " rimane costante."
}], "Text"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Alpha] = 50  Degree;\)\), "\n", 
    \(pP = {Cos[\[Alpha]], Sin[\[Alpha]]}; pQ = {Cos[\[Alpha]], 0}; 
    origine = {0, 0};\), "\n", 
    \(\(Show[
        Graphics[{Circle[{0, 0}, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
            Line[{{0, \(-1.2\)}, {0, 1.2}}], 
            Line[{pP, origine}]}], \[IndentingNewLine]Graphics[{colBlu, 
            Arrow[origine, pQ, stileVet], 
            Arrow[pQ, pP, 
              stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
              origine, {1, 1}, TextStyle \[Rule] stileTesto], 
            Text["\<Q\>", pQ, {0, 1}, TextStyle \[Rule] stileTesto], 
            Text["\<P\>", pP, {0, \(-1\)}, TextStyle \[Rule] stileTesto]}], 
        Prolog -> {{colGiallo, Polygon[{origine, pQ, pP}]}, {colRosso, 
              Disk[{0, 0},  .2, {0, \[Alpha]}]}}, 
        AspectRatio \[Rule] Automatic, Axes \[Rule] True];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 .5 m
.75507 .5 L
.75507 .80399 L
F
1 0 0 r
.5 .5 m
.5 .5 .07937 0 50 arc
F
0 g
.5 Mabswid
newpath
.5 .5 .39683 0 365.73 arc
s
.02381 .5 m
.97619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.75507 .80399 m
.5 .5 L
s
0 0 1 r
.5 .5 m
.75507 .5 L
s
% Start of user PostScript
0 0 0.642788 0 MAarrowhead1
% End of user PostScript
.75507 .5 m
.75507 .80399 L
s
% Start of user PostScript
0.642788 0 0.642788 0.766044 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 .5 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .5 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .80399 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002P0?ooo`03
0?noM000000000000080000000H004RL0=ooo`3oool0oooO09a8M02oool80?ooo`030000003oool0
oooo0;80oooo002S0?ooob400000Y03oool009`0oooo1`0000030?ooo`050?oog`2LW;l0oooO09a8
M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000W@3oool009L0oooo1@00000;0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool05@3oool5000009P0oooo002C0?ooo`@0
00004@3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo01X0oooo1000002D0?ooo`00
SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000008l0oooo002;0?ooo`<000009@3o
ool00`000000oooo0?ooo`0S0?ooo`<00000S03oool008L0oooo1000000X0?ooo`030000003oool0
oooo02H0oooo100000280?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0Q@3oool00880oooo1000000]0?ooo`030000003oool0oooo02/0
oooo100000230?ooo`00O`3oool300000340oooo00<000000?ooo`3oool0;`3oool300000800oooo
001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000OP3oool007X0oooo0`00000f
0?ooo`030000003oool0oooo03@0oooo0`00001k0?ooo`00N03oool2000003T0oooo00<000000?oo
o`3oool0=`3oool2000007T0oooo001g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1f0?ooo`00M03oool3000003`0oooo0P00000k0?ooo`<00000
M@3oool00780oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001c0?ooo`00L03oool2
00000440oooo00<000000?ooo`3oool0?`3oool200000740oooo001_0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`00K@3oool2000004@0
oooo00<000000?ooo`3oool0@P3oool2000006h0oooo001/0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`00J@3oool3000004L0oooo00<0
00000?ooo`3oool0A@3oool3000006X0oooo001W0?ooo`800000BP3oool00`000000oooo0?ooo`18
0?ooo`800000J03oool006H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo06D0oooo001T0?ooo`800000C@3oool00`000000oooo0?ooo`1;0?ooo`80
0000I@3oool006<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0680oooo001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3o
ool00600oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo05l0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool005d0
oooo00<000000?ooo`3oool0D`3oool2000005@0oooo00<000000?ooo`3oool0G03oool005`0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo
001K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1J0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0F@3oool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?oo
o`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0EP3oool005H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo05D0oooo001E0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0D`3oool005<0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0D03oool00500oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04l0oooo001?
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1>
0?ooo`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=0?oo
o`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0C03oool004`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo04/0oooo001;0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`1:0?ooo`00BP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0B@3oool004T0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo00180?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`170?ooo`00A`3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool004H0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo0015
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`14
0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0A03oool004@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo
0700oooo0P00001a0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?P3oool003h0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03d0oooo000n
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0m
0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0?03oool003`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0k0?ooo`00>`3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0>P3oool003X0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0i0?ooo`00>@3oool00`000000
oooo0?ooo`1S0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md00800000
00<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03P0oooo
000i0?ooo`030000003oool0oooo0680oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`06
0?noM018W=l0oooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo03P0oooo000h0?ooo`030000003oool0oooo05`0oooo00<0okmd0000000000000P0000002000
B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`050?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0>03oool003P0oooo00<000000?ooo`3oool0H`3o
ool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol6
0?ooo`<00000N03oool00`000000oooo0?ooo`0g0?ooo`00=`3oool00`000000oooo0?ooo`1T0?oo
o`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0f0?ooo`00=P3oool00`000000oooo0?oo
o`1U0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`090?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0
IP3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol01P3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0d0?ooo`00=03oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0=03oool003@0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo000c
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c
0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool0<P3oool003<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0b0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0`0?ooo`00<03oool00`000000
oooo0?ooo`200?ooo`800000P@3oool00`000000oooo0?ooo`0_0?ooo`00<03oool00`000000oooo
0?ooo`200?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;`3oool00300oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo02l0oooo000_
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0^
0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0;P3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0;@3oool002d0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0;03oool002`0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo
000/0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0[0?ooo`00:`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool2000008H0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo02X0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0Z0?ooo`00:P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo02T0oooo000Y0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0:03oool002T0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo
000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo02P0oooo000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`00
0000oooo0?ooo`290?ooo`800000RP3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool09P3oool002L0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo02H0oooo
000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0V0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0o0?ooo`0:0;md0000
0000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool0>`3oool2
000003l0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18
W=l0oooo0?ooo`0n0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000003oool0oooO09a8
M02oool0?P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo
0=nLB01d_oll0?ooo`030000003oool0oooo03d0oooo00H0okmd0018W03Oool0okmd0018W03Oool3
0?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo?`3oool00`000000W4Qd0;ooo`0T0?ooo`007P3o
ool00`3o_g@0000000000002000000070018W03Oool000000?ooo`3ooml0W4Qd0;ooo`0g0?ooo`03
0?noM000000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0
okmd04RLg`3oool0>`3oool00`000000oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0
_ooo1`3oool00`3o_g@0B9cO0?ooo`0=0?ooo`030?noM000M;l0oooo02h0oooo00<0000009a8M02o
ool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0n0?ooo`060=nLB01d_ol0oooo0?oo
g`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia807Booc80oooo00H0oono07@000000000
00000000M02oool40?ooo`030000003oool0oooo03d0oooo00H0gia807Boo`3oool0oooO09a8M02o
ool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo2@3oool00`3ookl0M0000000000200000003
0000M02oool0oooo02h0oooo00<0000009a8M02oool0903oool002D0oooo00D0000009bL_`3ooml0
W4Qd0;ooo`0n0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000
000007Bo0380oooo00P0oono07@00000B9`0gooo0?oog`2LB000001d0;ooo`<0oooo00<000000?oo
o`3oool0?@3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`<0oooo00D0oono07A8B01800000000
001d_`090?ooo`080?oo_`1d000004RL0=ooo`2oM00000000000B02Lgol]0?ooo`050?oog`2LW;l0
000009a8M02oool0903oool002D0oooo00D000000?noM0000000001d0;ooo`0n0?ooo`060?noM000
B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`0d0?ooo`030?noM00004P0W=oo0080
oooo00<0omnL04P0001d_ol00`3oool00`000000oooo0?ooo`0m0?ooo`060?noM000B9`0gooo0?no
M000B9`0gooo0`3oool00`3ooml0W4Q809cOo`0;0?ooo`080?noM00004P0W=oo0?oOW018B9`0gmnL
04P00018W=l^0?ooo`040?noM0000000001d0;ooob@0oooo000U0?ooo`050000003oool0oono07@0
M02oool0?`3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol0<@3o
ool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo00<000000?ooo`3oool0?P3o
ool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol0203oool00`3OW4P0
001d0;ooo`020?ooo`030?oo_`1d0000B9cO02l0oooo00<0000007@0M02oool0903oool002D0oooo
00<000000?ooo`3oool0P03oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<000000?ooo`3oool0E03oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO02l0oooo
00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0P03oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo00<0oooo00<000000?ooo`3oool0E03oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo02l0oooo00<000000?ooo`3oool0903oool002D0oooo00<00000
0?ooo`3oool0P03oool00`3ookl0M000001d_`020?ooo`030;md000007@0_ooo00<0oooo00<00000
0?ooo`3oool0E03oool0203ookl0M0000018W03Oool0oooo0;md0000B9`0gooo;`3oool00`000000
oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`210?ooo`060?oo_`1d0000000000000000
07@0_ooo103oool00`000000oooo0?ooo`1E0?ooo`060?oo_`1d0000000000000000B9`0gooo<03o
ool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo04h0oooo0P000?lk0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0CP3oool60000ocL0oooo00<000000?ooo`3oool0903oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`1?0?ooo`T0003o<`3oool00`000000
oooo0?ooo`0T0?ooo`00/`00001M0000oeP0000000080?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`8000006P3o000f0?oo00T0003o00<0
ool00000o`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01`3oool002D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`14
0?ooo`030000003oool0000001T0o`00=@3oo`060000o`D0ool000<0003o0?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`040000003oool0oooo
000001P0o`00=@3oo`020000o`T0ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T
0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`040000003oool0oooo000001P0o`00@03oo`00
0`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00D000000?ooo`3oool0oooo0000000G0?l00400ool000<0003o0?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
0080oooo00<000000?l0003o0000503o00100?oo00030000o`3oool0oooo02l0oooo00<000000?oo
o`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`030?ooo`03
0000003o0000o`0001<0o`00@03oo`000`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0103oool00`000000o`00
0?l0000B0?l00400ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3o
ool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00D0oooo00<000000?l0003o0000403o
00110?oo00030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0903oool002D0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`050?ooo`030000003o0000o`000100o`00@@3oo`00
0`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool01P3oool00`000000o`000?l0000?0?l00440ool000<0003o0?oo
o`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo00L0oooo00<000000?l0003o00003@3o00120?oo00030000o`3oool0oooo02l0
oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`080?ooo`030000003o0000o`0000`0o`00@P3oo`000`000?l0oooo0?ooo`0_0?ooo`030000
003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo0P00000:0?ooo`030000003o
0000o`0000X0o`00@`3oo`000`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U
0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool02P3oool00`000000o`000?l00008
0?l004@0ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o00001`3o00140?oo
00030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000H0o`00A@3oo`000`000?l0
oooo0?ooo`0^0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo
00<000000?ooo`3oool0303oool00`000000o`000?l000050?l004D0ool000<0003o0?ooo`3oool0
;P3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo00d0oooo00<000000?l0003o00000`3o00160?oo00030000o`3oool0oooo02h0oooo00<0
00000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0>
0?ooo`040000003o0000o`000?l004L0ool000<0003o0?ooo`3oool0;P3oool00`000000oooo0?oo
o`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00l0oooo00<00000
0?l0003oo`00A`3oo`000`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo02D0oooo000V0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0403oool00`000000ool00?oo00160?oo
00030000o`3oool0oooo02h0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0@0?ooo`030000003oo`00ool004H0ool000<0003o0?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo0140oooo00<000000?oo003oo`00A@3oo`000`000?l0oooo0?ooo`0]0?ooo`030000
003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool04P3o
ool00`000000ool00?oo00140?oo00030000o`3oool0oooo02d0oooo00<000000?ooo`3oool09P3o
ool002L0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0C0?ooo`030000003oo`00
ool004<0ool000<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo01@0oooo00<000000?oo003oo`00@P3oo`000`00
0?l0oooo0?ooo`0]0?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo08T0
oooo0P00000F0?ooo`030000003oo`00ool00440ool000<0003o0?ooo`3oool0;@3oool00`000000
oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo01D0oooo
00<000000?oo003oo`00@@3oo`000`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo02L0oooo
000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool05P3oool00`000000ool00?oo
00100?oo00030000o`3oool0oooo02`0oooo00<000000?ooo`3oool09`3oool002P0oooo00<00000
0?ooo`3oool0R03oool00`000000oooo0?ooo`0G0?ooo`030000003oo`00ool003l0ool000<0003o
0?ooo`3oool0;03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo01P0oooo00<000000?oo003oo`00?P3oo`000`000?l0oooo0?ooo`0/0?oo
o`030000003oool0oooo02L0oooo000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool06@3oool00`000000ool00?oo000m0?oo00030000o`3oool0oooo02/0oooo00<000000?ooo`3o
ool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oo`00ool003`0ool000<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0X0?ooo`00:@3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo01/0oooo00<000000?oo003oo`00>`3o
o`000`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool06`3oool00`000000ool00?oo000k0?oo00030000o`3oool0
oooo02/0oooo00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oo`00ool003X0ool000<0003o0?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo01d0
oooo00<000000?oo003oo`00>@3oo`000`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0
oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07P3oool00`000000ool0
0?oo000h0?oo00030000o`3oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`030000003oo`00ool003L0ool000<0
003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0200oooo00<000000?oo003oo`00=P3oo`000`000?l0oooo0?ooo`0Y
0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool0803oool00`000000ool00?oo000f0?oo00030000o`3oool0oooo02T0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool200000280oooo00<000000?oo003o
o`00=@3oo`000`000?l0oooo0?ooo`0Y0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool08P3oool00`000000ool00?oo000d0?oo00030000
o`3oool0oooo02T0oooo00<000000?ooo`3oool0:P3oool002`0oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`0S0?ooo`030000003oo`00ool003<0ool000<0003o0?ooo`3oool0:03o
ool00`000000oooo0?ooo`0[0?ooo`00;03oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo02@0oooo00<000000?oo003oo`00<P3oo`000`000?l0oooo0?ooo`0W0?ooo`030000003oool0
oooo02`0oooo000]0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool09@3oool00`00
0000ool00?oo000a0?oo00030000o`3oool0oooo02L0oooo00<000000?ooo`3oool0;03oool002d0
oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0V0?ooo`030000003oo`00ool00300
ool000<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000oooo
0?ooo`230?ooo`030000003oool0oooo02H0oooo00<000000?oo003oo`00<03oo`000`000?l0oooo
0?ooo`0W0?ooo`030000003oool0oooo02`0oooo000^0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool09`3oool00`000000ool00?oo000_0?oo00030000o`3oool0oooo02H0oooo00<0
00000?ooo`3oool0;@3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0X
0?ooo`030000003oo`00ool002h0ool000<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`0]
0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo02T0oooo00<000000?oo
003oo`00;@3oo`000`000?l0oooo0?ooo`0V0?ooo`030000003oool0oooo02d0oooo000^0?ooo`03
0000003oool0oooo0880oooo00<000000?ooo`3oool0:P3oool00`000000ool00?oo000/0?oo0003
0000o`3oool0oooo02D0oooo00<000000?ooo`3oool0;P3oool002l0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`0[0?ooo`030000003oo`00ool002/0ool000<0003o0?ooo`3oool0
9@3oool00`000000oooo0?ooo`0^0?ooo`00<03oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo02/0oooo00<000000?oo003oo`00:`3oo`000`000?l0oooo0?ooo`0T0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;03oool0
0`000000ool00?oo000Z0?oo00030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0;`3oool0
0300oooo00<000000?ooo`3oool0P03oool2000002h0oooo00<000000?oo003oo`00:@3oo`000`00
0?l0oooo0?ooo`0T0?ooo`030000003oool0oooo02l0oooo000`0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool0;P3oool00`000000ool00?oo000X0?oo00030000o`3oool0oooo02<0
oooo00<000000?ooo`3oool0<03oool00340oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`0_0?ooo`030000003oo`00ool002L0ool000<0003o0?ooo`3oool08`3oool00`000000oooo
0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0300oooo00<0
00000?oo003oo`009P3oo`000`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo0340oooo000b
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0<03oool00`000000ool00?oo000V
0?oo00030000o`3oool0oooo0240oooo00<000000?ooo`3oool0<P3oool003<0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`030000003oo`00ool002D0ool000<0003o0?oo
o`3oool08@3oool00`000000oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo00<000000?oo003oo`00903oo`000`000?l0oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0380oooo000c0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
<`3oool00`000000ool00?oo000S0?oo00030000o`3oool0oooo0200oooo00<000000?ooo`3oool0
<`3oool003@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0d0?ooo`030000003o
o`00ool00280ool000<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0c0?ooo`00=03oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo00<000000?oo003oo`008@3oo`00
0`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo000e0?ooo`030000003oool0oooo
07/0oooo00<000000?ooo`3oool0=P3oool00`000000ool00?oo000P0?oo00030000o`3oool0oooo
01l0oooo00<000000?ooo`3oool0=03oool003H0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`0f0?ooo`030000003oo`00ool00200ool000<0003o0?ooo`3oool07P3oool00`000000
oooo0?ooo`0e0?ooo`00=P3oool00`000000oooo0?ooo`1V0?ooo`0:0;md00000000001809cOo`3o
ool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oo`00ool001l0ool000<0003o0?ooo`3oool07@3oool00`000000oooo0?oo
o`0f0?ooo`00=`3oool00`000000oooo0?ooo`1T0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo
0`3oool01P3o_g@0B9cO0?ooo`3oool0gia807Boo`H0oooo00<000000?ooo`3oool0>03oool00`00
0000ool00?oo000N0?oo00030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0=P3oool003P0
oooo00<000000?ooo`3oool0H`3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0okmd
04RLg`3oool01@3oool3000003T0oooo00<000000?oo003oo`007@3oo`000`000?l0oooo0?ooo`0L
0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo06<0oooo00H0gia807Bo
o`3oool0oooO09a8M02oool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo1P3oool00`000000
oooo0?ooo`0j0?ooo`030000003oo`00ool001`0ool000<0003o0?ooo`3oool06`3oool00`000000
oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`1R0?ooo`060=nLB018W=l0oooo0?oo_`1d
07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo00<000000?ooo`3oool0>`3oool0
0`000000ool00?oo000K0?oo00030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0>03oool0
03T0oooo00<000000?ooo`3oool0HP3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0
oooO09a8B02Lgol02@3oool00`000000oooo0?ooo`0k0?ooo`030000003oo`00ool001/0ool000<0
003o0?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`1R
0?ooo`040;md00000000001809cOo`D0oooo00D0_g@0000000000000001809cOo`060?ooo`030000
003oool0oooo03`0oooo00<000000?oo003oo`006P3oo`000`000?l0oooo0?ooo`0J0?ooo`030000
003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0?@3o
ool00`000000ool00?oo000I0?oo00030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0>@3o
ool003/0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0n0?ooo`030000003oo`00
ool001P0ool000<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo03l0oooo00<000000?oo003oo`005`3oo`000`00
0?l0oooo0?ooo`0H0?ooo`030000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool0@03oool00`000000ool00?oo000F0?oo00030000o`3oool0oooo01P0
oooo00<000000?ooo`3oool0>`3oool003d0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`110?ooo`030000003oo`00ool001D0ool000<0003o0?ooo`3oool05`3oool00`000000oooo
0?ooo`0l0?ooo`00?P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0440oooo00<0
00000?oo003oo`005@3oo`000`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo03d0oooo000n
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0@P3oool00`000000ool00?oo000D
0?oo00030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0?@3oool003l0oooo00<000000?oo
o`3oool0L@3oool00`000000oooo0?ooo`130?ooo`030000003oo`00ool001<0ool000<0003o0?oo
o`3oool05@3oool00`000000oooo0?ooo`0n0?ooo`00@03oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo04@0oooo00<000000?oo003oo`004P3oo`000`000?l0oooo0?ooo`0D0?ooo`03
0000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700oooo0P0000160?ooo`030000
003oo`00ool00140ool000<0003o0?ooo`3oool0503oool00`000000oooo0?ooo`0o0?ooo`00@@3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo04H0oooo00<000000?oo003oo`00403o
o`000`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo0400oooo00120?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0AP3oool00`000000ool00?oo000@0?oo00030000o`3oool0
oooo0180oooo00<000000?ooo`3oool0@@3oool004<0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`170?ooo`030000003oo`00ool000l0ool000<0003o0?ooo`3oool04@3oool00`00
0000oooo0?ooo`120?ooo`00A03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo04P0
oooo00<000000?oo003oo`003P3oo`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo04<0
oooo00150?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0B@3oool00`000000ool0
0?oo000=0?oo00030000o`3oool0oooo00l0oooo00<000000?ooo`3oool0A03oool004D0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`1:0?ooo`030000003oo`00ool000`0ool000<0
003o0?ooo`3oool03`3oool00`000000oooo0?ooo`140?ooo`00AP3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo04/0oooo00<000000?oo003oo`002`3oo`000`000?l0oooo0?ooo`0>
0?ooo`030000003oool0oooo04D0oooo00170?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0B`3oool00`000000ool00?oo000;0?oo00030000o`3oool0oooo00d0oooo00<000000?oo
o`3oool0AP3oool004P0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1<0?ooo`03
0000003oo`00ool000X0ool000<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`170?ooo`00
B@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04d0oooo00<000000?oo003oo`00
2@3oo`000`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo04P0oooo001:0?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool0CP3oool00`000000ool00?oo00080?oo00030000o`3o
ool0oooo00X0oooo00<000000?ooo`3oool0B@3oool004/0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oo`00ool000L0ool000<0003o0?ooo`3oool02@3oool0
0`000000oooo0?ooo`1:0?ooo`00C03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
0500oooo00<000000?oo003oo`000`3oo`020000o`040?oo00000?l0oooo0000o`P0oooo00<00000
0?ooo`3oool0B`3oool004d0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1A0?oo
o`030000003oo`00ool00080ool01P000?l70?ooo`030000003oool0oooo04`0oooo001>0?ooo`03
0000003oool0oooo0680oooo0P00001B0?ooo`030000003oo`00ool000<0ool01@000?l60?ooo`03
0000003oool0oooo04d0oooo001?0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
DP3oool00`000000ool00?oo00020?oo00@0003o1P3oool00`000000oooo0?ooo`1>0?ooo`00D03o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo05<0oooo00@000000?oo003oo`00ool0
10000?l50?ooo`030000003oool0oooo04l0oooo001A0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0E03oool00`000000ool00?oo00040000o`@0oooo00<000000?ooo`3oool0D03o
ool00580oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1E0?ooo`030000003oo`00
ool000<0003o0`3oool00`000000oooo0?ooo`1A0?ooo`00D`3oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo05H0oooo00<000000?oo00000?l00P000?l20?ooo`030000003oool0oooo
0580oooo001D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0EP3oool00`000000
ool00000o`020000o`030?ooo`000000oooo05@0oooo001E0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0E`3oool01@000000003o0000o`3oool0000005H0oooo001F0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0F03oool00`000000003o0000001G0?ooo`00E`3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<0003o0?ooo`3oool0EP3o
ool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?ooo`00FP3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0F@3oool005/0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05X0
oooo001L0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`1K0?ooo`00G@3oool00`000000oooo0?ooo`1C0?ooo`800000E03oool01@000000oooo0?oo
_`1d0000B9cO05X0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`8000000P3o
ool00`3ookl0M00004RLg`1J0?ooo`00H03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool00P3oool00`3ookl0M00004RLg`1J0?ooo`00H@3oool20000
0500oooo00<000000?ooo`3oool0CP3oool2000000D0oooo00<0oono07@0000000000P0000000`00
M;l0oooo0?ooo`1E0?ooo`00H`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool01@3oool01`3ookl0M00004RLg`3oool0omnL04P00018W=l0EP3oool0
06@0oooo0P00001=0?ooo`030000003oool0oooo04/0oooo0P0000080?ooo`070?oo_`1d0000B9cO
0?ooo`3ookl0M000001d_`1F0?ooo`00IP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0203oool01`3ookl0M00004RLg`3oool0omnL04P00018W=l0
EP3oool006L0oooo0P00001:0?ooo`030000003oool0oooo04P0oooo0P00000;0?ooo`030?oo_`1d
000000000080000000<004RL0=ooo`3oool0E@3oool006T0oooo0P0000180?ooo`030000003oool0
oooo04H0oooo0P00001Z0?ooo`00J`3oool2000004H0oooo00<000000?ooo`3oool0A03oool20000
06`0oooo001]0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`1/0?ooo`00KP3oool2000004<0oooo00<000000?ooo`3oool0@@3oool2000006l0oooo
001`0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`1_0?ooo`00L@3oool200000400oooo00<000000?ooo`3oool0?P3oool200000780oooo001c0?oo
o`<00000?@3oool2000003`0oooo0`00001d0?ooo`00MP3oool2000003/0oooo00<000000?ooo`3o
ool0>@3oool2000007L0oooo001h0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`1g0?ooo`00N@3oool4000003H0oooo00<000000?ooo`3oool0=03o
ool4000007X0oooo001m0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`1l0?ooo`00OP3oool400000340oooo00<000000?ooo`3oool0;`3oool40000
07l0oooo00220?ooo`<00000;P3oool00`000000oooo0?ooo`0/0?ooo`<00000P`3oool008D0oooo
0P00000/0?ooo`030000003oool0oooo02X0oooo0P0000260?ooo`00Q`3oool3000002T0oooo00<0
00000?ooo`3oool09`3oool3000008P0oooo002:0?ooo`<000009P3oool00`000000oooo0?ooo`0T
0?ooo`<00000R`3oool008d0oooo1P00000P0?ooo`030000003oool0oooo01h0oooo1P00002>0?oo
o`00T`3oool3000001d0oooo00<000000?ooo`3oool06`3oool3000009@0oooo002F0?ooo`D00000
3@3oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo01H0oooo1@00002G0?ooo`00V`3o
ool7000000H0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`0?0?ooo`L00000W03o
ool00:80oooo8`00002S0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo
0;80oooo002V0?ooo`050?oog`2LW;l0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b0?oo
o`00Y`3oool0103o_g@000000000M02oool80?ooo`030000003oool0oooo0;80oooo002X0?ooo`03
0?oo_`1d07@0_ooo00P0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo
00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`00
0000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo0000\
\>"],
  ImageRangeCache->{{{130.125, 330.688}, {301.5, 100.938}} -> {-2.89501, \
0.00824565, 0.00879536, 0.00879536}},
  CellTags->"figura3"]
}, Closed]],

Cell[CellGroupData[{

Cell["Variazione della funzione seno", "Subsection"],

Cell[TextData[{
  "Per come abbiamo esteso l'insieme delle ampiezze di un angolo riusciamo ad \
associare ad ogni valore reale ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " un punto ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " sulla circonferenza e quindi siamo pure in grado di calcolare il rapporto \
tra ",
  Cell[BoxData[
      FormBox[
        StyleBox["QP",
          FontSlant->"Italic"], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontSlant->"Italic"], TraditionalForm]]],
  " ossia il valore di ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\[Alpha])\)]],
  ". In tal modo disponiamo di una funzione che associa ad ogni ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " reale il valore ",
  Cell[BoxData[
      \(TraditionalForm\`y = sen(\[Alpha])\)]],
  ". "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[Cell[TextData[Cell[BoxData[
          \(TraditionalForm\`\[Alpha] \[Element] \[DoubleStruckCapitalR]\ \
\[LongRightArrow]\ y = sen(\[Alpha])\)]]]], TraditionalForm]]]], "Theorem"],

Cell[TextData[{
  "Ci chiediamo ora quale siano le caratteristiche di tale funzione, in \
particolare il suo grafico e il suo codominio. Faremo pertanto variare ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " su un insieme di valori reali ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, 2  \[Pi]]\)\)]],
  " analizzando, dapprima qualitativamente, le variazioni del segmento \
orientato ",
  Cell[BoxData[
      FormBox[
        StyleBox["QP",
          FontSlant->"Italic"], TraditionalForm]]],
  " e del suo rapporto con ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontSlant->"Italic"], TraditionalForm]]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(origine = {0, 0};\)\), "\[IndentingNewLine]", 
    \(\(\(Show[
            Graphics[{Circle[{0, 0}, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
                Line[{{0, \(-1.2\)}, {0, 1.2}}], 
                Line[{{Cos[#], Sin[#]}, 
                    origine}]}], \[IndentingNewLine]Graphics[{colBlu, 
                Arrow[origine, {Cos[#], 0}, stileVet], 
                Arrow[{Cos[#], 0}, {Cos[#], Sin[#]}, 
                  stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
                  origine, {1, 1}, TextStyle -> stileTesto], 
                Text["\<Q\>", {Cos[#], 0}, {0, 1}, TextStyle -> stileTesto], 
                Text["\<P\>", {Cos[#], Sin[#]}, {0, \(-1\)}, 
                  TextStyle -> stileTesto]}], 
            Prolog -> {{colGiallo, 
                  Polygon[{origine, {Cos[#], 0}, {Cos[#], 
                        Sin[#]}}]}, {colRosso, Disk[{0, 0},  .2, {0, #}]}}, 
            AspectRatio \[Rule] Automatic, Axes \[Rule] True, 
            PlotRange \[Rule] {{\(-1.26\), 2.2}, {\(-1.26\), 1.26}}, 
            Epilog \[Rule] {{Text["\<sen(\>" <> ToString[#] <> "\< ) = \>" <> 
                      ToString[N[Sin[#]]], {1.1, 0.5}, {\(-1\), 0}, 
                    TextStyle -> stileTesto]}}, 
            ImageSize \[Rule] {400, 300}] &\) /@ 
        Table[\[Alpha], {\[Alpha], 0, 360\ Degree, 
            10  Degree}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .72832 
%%ImageSize: 400 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.364162 0.289017 0.364162 0.289017 [
[.07514 .35166 -6.96875 -10.9375 ]
[.07514 .35166 6.96875 0 ]
[.21965 .35166 -10.3125 -10.9375 ]
[.21965 .35166 10.3125 0 ]
[.50867 .35166 -7.5625 -10.9375 ]
[.50867 .35166 7.5625 0 ]
[.65318 .35166 -4.21875 -10.9375 ]
[.65318 .35166 4.21875 0 ]
[.79769 .35166 -7.5625 -10.9375 ]
[.79769 .35166 7.5625 0 ]
[.9422 .35166 -4.21875 -10.9375 ]
[.9422 .35166 4.21875 0 ]
[.35166 .07514 -13.9375 -5.46875 ]
[.35166 .07514 0 5.46875 ]
[.35166 .21965 -20.625 -5.46875 ]
[.35166 .21965 0 5.46875 ]
[.35166 .50867 -15.125 -5.46875 ]
[.35166 .50867 0 5.46875 ]
[.35166 .65318 -8.4375 -5.46875 ]
[.35166 .65318 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .72832 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07514 .36416 m
.07514 .37041 L
s
gsave
.07514 .35166 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.21965 .36416 m
.21965 .37041 L
s
gsave
.21965 .35166 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.50867 .36416 m
.50867 .37041 L
s
gsave
.50867 .35166 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.65318 .36416 m
.65318 .37041 L
s
gsave
.65318 .35166 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.79769 .36416 m
.79769 .37041 L
s
gsave
.79769 .35166 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.9422 .36416 m
.9422 .37041 L
s
gsave
.9422 .35166 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.10405 .36416 m
.10405 .36791 L
s
.13295 .36416 m
.13295 .36791 L
s
.16185 .36416 m
.16185 .36791 L
s
.19075 .36416 m
.19075 .36791 L
s
.24855 .36416 m
.24855 .36791 L
s
.27746 .36416 m
.27746 .36791 L
s
.30636 .36416 m
.30636 .36791 L
s
.33526 .36416 m
.33526 .36791 L
s
.39306 .36416 m
.39306 .36791 L
s
.42197 .36416 m
.42197 .36791 L
s
.45087 .36416 m
.45087 .36791 L
s
.47977 .36416 m
.47977 .36791 L
s
.53757 .36416 m
.53757 .36791 L
s
.56647 .36416 m
.56647 .36791 L
s
.59538 .36416 m
.59538 .36791 L
s
.62428 .36416 m
.62428 .36791 L
s
.68208 .36416 m
.68208 .36791 L
s
.71098 .36416 m
.71098 .36791 L
s
.73988 .36416 m
.73988 .36791 L
s
.76879 .36416 m
.76879 .36791 L
s
.82659 .36416 m
.82659 .36791 L
s
.85549 .36416 m
.85549 .36791 L
s
.88439 .36416 m
.88439 .36791 L
s
.91329 .36416 m
.91329 .36791 L
s
.04624 .36416 m
.04624 .36791 L
s
.01734 .36416 m
.01734 .36791 L
s
.9711 .36416 m
.9711 .36791 L
s
1 .36416 m
1 .36791 L
s
.25 Mabswid
0 .36416 m
1 .36416 L
s
.36416 .07514 m
.37041 .07514 L
s
gsave
.35166 .07514 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.36416 .21965 m
.37041 .21965 L
s
gsave
.35166 .21965 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36416 .50867 m
.37041 .50867 L
s
gsave
.35166 .50867 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.36416 .65318 m
.37041 .65318 L
s
gsave
.35166 .65318 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.36416 .10405 m
.36791 .10405 L
s
.36416 .13295 m
.36791 .13295 L
s
.36416 .16185 m
.36791 .16185 L
s
.36416 .19075 m
.36791 .19075 L
s
.36416 .24855 m
.36791 .24855 L
s
.36416 .27746 m
.36791 .27746 L
s
.36416 .30636 m
.36791 .30636 L
s
.36416 .33526 m
.36791 .33526 L
s
.36416 .39306 m
.36791 .39306 L
s
.36416 .42197 m
.36791 .42197 L
s
.36416 .45087 m
.36791 .45087 L
s
.36416 .47977 m
.36791 .47977 L
s
.36416 .53757 m
.36791 .53757 L
s
.36416 .56647 m
.36791 .56647 L
s
.36416 .59538 m
.36791 .59538 L
s
.36416 .62428 m
.36791 .62428 L
s
.36416 .04624 m
.36791 .04624 L
s
.36416 .01734 m
.36791 .01734 L
s
.36416 .68208 m
.36791 .68208 L
s
.36416 .71098 m
.36791 .71098 L
s
.25 Mabswid
.36416 0 m
.36416 .72832 L
s
0 0 m
1 0 L
1 .72832 L
0 .72832 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.36416 .36416 m
.11387 .36416 L
.11387 .50867 L
F
1 0 0 r
.36416 .36416 m
.36416 .36416 .0578 0 150 arc
F
0 g
.5 Mabswid
newpath
.36416 .36416 .28902 0 365.73 arc
s
.01734 .36416 m
.71098 .36416 L
s
.36416 .01734 m
.36416 .71098 L
s
.11387 .50867 m
.36416 .36416 L
s
0 0 1 r
.36416 .36416 m
.11387 .36416 L
s
% Start of user PostScript
0 0 -0.866025 0 MAarrowhead1
% End of user PostScript
.11387 .36416 m
.11387 .50867 L
s
% Start of user PostScript
-0.866025 0 -0.866025 0.5 MAarrowhead1
% End of user PostScript
0 g
gsave
.36416 .36416 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.11387 .36416 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.11387 .50867 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.68208 .50867 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sen) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.500 13.375 moveto
(H) show
81.625 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
99.125 13.375 moveto
(Degree) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
132.000 13.375 moveto
(L) show
137.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
146.250 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
158.750 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 300},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001Mb000`400?l00000o`00003oo`3ooooe
0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe0?ooo`00o`3ooooe
0?ooo`00]@3oool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0
oooo?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?oo
o`3o0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0oooo?@3oool00;D0oooo00<000000?oo
o`3oool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000
003oool0oooo0?l0oooo?@3oool00;D0oooo0`00003o0?ooocd0oooo002e0?ooo`030000003oool0
oooo0?l0oooo?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3oool00`000000
oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0oooo?@3oool00;D0oooo00<0
00000?ooo`3oool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?oo
o`030000003oool0oooo0?l0oooo?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00
]@3oool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0oooo?@3o
ool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?ooo`3o0?oo
ocd0oooo002e0?ooo`030000003oool0oooo0?l0oooo?@3oool00;D0oooo00<000000?ooo`3oool0
o`3ooolm0?ooo`00]@3oool300000?l0oooo?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm
0?ooo`00]@3oool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0
oooo?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?oo
o`3o0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0oooo?@3oool00;D0oooo00<000000?oo
o`3oool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000
003oool0oooo0?l0oooo?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3oool0
0`000000oooo0?ooo`3o0?ooocd0oooo002Y0?ooo`030?oog`2LB7@0_ooo00T0oooo00<000000?oo
o`3oool0o`3ooolm0?ooo`00Z@3oool00`3ooml0W4Qd0;ooo`090?ooo`030000003oool0oooo0?l0
oooo?@3oool00:00oooo00<0okmd0000000000000P0000001`00B9`0gooo0?ooo`3oool0oooO09a8
M02oool00P3oool?00000?l0oooo>03oool00:<0oooo2`0000070?ooo`030000003oool0oooo00D0
oooo2`00003o0?ooobd0oooo002L0?ooo`L00000103oool01@3ooml0W9bo0?oog`2LB7@0_ooo00T0
oooo00<000000?ooo`3oool0403oool700000?l0oooo9P3oool009L0oooo1@00000<0?ooo`040?no
M0000000001d0;ooo`T0oooo00<000000?ooo`3oool05`3oool400000?l0oooo8P3oool009<0oooo
1000000B0?ooo`030?oo_`1d07@0_ooo00T0oooo00<000000?ooo`3oool06`3oool500000?l0oooo
7@3oool00900oooo0`00000R0?ooo`030000003oool0oooo0200oooo1000003o0?oooaT0oooo002<
0?ooo`@000009@3oool00`000000oooo0?ooo`0T0?ooo`<00000o`3ooolF0?ooo`00R@3oool30000
02T0oooo00<000000?ooo`3oool09`3oool300000?l0oooo4`3oool008H0oooo0`00000/0?ooo`03
0000003oool0oooo02X0oooo1000003o0?ooo`l0oooo00240?ooo`800000;`3oool00`000000oooo
0?ooo`0^0?ooo`800000o`3oool=0?ooo`00P@3oool300000340oooo00<000000?ooo`3oool0<03o
ool300000?l0oooo2P3oool007l0oooo0P00000d0?ooo`030000003oool0oooo03<0oooo0P00003o
0?ooo`P0oooo001l0?ooo`<00000=P3oool00`000000oooo0?ooo`0e0?ooo`<00000o`3oool50?oo
o`00NP3oool2000003T0oooo00<000000?ooo`3oool0>03oool200000?l0oooo0`3oool007P0oooo
0P00000k0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0o`3oool007D0oooo0`00
000m0?ooo`<00000>`3oool300000?h0oooo001c0?ooo`800000@03oool00`000000oooo0?ooo`0n
0?ooo`800000o03oool00780oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`100?oo
o`800000nP3oool00700oooo0P0000130?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool0m`3oool006l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`800000
m`3oool006`0oooo0`0000160?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0m03o
ool006X0oooo0P0000190?ooo`030000003oool0oooo04H0oooo0`00003c0?ooo`00J@3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo0P00003a0?ooo`00I`3oool2000004`0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`3^0?ooo`00I@3oool2000004h0oooo
00<000000?ooo`3oool0C03oool200000>h0oooo001T0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`3[0?ooo`00HP3oool200000540oooo00<00000
0?ooo`3oool0C`3oool200000>/0oooo001Q0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`3X0?ooo`00H03oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool0i`3oool005l0oooo00<000000?ooo`3oool0
D`3oool3000005<0oooo00<000000?ooo`3oool0iP3oool005h0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0>D0oooo001L0?ooo`800000E`3oool0
0`000000oooo0?ooo`1E0?ooo`800000i@3oool005/0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo0>80oooo001J0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0F03oool200000>80oooo001I0?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`3O0?ooo`00E`3oool2000005`0oooo00<0
00000?ooo`3oool0F`3oool200000=l0oooo001F0?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool0G@3oool00`000000oooo0?ooo`3L0?ooo`00E@3oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool0f`3oool005@0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0=/0oooo001C0?ooo`030000
003oool0oooo05l0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3J0?ooo`00DP3o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0600oooo0P00003J0?ooo`00D@3oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0e`3oool0
0500oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo
0=H0oooo001?0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`3F0?ooo`00CP3oool00`000000oooo0?ooo`1T0?ooo`<00000I03oool00`000000oooo
0?ooo`3E0?ooo`00C@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06D0oooo0P00
003E0?ooo`00C03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool0dP3oool004/0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1X0?oo
o`030000003oool0oooo0=40oooo001:0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`3A0?ooo`00B@3oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool0d03oool004P0oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0<l0oooo00180?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`3>0?ooo`00A`3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0c@3oool004H0
oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0<`0
oooo00150?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0K@3oool00`000000oooo
0?ooo`3<0?ooo`00A03oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool0b`3oool004<0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0<X0oooo00120?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`390?ooo`00@@3oool00`000000oooo0?ooo`1a0?ooo`<0
0000L@3oool00`000000oooo0?ooo`380?ooo`00@@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool0b03oool00400oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0<L0oooo000o0?ooo`030000003oool0
oooo07<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`360?ooo`00?`3oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0aP3oool003h0
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo0<D0
oooo000m0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0M@3oool00`000000oooo
0?ooo`340?ooo`00?@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo07D0oooo00<0
00000?ooo`3oool0a03oool003`0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo0<<0oooo000k0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0M`3oool00`000000oooo0?ooo`320?ooo`00>`3oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0`P3oool003X0oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0<40oooo000i0?ooo`030000003o
ool0oooo06@0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P000000
0`18W=l0oooo0?ooo`060?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0`@3oool0
03T0oooo00<000000?ooo`3oool0H`3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0
okmd04RLg`3oool0oooo0=nLB01d_ol70?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0`03oool003P0oooo00<000000?ooo`3oool0G@3oool00`3o_g@0000000000002000000080018
W03Oool0gia804RLg`3oool0oono07@0M02oool70?ooo`030?noM018W=l0oooo00H0oooo1000001i
0?ooo`030000003oool0oooo0;l0oooo000g0?ooo`030000003oool0oooo06D0oooo00H0gia807Bo
o`3oool0oooO09a8M02oool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo1`3oool00`000000
oooo0?ooo`1j0?ooo`030000003oool0oooo0;l0oooo000g0?ooo`030000003oool0oooo06D0oooo
00H0gia804RLg`3oool0oono07@0M02oool30?ooo`050?oo_`1dB4P0B00000000000M;l0203oool0
0`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0;h0oooo000g0?ooo`030000003oool0oooo
06D0oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo00X0oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`2n0?ooo`00=`3oool00`000000oooo0?ooo`1V
0?ooo`040;md00000000001809cOo`D0oooo00D0_g@0000000000000001809cOo`070?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool0_@3oool003H0oooo00<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0;`0oooo000e0?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`2l0?ooo`00=@3oool00`00
0000oooo0?ooo`1m0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0^`3oool003@0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0;/0
oooo000c0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`2k0?ooo`00<`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0^P3oool003<0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`1o
0?ooo`030000003oool0oooo0;X0oooo000c0?ooo`030000003oool0oooo07l0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`2i0?ooo`00<P3oool00`000000oooo0?ooo`200?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool0^03oool00340oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;P0oooo000a0?ooo`030000003o
ool0oooo0840oooo0`0000210?ooo`030000003oool0oooo0;P0oooo000`0?ooo`030000003oool0
oooo0880oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2h0?ooo`00<03oool00`00
0000oooo0?ooo`220?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0]`3oool00300
oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0;H0
oooo000_0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0P`3oool00`000000oooo
0?ooo`2f0?ooo`00;`3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo08<0oooo00<0
00000?ooo`3oool0]P3oool002h0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`23
0?ooo`030000003oool0oooo0;H0oooo000^0?ooo`030000003oool0oooo08@0oooo00<000000?oo
o`3oool0Q03oool00`000000oooo0?ooo`2e0?ooo`00;P3oool00`000000oooo0?ooo`240?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool0]03oool002d0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0;@0oooo000]0?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`2d0?ooo`00;@3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0]03oool0
02d0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
0;<0oooo000/0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`2b0?ooo`00:`3oool00`000000oooo0?ooo`270?ooo`<00000Q`3oool00`000000oooo
0?ooo`2b0?ooo`00:`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0/P3oool002/0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo0;80oooo000[0?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`2a0?ooo`00:P3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0/@3oool002X0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;40oooo000Z0?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2`0?ooo`00:@3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0/03oool0
02T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
0;00oooo000Y0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R@3oool00`000000
oooo0?ooo`2`0?ooo`00:@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo08T0oooo
00<000000?ooo`3oool0/03oool002T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo0:l0oooo000X0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`2_0?ooo`00:03oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0[`3oool002P0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0:l0oooo000X0?ooo`030000
003oool0oooo08X0oooo0`00002;0?ooo`030000003oool0oooo0:h0oooo000X0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2^0?ooo`00:03oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0[P3oool0
02L0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
0:h0oooo000W0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool00`000000
oooo0?ooo`2^0?ooo`009`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0[@3oool002L0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo0:d0oooo000W0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`2]0?ooo`009P3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0[@3oool002H0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0:d0oooo000V0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2]0?ooo`009P3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0[@3o
ool002H0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0:`0oooo000V0?ooo`050000003oool0oooO09a8M02oool0@03oool02P2oM00000000000B02L
gol0oooo0?oo_`1dB9`0gooo0?ooo`2oM0020000000304RLg`3oool0oooo03/0oooo00<000000?oo
o`3oool0?`3oool02P2oM00000000000B02Lgol0oooo0?oo_`1dB9`0gooo0?ooo`2oM00200000003
04RLg`3oool0oooo03l0oooo00<0000009a8M02oool0@@3oool02@3ooml0W4Qd0;ooo`3oool0oono
07A8W03Oool0oooo0;md00020000000304RLg`3oool0oooo03`0oooo00<0_g@00000000000000P00
00000`18W=l0oooo0?ooo`0I0?ooo`009P3oool01@000000oooo0?oog`2LB7@0_ooo03l0oooo00H0
okmd0018W03Oool0okmd0018W03Oool30?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo?03oool3
000003h0oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`060?noM018W=l0oooo0?ooo`3O
W4P0M;oo@03oool00`000000W4Qd0;ooo`110?ooo`030?oog`2LB7@0_ooo00@0oooo00H0okmd04RL
g`3oool0oooo0=nLB01d_olm0?ooo`030?oog`2LB000M;oo01h0oooo000O0?ooo`030?noM0000000
00000080000000L004RL0=ooo`000000oooo0?oog`2LB7@0_ooo03P0oooo00<0okmd000000000000
0P0000002000B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`0k
0?ooo`030000003oool0oooo03h0oooo00H0gia804RLg`3oool0oono07@0M02oool70?ooo`030?no
M018W=l0oooo03l0oooo00<0000009a8M02oool0@@3oool00`3ooml0W4Qd0;ooo`080?ooo`030?no
M018W=l0oooo03h0oooo00<0_g@0001d_`3oool0703oool002H0oooo00D000000?ooo`3ooml0W4Qd
0;ooo`0o0?ooo`060=nLB01d_ol0oooo0?oog`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0
gia807Booc`0oooo00<000000?ooo`3oool0?P3oool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0
oooo00H0okmd0000M02oool0oooo0=nLB01d_om00?ooo`030000002LB7@0_ooo0440oooo00<0oooO
09a8M02oool0103oool01P3o_g@0001d0;ooo`3oool0gia807Bood00oooo00<0okmd001d_`3oool0
6`3oool002D0oooo00H000000?oog`2LW;l0oooO09a8M02oool?0?ooo`030?noM000M;l0oooo02d0
oooo00H0gia804RLg`3oool0oono07@0M02oool30?ooo`050?oo_`1dB4P0B00000000000M;l0?@3o
ool00`000000oooo0?ooo`0n0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0
M4Q804P00000000007Bo03l0oooo00D0oooO09bL_`000000W4Qd0;ooo`0o0?ooo`050?oog`2LW;l0
oooO09a8M02oool0103oool01@3ookl0M4Q804P00000000007Bo0480oooo00<0gia807Boo`3oool0
6P3oool002D0oooo00H000000?ooo`3o_g@000000000M02oool:0?ooo`030?oo_`1d000000000080
000000<0001d0;ooo`3oool0;@3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO
09a8B02Lgol0=@3oool01P3ookl0M000000000000000001d0;ooo`@0oooo00<000000?ooo`3oool0
?P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol0@P3oool0103o
_g@000000000M02ooom00?ooo`040?noM0000000001d0;ooo`@0oooo00<0oooO09a8B02Lgol0@03o
ool01P3o_g@007Bo0?ooo`3oool0_g@007Booa/0oooo000U0?ooo`060000003oool0oooo0?oo_`1d
07@0_ooo2@3oool0203ookl0M0000018W03Oool0_g@00000000004P0W=oo;`3oool0102oM0000000
0000B02Lgol50?ooo`050;md0000000000000000B02Lgol0<@3oool0203ookl0M0000018W03Oool0
oooO09a8000007@0_ooo0`3oool00`000000oooo0?ooo`0o0?ooo`040;md00000000001809cOo`D0
oooo00D0_g@0000000000000001809cOo`100?ooo`030000001d07@0_ooo0440oooo00<0oono07@0
M02oool01@3oool01@2oM00000000000000004P0W=oo03d0oooo00H0oooO09a80000000000000018
W03OoolK0?ooo`009@3oool00`000000oooo0?ooo`0<0?ooo`080?noM00004P0W=oo0?oOW018B9`0
gmnL04P00018W=m^0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol00`3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo0:`0oooo000U0?ooo`030000003oool0oooo00`0
oooo00<0gia80000M02oool00P3oool00`3ookl0M00004RLg`1^0?ooo`030=nLB00007@0_ooo0080
oooo00<0oono07@00018W=l00`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0:`0
oooo000U0?ooo`030000003oool0oooo00`0oooo00<0gia80000M02oool00P3oool00`3ookl0M000
04RLg`1^0?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@00018W=l00`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo0:`0oooo000U0?ooo`030000003oool0oooo00`0oooo00<0
okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`1^0?ooo`030?noM00004P0W=oo0080oooo00<0
omnL04P0001d_ol00`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0:`0oooo000U
0?ooo`030000003oool0oooo00`0oooo00P0oono07@00000B9`0gooo0?ooo`2oM00004RL0=ooofh0
oooo00<0oono07@00000M;l00P3oool00`2oM000001d0;ooo`030?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0[03oool002D0oooo00<000000?ooo`3oool03@3oool01P3ookl0M000
00000000000004RL0=ooo`X0oooo0`000?mS0?ooo`060?oo_`1d000000000000000007@0_ooo103o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0:`0oooo000U0?ooo`030000003oool0
oooo01P0oooo20000?m]0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0[03oool0
02D0oooo00<000000?ooo`3oool04`3oool<0000ofh0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`2/0?ooo`00>000001n0000ool00000?P0000010?ooo`00203oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`030000o`3oo`00003o00`0003oK03oo`03000001`0o`0000<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool000P0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3o
ool00`000?l0ool00?oo00030?oo00T0003oJP3oo`0200000080o`0000<000000?l0003o00006P3o
00000`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`009@3oool0
0`000000oooo0?ooo`0@0?ooo`030000o`3oo`00ool000L0ool01P000?mX0?oo00030000003o0000
o`000080o`0000<000000?l0003o00006P3o000[0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01/0oooo000U0?oo
o`030000003oool0oooo0100oooo00<0003o0?oo003oo`002`3oo`020000ofH0ool00P0000050?l0
00030000003o0000o`0001X0o`00:`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0K0?ooo`009@3oool00`000000
oooo0?ooo`0@0?ooo`030000o`3oo`00ool00740ool00P0000070?l000030000003o0000o`0001X0
o`00L`3oool00`000000oooo0?ooo`2/0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`030000
o`3oo`00ool006l0ool00P0000090?l000030000003o0000o`0001X0o`00L`3oool00`000000oooo
0?ooo`2/0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oo`00ool006h0ool000<0
00000?l0003o00002@3o00000`000000o`000?l0000J0?l007<0oooo00<000000?ooo`3oool0[03o
ool002D0oooo00<000000?ooo`3oool0403oool00`000?l0ool00?oo001/0?oo00800000303o0000
0`000000o`000?l0000I0?l007@0oooo00<000000?ooo`3oool0[03oool002D0oooo00<000000?oo
o`3oool0403oool00`000?l0ool00?oo001Z0?oo008000003P3o00000`000000o`000?l0000I0?l0
07@0oooo00<000000?ooo`3oool0[03oool002D0oooo00<000000?ooo`3oool0403oool00`000?l0
ool00?oo001Y0?oo00030000003o0000o`0000h0o`0000<000000?l0003o00006@3o001d0?ooo`03
0000003oool0oooo0:`0oooo000U0?ooo`030000003oool0oooo0100oooo00<0003o0?oo003oo`00
I`3oo`0200000140o`0000<000000?l0003o00006@3o001d0?ooo`030000003oool0oooo0:`0oooo
000U0?ooo`030000003oool0oooo0100oooo00<0003o0?oo003oo`00I@3oo`02000001<0o`0000<0
00000?l0003o0000603o001e0?ooo`030000003oool0oooo0:`0oooo000V0?ooo`030000003oool0
oooo00l0oooo00<0003o0?oo003oo`00H`3oo`02000001D0o`0000<000000?l0003o0000603o001e
0?ooo`030000003oool0oooo0:`0oooo000V0?ooo`030000003oool0oooo00l0oooo00<0003o0?oo
003oo`00HP3oo`000`000000o`000?l0000E0?l000030000003o0000o`0001L0o`00MP3oool00`00
0000oooo0?ooo`2/0?ooo`009P3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oo`00ool00600
ool00P00000H0?l000030000003o0000o`0001H0o`00M`3oool00`000000oooo0?ooo`2/0?ooo`00
9P3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oo`00ool005h0ool00P0000020?oooaP0o`00
00<000000?l0003o00005@3o001h0?ooo`030000003oool0oooo0:`0oooo000V0?ooo`030000003o
ool0oooo00l0oooo00<0003o0?oo003oo`00G@3oo`000`000000oooo0?ooo`030?oooaL0o`0000<0
00000?l0003o00005@3o001h0?ooo`030000003oool0oooo0:`0oooo000V0?ooo`030000003oool0
oooo00l0oooo00<0003o0?oo003oo`00F`3oo`02000000L0oooo5P3o00000`000000o`000?l0000D
0?l007P0oooo00<000000?ooo`3oool0[@3oool002H0oooo00<000000?ooo`3oool03`3oool00`00
0?l0ool00?oo001I0?oo008000002@3ooolF0?l000030000003o0000o`0001@0o`00N03oool00`00
0000oooo0?ooo`2]0?ooo`009P3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oo`00ool005L0
ool00P00000<0?oooaD0o`0000<000000?l0003o00004`3o001i0?ooo`030000003oool0oooo0:d0
oooo000V0?ooo`030000003oool0oooo00l0oooo00<0003o0?oo003oo`00EP3oo`000`000000oooo
0?ooo`0<0?oooaD0o`0000<000000?l0003o00004P3o001j0?ooo`030000003oool0oooo0:d0oooo
000W0?ooo`030000003oool0oooo00h0oooo00<0003o0?oo003oo`00E03oo`0200000140oooo4`3o
00000`000000o`000?l0000A0?l007/0oooo00<000000?ooo`3oool0[@3oool002L0oooo00<00000
0?ooo`3oool03P3oool00`000?l0ool00?oo001B0?oo00800000503ooolB0?l000030000003o0000
o`0000l0o`00O@3oool00`000000oooo0?ooo`2]0?ooo`009`3oool00`000000oooo0?ooo`0>0?oo
o`030000o`3oo`00ool00540ool000<000000?ooo`3oool05@3ooolA0?l000030000003o0000o`00
00d0o`00O`3oool00`000000oooo0?ooo`2]0?ooo`009`3oool00`000000oooo0?ooo`0>0?ooo`03
0000o`3oo`00ool004l0ool00P00000J0?ooo`l0o`0000<000000?l0003o0000303o001o0?ooo`03
0000003oool0oooo0:h0oooo000W0?ooo`030000003oool0oooo00h0oooo00<0003o0?oo003oo`00
C@3oo`02000001h0oooo3@3o00000`000000o`000?l0000;0?l00800oooo00<000000?ooo`3oool0
[P3oool002P0oooo00<000000?ooo`3oool03@3oool00`000?l0ool00?oo001;0?oo008000008P3o
ool;0?l000030000003o0000o`0000T0o`00PP3oool00`000000oooo0?ooo`2^0?ooo`00:03oool0
0`000000oooo0?ooo`0=0?ooo`030000o`3oo`00ool004X0ool000<000000?ooo`3oool0903oool9
0?l000030000003o0000o`0000L0o`00Q03oool00`000000oooo0?ooo`2^0?ooo`00:03oool00`00
0000oooo0?ooo`0=0?ooo`030000o`3oo`00ool004P0ool00P00000Z0?ooo`H0o`0000<000000?l0
003o00000P3o00290?ooo`030000003oool0oooo0:h0oooo000X0?ooo`030000003oool0oooo00d0
oooo00<0003o0?oo003oo`00AP3oo`0200000380oooo00<000000?ooo`3oool0RP3oool00`000000
oooo0?ooo`2_0?ooo`00:03oool00`000000oooo0?ooo`0=0?ooo`030000o`3oo`00ool004D0ool0
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0:l0oooo
000X0?ooo`030000003oool0oooo00d0oooo00<0003o0?oo003oo`00@`3oo`02000003D0oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`2_0?ooo`00:@3oool00`000000oooo0?ooo`0<
0?ooo`030000o`3oo`00ool00440ool00P00000g0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool0[`3oool002T0oooo00<000000?ooo`3oool0303oool00`000?l0ool00?oo000o0?oo
00800000>@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;00oooo000Y0?ooo`03
0000003oool0oooo00`0oooo00<0003o0?oo003oo`00?P3oo`000`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool0/03oool002T0oooo00<000000?ooo`3oool0
303oool00`000?l0ool00?oo000l0?oo00800000?03oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo0;00oooo000Y0?ooo`030000003oool0oooo00`0oooo00<0003o0?oo003oo`00>P3o
o`02000003h0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2`0?ooo`00:P3oool0
0`000000oooo0?ooo`0;0?ooo`030000o`3oo`00ool003T0ool000<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo0;00oooo000Z0?ooo`030000003oool0oooo
00/0oooo00<0003o0?oo003oo`00=`3oo`0200000440oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`2a0?ooo`00:P3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oo`00ool003D0
ool00P0000130?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0/@3oool002/0oooo
00<000000?ooo`3oool02P3oool00`000?l0ool00?oo000c0?oo00800000A@3oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo0;40oooo000[0?ooo`030000003oool0oooo00X0oooo00<0
003o0?oo003oo`00<P3oo`000`000000oooo0?ooo`150?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0/P3oool002/0oooo00<000000?ooo`3oool02P3oool00`000?l0ool00?oo000`
0?oo00800000B03oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0;80oooo000[0?oo
o`030000003oool0oooo00X0oooo00<0003o0?oo003oo`00;P3oo`02000004X0oooo0`0000260?oo
o`030000003oool0oooo0;<0oooo000/0?ooo`030000003oool0oooo00T0oooo00<0003o0?oo003o
o`00;@3oo`000`000000oooo0?ooo`1:0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0/`3oool002d0oooo00<000000?ooo`3oool0203oool00`000?l0ool00?oo000[0?oo00800000
C@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0;<0oooo000]0?ooo`030000003o
ool0oooo00P0oooo00<0003o0?oo003oo`00:@3oo`02000004l0oooo00<000000?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`2d0?ooo`00;@3oool00`000000oooo0?ooo`080?ooo`030000o`3oo`00
ool002L0ool00P00001A0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0]03oool0
02d0oooo00<000000?ooo`3oool0203oool00`000?l0ool00?oo000V0?oo00030000003oool0oooo
0540oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`2d0?ooo`00;P3oool00`000000
oooo0?ooo`070?ooo`030000o`3oo`00ool002@0ool00P00001D0?ooo`030000003oool0oooo08D0
oooo00<000000?ooo`3oool0]03oool002h0oooo00<000000?ooo`3oool01`3oool00`000?l0ool0
0?oo000R0?oo00800000EP3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo0;D0oooo
000^0?ooo`030000003oool0oooo00L0oooo00<0003o0?oo003oo`008@3oo`000`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0]@3oool002l0oooo00<00000
0?ooo`3oool01P3oool00`000?l0ool00?oo000O0?oo00800000F@3oool00`000000oooo0?ooo`23
0?ooo`030000003oool0oooo0;H0oooo000_0?ooo`030000003oool0oooo00H0oooo00<0003o0?oo
003oo`007@3oo`02000005/0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`2f0?oo
o`00<03oool00`000000oooo0?ooo`050?ooo`030000o`3oo`00ool001/0ool00P00001M0?ooo`03
0000003oool0oooo08<0oooo00<000000?ooo`3oool0]P3oool00300oooo00<000000?ooo`3oool0
1@3oool00`000?l0ool00?oo000J0?oo00030000003oool0oooo05d0oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`2g0?ooo`00<03oool00`000000oooo0?ooo`050?ooo`030000o`3o
o`00ool001P0ool00P00001P0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0]`3o
ool00340oooo00@000000?ooo`3oool0oooo0P000?l0103oool0003o0?oo003oo`020000oa@0ool0
0P00001R0?ooo`<00000P@3oool00`000000oooo0?ooo`2h0?ooo`00<@3oool010000000oooo0?oo
o`3oool80000oa<0ool000<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0;P0oooo000b0?ooo`030000003oool0oooo00L0003o4P3oo`02000006D0oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`2h0?ooo`00<`3oool00`000000oooo0?ooo`06
0000oa00ool00P00001W0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^@3oool0
03<0oooo00<000000?ooo`3oool01P000?l>0?oo00800000J@3oool00`000000oooo0?ooo`1o0?oo
o`030000003oool0oooo0;X0oooo000c0?ooo`030000003oool0oooo00H0003o3@3oo`000`000000
oooo0?ooo`1Y0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0^P3oool003<0oooo
00<000000?ooo`3oool01@000?l<0?oo00800000K03oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo0;/0oooo000d0?ooo`030000003oool0003o00@0003o2P3oo`02000006h0oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`2k0?ooo`00=@3oool00`000000oooo0000o`03
0000o`T0ool000<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo0;/0oooo000e0?ooo`030000003oool0003o00<0003o1`3oo`0200000740oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`2l0?ooo`00=P3oool010000000003o0000o`000?l60?oo
00800000L`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo03@0oooo00<0gia807Bo
o`3oool08P3oool00`3ogi`0B000000000020000000304RLg`3oool0oooo01@0oooo00<0okmd04RL
g`3oool0A03oool003L0oooo0`000?l40?oo00800000M@3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo03@0oooo00<0omnL07BLg`3oool09`3oool00`3o_g@0001809cOo`0F0?ooo`03
0=nLB01d_ol0oooo04<0oooo000g0?ooo`<0003o0`3oo`000`000000oooo0?ooo`1P0?ooo`0:0;md
00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool01P3o
ool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0240oooo00D0gia80000000000000000
04RLg`020?ooo`0?0?noM000000000000000001d_ol0oooo0?noM0000000M;oo0?ooo`3ogi`0B000
07Bog`2LB4P0W=oo00<0oooo00H0okmd0000001d_ol0oooo0?oog`2LB00200000004001d_`3oool0
oooo0=nLB080000000<0M;oo0?ooo`3oool00P3oool00`3ogi`0B000000000020000000407Boo`3o
ool0oooo0?noM0<0000000@0M;oo0?ooo`3oool0gia80P0000001P1dW9`0B00007Boo`3ookl0M000
04RLg`<0oooo00D0okmd000000000000000007Boo`020?ooo`050?noM000000000000000001d_ol0
103oool00`3ogi`0B4RL0=ooo`0>0?ooo`0:0=nLB0000000000007Boo`3oool0omnL04P0001d_ol0
oooO09a80080000000<007Bo0?ooo`3oool09P3oool003L0oooo00@000000000o`000?l0ool00P00
001R0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool01P3o_g@0B9cO0?ooo`3oool0gia8
07Boo`L0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0P0?ooo`0G0?oOW0180000
B9cO0?ooo`3o_g@0001809cOo`3ogi`0B000001d_`3oool0okmd0000B02Lgol0okmd0000001d_ol0
oooo0?oOW0180000M:RL04P0M02oool00`3oool0403o_g@0000007Boo`3oool0gia80000B02Lgol0
omnL04P00018W=l0omnL04P0001d_ol0okmd0000B02Lgol30?ooo`0H0?oOW0180000M;oo0?ooo`3o
_g@0001809cOo`3ogi`0B000001d_`3oool0okmd0000B02Lgol0okmd0000001d_ol0oooo0;md0000
0000M;oo0?oo_`1d0000B9cO0P3oool03P3ogi`0B000001d_`3oool0okmd0000B02Lgol0omnL04P0
0000M;l0oooo0?noM00004P0W=oo0`3oool00`3ookl0M00007Boo`030?ooo`030?noM00000000000
00<0000001<004RL0=ooo`3oool0oooo0?oOW0180000M;oo0?noM00004P0W=oo0?oOW0180000M;oo
0=nLB00004P0W=oo0?oOW0180000B9cO02L0oooo000g0?ooo`04000000000?l00000000006@0oooo
00H0gia804RLg`3oool0oono07@0M02oool70?ooo`030?noM018W=l0oooo00H0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`0S0?ooo`080?oo_`1d000000000000M02oool0gia80000
B02Lgol40?ooo`090?noM0000000M;oo0?ooo`3ogi`0B00007B?M00007@0_ooo00<0oooo00<0okmd
0000001d_ol0103oool02@3ooml0W4P0001d_`3OW4P0001d0;ooo`3ogi`0B00007Boo`030?ooo`0:
0?oOW0180000M;oo0?ooo`3ookl0M00004RLg`3OW4P0001809cOo`@0oooo00X0gia80000M02oool0
oooo0?oOW0180000M;oo0?oo_`1d0000B9cO0P3oool00`3OW4P0001809cOo`040?ooo`030=nLB000
04P0W=oo00L0oooo00<0oooO09a8001d_ol03@3oool01P3OW4P0001d0;ooo`3ogi`0B00007Boo`H0
oooo00<0oooO09a80000M;l09`3oool003P0oooo00<0003o0?ooo`3oool0I03oool01P3OW4P0M;oo
0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol70?ooo`@00000N@3o
ool00`000000oooo0?ooo`0Q0?ooo`050?oog`2LB00000000000001d_ol00P3oool00`3OW4P00000
000000030000000:04RLg`3o_g@0000007Boo`3oool0omnL04P0001dSg@0001d0;ooo`<0oooo0100
okmd0000001d_ol0oooo0?noM00004P0W=oo0?oOW0180000B9cO0;md000007@0_ooo0?oOW0180000
B9cO0`3oool0203ogi`0B00007Boo`3oool0oooO09a80000M;l0gia81@0000002`18W=l0gia80000
M02oool0oooo0?oOW0180000M;oo0?oo_`1d0000B9cO0080oooo00<0gia80000000000000`000000
0`18W=l0gia8000000040000000704RLg`3oool0oooo0?ooo`3ooml0W4P007Boo`0=0?ooo`060;md
000007@0_ooo0?oOW0180000B9cO0`3oool01P3o_g@0001809cOo`3ogi`0B00004RLgbL0oooo000i
0?ooo`030000003oool0oooo06<0oooo00H0gia804RLg`3oool0oono07@0M02oool30?ooo`050?oo
_`1dB4P0B00000000000M;l0203oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0280
oooo0200omnL04P00018W=l0oooo0;md0000B9`0gooo0?oOW0180000M;oo0?ooo`3ogi`0B00007Bo
o`3o_g@00000001d_`3oool0okmd0000001dZ9`0B01d0;ooo`3oool0omnL04Qd_`3o_g@0000007Bo
o`3oool0omnL04P00080000000P004RL0=ooo`2oM000001d0;ooo`3ogi`0B00004RLg`<0oooo02P0
omnL04P0001d_ol0oooo0?oog`2LB00007Bo0?oOW0180000M;oo0?ooo`3ogi`0B00007Boo`3o_g@0
000007Boo`3oool0_g@00000001d_ol0oono07@00000B9`0gooo0?ooo`3ogi`0B00007Boo`3oool0
omnL04P0001d_ol0omnL04P0001d_ol0oooo0?oOW0180000M;oo0`3oool00`3ookl0M00007Boo`03
0?ooo`030?noM0000000000000<0000000X004RL0=ooo`3oool0oooo0;md000007@0_ooo0?oOW018
0000B9cO0`3oool01P3ogi`0B00000000000000004RL0=ooobL0oooo000i0?ooo`030000003oool0
oooo06<0oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo00X0oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0T0?ooo`050=nLB000000000000000001d
_ol00P3oool02@3o_g@00000000000000000B9cO0?ooo`3o_g@0000007AdM002000000070018W03O
oml0W4Q809cOo`3oool0omnL04P000020000000507Boo`3oool0oono07@0001d_ol00`3oool01P3O
W4P0001d0;ooo`3ogi`0B00007Boo`<0oooo00T0omnL04P0001d_ol0oooo0?oo_`1d0000B9cO0?oo
o`3o_g@00`0000001018W=l0oooo0?ooo`3OW4P20000000:04QdM0180000M;oo0?oo_`1d0000B7Ad
04P0000007@0_ooo0?noM0<0000000@0B9cO0?ooo`3oool0okmd0`0000000`18W=l0oooo0?ooo`02
0?ooo`030?oOW018B9`0gooo00d0oooo00H0gia80000M02oool0omnL04P0001d_ol30?ooo`030?oo
_`1d0000M;oo02X0oooo000j0?ooo`030000003oool0oooo06<0oooo00@0_g@00000000004P0W=oo
1@3oool01@2oM00000000000000004P0W=oo00L0oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0h0?ooo`0<0?oOW018B9`0gooo0?ooo`3ogi`0B0000000001d_ol0oooo0?oog`2LB000
07Bo0`3oool01P3ogi`0B01809cOo`3o_g@0001809cOo`<0oooo00L0omnL04P0001d_ol0oooo0=nL
B00004P0W=oo02@0oooo00<0_g@007Boo`3oool03@3oool01P3ogi`0B01809cOo`3o_g@0001809cO
o`<0oooo00<0oooO09a80000M;l0:P3oool003/0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo03X0oooo00L0omnL09boo`3oool0oooo0?oOW0180000
M;oo0080oooo00L0_g@0000000000000000007Boo`3oool0gia80080000000<0M;oo0?ooo`3oool0
0P3oool00`3ogi`0B000000000020000000307Boo`3oool0oooo0280oooo00<0okmd07Boo`3oool0
3`3oool0103OW4P000000000001d_ol50?ooo`050;md0000000000000000001d_ol09`3oool003D0
oooo00<0oono07@00018W=l00`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0``3oool003D0oooo00<0oono07@00018W=l0103oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0``3oool003D0oooo00<0
oono07@00018W=l01@3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo07D0oooo00<0
00000?ooo`3oool0a03oool003D0oooo00<0oono07@0000000000P0000001000M;l0oooo0?ooo`00
001g0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0a03oool003D0oooo00L0oono
07@00018W=l0oooo0?oOW0180000B9cO0080oooo00<000000?ooo`3oool0M03oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo0<D0oooo000e0?ooo`070?oo_`1d0000B9cO0?ooo`3ookl0
M000001d_`030?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0L`3oool00`000000
oooo0?ooo`360?ooo`00=@3oool01`3ookl0M00004RLg`3oool0omnL04P00018W=l00`3oool00`00
0000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0aP3oool003D0
oooo00<0oono07@0000000000P0000000`00B9`0gooo0?ooo`030?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`370?ooo`00@@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0b03oool00440oooo00<0
00000?ooo`3oool0L@3oool300000740oooo00<000000?ooo`3oool0b03oool00480oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<T0oooo00130?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`3:0?oo
o`00A03oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3o
ool0b`3oool004D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo0<`0oooo00160?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`3<0?ooo`00A`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo06`0oooo00<000000?ooo`3oool0c@3oool004P0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo0<h0oooo00180?ooo`030000003oool0oooo06X0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`3?0?ooo`00B@3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0d03oool004X0oooo00<0
00000?ooo`3oool0J03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0=40oooo001:
0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`3A
0?ooo`00B`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0dP3oool004`0oooo0P00001W0?ooo`030000003oool0oooo06D0oooo0P00003E0?ooo`00
CP3oool00`000000oooo0?ooo`1T0?ooo`<00000I03oool00`000000oooo0?ooo`3E0?ooo`00C`3o
ool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0eP3o
ool00500oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0=H0oooo001A0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`3G0?ooo`00DP3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0600
oooo0P00003J0?ooo`00D`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool0fP3oool005@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo0=/0oooo001E0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`3K0?ooo`00EP3oool00`000000oooo0?ooo`1L0?oo
o`030000003oool0oooo05d0oooo00<000000?ooo`3oool0g03oool005L0oooo0P00001L0?ooo`03
0000003oool0oooo05/0oooo0P00003O0?ooo`00F@3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0g`3oool005X0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`1H0?ooo`800000hP3oool005/0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0>80oooo001L0?ooo`800000E`3oool00`00
0000oooo0?ooo`1E0?ooo`800000i@3oool005h0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0>D0oooo001O0?ooo`030000003oool0oooo05<0oooo
0`00001C0?ooo`030000003oool0oooo0>H0oooo001P0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`3W0?ooo`00H@3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0j03oool00680oooo0P00001A0?oo
o`030000003oool0oooo04l0oooo0P00003[0?ooo`00I03oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0j`3oool006D0oooo0P00001>0?ooo`030000
003oool0oooo04`0oooo0P00003^0?ooo`00I`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0kP3oool006P0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`190?ooo`800000l@3oool006T0oooo100000180?ooo`030000003oool0oooo
04L0oooo0P00003c0?ooo`00K@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04D0
oooo0P00003e0?ooo`00KP3oool2000004D0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`3e0?ooo`00L03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0480oooo0P00
003h0?ooo`00L@3oool200000480oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3h
0?ooo`00L`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03l0oooo0P00003k0?oo
o`00M03oool4000003d0oooo0`00000l0?ooo`<00000o@3oool007P0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0j0?ooo`800000o`3oool10?ooo`00N@3oool2000003X0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?ooo`40oooo001k0?ooo`<00000=`3oool0
0`000000oooo0?ooo`0e0?ooo`@00000o`3oool40?ooo`00OP3oool2000003D0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`3o0?ooo`H0oooo00200?ooo`<00000<P3oool00`000000
oooo0?ooo`0`0?ooo`@00000o`3oool90?ooo`00P`3oool200000300oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`3o0?ooo`/0oooo00250?ooo`<00000;@3oool00`000000oooo0?oo
o`0[0?ooo`@00000o`3oool>0?ooo`00R03oool4000002T0oooo00<000000?ooo`3oool0:03oool3
00000?l0oooo4P3oool008`0oooo0`00000V0?ooo`030000003oool0oooo02@0oooo1000003o0?oo
oaD0oooo002?0?ooo`@000008P3oool00`000000oooo0?ooo`0Q0?ooo`<00000o`3ooolI0?ooo`00
T`3oool5000001d0oooo00<000000?ooo`3oool0703oool500000?l0oooo703oool009P0oooo0`00
000>0?ooo`030?oog`2LB7@0_ooo00T0oooo00<000000?ooo`3oool0603oool400000?l0oooo8@3o
ool009/0oooo1`0000070?ooo`030?oog`2LB7@0_ooo00T0oooo00<000000?ooo`3oool04@3oool7
00000?l0oooo9@3oool00:80oooo2`0000080?ooo`030000003oool0oooo00H0oooo2`00003o0?oo
ob`0oooo002Y0?ooo`040?oog`2LB7@0_ooo0?oooa400000o`3ooolg0?ooo`00Y`3oool01@3ooml0
W9bo0?oog`2LB7@0_ooo00T0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00Z03oool0103o_g@0
00000000M02oool90?ooo`030000003oool0oooo0?l0oooo?@3oool00:T0oooo00<0oono07@0M02o
ool02@3oool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0oooo
?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?ooo`3o
0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0oooo?@3oool00;D0oooo00<000000?ooo`3o
ool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000003o
ool0oooo0?l0oooo?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3oool00`00
0000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0oooo?@3oool00;D0oooo
0`00003o0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0oooo?@3oool00;D0oooo00<00000
0?ooo`3oool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`03
0000003oool0oooo0?l0oooo?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3o
ool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0oooo?@3oool0
0;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?ooo`3o0?ooocd0
oooo002e0?ooo`030000003oool0oooo0?l0oooo?@3oool00;D0oooo00<000000?ooo`3oool0o`3o
oolm0?ooo`00]@3oool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000003oool0oooo
0?l0oooo?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3oool300000?l0oooo
?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?ooo`3o
0?ooocd0oooo002e0?ooo`030000003oool0oooo0?l0oooo?@3oool00;D0oooo00<000000?ooo`3o
ool0o`3ooolm0?ooo`00]@3oool00`000000oooo0?ooo`3o0?ooocd0oooo002e0?ooo`030000003o
ool0oooo0?l0oooo?@3oool00;D0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00]@3oool00`00
0000oooo0?ooo`3o0?ooocd0oooo003o0?ooooD0oooo003o0?ooooD0oooo003o0?ooooD0oooo003o
0?ooooD0oooo003o0?ooooD0oooo0000\
\>"],
  ImageRangeCache->{{{94.4375, 373.375}, {309.875, 100.938}} -> {-2.43146, \
-0.0438098, 0.00868305, 0.00868305}}],

Cell[TextData[{
  "L'animazione ci fa comprendere come all'aumentare di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " da ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  " al valore di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  " il seno aumenti raggiungendo il suo valore massimo, ",
  Cell[BoxData[
      \(TraditionalForm\`\(+1\)\)]],
  ", in corrispondenza di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  ". Per valori maggiori ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\[Alpha])\)]],
  " diminuisce passando per il valore nullo quando ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \[Pi]\)]],
  " e assumendo valori negativi per ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi] \[LessEqual] \[Alpha] \[LessEqual] \(3\/2\) \
\[Pi]\)]],
  ". Infine raggiunto il valore minimo ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\(3\/2\) \[Pi]) = \(-1\)\)]],
  ", la funzione ricomincia poi a crescere fino ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  ". Il codominio appare quindi essere l'intervallo ",
  Cell[BoxData[
      \(TraditionalForm\`\([\(-1\), 1]\)\)]],
  ". "
}], "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico della funzione seno e periodicit\[AGrave]", "Section"],

Cell[TextData[{
  "Per visualizzare un grafico della funzione seno al variare di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " \[EGrave] comunque necessario un approccio pi\[UGrave] preciso. \
Riporteremo quindi i valori dell'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " sull'asse della variabile indipendente di un sistema cartesiano e, in \
corrispondenza, associamo all'ordinata il valore di ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\[Alpha])\)]],
  ". Per facilitare il riconoscimento del legame tra angolo e valore \
dell'ascissa riportiamo entrambi con lo stesso colore (blu) mentre per \
mostrare che l'ordinata \[EGrave] effettivamente il valore del seno \
corrispondente tracciamo la circonferenza goniometrica (quindi ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OP",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["1",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(sen(\[Alpha])\), "=", 
          RowBox[{
            StyleBox["QP",
              FontSlant->"Italic"], "=", 
            SubscriptBox[
              StyleBox["y",
                FontSlant->"Italic"], "P"]}]}], TraditionalForm]]],
  ") traslata di una unit\[AGrave] nel verso delle ascisse negative per non \
interferire con il grafico. Abbiamo pertanto "
}], "Text"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(numImmag = 100;\)\), "\n", 
    \(\(sinGraf = 
        Plot[Sin[x], {x, 0, 2  \[Pi]}, 
          Ticks \[Rule] {{\[Pi]/2, \[Pi], 3  \[Pi]/2, 2  \[Pi]}, Automatic}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(coordinateSin = 
        Table[{x, Sin[x]}, {x, 0, 2  \[Pi], 2  \[Pi]/numImmag}];\)\), "\n", 
    \(\(listaSin1 = \(Show[sinGraf, 
              If[#[\([1]\)] \[NotEqual] 0, 
                ParametricPlot[{Sign[t] t\ Cos[t] - 20  \[Pi], 
                        Sign[t]\ t\ Sin[t]}/200  \[Pi], {t, 
                    Sign[#[\([1]\)]] 2  \[Pi], 
                    Sign[#[\([1]\)]] 2\ \[Pi] + #[\([1]\)]}, 
                  Axes \[Rule] False, DisplayFunction \[Rule] Identity, 
                  PlotStyle \[Rule] {AbsoluteThickness[2], colBlu}], 
                Graphics[{Point[{Cos[#[\([1]\)]] - 1, Sin[#[\([1]\)]]}]}]], 
              Graphics[
                Circle[{\(-1\), 0}, 
                  1]], \[IndentingNewLine]Graphics[{Line[{{\(-1\), 
                        0}, {Cos[#[\([1]\)]] - 1, 
                        Sin[#[\([1]\)]]}, #, {#[\([1]\)], 0}}], 
                  Line[{{Cos[#[\([1]\)]] - 1, 
                        Sin[#[\([1]\)]]}, {Cos[#[\([1]\)]] - 1, 
                        0}}], {AbsoluteThickness[2], colBlu, 
                    Line[{{0, 0}, {#[\([1]\)], 
                          0}}]}}], \
\[IndentingNewLine]Graphics[{AbsolutePointSize[5], Point[#], 
                  Point[{Cos[#[\([1]\)]] - 1, 
                      Sin[#[\([1]\)]]}]}], \[IndentingNewLine]Epilog \[Rule] \
{{Text["\<sen ( \>" <> ToString[N[#[\([1]\)]/\[Pi]]] <> "\< \[Pi]) = \>" <> 
                        ToString[N[#[\([2]\)]]], {4, 0.75}, {\(-1\), 0}, 
                      TextStyle \[Rule] 
                        stileTesto]}}, \[IndentingNewLine]DisplayFunction \
\[Rule] Identity] &\) /@ coordinateSin;\)\), "\n", 
    \(\(listaSin2 = \(If[#[\([1]\)] \[Equal] 0, 
              Show[Graphics[{AbsolutePointSize[5], Point[{0, 0}]}], 
                DisplayFunction \[Rule] Identity], 
              Plot[Sin[x], {x, 0, #[\([1]\)]}, Axes -> False, 
                PlotStyle \[Rule] {AbsoluteThickness[2], colRosso}, 
                DisplayFunction \[Rule] Identity]] &\) /@ 
          coordinateSin;\)\), "\n", 
    \(\(\(Show[#, DisplayFunction \[Rule] $DisplayFunction, 
            AspectRatio \[Rule] Automatic, ImageSize \[Rule] {600, 200}] &\) /@ 
        Thread[{listaSin1, listaSin2}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .24145 
%%ImageSize: 600 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.253765 0.114978 0.120727 0.114978 [
[.43437 .10823 -6.09375 -17.8125 ]
[.43437 .10823 6.09375 0 ]
[.61498 .10823 -4.09375 -10.9375 ]
[.61498 .10823 4.09375 0 ]
[.79558 .10823 -8.96875 -20 ]
[.79558 .10823 8.96875 0 ]
[.97619 .10823 -7.09375 -10.9375 ]
[.97619 .10823 7.09375 0 ]
[.24126 .00575 -13.9375 -5.46875 ]
[.24126 .00575 0 5.46875 ]
[.24126 .06324 -20.625 -5.46875 ]
[.24126 .06324 0 5.46875 ]
[.24126 .17822 -15.125 -5.46875 ]
[.24126 .17822 0 5.46875 ]
[.24126 .2357 -8.4375 -5.46875 ]
[.24126 .2357 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .24145 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.43437 .12073 m
.43437 .12698 L
s
gsave
.43437 .10823 -67.0938 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

65.000 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 14.500 moveto
(\\200\\200) show
66.188 14.500 moveto
(\\200\\200) show
68.313 14.500 moveto
(\\200) show
68.813 14.500 moveto
(\\200) show
64.875 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.61498 .12073 m
.61498 .12698 L
s
gsave
.61498 .10823 -65.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.79558 .12073 m
.79558 .12698 L
s
gsave
.79558 .10823 -69.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
70.875 10.750 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.688 moveto
(\\200\\200\\200\\200) show
68.313 16.688 moveto
(\\200\\200\\200\\200) show
72.563 16.688 moveto
(\\200\\200) show
74.563 16.688 moveto
(\\200) show
67.750 23.000 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 .12073 m
.97619 .12698 L
s
gsave
.97619 .10823 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 .12073 m
1 .12073 L
s
.25376 .00575 m
.26001 .00575 L
s
gsave
.24126 .00575 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.25376 .06324 m
.26001 .06324 L
s
gsave
.24126 .06324 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.25376 .17822 m
.26001 .17822 L
s
gsave
.24126 .17822 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.25376 .2357 m
.26001 .2357 L
s
gsave
.24126 .2357 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.25376 .01725 m
.25751 .01725 L
s
.25376 .02874 m
.25751 .02874 L
s
.25376 .04024 m
.25751 .04024 L
s
.25376 .05174 m
.25751 .05174 L
s
.25376 .07474 m
.25751 .07474 L
s
.25376 .08623 m
.25751 .08623 L
s
.25376 .09773 m
.25751 .09773 L
s
.25376 .10923 m
.25751 .10923 L
s
.25376 .13222 m
.25751 .13222 L
s
.25376 .14372 m
.25751 .14372 L
s
.25376 .15522 m
.25751 .15522 L
s
.25376 .16672 m
.25751 .16672 L
s
.25376 .18971 m
.25751 .18971 L
s
.25376 .20121 m
.25751 .20121 L
s
.25376 .21271 m
.25751 .21271 L
s
.25376 .22421 m
.25751 .22421 L
s
.25 Mabswid
.25376 0 m
.25376 .24145 L
s
0 0 m
1 0 L
1 .24145 L
0 .24145 L
closepath
clip
newpath
.5 Mabswid
.25376 .12073 m
.28307 .14972 L
.31503 .17914 L
.34505 .20272 L
.37392 .22017 L
.38876 .22678 L
.39702 .22969 L
.40465 .23188 L
.41239 .23361 L
.41648 .23431 L
.42081 .2349 L
.42261 .2351 L
.42456 .23529 L
.42624 .23542 L
.42808 .23553 L
.42919 .23559 L
.43022 .23563 L
.43121 .23566 L
.43171 .23567 L
.43226 .23568 L
.4328 .23569 L
.43329 .2357 L
.43426 .2357 L
.43515 .2357 L
.43608 .23569 L
.43701 .23567 L
.43753 .23566 L
.43801 .23565 L
.43984 .23557 L
.44151 .23548 L
.44327 .23536 L
.44694 .23502 L
.45098 .23451 L
.45815 .23325 L
.46489 .23168 L
.4802 .22669 L
.49423 .22047 L
.52429 .2023 L
.5532 .17958 L
.58396 .15137 L
.61358 .12212 L
.64506 .09099 L
.67539 .06306 L
.70457 .03993 L
.71935 .03011 L
.73561 .02104 L
.75105 .01427 L
.76549 .00966 L
.77339 .00788 L
.77728 .0072 L
Mistroke
.78088 .00669 L
.78414 .00632 L
.78761 .00603 L
.78959 .0059 L
.79057 .00586 L
.79146 .00582 L
.79226 .0058 L
.79313 .00577 L
.79402 .00576 L
.79494 .00575 L
.79594 .00575 L
.79686 .00576 L
.79734 .00576 L
.79786 .00577 L
.79893 .0058 L
.79987 .00583 L
.80088 .00587 L
.80271 .00597 L
.8045 .00609 L
.80639 .00626 L
.80977 .00662 L
.81371 .00717 L
.81736 .0078 L
.82565 .00966 L
.83365 .01199 L
.8412 .01468 L
.85531 .02091 L
.88452 .03847 L
.9156 .0629 L
.94553 .09043 L
.97431 .11885 L
.97619 .12073 L
Mfstroke
0 0 1 r
2 Mabswid
.15163 .12073 m
.15169 .12115 L
.15172 .1214 L
.15174 .12162 L
.15176 .12186 L
.15176 .122 L
.15177 .12212 L
.15177 .12218 L
.15177 .12224 L
.15177 .12229 L
.15177 .12234 L
.15177 .1224 L
.15177 .12246 L
.15177 .12249 L
.15177 .12253 L
.15177 .12259 L
.15177 .12262 L
.15177 .12265 L
.15177 .12272 L
.15177 .12278 L
.15177 .12284 L
.15177 .12296 L
.15176 .1231 L
.15175 .12333 L
.15173 .12358 L
.1517 .12385 L
.15166 .12414 L
.15157 .12466 L
.15147 .12517 L
.15133 .12571 L
.151 .12669 L
.1506 .12763 L
.15008 .1286 L
.14892 .13025 L
.14738 .1318 L
.14563 .13306 L
.14464 .13361 L
.14353 .13409 L
.14244 .13446 L
.1414 .13472 L
.14079 .13484 L
.14021 .13492 L
.13968 .13498 L
.13938 .135 L
.1391 .13501 L
.13895 .13502 L
.13882 .13502 L
.13875 .13502 L
.13871 .13502 L
.13867 .13502 L
Mistroke
.13859 .13502 L
.13852 .13502 L
.13845 .13502 L
.13837 .13502 L
.1383 .13502 L
.13823 .13502 L
.1381 .13502 L
.13797 .13501 L
.13782 .13501 L
.13766 .135 L
.13737 .13498 L
.13703 .13495 L
.13672 .13491 L
.13611 .13483 L
.13555 .13472 L
.1343 .1344 L
.13319 .13402 L
.132 .1335 L
.13082 .13285 L
.12978 .13216 L
.12786 .13051 L
.12616 .12848 L
.12484 .12624 L
.1243 .125 L
.12383 .12362 L
.12365 .12293 L
.12348 .12217 L
.12335 .12143 L
.12327 .12075 L
.12324 .12042 L
.12321 .12006 L
.1232 .11989 L
.12319 .11973 L
.12318 .11958 L
.12318 .11942 L
.12317 .11932 L
.12317 .11924 L
.12317 .11915 L
.12317 .11909 L
.12317 .11905 L
.12317 .11897 L
.12317 .11888 L
.12317 .11879 L
.12317 .1187 L
.12317 .11866 L
.12317 .1186 L
.12318 .11851 L
.12318 .11833 L
.12319 .11812 L
.1232 .11793 L
Mistroke
.12322 .11759 L
.12325 .11723 L
.12333 .11657 L
.12346 .1158 L
.1236 .11509 L
.12397 .11373 L
.12449 .11228 L
.12511 .11094 L
.1259 .10956 L
.12762 .10724 L
Mfstroke
0 g
.5 Mabswid
newpath
.13879 .12073 .11498 0 365.73 arc
s
.13879 .12073 m
.06008 .03691 L
.70889 .03691 L
.70889 .12073 L
s
.06008 .03691 m
.06008 .12073 L
s
0 0 1 r
2 Mabswid
.25376 .12073 m
.70889 .12073 L
s
0 g
5 Mabswid
.70889 .03691 Mdot
.06008 .03691 Mdot
1 0 0 r
2 Mabswid
.25376 .12073 m
.27223 .13911 L
.29236 .1586 L
.31127 .17587 L
.32946 .19107 L
.34882 .20532 L
.36745 .21677 L
.37695 .22166 L
.38726 .22619 L
.39634 .22947 L
.40634 .2323 L
.41091 .23332 L
.41582 .23421 L
.41853 .23461 L
.42101 .23493 L
.42336 .23518 L
.42587 .23539 L
.42714 .23548 L
.42834 .23555 L
.4295 .2356 L
.43058 .23564 L
.4316 .23567 L
.43211 .23568 L
.43267 .23569 L
.43324 .2357 L
.43385 .2357 L
.43442 .2357 L
.43494 .2357 L
.43556 .2357 L
.43587 .23569 L
.43621 .23569 L
.43681 .23568 L
.43738 .23566 L
.43865 .23562 L
.44003 .23556 L
.44254 .23541 L
.44485 .23523 L
.44953 .23471 L
.45389 .23405 L
.46378 .23196 L
.47356 .22909 L
.48244 .2258 L
.50155 .21663 L
.51993 .20531 L
.53949 .19091 L
.55832 .17512 L
.57642 .15856 L
.5957 .13991 L
.61425 .12145 L
.63398 .10181 L
Mistroke
.65298 .08341 L
.67126 .06667 L
.6907 .05036 L
.70889 .03691 L
Mfstroke
0 g
gsave
.71368 .20696 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sen) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.375 moveto
(H) show
86.625 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.26) show
106.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.625 13.375 moveto
(L) show
117.250 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
125.875 13.375 moveto
(-) show
132.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.728969) show
169.500 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{599.875, 199.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006S0000Rb000`400?l00000o`00003oo`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooocL0oooo
001Z0?ooo`030000003oool0oooo0?l0oooo=`3oool006X0oooo00<000000?ooo`3oool0o`3ooolg
0?ooo`00<`3oool>000001/0oooo0`0000020?ooo`030000003oool0oooo00H0oooo0`00003J0?oo
o`h00000CP3oool002l0oooo1000000>0?ooo`D000006`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0=D0oooo1@00000>0?ooo`<00000B`3oool002X0oooo1@00000G0?ooo`@00000
5`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0=40oooo1000000F0?ooo`<00000
B03oool002P0oooo0P00000P0?ooo`8000007P3oool00`000000oooo0?ooo`3=0?ooo`@000007@3o
ool4000004@0oooo000V0?ooo`800000903oool3000001/0oooo00<000000?ooo`3oool0b`3oool2
000002D0oooo0`0000110?ooo`00903oool2000002T0oooo0P00000I0?ooo`800000bP3oool20000
02X0oooo0`00000n0?ooo`008P3oool2000002d0oooo0P00000G0?ooo`030000003oool0oooo0<L0
oooo0P00000_0?ooo`800000?03oool00240oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0<D0oooo0P00000c0?ooo`800000>P3oool00200oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0<<0oooo0P00
000g0?ooo`030000003oool0oooo03L0oooo000N0?ooo`800000=@3oool2000001<0oooo00<00000
0?ooo`3oool0`@3oool2000003X0oooo0P00000g0?ooo`00703oool2000003T0oooo0P00000A0?oo
o`800000`@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03@0oooo000K0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2n0?ooo`80
0000@03oool2000003@0oooo000H0?ooo`030000003oool0000003l0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0000004@0oooo00<000000?ooo`3oool0
<@3oool001L0ooooo`00000B000000030?l000000000oooo04D0oooo0P00000a0?ooo`00603oool3
00000400oooo00<000000?ooo`3oool0303oool200000;/0oooo00<0o`000000003oool0B03oool0
0`000000oooo0?ooo`0^0?ooo`005P3oool2000000040?ooo`000000oooo00000400oooo0P00000<
0?ooo`030000003oool0oooo0;T0oooo00<0o`000?ooo`000000BP3oool00`000000oooo0?ooo`0]
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0;L0oooo0P3o00020?ooo`030000003oool0
oooo04T0oooo0P00000]0?ooo`005@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;H0oooo00<0o`00
0?ooo`3oool00P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02X0oooo000D0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0]@3oool00`3o0000oooo0?ooo`030?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0:@3oool001<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool01`3oool200000;@0oooo00<000000?l0003oool01@3oool00`000000oooo0?ooo`1=0?ooo`80
0000:@3oool00180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`030000
003o0000oooo00H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0V0?ooo`004P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0;40oooo0P3o00080?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool09@3oool00140oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`2_0?ooo`030000003o0000oooo00T0oooo00<000000?ooo`3oool0D@3oool2
000002D0oooo000A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0f0?ooo`<0000000<0oooo0000000000000`0000060?ooo`030000003oool0oooo
0:h0oooo00<000000?l0003oool02P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0280oooo000@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0a0?ooo`<0000000@0oooo0000003oool00000103oool2000000H0oooo0`00002]0?oo
o`80o`00303oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0240oooo000?0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool000000080oooo0`0000000`3oool000000?ooo`040?ooo`030000003oool0oooo0:`0
oooo00<0o`000?ooo`3oool0303oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0200
oooo000>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0c0?ooo`<000000P3oool200000080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`2[0?ooo`030?l0003oool0oooo00d0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0O0?ooo`003P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:X0oooo00<0
o`000?ooo`3oool03P3oool00`000000oooo0?ooo`1G0?ooo`8000007`3oool000d0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`2Y0?ooo`030?l0003oool0oooo00l0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`0L0?ooo`003@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0>`3oool010000000oooo0?ooo`3oool2
00000:P0oooo0P3o000B0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool06`3oool0
00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
03X0oooo00D000000?ooo`3oool0oooo0000002X0?ooo`030?l000000000oooo0180oooo00<00000
0?ooo`3oool0F`3oool00`000000oooo0?ooo`0J0?ooo`00303oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0>P3oool010000000oooo0?ooo`00002W
0?ooo`030?l000000000oooo01<0oooo00<000000?ooo`3oool0803oool3000003T0oooo00<00000
0?ooo`3oool06@3oool000`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo03T0oooo00@000000?ooo`3oool00000B@3oool3000005X0oooo00<0o`00
0000003oool0503oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03T0oooo0P00000I
0?ooo`00303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0>03oool010000000oooo0?ooo`00001:0?ooo`030000003oool0oooo05P0oooo00<0o`00
0000003oool05@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool05P3oool000`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo03P0oooo00@000000?ooo`0000000000BP3oool00`000000oooo0?ooo`1F
0?ooo`030?l000000000oooo01H0oooo00<000000?ooo`3oool0803oool3000003d0oooo00<00000
0?ooo`3oool05@3oool000/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`000000B@3oool3000005L0oooo00<0o`000000
003oool05`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo01@0oooo000;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool000000:80oooo00<0o`000000003oool0603oool00`000000oooo0?ooo`0N0?ooo`P0
0000?03oool00`000000oooo0?ooo`0C0?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo000000180?ooo`D00000
E03oool00`3o000000000?ooo`0I0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0
4P3oool000X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo03D0oooo0`00002D0?ooo`8000002@3oool00`3o000000000?ooo`0J0?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool00`3oool3000000030?ooo`000000000000P0oooo000:
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0d
0?ooo`800000U`3oool00`000000oooo0?ooo`050?ooo`030?l000000000oooo01/0oooo00<00000
0?ooo`3oool07P3oool3000000030?ooo`00000000000440oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo000:0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0d0?ooo`800000U@3oool30000
00H0oooo00<0o`000000003oool0703oool00`000000oooo0?ooo`0O0?ooo`8000000`3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000P0000070?oo
o`002P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0<`3oool2000004T0oooo0P00001B0?ooo`030?l000000000oooo01d0oooo00<000000?ooo`3o
ool07P3oool010000000oooo0000003oool300000480oooo00<000000?ooo`3oool00`00000;0?oo
o`002P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01P0oooo00<000000000o`3o
ool0<P3oool2000004/0oooo00<000000?ooo`3oool0CP3oool00`3o000000000?ooo`0N0?ooo`03
0000003oool0oooo01h0oooo0`0000170?ooo`030000003oool0oooo00d0oooo000:0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0603oool00`000?l000000?ooo`0c0?ooo`800000
B03oool3000004l0oooo00<0o`000000003oool07`3oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo00`0oooo000:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0603o
ool00`000?l0oooo0000000c0?ooo`030000003oool0oooo09P0oooo00<0o`000000003oool0803o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00/0oooo000:0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool05`3oool20000o`80oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`2G0?ooo`030?l000000000oooo0240oooo00<000000?ooo`3oool0J`3oool0
0`000000oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
01L0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
09H0oooo00<0o`000000003oool08P3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo
00T0oooo00090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05`3oool00`000?l0
oooo0?ooo`030?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0U@3oool00`3o0000
00000?ooo`0S0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0203oool003<00000
00<0003o0000000000002@0000000`000?l000000000000X000000030?l000000?l0003o09@0003o
00<0o`000000o`000?l09@000?mj000000002@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo00T0oooo00<0003o0?ooo`3oool0:03oool00`000000o`000?ooo`180?ooo`030000003o
ool0oooo04P0oooo00<0o`000000003oool0BP3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo00P0oooo000:0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0X0?ooo`030000003oool0o`0004P0oooo00<000000?ooo`3oool0A`3oool0
0`3o000000000000001;0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0203oool0
00X0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`070?ooo`80003o:P3oool01000
0000oooo0?ooo`3o00170?ooo`030000003oool0oooo04H0oooo00@0o`000000003oool00000B`3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0
oooo02P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0Y0?ooo`050000003oool0
oooo0?ooo`3o0000SP3oool00`3o000000000?ooo`2S0?ooo`002P3oool00`000000oooo0?ooo`0Y
0?ooo`80003o00@0oooo0000o`3oool0oooo0P000?l/0?ooo`8000000`3oool00`3o0000oooo0?oo
o`2:0?ooo`030?l000000000oooo0:@0oooo000:0?ooo`030000003oool0oooo02X0oooo1P000?l/
0?ooo`8000001@3oool00`3o0000oooo0?ooo`280?ooo`030?l000000000oooo0:D0oooo000:0?oo
o`030000003oool0oooo05`0oooo0P0000060?ooo`030?l0003oool0oooo08H0oooo00<0o`000000
003oool0YP3oool000X0oooo00<000000?ooo`3oool0G03oool2000000L0oooo00<0o`000?ooo`3o
ool0Q03oool00`3o0000oooo0?ooo`2W0?ooo`002P3oool00`000000oooo0?ooo`1L0?ooo`800000
203oool00`3o0000oooo0?ooo`220?ooo`030?l0003oool0oooo0:P0oooo000:0?ooo`030000003o
ool0oooo05`0oooo0`0000080?ooo`030?l0003oool0oooo0800oooo00<0o`000?ooo`3oool0Z@3o
ool000X0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0000000:0?ooo`030?l0003oool0
oooo07h0oooo00<0o`000?ooo`3oool0ZP3oool000/0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0000000;0?ooo`030?l0003oool0oooo07`0oooo00<0o`000?ooo`3oool0Z`3oool000/0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0000000<0?ooo`030?l0003oool0oooo07X0
oooo00<0o`000?ooo`3oool0[03oool000`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0000000=0?ooo`030?l0003oool0oooo07P0oooo00<0o`000?ooo`3oool0[@3oool000`0oooo00<0
00000?ooo`3oool0F@3oool010000000oooo00000000000=0?ooo`030?l0003oool0oooo07H0oooo
00<0o`000?ooo`3oool0[P3oool000`0oooo00<000000?ooo`3oool0F03oool010000000oooo0?oo
o`00000?0?ooo`030?l0003oool0oooo07@0oooo00<0o`000?ooo`3oool0[`3oool000`0oooo00<0
00000?ooo`3oool0F03oool010000000oooo0?ooo`00000@0?ooo`030?l0003oool0oooo0780oooo
00<0o`000?ooo`3oool0/03oool000`0oooo00<000000?ooo`3oool0E`3oool01@000000oooo0?oo
o`3oool000000140oooo00<0o`000?ooo`3oool0L03oool00`3o0000oooo0?ooo`2a0?ooo`003@3o
ool00`000000oooo0?ooo`1F0?ooo`040000003oool0oooo0?ooo`8000004@3oool00`3o0000oooo
0?ooo`1]0?ooo`030000003o0000oooo0;<0oooo000=0?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`80o`00K03oool20?l00;D0oooo000>
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B
0?ooo`030000003o0000oooo06T0oooo00<0o`000?ooo`3oool0]@3oool000h0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01<0oooo00<000000?l0
003oool0I`3oool00`3o0000oooo0?ooo`2f0?ooo`003`3oool00`000000oooo0?ooo`190?ooo`<0
000000<0oooo0000000000000P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01@0
oooo00<000000?l0003oool0I@3oool00`3o0000oooo0?ooo`2g0?ooo`00403oool00`000000oooo
0?ooo`180?ooo`030000003oool0000000@0oooo0P0000060?ooo`<000005@3oool00`000000o`00
0?ooo`1S0?ooo`030?l0003oool0oooo0;P0oooo000A0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`0000000P3oool4000000H0oooo00<000000?ooo`3oool05P3oool00`000000o`000?oo
o`1P0?ooo`80o`00^`3oool00140oooo00<000000?ooo`3oool0A`3oool300000080oooo0`000007
0?ooo`030000003oool0oooo01L0oooo00<000000?l0003oool0GP3oool00`3o000000000?ooo`2k
0?ooo`004P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool06@3oool20?l005`0oooo00<0o`000000003oool0_03oool00180oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo00<000000?l0003o
ool0F03oool20?l00;l0oooo000C0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
1`3oool2000001d0oooo00<0o`000?ooo`3oool0E@3oool00`3o000000000?ooo`2o0?ooo`00503o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07@3o
ool00`3o0000oooo0?ooo`1C0?ooo`030?l000000000oooo0<00oooo000E0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`80o`00D@3oool2
0?l00<<0oooo000E0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo04d0oooo00<0o`000000003oool0``3oool001H0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0240
oooo0P3o001<0?ooo`030?l000000000oooo0<@0oooo000G0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool02`3oool2000002@0oooo0P3o00180?ooo`80o`00GP3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo05<0oooo000H0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0T0?ooo`030000003o0000oooo04D0oooo00<0
o`000000003oool0D03oool7000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo00000002000000030?ooo`000000000000<0oooo0`0000000`3oool000000?oo
o`0=0?ooo`<000000P3oool00`000000oooo00000008000000030?ooo`000000000000<00000<03o
ool001T0oooo0P00000o0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool2
0?l00480oooo0P3o001D0?ooo`H0000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`06
0?ooo`050000003oool000000?ooo`0000000`3oool01@000000oooo0000003oool0000000<0oooo
100000020?ooo`D0000000<0oooo0000003oool00P3oool02@000000oooo0?ooo`000000oooo0000
003oool000000?ooo`03000000030?ooo`000000oooo00800000<03oool001/0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02L0oooo00<000000?l0
003oool0?`3oool00`3o000000000?ooo`1C0?ooo`050000003oool000000000003oool010000004
0?ooo`040000003oool0oooo000000H0oooo100000030?ooo`<0000000<0oooo0000003oool00P3o
ool4000000H0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`3oool000000?ooo`<0
000000<0oooo0000000000000`0000000`3oool000000?ooo`0_0?ooo`00703oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:@3oool00`3o0000oooo
0?ooo`0l0?ooo`030?l0003oool0oooo0680oooo00@000000?ooo`3oool000000`3oool00`000000
oooo000000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000
oooo000000020?ooo`@0000000@0oooo000000000000oooo0P000000103oool000000?ooo`3oool2
000000030?ooo`000000oooo02l0oooo000M0?ooo`800000=`3oool200000180oooo0P00000[0?oo
o`80o`00>P3oool20?l00<h0oooo000O0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0/0?ooo`030?l0003oool0oooo03H0oooo00<0o`000?ooo`3o
ool0cP3oool00200oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo02d0oooo0P3o000d0?ooo`80o`00d@3oool00240oooo0P00000_0?ooo`8000005P3o
ool00`000000oooo0?ooo`0_0?ooo`<0o`00;`3oool20?l00=<0oooo000S0?ooo`800000:P3oool3
000001P0oooo0P00000b0?ooo`030000003o0000o`0002X0oooo00<000000?l0003o0000e@3oool0
02D0oooo0P00000V0?ooo`8000006`3oool00`000000oooo0?ooo`0d0?ooo`80o`009@3oool01000
0000o`000?l0003o003G0?ooo`009`3oool200000280oooo0P00000M0?ooo`030000003oool0oooo
03H0oooo0P3o000Q0?ooo`<0o`00fP3oool002T0oooo1@00000H0?ooo`D000007`3oool00`000000
oooo0?ooo`0h0?ooo`<0o`00703oool20?l00=d0oooo000^0?ooo`D000003`3oool4000002@0oooo
00<000000?ooo`3oool0>`3oool50?l00140oooo0`0000030?l00=l0oooo000c0?ooo`l000007`3o
ool00`000000oooo0?ooo`060?ooo`<00000@03ooolD0?l00>80oooo001Q0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`00H@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0?l0oooo=`3oool006X0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`00
o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00
o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00
o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00
o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00\
\>"],
  ImageRangeCache->{{{94.4375, 513.313}, {523.75, 384.875}} -> {-4.16799, \
6.54964, 0.0145346, 0.0145346}}],

Cell[TextData[{
  "Il grafico emerge ora con immediatezza e ci permette di riconoscere con \
facilit\[AGrave] gli intervalli dove ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\[Alpha])\)]],
  " \[EGrave] crescente ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, \(\[Pi]\/2\)[\[Union]] \(3\/2\) \[Pi], 
        2  \[Pi]]\)\)]],
  " e dove invece risulta decrescente ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(]\) \(\[Pi]\/2\)\), \(3\/2\) \
\(\(\[Pi]\)\([\)\)\)]],
  ". Appaiono confermati pure i valori dell'angolo in corrispondenza dei \
quali il seno assume i valori massimo, ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\[Pi]\/2) = 1\)]],
  ", e minimo ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\(3\/2\) \[Pi]) = \(-1\)\)]],
  "cos\[IGrave] come il codominio ",
  Cell[BoxData[
      \(TraditionalForm\`\([\(-1\), 1]\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Possiamo infine dedurre un'altra importante propriet\[AGrave] della \
funzione seno e del suo grafico. Se estendiamo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " a valori maggiori di ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  " la configurazione geometrica del triangolo ",
  Cell[BoxData[
      FormBox[
        StyleBox["OQP",
          FontSlant->"Italic"], TraditionalForm]]],
  " (",
  ButtonBox["fig. 3",
    ButtonData:>"figura3",
    ButtonStyle->"Hyperlink"],
  ") rimane inalterata e ci\[OGrave] evidentemente a seguito del modo con cui \
abbiamo esteso il dominio degli angoli. Di conseguenza la funzione ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\[Alpha])\)]],
  " riprende gli stessi valori ma in corrispondenza di angoli diversi che \
differiscono dai precedenti per multipli di ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  ". L'animazione seguente mostra quanto avviene per angoli nell'intervallo \
",
  Cell[BoxData[
      \(TraditionalForm\`\([0, 4  \[Pi]]\)\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(numImmag = 100;\)\), "\n", 
    \(\(sinGraf = 
        Plot[Sin[x], {x, 0, 4  \[Pi]}, 
          Ticks \[Rule] {Range[1/2, 4, 1/2] \[Pi], Automatic}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(coordinateSin = 
        Table[{x, Sin[x]}, {x, 0, 4  \[Pi], 2  \[Pi]/numImmag}];\)\), "\n", 
    \(\(listaSin1 = \(Show[sinGraf, 
              If[#[\([1]\)] \[NotEqual] 0, 
                ParametricPlot[{Sign[t] t\ Cos[t] - 20  \[Pi], 
                        Sign[t]\ t\ Sin[t]}/200  \[Pi], {t, 
                    Sign[#[\([1]\)]] 2  \[Pi], 
                    Sign[#[\([1]\)]] 2\ \[Pi] + #[\([1]\)]}, 
                  Axes \[Rule] False, DisplayFunction \[Rule] Identity, 
                  PlotStyle \[Rule] {AbsoluteThickness[2], colBlu}], 
                Graphics[{Point[{Cos[#[\([1]\)]] - 1, 
                        Sin[#[\([1]\)]]}]}]], \[IndentingNewLine]Graphics[
                Circle[{\(-1\), 0}, 1]], 
              Graphics[{Line[{{\(-1\), 0}, {Cos[#[\([1]\)]] - 1, 
                        Sin[#[\([1]\)]]}, #, {#[\([1]\)], 0}}], 
                  Line[{{Cos[#[\([1]\)]] - 1, 
                        Sin[#[\([1]\)]]}, {Cos[#[\([1]\)]] - 1, 
                        0}}], {AbsoluteThickness[2], colBlu, 
                    Line[{{0, 0}, {#[\([1]\)], 
                          0}}]}}], \
\[IndentingNewLine]Graphics[{AbsolutePointSize[5], Point[#], 
                  Point[{Cos[#[\([1]\)]] - 1, 
                      Sin[#[\([1]\)]]}]}], \[IndentingNewLine]Epilog \[Rule] \
{{Text["\<sen(\>" <> ToString[N[#[\([1]\)]/\[Pi]]] <> "\< \[Pi]) = \>" <> 
                        ToString[N[#[\([2]\)]]], {3, 0.75}, {\(-1\), 0}, 
                      TextStyle \[Rule] 
                        stileTesto]}}, \[IndentingNewLine]DisplayFunction \
\[Rule] Identity] &\) /@ coordinateSin;\)\), "\n", 
    \(\(listaSin2 = \(If[#[\([1]\)] \[Equal] 0, 
              Show[Graphics[{AbsolutePointSize[5], Point[{0, 0}]}], 
                DisplayFunction \[Rule] Identity], 
              Plot[Sin[x], {x, 0, #[\([1]\)]}, Axes -> False, 
                PlotStyle \[Rule] {AbsoluteThickness[2], colRosso}, 
                DisplayFunction \[Rule] Identity]] &\) /@ 
          coordinateSin;\)\), "\n", 
    \(\(\(Show[#, DisplayFunction \[Rule] $DisplayFunction, 
            AspectRatio \[Rule] Automatic, ImageSize \[Rule] {600, 150}] &\) /@ 
        Thread[{listaSin1, listaSin2}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1373 
%%ImageSize: 600 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.154574 0.0653822 0.0686513 0.0653822 [
[.25728 .05615 -6.09375 -17.8125 ]
[.25728 .05615 6.09375 0 ]
[.35998 .05615 -4.09375 -10.9375 ]
[.35998 .05615 4.09375 0 ]
[.46268 .05615 -8.96875 -20 ]
[.46268 .05615 8.96875 0 ]
[.56538 .05615 -7.09375 -10.9375 ]
[.56538 .05615 7.09375 0 ]
[.66808 .05615 -8.96875 -19.875 ]
[.66808 .05615 8.96875 0 ]
[.77079 .05615 -7.09375 -10.9375 ]
[.77079 .05615 7.09375 0 ]
[.87349 .05615 -8.96875 -19.875 ]
[.87349 .05615 8.96875 0 ]
[.97619 .05615 -7.09375 -10.9375 ]
[.97619 .05615 7.09375 0 ]
[.14207 .00327 -13.9375 -5.46875 ]
[.14207 .00327 0 5.46875 ]
[.14207 .03596 -20.625 -5.46875 ]
[.14207 .03596 0 5.46875 ]
[.14207 .10134 -15.125 -5.46875 ]
[.14207 .10134 0 5.46875 ]
[.14207 .13403 -8.4375 -5.46875 ]
[.14207 .13403 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .1373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25728 .06865 m
.25728 .0749 L
s
gsave
.25728 .05615 -67.0938 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

65.000 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 14.500 moveto
(\\200\\200) show
66.188 14.500 moveto
(\\200\\200) show
68.313 14.500 moveto
(\\200) show
68.813 14.500 moveto
(\\200) show
64.875 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.35998 .06865 m
.35998 .0749 L
s
gsave
.35998 .05615 -65.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.46268 .06865 m
.46268 .0749 L
s
gsave
.46268 .05615 -69.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
70.875 10.750 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.688 moveto
(\\200\\200\\200\\200) show
68.313 16.688 moveto
(\\200\\200\\200\\200) show
72.563 16.688 moveto
(\\200\\200) show
74.563 16.688 moveto
(\\200) show
67.750 23.000 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.56538 .06865 m
.56538 .0749 L
s
gsave
.56538 .05615 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.66808 .06865 m
.66808 .0749 L
s
gsave
.66808 .05615 -69.9688 -23.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
70.875 10.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.563 moveto
(\\200\\200\\200\\200) show
68.313 16.563 moveto
(\\200\\200\\200\\200) show
72.563 16.563 moveto
(\\200\\200) show
74.563 16.563 moveto
(\\200) show
67.750 22.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.77079 .06865 m
.77079 .0749 L
s
gsave
.77079 .05615 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.87349 .06865 m
.87349 .0749 L
s
gsave
.87349 .05615 -69.9688 -23.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
70.875 10.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.563 moveto
(\\200\\200\\200\\200) show
68.313 16.563 moveto
(\\200\\200\\200\\200) show
72.563 16.563 moveto
(\\200\\200) show
74.563 16.563 moveto
(\\200) show
67.750 22.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 .06865 m
.97619 .0749 L
s
gsave
.97619 .05615 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 .06865 m
1 .06865 L
s
.15457 .00327 m
.16082 .00327 L
s
gsave
.14207 .00327 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.15457 .03596 m
.16082 .03596 L
s
gsave
.14207 .03596 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.15457 .10134 m
.16082 .10134 L
s
gsave
.14207 .10134 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.15457 .13403 m
.16082 .13403 L
s
gsave
.14207 .13403 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.15457 .00981 m
.15832 .00981 L
s
.15457 .01635 m
.15832 .01635 L
s
.15457 .02288 m
.15832 .02288 L
s
.15457 .02942 m
.15832 .02942 L
s
.15457 .0425 m
.15832 .0425 L
s
.15457 .04904 m
.15832 .04904 L
s
.15457 .05557 m
.15832 .05557 L
s
.15457 .06211 m
.15832 .06211 L
s
.15457 .07519 m
.15832 .07519 L
s
.15457 .08173 m
.15832 .08173 L
s
.15457 .08827 m
.15832 .08827 L
s
.15457 .0948 m
.15832 .0948 L
s
.15457 .10788 m
.15832 .10788 L
s
.15457 .11442 m
.15832 .11442 L
s
.15457 .12096 m
.15832 .12096 L
s
.15457 .1275 m
.15832 .1275 L
s
.25 Mabswid
.15457 0 m
.15457 .1373 L
s
0 0 m
1 0 L
1 .1373 L
0 .1373 L
closepath
clip
newpath
.5 Mabswid
.15457 .06865 m
.1879 .10056 L
.20525 .11441 L
.21443 .12049 L
.22425 .12587 L
.22901 .12802 L
.23351 .12976 L
.23789 .13118 L
.24193 .13224 L
.24576 .13302 L
.24772 .13334 L
.24982 .13361 L
.25092 .13373 L
.25193 .13381 L
.25295 .13389 L
.2539 .13395 L
.255 .13399 L
.25558 .13401 L
.2562 .13402 L
.25679 .13403 L
.25735 .13403 L
.25839 .13402 L
.2594 .134 L
.26047 .13396 L
.26148 .1339 L
.26241 .13383 L
.26467 .13362 L
.26682 .13334 L
.27108 .13258 L
.27571 .13145 L
.28399 .12865 L
.29165 .1252 L
.30775 .1155 L
.32553 .10153 L
.36021 .06842 L
.39358 .03651 L
.41053 .02298 L
.4195 .01702 L
.42908 .01172 L
.43835 .00774 L
.44274 .00629 L
.44678 .00519 L
.45085 .00434 L
.45299 .00399 L
.45526 .00369 L
.45723 .0035 L
.45817 .00342 L
.45907 .00337 L
.46012 .00332 L
.46109 .00329 L
Mistroke
.46213 .00327 L
.46326 .00327 L
.46382 .00328 L
.46441 .00329 L
.46547 .00333 L
.46661 .00339 L
.46786 .00347 L
.4701 .00369 L
.47218 .00396 L
.47609 .00464 L
.48026 .00562 L
.48513 .00709 L
.48974 .00879 L
.49837 .01277 L
.51558 .02353 L
.53148 .03625 L
.5654 .06867 L
.59801 .09994 L
.61614 .11446 L
.62407 .11977 L
.63274 .12471 L
.64062 .12835 L
.64903 .13128 L
.65369 .13245 L
.65791 .13324 L
.65995 .13353 L
.66102 .13365 L
.66216 .13377 L
.66315 .13385 L
.66424 .13392 L
.66523 .13397 L
.66616 .13401 L
.66725 .13403 L
.66779 .13403 L
.6684 .13403 L
.66947 .13402 L
.67047 .13399 L
.67104 .13397 L
.67165 .13394 L
.67273 .13387 L
.67389 .13378 L
.67516 .13365 L
.6773 .13339 L
.67958 .13302 L
.6837 .13218 L
.68801 .13102 L
.69208 .12968 L
.6997 .12654 L
.71694 .11661 L
.73286 .10449 L
Mistroke
.76682 .07261 L
.79948 .04087 L
.81764 .0257 L
.83425 .01469 L
.84246 .01049 L
.84679 .00864 L
.85141 .00696 L
.85585 .00563 L
.85987 .00468 L
.86181 .00431 L
.86391 .00397 L
.8659 .00371 L
.86772 .00352 L
.8687 .00344 L
.86977 .00337 L
.8709 .00332 L
.87196 .00329 L
.87296 .00327 L
.87402 .00327 L
.87493 .00328 L
.87593 .00331 L
.8765 .00334 L
.87709 .00337 L
.87816 .00344 L
.88057 .00365 L
.88266 .00391 L
.88493 .00427 L
.88949 .00522 L
.89435 .00657 L
.90311 .00986 L
.91195 .01426 L
.92154 .02014 L
.93893 .03337 L
.97424 .06671 L
.97619 .06865 L
Mfstroke
0 0 1 r
2 Mabswid
.0965 .06865 m
.09652 .06881 L
.09654 .06898 L
.09656 .06914 L
.09657 .06929 L
.09657 .06938 L
.09657 .06946 L
.09658 .06955 L
.09658 .0696 L
.09658 .06965 L
.09658 .06974 L
.09658 .06983 L
.09657 .06992 L
.09657 .07 L
.09656 .07009 L
.09656 .07018 L
.09654 .07035 L
.09652 .07056 L
.09649 .07074 L
.09642 .0711 L
.09633 .07145 L
.09608 .0722 L
.09576 .07288 L
.09532 .07359 L
.09476 .07429 L
.09422 .07483 L
.09357 .07535 L
.0929 .07577 L
.09224 .07611 L
.09142 .07641 L
.09098 .07654 L
.09049 .07665 L
.09029 .07668 L
.09007 .07671 L
.08987 .07674 L
.08966 .07676 L
.08954 .07677 L
.08942 .07677 L
.0893 .07678 L
.08923 .07678 L
.08917 .07678 L
.08906 .07678 L
.089 .07678 L
.08894 .07678 L
.08883 .07678 L
.08872 .07678 L
.08861 .07677 L
.08849 .07676 L
.08828 .07675 L
.08807 .07673 L
Mistroke
.08787 .0767 L
.08743 .07663 L
.08696 .07652 L
.08611 .07625 L
.08536 .07593 L
.08453 .07547 L
.08381 .07495 L
.08302 .07426 L
.08236 .07353 L
.08179 .07273 L
.08134 .07194 L
.08093 .07101 L
.08075 .07051 L
.0806 .06996 L
.08049 .06948 L
.08044 .06922 L
.0804 .06894 L
.08037 .06868 L
.08035 .06844 L
.08033 .06822 L
.08032 .0681 L
.08032 .06798 L
.08031 .0679 L
.08031 .06783 L
.08031 .06775 L
.08031 .06769 L
.08031 .06756 L
.08031 .06742 L
.08031 .06735 L
.08032 .06727 L
.08032 .06714 L
.08033 .06698 L
.08034 .06683 L
.08037 .06656 L
.0804 .06628 L
.08049 .06576 L
.08061 .06524 L
.08074 .06476 L
.08113 .06369 L
.08163 .06268 L
.0823 .06165 L
.08386 .05997 L
.08478 .05925 L
.08589 .05858 L
.087 .05807 L
.08807 .05772 L
.08867 .05757 L
.089 .0575 L
.08934 .05744 L
.08965 .0574 L
Mistroke
.08998 .05736 L
.09013 .05735 L
.09029 .05734 L
.09044 .05733 L
.09058 .05732 L
.09066 .05732 L
.09075 .05732 L
.0909 .05731 L
.09098 .05731 L
.09107 .05731 L
.09123 .05731 L
.09138 .05732 L
.09152 .05732 L
.09167 .05733 L
.09183 .05734 L
.0922 .05737 L
.09255 .05741 L
.0932 .05751 L
.09382 .05765 L
.09438 .0578 L
.09564 .05826 L
.09675 .05881 L
.09774 .05944 L
.09878 .06025 L
.09977 .06123 L
.10058 .06223 L
.10135 .06342 L
.10193 .06458 L
.10237 .06572 L
.10256 .06639 L
.10274 .06713 L
.1028 .06747 L
.10286 .06784 L
.1029 .06816 L
.10294 .0685 L
.10295 .06867 L
.10296 .06884 L
.10297 .06899 L
.10298 .06914 L
.10298 .06928 L
.10299 .06943 L
.10299 .06959 L
.10299 .06974 L
.10299 .06992 L
.10298 .07008 L
.10298 .07026 L
.10297 .07045 L
.10294 .07077 L
.10291 .07112 L
.10287 .07148 L
Mistroke
.10281 .07186 L
.10267 .07256 L
.1023 .07385 L
.10204 .07457 L
.10171 .07532 L
.10101 .07661 L
.10022 .07775 L
.09924 .07889 L
.09715 .08068 L
.09585 .08148 L
.09431 .0822 L
.09358 .08247 L
.09279 .08271 L
.09208 .08288 L
.09131 .08302 L
.09092 .08308 L
.09048 .08313 L
.09029 .08315 L
.09008 .08317 L
.08989 .08318 L
.08971 .08319 L
.0896 .0832 L
.08948 .0832 L
.08936 .0832 L
.08924 .08321 L
.08912 .08321 L
.089 .08321 L
.08889 .08321 L
.08879 .0832 L
.08859 .0832 L
.08848 .0832 L
.08838 .08319 L
.08817 .08318 L
.08795 .08317 L
.08753 .08313 L
.08708 .08308 L
.08627 .08295 L
.08549 .08277 L
.08477 .08258 L
.0833 .08205 L
.08196 .08141 L
.08057 .08055 L
.07918 .07946 L
.07797 .07828 L
.07681 .07684 L
.07586 .07534 L
.07514 .07386 L
.07482 .07305 L
.07453 .07215 L
.07431 .07134 L
Mistroke
.07413 .07047 L
.07401 .06968 L
.07396 .06922 L
.07394 .069 L
.07392 .0688 L
.07391 .06861 L
.0739 .0684 L
.07389 .06822 L
.07388 .06804 L
.07388 .06786 L
.07388 .06765 L
.07388 .06744 L
.07388 .06723 L
.07389 .06703 L
.0739 .06681 L
.07391 .0666 L
.07393 .06641 L
.07397 .06594 L
.07402 .0655 L
.07416 .06463 L
.07436 .06369 L
.07487 .06205 L
.07548 .06057 L
.077 .05801 L
.07806 .05668 L
.07919 .05552 L
Mfstroke
0 g
.5 Mabswid
newpath
.08919 .06865 .06538 0 365.73 arc
s
.08919 .06865 m
.04752 .01827 L
.8283 .01827 L
.8283 .06865 L
s
.04752 .01827 m
.04752 .06865 L
s
0 0 1 r
2 Mabswid
.15457 .06865 m
.8283 .06865 L
s
0 g
5 Mabswid
.8283 .01827 Mdot
.04752 .01827 Mdot
1 0 0 r
2 Mabswid
.15457 .06865 m
.1819 .09519 L
.19613 .10747 L
.21171 .11879 L
.21871 .12299 L
.2262 .12679 L
.23322 .12966 L
.23971 .13169 L
.24321 .13253 L
.24693 .13322 L
.24886 .13349 L
.25067 .1337 L
.25265 .13387 L
.25376 .13394 L
.25429 .13397 L
.25478 .13399 L
.25565 .13401 L
.25659 .13403 L
.25745 .13403 L
.25827 .13403 L
.25873 .13402 L
.25922 .134 L
.2601 .13397 L
.26104 .13392 L
.26208 .13386 L
.26381 .13371 L
.26567 .1335 L
.26902 .13298 L
.27276 .13221 L
.27622 .13131 L
.28405 .12863 L
.29095 .12555 L
.29828 .12159 L
.32499 .10199 L
.35343 .07519 L
.3808 .04818 L
.3947 .03554 L
.4099 .02344 L
.42442 .01415 L
.4309 .01084 L
.43793 .0079 L
.4418 .00657 L
.44537 .00555 L
.44872 .00475 L
.4524 .00408 L
.45399 .00385 L
.4557 .00364 L
.45732 .00349 L
.45879 .00338 L
.45965 .00334 L
Mistroke
.46045 .00331 L
.46133 .00328 L
.46226 .00327 L
.46315 .00327 L
.46399 .00328 L
.46474 .0033 L
.46555 .00333 L
.46643 .00338 L
.46724 .00343 L
.46904 .00358 L
.47071 .00376 L
.47229 .00397 L
.47584 .00459 L
.47968 .00547 L
.48743 .0079 L
.49459 .0109 L
.50782 .01825 L
.52241 .02871 L
.55089 .05427 L
.57829 .08148 L
.60743 .10786 L
.62198 .11844 L
.62907 .12273 L
.6355 .12608 L
.64177 .12881 L
.64856 .13114 L
.65229 .13214 L
.65573 .13287 L
.65902 .13341 L
.66067 .13361 L
.66249 .13379 L
.66427 .13392 L
.66527 .13397 L
.66619 .13401 L
.667 .13402 L
.66789 .13403 L
.66883 .13403 L
.6697 .13401 L
.6705 .13399 L
.67135 .13395 L
.67287 .13386 L
.67449 .13372 L
.67628 .13352 L
.67998 .13295 L
.68394 .13212 L
.69107 .13004 L
.6983 .12717 L
.70615 .12326 L
.7204 .1142 L
.74932 .08973 L
Mistroke
.77718 .06227 L
.80395 .03689 L
.8283 .01827 L
Mfstroke
0 g
gsave
.35072 .11769 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sen) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.500 13.375 moveto
(H) show
81.625 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.28) show
101.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
106.625 13.375 moveto
(L) show
112.250 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
120.875 13.375 moveto
(-) show
127.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.770513) show
164.500 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 150},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;^0000^b000`400?l00000o`00003oo`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0
ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool0
0?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3o
ooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00
o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oo
oo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o
0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0oooo
l03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0
ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`
0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3o
oooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00I03oool00`3ooml0
W4Qd0;ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooomj0?ooo`00I03oool00`3ooml0W4Qd
0;ooo`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooomj0?ooo`00?P3oool9000001@0oooo00<0
okmd0000000000000P0000001`00B9`0gooo0?ooo`3oool0oooO09a8M02oool0303oool600000=`0
oooo2`3o003o0?ooobX0oooo2@00001L0?ooo`00>@3oool5000000T0oooo1@00000H0?ooo`030?oo
g`2LB7@0_ooo00`0oooo00<000000?ooo`3oool0e`3ooolK0?l00?l0oooo703oool6000000T0oooo
1P00001F0?ooo`00=@3oool4000001<0oooo1@00000A0?ooo`050?oog`2LW;l0oooO09a8M02oool0
303oool00`000000oooo0?ooo`3D0?ooo``0o`002@3oool<0?l00?l0oooo5P3oool3000001D0oooo
1000001B0?ooo`00<P3oool3000001`0oooo0P00000@0?ooo`040?noM0000000001d0;ooo``0oooo
00<000000?ooo`3oool0dP3oool60?l001T0oooo1`3o003o0?ooo`l0oooo1000000L0?ooo`<00000
C`3oool00300oooo0P00000Q0?ooo`8000003`3oool00`3ookl0M01d0;ooo`0<0?ooo`030000003o
ool0oooo0<l0oooo1P3o000O0?ooo`H0o`00o`3oool;0?ooo`8000008`3oool4000004/0oooo000^
0?ooo`8000009@3oool3000001/0oooo1000003;0?ooo`L0o`00903oool60?l00?l0oooo1P3oool2
000002T0oooo0P0000190?ooo`00;03oool2000002X0oooo0P00000I0?ooo`030000003oool0oooo
0<T0oooo1`3o000Y0?ooo`H0o`00o`3oool20?ooo`800000;@3oool2000004L0oooo000Z0?ooo`80
0000;P3oool2000001L0oooo00<000000?ooo`3oool0a`3oool60?l002l0oooo1@3o003m0?ooo`80
0000<@3oool2000004D0oooo000X0?ooo`800000<P3oool2000001D0oooo00<000000?ooo`3oool0
aP3oool40?l000030000003oool0oooo0340oooo1@3o003i0?ooo`800000=@3oool2000004<0oooo
000R0?ooo`8000000P3oool2000003H0oooo0P00000C0?ooo`030000003oool0oooo0<@0oooo103o
00000`000000oooo0?ooo`0e0?ooo`D0o`00l03oool2000000<0oooo0P00000i0?ooo`030000003o
ool0oooo0400oooo000Q0?ooo`D00000>P3oool00`000000oooo0?ooo`0@0?ooo`@00000`P3oool4
0?l003/0oooo1@3o003]0?ooo`H00000?03oool200000400oooo000P0?ooo`H00000>`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0<40oooo103o000o0?ooo`@0o`00j`3oool30000
00030?l000000000000003l0oooo0P00000n0?ooo`00803ooooo000001L00000103o0012000000@0
o`00j`0000030?l000030000003oool0oooo03l0oooo0P00000l0?ooo`008@3oool4000003h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`2n0?ooo`@0o`00A@3oool40?l00>P0oooo
103o00000`000000oooo0?ooo`120?ooo`030000003oool0oooo03T0oooo000P0?ooo`@0000000<0
oooo0000003oool0?@3oool2000000d0oooo00<000000?ooo`3oool0_@3oool40?l004P0oooo0`3o
003V0?ooo`@0o`0000<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0h0?ooo`007`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0;0?ooo`@00000^`3oool30?l004/0oooo103o003R0?ooo`@0o`000P3oool00`000000oooo0?oo
o`150?ooo`800000>03oool001h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000o0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0^P3oool40?l004d0oooo103o
003P0?ooo`@0o`000`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo03D0oooo000M
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000o0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0^@3oool40?l002@0oooo00<0_g@00000000000000P00
00000`18W=l0oooo0?ooo`0T0?ooo`@0o`00JP3oool00`2oM0000000000000020000000304RLg`3o
ool0oooo06/0oooo0`3o00050?ooo`030000003oool0oooo01`0oooo00<0_g@00000000000000P00
00000`18W=l0oooo0?ooo`0T0?ooo`030000003oool0oooo03@0oooo000M0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0^03oool30?l002H0oooo00<0oooO09a8001d_ol0:P3oool4
0?l006T0oooo00<0oooO09a8001d_ol0KP3oool40?l000H0oooo00<000000?ooo`3oool0703oool0
0`3ooml0W4P007Boo`0Z0?ooo`800000=03oool001`0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`2f0?ooo`@0o`00:@3oool00`2oM00007Bo0?ooo`0Z0?ooo`<0o`00JP3oool00`2o
M00007Bo0?ooo`1[0?ooo`@0o`001`3oool00`000000oooo0?ooo`0N0?ooo`030;md0000M;l0oooo
02X0oooo00<000000?ooo`3oool0<@3oool001/0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool01`3oool4000004H0
oooo00<0_g@00000000000000P0000000`18W=l0oooo0?ooo`1V0?ooo`@0o`00:`3oool00`3o_g@0
07Bo0?ooo`0Z0?ooo`<0o`00JP3oool00`3o_g@007Bo0?ooo`1Y0?ooo`<0o`002@3oool00`000000
oooo0?ooo`0O0?ooo`030?noM000M;l0oooo02X0oooo00<000000?ooo`3oool0<03oool001X0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`170?ooo`030?oog`2LB000M;oo06X0oooo
0`3o000^0?ooo`030=nLB01d_ol0oooo02X0oooo0`3o001Z0?ooo`030=nLB01d_ol0oooo06H0oooo
103o000:0?ooo`030000003oool0oooo0200oooo00<0gia807Boo`3oool0:P3oool200000300oooo
000J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0]0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000D0B9cO
0?ooo`3oool0oooo000000070?ooo`030000003oool0oooo04T0oooo00<0_g@0001d_`3oool0IP3o
ool40?l002/0oooo00H0okmd001d_`3oool0oooo0;md001d_ol/0?ooo`<0o`00I@3oool01P3o_g@0
07Bo0?ooo`3oool0_g@007BoofH0oooo103o000;0?ooo`030000003oool0oooo01`0oooo00H0okmd
001d_`3oool0oooo0;md001d_ol]0?ooo`030000003oool0oooo02d0oooo000I0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0[0?ooo`060?noM000
B9`0gooo0?noM000B9`0gooo0`3oool01P3o_g@0B9cO0?ooo`3oool0gia807Boo`80oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`1:0?ooo`030?noM000M;l0oooo06@0oooo103o000/
0?ooo`060?oog`2LB000000000000000B9`0gooo;@3oool40?l006<0oooo00H0oooO09a800000000
00000018W03OoomT0?ooo`@0o`003@3oool00`000000oooo0?ooo`0L0?ooo`060?oog`2LB0000000
00000000B9`0gooo;P3oool00`000000oooo0?ooo`0/0?ooo`006@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`3o_g@0000000000002
000000080018W03Oool0gia804RLg`3oool0oono07@0M02oool70?ooo`030?noM018W=l0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1;0?ooo`030=nLB01d_ol0oooo0680
oooo0`3o001R0?ooo`@0o`00b`3oool40?l000h0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`0[0?ooo`00603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0:@3oool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000
M02oool0oooo0=nLB01d_ol30?ooo`030000003oool0oooo00@0oooo1P0000140?ooo`060?noM000
M;l0oooo0?ooo`2oM000M;ooHP3oool30?l006D0oooo0`3o00390?ooo`<0o`00403oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo02X0oooo000G0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0X0?ooo`060=nLB018W=l0oooo0?oo_`1d
07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`170?ooo`060?oog`2LB000000000000000B9`0goooH@3oool30?l006L0oooo
0`3o00370?ooo`<0o`004@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo02T0oooo
000F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0W0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0[@3oool30?l002`0oooo00H0oono07@00000
M7@0M000001dM01d000300000003001dM01d0000000000<0000000<007Bo0?ooo`3oool0:`3oool3
0?l005T0oooo00`0oono07@00000M7@0M000001dM01d000007AG03D00000=EL0M000001dM01d0004
00000003001d_`3oool0oooo05T0oooo0`3o000B0?ooo`030000003oool0oooo01H0oooo00`0oono
07@00000M7@0M000001dM01d000007AG03D00000=EL0M000001dM01d000300000003000eS`3oool0
oooo02`0oooo00<000000?ooo`3oool0:03oool001H0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo00@0_g@00000000004P0W=oo1@3oool0
1@2oM00000000000000004P0W=oo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`2/0?ooo`<0o`00J`3oool30?l00<<0oooo0`3o000C0?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool09`3oool001D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2[
0?ooo`<0o`00K@3oool30?l00<40oooo0`3o000D0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool09P3oool001D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo03X0oooo00@000000?ooo`3oool0oooo100000140?ooo`090?oo_`1d0000
07Ad07@00000000007Ad07@00000000003F?05`0oooo0`3o001_0?ooo`<0o`00_`3oool30?l001D0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0U0?ooo`00503oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>@3oool01@000000oooo
0?ooo`3oool0000009H0oooo00H0oono07@0B02Lgol0omnL04P0M02oool?0?ooo`<0o`00L@3oool3
0?l000/0oooo00<0_g@00000000000000P0000001`18W=l0oono07@0B02Lgol0omnL04P0M02oool0
SP3oool0102oM000000000000000M;l20?ooo`060?oo_`1d04P0W=oo0?oOW01807@0_ooo303oool3
0?l001H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0=0?ooo`0:0?noM018W=l0
oooo0?ooo`3ookl0M01809cOo`3ogi`0B01d0;ooo`d0oooo000D0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0i0?ooo`040000003oool0oooo0000
09L0oooo00@0oono07Ad_`3ogi`0M9cO3`3oool30?l003@0oooo00/0_g@000000000000007Bo0?oo
o`3ookl0M01809cOo`3ogi`0B01d0;ooo`0d0?ooo`<0o`002P3oool00`3ooml0W4P007Boo`040?oo
o`040?oo_`1dM;l0omnL07BLghh0oooo00H0okmd04RLg`3oool0oooo0=nLB018W=l20?ooo`040?oo
_`1dM;l0omnL07BLg``0oooo0`3o000G0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0303oool00`3o_g@0B9cO0?ooo`020?ooo`040?oo_`1dM;l0omnL07BLg`h0oooo000D0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0h0?ooo`04
0000003oool0oooo000009P0oooo00<0_gAd0;oog`2LW;l03P3oool30?l003@0oooo00/0okmd04RL
g`3oool0oooo0=nLB018W=l0oooo0?oo_`1dM;l0omnL07BLg`0f0?ooo`@0o`002P3oool00`2oM000
07Bo0?ooo`030?ooo`030;mdM02ooml0W9bo0480oooo00@0_g@0000000000000B9cO0P3oool01P3o
okl0M01809cOo`3ogi`0B01d0;oood@0oooo00<0gia804RLg`3oool00P3oool00`2oM7@0_ooO09bL
_`0;0?ooo`<0o`00603oool00`000000oooo0?ooo`0I0?ooo`030?oOW018M;l0oooo00<0oooo00H0
oono07@0B02Lgol0omnL04P0M02ooole0?ooo`030000003oool0oooo00P0oooo00<0gia800000000
00000P0000001`18W=l0oooo0?ooo`3oool0_gAd0;oog`2LW;l03P3oool001@0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03P0oooo00@000000?oo
o`3oool00000U`3oool01@2oW9`0gkmd07Boo`2oW9`0gooo00`0oooo0`3o000i0?ooo`070=nLB018
W=l0oooo0?ooo`2oM7@0_ooO09bL_`0g0?ooo`@0o`002P3oool02@3o_g@007Bo0?ooo`3oool0_ibL
0=noM01d_ol0_ibL0=ooo`100?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo0P3oool0103ookl0
M7Bo0?oOW01dW=m30?ooo`030;md00000000B9cO00<0oooo00D0_ibL0=noM01d_ol0_ibL0=ooo`08
0?ooo`@0o`006@3oool00`000000oooo0?ooo`0I0?ooo`030?oo_`1dB9`0gooo00@0oooo00@0oono
07Ad_`3ogi`0M9cO=`3oool00`000000oooo0?ooo`070?ooo`050?oo_`1d07@0_ooo0?noM018W=l0
0`3oool01@2oW9`0gkmd07Boo`2oW9`0gooo00d0oooo000D0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0h0?ooo`030000003oool0000000<00000
AP3oool01P3ookl0M01809cOo`3ogi`0B01d0;ooodP0oooo00H0omnL04P00000000000000000B02L
gol:0?ooo`<0o`00>03oool00`2oM000000004RLg`020?ooo`050;nLW03O_g@0M;oo0;nLW03Oool0
>03oool30?l000X0oooo00D0gia807Boo`3oool0omnL04P00002000000030000B02Lgol0oooo0480
oooo00<0okmd04RLg`3oool00P3oool00`2oM7@0_ooO09bL_`140?ooo`030?oo_`1d07@0_ooo0080
oooo00H0omnL04P00000000000000000B02Lgol60?ooo`@0o`006P3oool00`000000oooo0?ooo`0J
0?ooo`030;mdB02Lgol0oooo00@0oooo00<0_gAd0;oog`2LW;l0>03oool00`000000oooo0?ooo`07
0?ooo`040?oOW018B9`0gkmd04RLg`<0oooo00H0omnL04P00000000000000000B02Lgol<0?ooo`00
4`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0000001:0?ooo`040?oo_`1dM;l0omnL07BLgeP0oooo0`3o000j0?ooo`06
0?oo_`1d07@0_ooo0?ooo`3ogi`0B0000P0000000`0004P0W=oo0?ooo`0g0?ooo`<0o`001@3oool0
1P3o_g@007Bo0?ooo`3oool0_g@007BoodH0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol20?oo
o`050;nLW03O_g@0M;oo0;nLW03Oool0@03oool01P3o_g@007Bo0?ooo`3ookl0M01d0;ooo`d0oooo
0`3o000L0?ooo`030000003oool0oooo01X0oooo00<0okmd001d_`3oool00`3oool01@2oW9`0gkmd
07Boo`2oW9`0gooo03P0oooo0P0000080?ooo`030?noM0000000B9cO01D0oooo000C0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`800000
B`3oool00`2oM7@0_ooO09bL_`1G0?ooo`<0o`00>03oool01P3o_g@007Bo0?ooo`3ookl0M01d0;oo
od00oooo0`3o00040?ooo`060?oog`2LB000000000000000B9`0goooAP3oool01@3ookl0M4Q804P0
0000000007Bo00<0oooo00H0omnL04P00000000000000000B02Lgom00?ooo`040;md000000000000
07Boo`d0oooo0`3o000M0?ooo`030000003oool0oooo01/0oooo00<0_gA809cOo`3oool00P3oool0
1P3ogi`0B000000000000000001809cOocT0oooo00<000000?ooo`3oool01P3oool00`3OW4P0B9cO
0?ooo`0D0?ooo`004`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`000?l0=P3oool2000004X0oooo00D0_ibL0=noM01d_ol0_ibL0=ooo`1E0?ooo`<0o`00
>P3oool0102oM00000000000001d_om20?ooo`<0o`00C`3oool00`3ooml0W4Q809cOo`1K0?ooo`<0
o`007P3oool00`000000oooo0?ooo`0K0?ooo`030?oog`2LM9`0gooo0480oooo00<000000?ooo`3o
ool0703oool00180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`030000
00000?l0003o03D0oooo1@0000170?ooo`060?oOW018000000000000000004P0W=ooD`3oool30?l0
0880oooo0`3o001?0?ooo`050;md0000000000000000B02Lgol0E`3oool30?l001l0oooo00<00000
0?ooo`3oool0603oool00`3OW4P00000000000020000000304RLg`3oool0oooo0440oooo00<00000
0?ooo`3oool06`3oool00180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?oo
o`030000o`000000003o03H0oooo0P00002R0?ooo`<0o`00Q03oool30?l00:T0oooo0`3o000P0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool06P3oool00180oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0C0?ooo`80003o00<000000?ooo`3oool00P3oool90000obT0
oooo0P00002Q0?ooo`<0o`00QP3oool30?l00:L0oooo0`3o000Q0?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool06@3oool00180oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0B0?ooo`80003o0P3oool00`000000oooo0000o`0;0000obT0oooo00<000000?ooo`3oool0
WP3oool30?l008P0oooo0`3o002U0?ooo`<0o`008P3oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo01P0oooo000B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`020?ooo`04000000000?l0003o0000o`L0oooo0`000?lX0?ooo`030000
003oool0oooo09`0oooo103o002:0?ooo`<0o`00X`3oool30?l002<0oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`0G0?ooo`004P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0140oooo0P000?l30?ooo`80003o00<000000?ooo`3oool0203oool30000obL0oooo1000
002J0?ooo`@0o`00S03oool30?l00:40oooo0`3o000T0?ooo`030000003oool0oooo06H0oooo00<0
00000?ooo`3oool05P3oool00180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A
0?ooo`80003o0`3oool20000o`030?ooo`000000oooo00T0oooo0`000?lV0?ooo`030000003oool0
oooo09X0oooo0`3o002?0?ooo`<0o`00W`3oool30?l002D0oooo00<000000?ooo`3oool0I`3oool0
0`000000oooo0?ooo`0E0?ooo`004@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0140oooo00@0003o0?ooo`3oool0oooo0`000?l00`3oool000000?ooo`0:0?ooo`80003o9P3oool0
0`000000oooo0?ooo`2I0?ooo`<0o`00T@3oool30?l009d0oooo0`3o000V0?ooo`030000003oool0
oooo06P0oooo00<000000?ooo`3oool0503oool00140oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0@0?ooo`80003o0`3oool20000o`<0oooo00<000000?ooo`3oool0203oool20000
obH0oooo00<000000?ooo`3oool0V03oool30?l009<0oooo0`3o002K0?ooo`<0o`009`3oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo01<0oooo000A0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0403oool20000o`<0oooo0P000?l40?ooo`030000003oool0oooo00L0
oooo0`000?lU0?ooo`030?l0003oool0oooo09L0oooo0`3o002E0?ooo`<0o`00V@3oool30?l002P0
oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0B0?ooo`00=P0000020000o`<00000
0P000?l:00000080003o0P0000030000ob@000000`3o002G0000o`<0o`00U`000?l30?l009L0003o
0`3o000Z0000oh0000000@3oool00140oooo00<000000?ooo`3oool08P3oool20000o`<0oooo0P00
0?l:0?ooo`80003o0`3oool20000ob@0oooo00@0003o0?l0003o0000o`00U@000?l30?l009T0003o
0`3o002E0000o`<0o`00:`000?lQ0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
403oool00140oooo00<000000?ooo`3oool08P3oool20000o`<0oooo0P000?l:0?ooo`80003o0`3o
ool20000obD0oooo00@000000?l0003o0000o`00B@3oool00`000000oooo0?ooo`170?ooo`<0o`00
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`040000003o0000o`000?l004T0
oooo00<000000?ooo`3oool0A`3oool30?l000030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`0R0?ooo`<0003o
0P3oool30000o`P0oooo0`000?l20?ooo`<0003o9@3oool00`000000oooo0?l000020?l004P0oooo
00<000000?ooo`3oool0AP3oool30?l000030?ooo`000000oooo04/0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?l000020?l004P0oooo00<000000?ooo`3oool0AP3oool30?l000030?oo
o`000000oooo04/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`004@3o
ool00`000000oooo0?ooo`0S0?ooo`80003o0P3oool40000o`H0oooo0`000?l30?ooo`<0003o9@3o
ool00`000000oooo0?ooo`030?l004L0oooo00<000000?ooo`3oool0A@3oool30?l00080oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00<0o`00A`3o
ool00`000000oooo0?ooo`150?ooo`<0o`000P3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool0403oool00180oooo00<000000?ooo`3oool08P3oool3
0000o`80oooo10000?l50?ooo`<0003o0`3oool20000obH0oooo100000030?l004H0oooo00<00000
0?ooo`3oool0A03oool30?l000<0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:
0?ooo`040000003oool0oooo0?ooo`<0o`00AP3oool00`000000oooo0?ooo`140?ooo`<0o`000`3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403o
ool00180oooo00<000000?ooo`3oool08`3oool30000o`80oooo2P000?l30?ooo`<0003o9P3oool0
0`000000oooo0?ooo`020?ooo`<0o`00R`3oool30?l00:<0oooo0`3o002;0?ooo`<0o`00/@3oool0
0180oooo00<000000?ooo`3oool0903oool30000o`80oooo20000?l40?ooo`80003o9`3oool00`00
0000oooo0?ooo`030?ooo`<0o`00R@3oool30?l00:D0oooo0`3o00290?ooo`<0o`00/P3oool00180
oooo00<000000?ooo`3oool09@3oool30000o`/0oooo10000?lW0?ooo`030000003oool0oooo00@0
oooo0`3o00270?ooo`<0o`00Y`3oool30?l008L0oooo0`3o002c0?ooo`004P3oool00`000000oooo
0?ooo`0V0?ooo`<0003o2@3oool40000obL0oooo0P0000070?ooo`<0o`00Q@3oool30?l00:T0oooo
0`3o00250?ooo`<0o`00]03oool00180oooo00<000000?ooo`3oool09`3oool40000o`D0oooo1000
0?lY0?ooo`D000001@3oool40?l00880oooo0`3o002[0?ooo`<0o`00P`3oool30?l00;D0oooo000B
0?ooo`030000003oool0oooo02P0oooo2`000?lZ0?ooo`8000002@3oool40?l00800oooo0`3o002]
0?ooo`<0o`00P@3oool30?l00;H0oooo000C0?ooo`030000003oool0oooo02T0oooo20000?l[0?oo
o`8000002`3oool30?l007h0oooo0`3o002_0?ooo`<0o`00O`3oool30?l00;L0oooo000C0?ooo`03
0000003oool0oooo05`0oooo0P00000<0?ooo`<0o`00O03oool30?l00;40oooo0`3o001m0?ooo`<0
o`00^03oool001@0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0000000=0?ooo`<0o`00
N@3oool40?l00;<0oooo0`3o001k0?ooo`<0o`00^@3oool001@0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo00000003000000/0oooo0`3o001g0?ooo`@0o`00]@3oool30?l007T0oooo0`3o
002j0?ooo`00503oool00`000000oooo0?ooo`1I0?ooo`040000003oool0oooo000000l0oooo0`3o
001e0?ooo`<0o`00^03oool30?l007L0oooo0`3o002k0?ooo`00503oool00`000000oooo0?ooo`1I
0?ooo`040000003oool0oooo00000100oooo0`3o001c0?ooo`<0o`00^P3oool30?l007D0oooo0`3o
002l0?ooo`00503oool00`000000oooo0?ooo`1H0?ooo`050000003oool0oooo0?ooo`0000004@3o
ool30?l00740oooo0`3o002l0?ooo`<0o`00LP3oool40?l00;d0oooo000E0?ooo`030000003oool0
oooo05L0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`<0o`00K`3oool30?l00;h0oooo0`3o
001`0?ooo`@0o`00_P3oool001D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`02
0?ooo`@00000403oool30?l006d0oooo0`3o00300?ooo`@0o`00K@3oool30?l00<00oooo000F0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?oo
o`<0o`00J`3oool30?l00<80oooo103o001[0?ooo`<0o`00`@3oool001H0oooo00<000000?ooo`3o
ool0@P3oool02P2oM00000000000B02Lgol0oooo0?oo_`1dB9`0gooo0?ooo`2oM0020000000304RL
g`3oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`<0o`00
J@3oool30?l00<D0oooo0`3o001X0?ooo`@0o`00`P3oool001L0oooo00<000000?ooo`3oool0@03o
ool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo0=nLB01d_ol4
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0503oool30?l006L0oooo0`3o0037
0?ooo`<0o`00IP3oool40?l00<<0oooo000G0?ooo`030000003oool0oooo0400oooo00H0gia804RL
g`3oool0oono07@0M02oool70?ooo`030?noM018W=l0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0E0?ooo`@0o`00I03oool30?l00<T0oooo0`3o001T0?ooo`<0o`00a@3o
ool001P0oooo00<000000?ooo`3oool0?`3oool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo
00H0okmd0000M02oool0oooo0=nLB01d_ol30?ooo`030000003oool0oooo00@0oooo1P00000C0?oo
o`@0o`00HP3oool30?l00</0oooo0`3o001R0?ooo`<0o`00aP3oool001T0oooo00<000000?ooo`3o
ool0?P3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`<0oooo00D0oono07A8B01800000000001d
_`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603oool30?l005l0oooo103o
003=0?ooo`<0o`00H03oool30?l00<L0oooo000I0?ooo`030000003oool0oooo03h0oooo00H0okmd
0018W03Oool0okmd0018W03Oool30?ooo`030?oog`2LB4P0W=oo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0I0?ooo`<0o`00G@3oool40?l00<l0oooo0`3o001M0?ooo`@0o`00
b03oool001X0oooo00<000000?ooo`3oool0?P3oool0102oM00000000000B02Lgol50?ooo`050;md
0000000000000000B02Lgol00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01X0
oooo0`3o001K0?ooo`<0o`00dP3oool30?l005/0oooo103o00390?ooo`006P3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool30?l005P0oooo
103o003D0?ooo`<0o`00F@3oool30?l00</0oooo000K0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool01`3oool4000001/0oooo103o001E0?ooo`@0o`00eP3oool30?l005L0oooo0`3o
003<0?ooo`00703oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool07@3oool40?l005<0oooo0`3o003I0?ooo`@0o`00D`3oool40?l00<d0oooo000M0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?oo
o`<0o`00D03oool40?l00380oooo00<0gia807Boo`3oool07P3oool00`3o_g@0B9cO0?ooo`250?oo
o`@0o`00D@3oool40?l00<h0oooo000M0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0P0?ooo`@0o`00C@3oool40?l00380oooo00<0omnL07BLg`3o
ool0803oool00`3OW4P0M;oo0?ooo`260?ooo`<0o`00C`3oool30?l00=00oooo000N0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?ooo`@0o`00
B`3oool30?l00240oooo00D0gia8000000000000000004RLg`020?ooo`0A0?noM000000000000000
001d_ol0oooo0?noM0000000M;oo0?ooo`3ogi`0B00004PeB02Lgol0oooo0?oog`2LB0000P000000
1P18W=l0oooo0?oOW0180000M;oo0=nLB0@0000000<0B9cO0?ooo`2oM0000P0000000`00M;l0oooo
0?ooo`020?ooo`0;0?oo_`1d0000B9cO0?ooo`2oM00004RL0=ooo`3oool0omnL04Q8W03Oool05`3o
ool0303OW4P000000000001d_ol0oooo0?oOW0180000M;oo0?ooo`2oM000001d0;ooo`<0oooo00<0
_g@00000M02oool00`3oool01`3OW4P000000000001d_ol0oooo0?oog`2LB0000P0000002P00M;l0
oooo0?ooo`3oool0okmd0000001d_ol0oooo0?oog`2LB0020000000304RLg`3oool0oooo04<0oooo
103o001;0?ooo`@0o`00d@3oool001l0oooo0P0000130?ooo`8000003@3oool400000280oooo0`3o
00180?ooo`@0o`008@3oool0903ogi`0B00004RLg`3oool0okmd0000B02Lgol0omnL04P00000M;l0
oooo0?noM00004P0W=oo0?noM0000000M;oo0?ooo`3ogi`0B0000200M02oool0oooo0=nLB00004P0
W=oo0?noM0000000M;oo0?oOW0180000M;oo0?oo_`1d000004RL0=ooo`80oooo00H0gia80000B02L
gol0okmd0000001d_ol40?ooo`050?oOW01807@0_ooO09a8001d_ol00P3oool00`3ookl0M00007Bo
o`030?ooo`030?noM0000000000000<0000000<004RL0=ooo`3oool02P3oool03@3ogi`0B00007Bo
o`3o_g@0001809cOo`3ogi`0B00007Boo`3oool0gia80000M02oool00`3oool00`3OW4P0001d0;oo
o`020?ooo`0<0?oOW0180000M;oo0?noM00004P0W=oo0=nLB00004P0W=oo0?oOW0180000B9cO0P3o
ool02P3o_g@0000007Boo`3oool0gia80000B02Lgol0okmd0000001d_om50?ooo`@0o`00B@3oool4
0?l00=80oooo000Q0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0T0?ooo`@0o`00A@3oool40?l002@0oooo00P0oono07@000000000001d0;ooo`3O
W4P0001809cOo`@0oooo00P0okmd0000001d_ol0oooo0?oOW0180000001d0;ooo`@0oooo00<0oono
07@00018W=l0103oool00`3ogi`0B000001d_`020?ooo`060;md000007@0_ooo0?oo_`1d0000B9cO
1@3oool0102oM000M;oo0;mdB02Lgol20?ooo`030?oog`2LB000M;oo00h0oooo00<0okmd00000000
00000`0000002000B9`0gooo0=nLB00007@0_ooo0?oOW0180000M;oo103oool00`3o_g@0000007Bo
o`030?ooo`030?noM0000000M;oo0080oooo00H0gia80000M02oool0omnL04P0001d_ol30?ooo`03
0?oog`2LB00007Bo0080oooo00<0okmd0000001d_ol0103oool00`3ookl0M00004RLg`170?ooo`@0
o`00A@3oool40?l00=@0oooo000R0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0U0?ooo`@0o`00@`3oool30?l002@0oooo00D0oooO09a800000000
000007Boo`020?ooo`030=nLB0000000000000<0000000T0B9cO0?noM0000000M;oo0?ooo`3ogi`0
B0000000M02oool0103oool00`3ogi`0B00007Boo`050?ooo`0:0?noM0000000B9cO0?ooo`3o_g@0
001809cOo`3ogi`0B00007Boo`D0oooo00@0okmd001d_`3OW4P0M;oo0P3oool00`3ooml0W4P007Bo
o`0F0?ooo`060;md000007@0_ooo0?oOW0180000B9cO103oool00`3ookl0M00004RLg`030?ooo`03
0?oo_`1d0000B9cO0080oooo00`0_g@00000M02oool0omnL04P00018W=l0okmd0000B02Lgol0omnL
04P00018W=l20?ooo`030?noM0000000M;oo00@0oooo00<0omnL04P0001d_ol0B03oool40?l004<0
oooo103o003E0?ooo`008`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool09`3oool40?l003l0oooo103o000U0?ooo`0F0?oOW0180000B9cO0?ooo`2o
M00004RL0=ooo`3ogi`0B00007Boo`3oool0omnL04P0001d_ol0okmd00000000M;l0oooo0?noM000
0000801d0;ooo`<0oooo00<0okmd0000M02oool01`3oool0203OW4P0001809cOo`3oool0okmd0000
000004P0W=oo1@3oool01@2oM7@0_ono07A8W03O_g@007Bo0080oooo00<0oono07@0001d_ol00`3o
ool00`3o_g@0000000000003000000030018W03Oool0oooo00X0oooo00H0_g@00000M02oool0omnL
04P00018W=l50?ooo`030;md000007@0_ooo00<0oooo00`0_g@00000M02oool0oooo0;md000007@0
_ooo0?oOW0180000B9cO0?oOW0180002000000070018W03Oool0omnL04Qd_`3o_g@0000007Boo`03
0?ooo`030?noM00007@0_ooo04/0oooo103o000o0?ooo`@0o`00e`3oool002@0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0?0?ooo`@000009`3oool40?l003d0oooo103o000W0?oo
o`050=nLB000000000000000001d_ol00P3oool02@3o_g@00000000000000000B9cO0?ooo`3o_g@0
000007AdM002000000030018R@28B4P0W=oo00@0oooo00<0gia80000M02oool01P3oool02@3ogi`0
B00004RLg`3o_g@0001809cOo`3o_g@0001809cOo`040?ooo`030?oo_`1d000000000080000000D0
001d0;ooo`3ogi`0B4RL0=ooo`0F0?ooo`060=nLB00007@0_ooo0?oOW0180000M;oo1@3oool00`3o
gi`0B00004RLg`030?ooo`0=0?oOW0180000B9cO0?ooo`3OW4P0001d0;ooo`3ogi`0B00007Boo`3o
okl0M00007Boo`030?ooo`050?oOW018000000000000001d_ol0103oool00`3OW4P0001d0;ooo`1;
0?ooo`D0o`00?03oool40?l00=P0oooo000U0?ooo`800000>03oool200000180oooo00<000000?oo
o`3oool0:P3oool40?l003T0oooo103o000l0?ooo`090?oOW018B9`0gooo0?noM0000000M;oo0=nL
B00004P0W=oo00<0oooo00`0okmd0000001d_ol0omnL04P0001d_ol0okmd0000B02Lgol0okmd0000
001d_ol;0?ooo`030;md001d_ol0oooo01H0oooo00H0omnL04P0B02Lgol0okmd0000B02Lgol60?oo
o`030=nLB00004P0W=oo00<0oooo00`0gia80000B02Lgol0omnL04P0B02Lgol0okmd0000B02Lgol0
oooO09a80000M;l40?ooo`0;0?oOW0180000000007Boo`3oool0okmd0000001d_ol0gia80000B02L
gol0C@3oool50?l003P0oooo103o003J0?ooo`009`3oool2000003@0oooo0P00000D0?ooo`030000
003oool0oooo02/0oooo1@3o000e0?ooo`D0o`00?P3oool0103ogi`0W;oo0?ooo`2oM00200000003
04RLg`3oool0oooo00<0oooo00@0_g@000000000000007Bo0P3oool0102oM000000000000000M;l;
0?ooo`030?noM01d_ol0oooo01P0oooo00@0gia8000000000000M;oo103oool00`3OW4P000000000
00020000000304RLg`3OW4P0000000<0000000<0B9cO0?ooo`3OW4P00P000000101d_ol0oooo0?oo
o`2oM0030000000607Boo`3oool0oooo0?oOW0180000M;oo0P3oool0102oM000000000000018W=m@
0?ooo`D0o`00=03oool50?l00=/0oooo000Y0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0]0?ooo`D0o`00<@3oool50?l00?T0oooo1@3o000a0?oo
o`@0o`00g@3oool002X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo02l0oooo1@3o000/0?ooo`H0o`00o@3oool50?l002d0oooo103o003O0?ooo`00
:`3oool2000002/0oooo0`00000H0?ooo`@00000<03oool50?l002P0oooo1P3o003o0?ooo`80oooo
1P3o000W0?ooo`H0o`00h03oool002d0oooo0P00000W0?ooo`8000006`3oool00`000000oooo0?oo
o`0c0?ooo`H0o`008P3oool60?l00?l0oooo1`3oool60?l00280oooo1`3o003R0?ooo`00;`3oool3
00000280oooo0P00000M0?ooo`030000003oool0oooo03D0oooo203o000K0?ooo`L0o`00o`3oool<
0?ooo`H0o`00703oool70?l00>D0oooo000b0?ooo`@000006@3oool500000100oooo00<0oooO09a8
M02oool0303oool00`000000oooo0?ooo`0h0?ooo`T0o`005@3oool60?l00?l0oooo4@3oool70?l0
01L0oooo1P3o003X0?ooo`00=P3oool5000000l0oooo1@00000E0?ooo`030?oog`2LB7@0_ooo00`0
oooo00<000000?ooo`3oool0?@3oool60?l000d0oooo2@3o003o0?oooaL0oooo2@3o000<0?ooo`T0
o`00j`3oool003/0oooo3`00000J0?ooo`030?oog`2LB7@0_ooo00`0oooo1P00000m0?oooaL0o`00
o`3ooolL0?oooaT0o`00k@3oool006@0oooo00<0oooO09a8M02oool0303oool00`000000oooo0?oo
o`120?ooo`l0o`00o`3ooolW0?ooo`h0o`00l`3oool00680oooo00D0oooO09bL_`3ooml0W4Qd0;oo
o`0<0?ooo`030000003oool0oooo0?l0ooooo`3ooomj0?ooo`00H`3oool0103o_g@000000000M02o
ool<0?ooo`030000003oool0oooo0?l0ooooo`3ooomj0?ooo`00I03oool00`3ookl0M01d0;ooo`3o
0?ooool0ooooR@3oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0oooo
l03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0
ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`
0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3o
oooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00
oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?oo
ool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03o
ool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0oooo
o`3oooo`0?ooo`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?oo
o`00o`3ooooo0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo
0?oooo00oooo003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00o`3ooooo0?oooo00oooo
003o0?ooool0ooool03oool00?l0ooooo`3oooo`0?ooo`00\
\>"],
  ImageRangeCache->{{{94.4375, 513.375}, {488.813, 384.875}} -> {-5.81202, \
12.1539, 0.025556, 0.025556}}],

Cell[TextData[{
  "Funzioni con tale propriet\[AGrave] ossia tali da assumere i medesimi \
valori in corrispondenza di valori della variabile indipendente che \
differiscano per un certo valore ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " o suoi multipli interi, nel nostro caso ",
  Cell[BoxData[
      \(TraditionalForm\`T = 2  \[Pi]\)]],
  ", verranno dette ",
  StyleBox["funzioni periodiche di periodo T",
    FontSlant->"Italic"],
  ". Per queste la definizione generale che si d\[AGrave] \[EGrave]"
}], "Text"],

Cell[TextData[{
  "La funzione ",
  StyleBox["f",
    FontSlant->"Italic"],
  " \[EGrave] periodica con periodo ",
  StyleBox["T",
    FontSlant->"Italic"],
  " se e solo se\n\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[ForAll]", " ", 
            RowBox[{"x", " ", "\[Element]", " ", 
              RowBox[{"Dom", "(", 
                StyleBox["f",
                  FontSlant->"Plain"], ")"}]}]}], ",", "    ", 
          RowBox[{
            RowBox[{
              StyleBox["f",
                FontSlant->"Plain"], "(", 
              RowBox[{"x", "+", 
                StyleBox["kT",
                  FontSlant->"Italic"]}], ")"}], " ", "=", " ", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox["f",
                    FontSlant->"Plain"], "(", "x", ")"}], "     ", "con", "   ",
                 "k"}], " ", "=", " ", "0"}]}], ",", " ", \(\[PlusMinus]1\), 
          ",", " ", \(\[PlusMinus]2\), ",", "..."}], TraditionalForm]]]
}], "Definition"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Alpha] = \[Pi]/4;\)\), "\[IndentingNewLine]", 
    \(\(Show[
        Plot[Sin[x], {x, \(-2\) \[Pi], 3  \[Pi]}, 
          Ticks \[Rule] {Range[\(-2\), 3, 1/2] \[Pi], Automatic}, 
          DisplayFunction \[Rule] Identity], 
        Graphics[{colRosso, 
            Line[{{\(-2\) \[Pi] + \[Alpha], 0}, {\(-2\) \[Pi] + \[Alpha], 
                  Sin[\[Alpha]]}, {\[Alpha], Sin[\[Alpha]]}, {\[Alpha], 
                  0}, {\[Alpha], Sin[\[Alpha]]}, {\[Alpha] + 2  \[Pi], 
                  Sin[\[Alpha]]}, {\[Alpha] + 2  \[Pi], 
                  0}, {\[Alpha] + 2  \[Pi], Sin[\[Alpha]]}, {3  \[Pi], 
                  Sin[\[Alpha]]}}]}], 
        Graphics[{colRosso, 
            Text["\<\[Alpha]-2\[Pi]\>", {\[Alpha] - 2  \[Pi], \(- .25\)}, 
              TextStyle \[Rule] stileTesto], 
            Text["\<\[Alpha]\>", {\[Alpha], \(- .25\)}, 
              TextStyle \[Rule] stileTesto], 
            Text["\<\[Alpha]+2\[Pi]\>", {\[Alpha] + 2  \[Pi], \(- .25\)}, 
              TextStyle \[Rule] stileTesto]}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        AspectRatio \[Rule] Automatic, 
        ImageSize \[Rule] {600, 150}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .12732 
%%ImageSize: 600 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.0606305 0.0636616 0.0606305 [
[.02381 .05116 -9.84375 -10.9375 ]
[.02381 .05116 9.84375 0 ]
[.11905 .05116 -11.7188 -20 ]
[.11905 .05116 11.7188 0 ]
[.21429 .05116 -6.84375 -10.9375 ]
[.21429 .05116 6.84375 0 ]
[.30952 .05116 -8.84375 -17.8125 ]
[.30952 .05116 8.84375 0 ]
[.5 .05116 -6.09375 -17.8125 ]
[.5 .05116 6.09375 0 ]
[.59524 .05116 -4.09375 -10.9375 ]
[.59524 .05116 4.09375 0 ]
[.69048 .05116 -8.96875 -20 ]
[.69048 .05116 8.96875 0 ]
[.78571 .05116 -7.09375 -10.9375 ]
[.78571 .05116 7.09375 0 ]
[.88095 .05116 -8.96875 -19.875 ]
[.88095 .05116 8.96875 0 ]
[.97619 .05116 -7.09375 -10.9375 ]
[.97619 .05116 7.09375 0 ]
[.39226 .00303 -13.9375 -5.46875 ]
[.39226 .00303 0 5.46875 ]
[.39226 .03335 -20.625 -5.46875 ]
[.39226 .03335 0 5.46875 ]
[.39226 .09398 -15.125 -5.46875 ]
[.39226 .09398 0 5.46875 ]
[.39226 .12429 -8.4375 -5.46875 ]
[.39226 .12429 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .12732 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .06366 m
.02381 .06991 L
s
gsave
.02381 .05116 -70.8438 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
74.500 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.11905 .06366 m
.11905 .06991 L
s
gsave
.11905 .05116 -72.7188 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 16.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.375 10.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
76.375 10.750 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.563 16.688 moveto
(\\200\\200\\200\\200) show
73.813 16.688 moveto
(\\200\\200\\200\\200) show
78.063 16.688 moveto
(\\200\\200) show
80.063 16.688 moveto
(\\200) show
73.250 23.000 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.21429 .06366 m
.21429 .06991 L
s
gsave
.21429 .05116 -67.8438 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.30952 .06366 m
.30952 .06991 L
s
gsave
.30952 .05116 -69.8438 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 14.500 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.500 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.563 14.500 moveto
(\\200\\200) show
71.688 14.500 moveto
(\\200\\200) show
73.813 14.500 moveto
(\\200) show
74.313 14.500 moveto
(\\200) show
70.375 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .06366 m
.5 .06991 L
s
gsave
.5 .05116 -67.0938 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

65.000 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 14.500 moveto
(\\200\\200) show
66.188 14.500 moveto
(\\200\\200) show
68.313 14.500 moveto
(\\200) show
68.813 14.500 moveto
(\\200) show
64.875 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.59524 .06366 m
.59524 .06991 L
s
gsave
.59524 .05116 -65.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.69048 .06366 m
.69048 .06991 L
s
gsave
.69048 .05116 -69.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
70.875 10.750 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.688 moveto
(\\200\\200\\200\\200) show
68.313 16.688 moveto
(\\200\\200\\200\\200) show
72.563 16.688 moveto
(\\200\\200) show
74.563 16.688 moveto
(\\200) show
67.750 23.000 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.78571 .06366 m
.78571 .06991 L
s
gsave
.78571 .05116 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.88095 .06366 m
.88095 .06991 L
s
gsave
.88095 .05116 -69.9688 -23.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
70.875 10.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.563 moveto
(\\200\\200\\200\\200) show
68.313 16.563 moveto
(\\200\\200\\200\\200) show
72.563 16.563 moveto
(\\200\\200) show
74.563 16.563 moveto
(\\200) show
67.750 22.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 .06366 m
.97619 .06991 L
s
gsave
.97619 .05116 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 .06366 m
1 .06366 L
s
.40476 .00303 m
.41101 .00303 L
s
gsave
.39226 .00303 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 .03335 m
.41101 .03335 L
s
gsave
.39226 .03335 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40476 .09398 m
.41101 .09398 L
s
gsave
.39226 .09398 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40476 .12429 m
.41101 .12429 L
s
gsave
.39226 .12429 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.40476 .00909 m
.40851 .00909 L
s
.40476 .01516 m
.40851 .01516 L
s
.40476 .02122 m
.40851 .02122 L
s
.40476 .02728 m
.40851 .02728 L
s
.40476 .03941 m
.40851 .03941 L
s
.40476 .04547 m
.40851 .04547 L
s
.40476 .05154 m
.40851 .05154 L
s
.40476 .0576 m
.40851 .0576 L
s
.40476 .06972 m
.40851 .06972 L
s
.40476 .07579 m
.40851 .07579 L
s
.40476 .08185 m
.40851 .08185 L
s
.40476 .08791 m
.40851 .08791 L
s
.40476 .10004 m
.40851 .10004 L
s
.40476 .1061 m
.40851 .1061 L
s
.40476 .11217 m
.40851 .11217 L
s
.40476 .11823 m
.40851 .11823 L
s
.25 Mabswid
.40476 0 m
.40476 .12732 L
s
0 0 m
1 0 L
1 .12732 L
0 .12732 L
closepath
clip
newpath
.5 Mabswid
.02381 .06366 m
.04262 .08217 L
.06244 .09973 L
.07216 .10705 L
.08255 .11364 L
.08852 .11677 L
.09396 .11917 L
.09911 .12104 L
.10458 .12257 L
.10686 .12307 L
.10932 .12351 L
.11072 .12372 L
.11201 .12388 L
.11332 .12402 L
.11454 .12412 L
.11563 .1242 L
.11679 .12425 L
.11808 .12428 L
.11925 .12429 L
.12036 .12428 L
.12155 .12424 L
.12269 .12418 L
.12373 .12411 L
.12493 .12401 L
.12622 .12387 L
.12854 .12355 L
.13131 .12306 L
.13383 .1225 L
.13932 .12094 L
.14451 .11902 L
.15416 .1144 L
.16442 .10809 L
.18284 .09372 L
.22059 .05737 L
.24156 .0373 L
.26079 .02158 L
.27056 .01513 L
.27964 .01025 L
.28911 .00643 L
.29413 .00498 L
.29673 .00438 L
.29948 .00386 L
.30202 .0035 L
.30346 .00333 L
.30481 .00321 L
.30605 .00313 L
.30718 .00308 L
.30848 .00304 L
.30972 .00303 L
.31042 .00304 L
Mistroke
.31106 .00305 L
.31179 .00307 L
.31248 .0031 L
.31371 .00318 L
.31504 .00328 L
.3165 .00343 L
.31805 .00363 L
.32083 .00408 L
.3258 .0052 L
.33044 .0066 L
.34098 .01101 L
.35146 .01696 L
.36137 .02388 L
.37994 .03953 L
.41832 .07711 L
.43774 .09504 L
.44805 .10337 L
.45915 .11105 L
.46975 .1169 L
.47438 .11896 L
.47945 .12084 L
.48426 .12226 L
.48872 .12325 L
.4912 .12365 L
.49344 .12394 L
.49468 .12406 L
.49603 .12416 L
.4973 .12423 L
.49847 .12427 L
.49973 .12429 L
.50093 .12429 L
.502 .12426 L
.50316 .12421 L
.50443 .12413 L
.50577 .12402 L
.50819 .12374 L
.51042 .1234 L
.51251 .12301 L
.51727 .12185 L
.52246 .12018 L
.52721 .11829 L
.53793 .11281 L
.55683 .09955 L
.57752 .08113 L
.61805 .04138 L
.63676 .02531 L
.64662 .01821 L
.65706 .01201 L
.66234 .00944 L
.66815 .0071 L
Mistroke
.67344 .00541 L
.67838 .00423 L
.68098 .00377 L
.68345 .00344 L
.68567 .00322 L
.68693 .00314 L
.68809 .00308 L
.68875 .00306 L
.68946 .00304 L
.69074 .00303 L
.69199 .00305 L
.69314 .00309 L
.69439 .00316 L
.69576 .00326 L
.69719 .0034 L
.69853 .00357 L
.70113 .00397 L
.70354 .00443 L
.70899 .00584 L
.71379 .00746 L
.7189 .00957 L
.73746 .02034 L
.75694 .03596 L
.77523 .05323 L
.81393 .09087 L
.83399 .107 L
.84407 .11342 L
.84974 .11644 L
.85509 .11886 L
.86003 .12072 L
.86538 .1223 L
.86774 .12286 L
.87024 .12335 L
.87258 .12372 L
.87472 .12397 L
.876 .12409 L
.87721 .12418 L
.87848 .12424 L
.87921 .12427 L
.87988 .12428 L
.8811 .12429 L
.88221 .12428 L
.8835 .12424 L
.8847 .12418 L
.88604 .12408 L
.88745 .12394 L
.88998 .12362 L
.8927 .12316 L
.89567 .12251 L
.90094 .12103 L
Mistroke
.90592 .11922 L
.91524 .11485 L
.92527 .1088 L
.93617 .10084 L
.97619 .06366 L
Mfstroke
1 0 0 r
.07143 .06366 m
.07143 .10653 L
.45238 .10653 L
.45238 .06366 L
.45238 .10653 L
.83333 .10653 L
.83333 .06366 L
.83333 .10653 L
.97619 .10653 L
s
gsave
.07143 .0485 -73.875 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(a) show
68.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(-) show
74.750 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(2) show
79.750 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(p) show
84.750 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45238 .0485 -65.8125 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(a) show
68.625 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83333 .0485 -73.875 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(a) show
68.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(+) show
74.750 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(2) show
79.750 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(p) show
84.750 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{599.875, 149.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006S0000J2000`400?l00000o`00003oo`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00Z@3oool0
0`000000oooo0?ooo`3g0?ooo`00OP3oool8000001D0oooo0`0000020?ooo`030000003oool0oooo
00H0oooo1000001`0?ooo`P00000OP3oool007/0oooo0`0000080?ooo`<000005`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo06d0oooo100000080?ooo`@00000NP3oool007P0oooo
0`00000>0?ooo`8000005@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06/0oooo
0P00000@0?ooo`<00000M`3oool007D0oooo0`00000C0?ooo`800000703oool3000006T0oooo0P00
000E0?ooo`800000M@3oool007<0oooo0P00000H0?ooo`<000006@3oool00`000000oooo0?ooo`1W
0?ooo`8000006@3oool2000007<0oooo001a0?ooo`8000007@3oool2000001L0oooo0`00001U0?oo
o`8000007@3oool200000740oooo001`0?ooo`030000003oool0oooo01l0oooo0P00000E0?ooo`03
0000003oool0oooo06<0oooo0P00000Q0?ooo`800000K`3oool006h0oooo0P00000T0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo06`0oooo000b0?ooo`<00000>03oool00`000000oooo0?ooo`0U0?ooo`8000004P3o
ool300000600oooo0P00000A0?ooo`<000004`3oool00`000000oooo0?ooo`0g0?ooo`<00000<@3o
ool003<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0GP3oool2000001@0oooo00<000000?ooo`3oool04`3oool2
000003P0oooo00<000000?ooo`3oool0<03oool003@0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0D0?ooo`<000004`3oool00`000000oooo0?ooo`0>0?ooo`<000008`3oool30000
03L0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0;`3oool00380oooo0`00000e0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool04`3oool2000000h0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo01@0oooo0`00000G0?ooo`030000003oool0oooo03<0
oooo0`00000a0?ooo`00J03oool2000001X0oooo00<000000?ooo`3oool0503oool3000000030?oo
o`0000000000008000001P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0<03oool2000006L0oooo000[0?ooo`<0000000<0oooo0000000000001`00
000_0?ooo`030000003oool0oooo01P0oooo0`00000B0?ooo`<0000000@0oooo0000000000000000
103oool00`000000oooo0?ooo`040?ooo`@000008P3oool3000003<0oooo0P00000F0?ooo`P00000
5`3oool00`000000oooo0?ooo`1T0?ooo`00IP3oool00`000000oooo0?ooo`0b0?ooo`050000003o
ool000000000003oool00`0000060?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0/0?ooo`T00000;P3oool006D0oooo00<000000?ooo`3oool0503o
ool300000080oooo1000000F0?ooo`<0000000@0oooo00000000000000001`3oool3000002<0oooo
1000000`0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0HP3oool000P0oooo0`00
00000`3oool000000000001<0?ooo`800000203oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0B`3oool2000000T0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`030?ooo`<0000000<0oooo000000000000BP3oool3000000030?ooo`00
0000000000P0oooo00040?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01l0oooo0`0000000`3oool000000000000P0?ooo`<000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool3000000030?ooo`000000
000001d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01l0oooo0`0000000`3oool000000000000S0?ooo`8000000`3oool00`000000oooo0?ooo`05
0?ooo`002P3oool00`000000oooo00000002000000L0oooo0`3o00050?ooo`<0o`0000@0oooo0?l0
003o0000o`00303oool2000000<0oooo00<000000?ooo`3oool08@3oool3000000D0oooo00<00000
0?ooo`3oool07@3oool2000001h0oooo00<000000?ooo`3oool0103oool3000000l0oooo0`3o000A
0?ooo`8000009P3oool3000000H0oooo00<000000?ooo`3oool06`3oool2000000<0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool00000008000002@3oool3
0?l000<0oooo00<0o`000?ooo`3o00000P3o0000103oool0o`000?l0003o000;0?ooo`050000003o
ool0oooo0?ooo`0000008@3oool010000000oooo0000003oool3000000L0oooo00080?ooo`<00000
2`3oool0103o0000oooo0?l0003oool40?l000070?ooo`3o0000oooo0?ooo`3o0000oooo0?l0000;
0?ooo`040000003oool000000?ooo`<00000:@3oool200000280oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<0o`000?ooo`3o00004`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01/0oooo00@000000?ooo`000000oooo
0`00000N0?ooo`030000003oool0oooo00<000003@3oool00`3o0000oooo0?l000020?ooo`<0o`00
00L0oooo0?l0003oool0oooo0?l0003oool0o`0000T0oooo0`000000103oool0000000000000000Q
0?ooo`<000002`3oool001L0oooo0`3o00060?ooo`030?l0003oool0o`000080o`002`3oool30000
02`0oooo00<000000?ooo`3oool0803oool3000001l0oooo00<000000?ooo`3oool00P3oool30000
0100oooo0`3o000@0?ooo`<00000;03oool00`000000oooo0?ooo`0L0?ooo`<000008`3oool00`00
0000oooo0?ooo`0@0?ooo`<0o`000P3oool01P3o0000oooo0?ooo`3oool0o`000?ooo`<0o`002@3o
ool2000003@0oooo000N0?ooo`030?l0003oool0o`0003d0oooo00<000000?ooo`3oool0A03oool0
1@000000oooo0?ooo`3oool0000005<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`0F0?ooo`030?l0003oool0o`0004<0oooo001M0?ooo`030000003oool0oooo04H0oooo00@00000
0?ooo`3oool00000DP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo05/0oooo001L
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`0000000P00001?0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0FP3oool005/0oooo00<000000?ooo`3oool0BP3oool20000
0500oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1I0?ooo`00FP3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`1H0?ooo`007@0000000`3o000000000000002M000000030?l000000000000009d00000
00<0o`00000000000000@`00000000T0oooo0P00000B0?ooo`030?l0003oool0oooo0140oooo00<0
00000?ooo`3oool0903oool2000002L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0000
000A0?ooo`030?l0003oool0oooo0140oooo00<000000?ooo`3oool08`3oool00`000000oooo0000
000W0?ooo`030000003oool0oooo02D0oooo0P00000B0?ooo`030?l0003oool0oooo0140oooo00<0
00000?ooo`3oool08`3oool2000000X0oooo00090?ooo`030000003oool000000140oooo00<0o`00
0?ooo`3oool04@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0000002L0oooo00<00000
0?ooo`3oool09@3oool400000100oooo00<0o`000?ooo`3oool04@3oool00`000000oooo0?ooo`0R
0?ooo`040000003oool0oooo000002L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0000
000A0?ooo`030?l0003oool0oooo0140oooo00<000000?ooo`3oool08P3oool00`000000oooo0000
000:0?ooo`00303oool00`000000oooo0?ooo`0>0?ooo`030?l0003oool0oooo03H0oooo00<00000
0?ooo`3oool0D03oool01@000000oooo0?ooo`3oool0000000l0oooo00<0o`000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00h0oooo00<0o`000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0;0?ooo`003@3oool2000000h0oooo00<0o`000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0d0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0d0?ooo`030000003oool0oooo00`0oooo000?0?ooo`030000003oool0oooo
00/0oooo00<0o`000?ooo`3oool0<`3oool2000005@0oooo0`0000030?ooo`030000003oool0oooo
00/0oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
00`0oooo00<0o`000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?ooo`00403oool00`000000
oooo0?ooo`0:0?ooo`030?l0003oool0oooo0380oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<0o`000?ooo`3oool0<P3oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo00/0oooo00<0o`000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0>0?ooo`004@3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo0340oooo
00<000000?ooo`3oool0E@3oool3000000D0oooo00<000000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0a0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0a0?ooo`030000003oool0oooo00l0oooo000B0?ooo`030000003oool0oooo00P0oooo00<0
o`000?ooo`3oool0<03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool00`3o0000oooo0?ooo`0`0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0_0?ooo`8000004P3oool001<0oooo00<00000
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0_0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030?l0003oool0oooo02l0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`080?ooo`030?l0003oool0oooo02h0oooo00<00000
0?ooo`3oool04P3oool001@0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0^0?oo
o`030000003oool0oooo05P0oooo0`0000080?ooo`030000003oool0oooo00H0oooo00<0o`000?oo
o`3oool0;P3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00L0oooo00<0o`000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`005@3oool2000000H0oooo00<0o`000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`1;0?ooo`<0000000<0oooo0000000000000P0000060?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0]0?ooo`03
0000003oool0oooo06@0oooo00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0/0?ooo`03
0000003oool0oooo01@0oooo000G0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool0
;03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
103oool4000000T0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0/0?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0[0?ooo`030000
003oool0oooo01D0oooo000H0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool000000080oooo0`0000060?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0[0?ooo`030000003o
ool0oooo06P0oooo0P0000050?ooo`030?l0003oool0oooo02X0oooo00<000000?ooo`3oool05P3o
ool001T0oooo00D000000?ooo`3oool0oooo0?l0000[0?ooo`800000D03oool300000080oooo0P00
00070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0Z0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0Y0?ooo`030000003oool0oooo01L0oooo000J0?ooo`040000003oool0oooo0?l002X0oooo00<0
00000?ooo`3oool0GP3oool3000000d0oooo0P0000020?ooo`030?l0003oool0oooo02T0oooo00<0
00000?ooo`3oool0K@3oool01@000000oooo0?ooo`3oool0o`0002X0oooo00<000000?ooo`3oool0
603oool001/0oooo00<000000?ooo`3o0000:@3oool00`000000oooo0?ooo`1O0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3o0000:@3oool200000740oooo0P0000000`3oool0o`000?oo
o`0W0?ooo`8000006`3oool001`0oooo00<000000?l0003oool09P3oool200000680oooo0`00000@
0?ooo`030000003o0000oooo02L0oooo00<000000?ooo`3oool0L`3oool00`000000o`000?ooo`0U
0?ooo`8000007@3oool001d0ooooo`3o001m0?l000X0oooo000O0?ooo`8000008P3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07`3oool2000007X0
oooo0P00000R0?ooo`030000003oool0oooo01h0oooo000Q0?ooo`8000007P3oool2000006H0oooo
0`00000E0?ooo`030000003oool0oooo01`0oooo0P00001n0?ooo`8000007P3oool200000240oooo
000S0?ooo`8000006`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo01H0oooo0P00
000J0?ooo`800000PP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0240oooo000U
0?ooo`030000003oool0oooo01H0oooo0P00001Y0?ooo`<00000603oool00`000000oooo0?ooo`0E
0?ooo`800000Q@3oool2000001P0oooo0P00000T0?ooo`009P3oool2000001@0oooo0P00001[0?oo
o`030000003oool0oooo01T0oooo0P00000C0?ooo`800000R@3oool400000180oooo0P00000V0?oo
o`00:03oool5000000X0oooo1@00001]0?ooo`030000003oool0oooo01/0oooo1000000;0?ooo`@0
0000S`3oool3000000T0oooo1P00000X0?ooo`00;@3oool:000006T0oooo00<000000?ooo`3oool0
1P3oool4000001h0oooo2`00002F0?ooo`T00000;P3oool00:00oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`3g0?ooo`00X03oool00`000000oooo0?ooo`3o0?ooo`40oooo003o0?oo
oj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oo
oj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oo
oj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oo
oj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oo
oj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo003o0?oooj@0oooo0000\
\>"],
  ImageRangeCache->{{{100.063, 518.938}, {204.813, 100.938}} -> {-10.616, \
1.92938, 0.027563, 0.027563}},
  CellTags->"figura4"],

Cell[TextData[{
  "La ",
  ButtonBox["figura 4",
    ButtonData:>"figura4",
    ButtonStyle->"Hyperlink"],
  " mette in evidenza che, pur essendo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[NotEqual] \[Alpha] - 
          2  \[Pi] \[NotEqual] \[Alpha] + 2  \[Pi]\)]],
  " ecc. le uguaglianze"
}], "Text"],

Cell[BoxData[
    \(sen \((\[Alpha])\) = \(sen \((\[Alpha] - 
              2  \[Pi])\) = \(sen \((\[Alpha] + 
                2  \[Pi])\) = \[TripleDot]\)\)\)], "DisplayFormula"],

Cell["\<\
 sono, per la funzione seno, certamente vere. Pertanto in generale, vale \
l'identit\[AGrave] \
\>", "Text"],

Cell[BoxData[
    \(sen \((\[Alpha])\) = 
      sen \((\[Alpha] + 
              2  k\ \[Pi])\)\ \ \ \ \ \ \ \ \ \(\[ForAll] \[Alpha] \[Element] \
\[DoubleStruckCapitalR]\) \[And] 
        k \[Element] \[DoubleStruckCapitalZ]\)], "DisplayFormula"],

Cell[TextData[{
  "e possiamo concludere che la funzione seno rientra nella definizione data \
sopra ed \[EGrave] quindi periodica con periodicit\[AGrave] ",
  Cell[BoxData[
      \(TraditionalForm\`T = 2  \[Pi]\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Definizione della funzione coseno di un angolo", "Section"],

Cell["\<\
Per quanto visto circa la funzione seno, la definizione della seconda \
funzione goniometrica fondamentale cio\[EGrave] del coseno di un angolo, \
discende abbastanza naturale. Si pone pertanto\
\>", "Text"],

Cell[TextData[{
  "Definizione del coseno di un angolo \[Alpha]\n\n",
  Cell[BoxData[
      \(TraditionalForm\`cos(\[Alpha]) = OQ\/OP\)]]
}], "Definition",
  CellTags->"definizionecoseno"],

Cell[TextData[{
  "essendo ",
  Cell[BoxData[
      FormBox[
        StyleBox["OQ",
          FontSlant->"Italic"], TraditionalForm]]],
  " il segmento orientato (o componente \"orizzontale\" del vettore ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontWeight->"Bold"], TraditionalForm]]],
  ") che individua l'ascissa di ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " nella circonferenza ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " di centro ",
  Cell[BoxData[
      \(TraditionalForm\`O\)]],
  " e raggio ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontSlant->"Italic"], TraditionalForm]]],
  " (",
  ButtonBox["fig. 5",
    ButtonData:>"figura5",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Alpha] = 50  Degree;\)\), "\n", 
    \(pP = {Cos[\[Alpha]], Sin[\[Alpha]]}; pQ = {Cos[\[Alpha]], 0}; 
    origine = {0, 0};\), "\n", 
    \(\(Show[
        Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
            Line[{{0, \(-1.2\)}, {0, 1.2}}], 
            Line[{pP, origine}]}], \[IndentingNewLine]Graphics[{colBlu, 
            Arrow[origine, pQ, stileVet], 
            Arrow[pQ, pP, 
              stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
              origine, {1, 1}, TextStyle \[Rule] stileTesto], 
            Text["\<Q\>", pQ, {0, 1}, TextStyle \[Rule] stileTesto], 
            Text["\<P\>", pP, {0, \(-1\)}, TextStyle \[Rule] stileTesto]}], 
        Prolog -> {{colGiallo, Polygon[{origine, pQ, pP}]}, {colRosso, 
              Disk[{0, 0},  .2, {0, \[Alpha]}]}}, 
        AspectRatio \[Rule] Automatic, Axes \[Rule] True];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 .5 m
.75507 .5 L
.75507 .80399 L
F
1 0 0 r
.5 .5 m
.5 .5 .07937 0 50 arc
F
0 g
.5 Mabswid
newpath
.5 .5 .39683 0 365.73 arc
s
.02381 .5 m
.97619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.75507 .80399 m
.5 .5 L
s
0 0 1 r
.5 .5 m
.75507 .5 L
s
% Start of user PostScript
0 0 0.642788 0 MAarrowhead1
% End of user PostScript
.75507 .5 m
.75507 .80399 L
s
% Start of user PostScript
0.642788 0 0.642788 0.766044 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 .5 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .5 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .80399 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002P0?ooo`03
0?noM000000000000080000000H004RL0=ooo`3oool0oooO09a8M02oool80?ooo`030000003oool0
oooo0;80oooo002S0?ooob400000Y03oool009`0oooo1`0000030?ooo`050?oog`2LW;l0oooO09a8
M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000W@3oool009L0oooo1@00000;0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool05@3oool5000009P0oooo002C0?ooo`@0
00004@3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo01X0oooo1000002D0?ooo`00
SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000008l0oooo002;0?ooo`<000009@3o
ool00`000000oooo0?ooo`0S0?ooo`<00000S03oool008L0oooo1000000X0?ooo`030000003oool0
oooo02H0oooo100000280?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0Q@3oool00880oooo1000000]0?ooo`030000003oool0oooo02/0
oooo100000230?ooo`00O`3oool300000340oooo00<000000?ooo`3oool0;`3oool300000800oooo
001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000OP3oool007X0oooo0`00000f
0?ooo`030000003oool0oooo03@0oooo0`00001k0?ooo`00N03oool2000003T0oooo00<000000?oo
o`3oool0=`3oool2000007T0oooo001g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1f0?ooo`00M03oool3000003`0oooo0P00000k0?ooo`<00000
M@3oool00780oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001c0?ooo`00L03oool2
00000440oooo00<000000?ooo`3oool0?`3oool200000740oooo001_0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`00K@3oool2000004@0
oooo00<000000?ooo`3oool0@P3oool2000006h0oooo001/0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`00J@3oool3000004L0oooo00<0
00000?ooo`3oool0A@3oool3000006X0oooo001W0?ooo`800000BP3oool00`000000oooo0?ooo`18
0?ooo`800000J03oool006H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo06D0oooo001T0?ooo`800000C@3oool00`000000oooo0?ooo`1;0?ooo`80
0000I@3oool006<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0680oooo001Q0?ooo`800000D03oool00`000000oooo0?ooo`1>0?ooo`800000HP3o
ool00600oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo05l0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`800000G`3oool005d0
oooo00<000000?ooo`3oool0D`3oool2000005@0oooo00<000000?ooo`3oool0G03oool005`0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo
001K0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`1J0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool0F@3oool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?oo
o`00E`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3o
ool0EP3oool005H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo05D0oooo001E0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`1D0?ooo`00E03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool0D`3oool005<0oooo00<000000?ooo`3oool0G@3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0580oooo001B0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1A0?ooo`00D@3oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0D03oool00500oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04l0oooo001?
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1>
0?ooo`00CP3oool00`000000oooo0?ooo`1R0?ooo`800000H`3oool00`000000oooo0?ooo`1=0?oo
o`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0C03oool004`0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo04/0oooo001;0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`1:0?ooo`00BP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0B@3oool004T0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo04P0oooo00180?ooo`030000003oool0oooo06P0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`170?ooo`00A`3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool004H0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo0015
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`14
0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0A03oool004@0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo04<0oooo00130?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`120?ooo`00@P3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3oool0K`3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0400oooo00100?ooo`030000003oool0oooo
0700oooo0P00001a0?ooo`030000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?P3oool003h0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03d0oooo000n
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0m
0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0?03oool003`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1d0?ooo`03
0000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0
M03oool00`000000oooo0?ooo`0k0?ooo`00>`3oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool0>P3oool003X0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0i0?ooo`00>@3oool00`000000
oooo0?ooo`1S0?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0oooo0;md00800000
00<0B9cO0?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03P0oooo
000i0?ooo`030000003oool0oooo0680oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`06
0?noM018W=l0oooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo03P0oooo000h0?ooo`030000003oool0oooo05`0oooo00<0okmd0000000000000P0000002000
B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`050?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0>03oool003P0oooo00<000000?ooo`3oool0H`3o
ool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol6
0?ooo`<00000N03oool00`000000oooo0?ooo`0g0?ooo`00=`3oool00`000000oooo0?ooo`1T0?oo
o`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0f0?ooo`00=P3oool00`000000oooo0?oo
o`1U0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`090?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0
IP3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol01P3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo03D0oooo000e0?ooo`030000003oool0oooo07/0
oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`0d0?ooo`00=03oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0=03oool003@0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo000c
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0c
0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07d0oooo00<000000?oo
o`3oool0<P3oool003<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo000b0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0b0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0<@3oool00340oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0`0?ooo`00<03oool00`000000
oooo0?ooo`200?ooo`800000P@3oool00`000000oooo0?ooo`0_0?ooo`00<03oool00`000000oooo
0?ooo`200?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;`3oool00300oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo02l0oooo000_
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0^
0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0;P3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`220?ooo`03
0000003oool0oooo02d0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0
PP3oool00`000000oooo0?ooo`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003o
ool0oooo0880oooo00<000000?ooo`3oool0;@3oool002d0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0;03oool002`0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0oooo
000/0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0[0?ooo`00:`3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool2000008H0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo02X0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0Z0?ooo`00:P3oool00`000000oooo0?ooo`260?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo02T0oooo000Y0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0Y0?ooo`00:@3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0:03oool002T0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo
000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo02P0oooo000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`00
0000oooo0?ooo`290?ooo`800000RP3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool09P3oool002L0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo02H0oooo
000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0V0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0o0?ooo`0:0;md0000
0000001809cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool0>`3oool2
000003l0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18
W=l0oooo0?ooo`0n0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000003oool0oooO09a8
M02oool0?P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo
0=nLB01d_oll0?ooo`030000003oool0oooo03d0oooo00H0okmd0018W03Oool0okmd0018W03Oool3
0?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo?`3oool00`000000W4Qd0;ooo`0T0?ooo`007P3o
ool00`3o_g@0000000000002000000070018W03Oool000000?ooo`3ooml0W4Qd0;ooo`0g0?ooo`03
0?noM000000000000080000000P004RL0=ooo`3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0
okmd04RLg`3oool0>`3oool00`000000oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0
_ooo1`3oool00`3o_g@0B9cO0?ooo`0=0?ooo`030?noM000M;l0oooo02h0oooo00<0000009a8M02o
ool0903oool002D0oooo00D000000?ooo`3ooml0W4Qd0;ooo`0n0?ooo`060=nLB01d_ol0oooo0?oo
g`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia807Booc80oooo00H0oono07@000000000
00000000M02oool40?ooo`030000003oool0oooo03d0oooo00H0gia807Boo`3oool0oooO09a8M02o
ool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo2@3oool00`3ookl0M0000000000200000003
0000M02oool0oooo02h0oooo00<0000009a8M02oool0903oool002D0oooo00D0000009bL_`3ooml0
W4Qd0;ooo`0n0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000
000007Bo0380oooo00P0oono07@00000B9`0gooo0?oog`2LB000001d0;ooo`<0oooo00<000000?oo
o`3oool0?@3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`<0oooo00D0oono07A8B01800000000
001d_`090?ooo`080?oo_`1d000004RL0=ooo`2oM00000000000B02Lgol]0?ooo`050?oog`2LW;l0
000009a8M02oool0903oool002D0oooo00D000000?noM0000000001d0;ooo`0n0?ooo`060?noM000
B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`0d0?ooo`030?noM00004P0W=oo0080
oooo00<0omnL04P0001d_ol00`3oool00`000000oooo0?ooo`0m0?ooo`060?noM000B9`0gooo0?no
M000B9`0gooo0`3oool00`3ooml0W4Q809cOo`0;0?ooo`080?noM00004P0W=oo0?oOW018B9`0gmnL
04P00018W=l^0?ooo`040?noM0000000001d0;ooob@0oooo000U0?ooo`050000003oool0oono07@0
M02oool0?`3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol0<@3o
ool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo00<000000?ooo`3oool0?P3o
ool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol0203oool00`3OW4P0
001d0;ooo`020?ooo`030?oo_`1d0000B9cO02l0oooo00<0000007@0M02oool0903oool002D0oooo
00<000000?ooo`3oool0P03oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO00<0oooo
00<000000?ooo`3oool0E03oool00`3OW4P0001d0;ooo`020?ooo`030?oo_`1d0000B9cO02l0oooo
00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0P03oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo00<0oooo00<000000?ooo`3oool0E03oool00`3o_g@0001809cO
o`020?ooo`030?oOW0180000M;oo02l0oooo00<000000?ooo`3oool0903oool002D0oooo00<00000
0?ooo`3oool0P03oool00`3ookl0M000001d_`020?ooo`030;md000007@0_ooo00<0oooo00<00000
0?ooo`3oool0E03oool0203ookl0M0000018W03Oool0oooo0;md0000B9`0gooo;`3oool00`000000
oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`210?ooo`060?oo_`1d0000000000000000
07@0_ooo103oool00`000000oooo0?ooo`1E0?ooo`060?oo_`1d0000000000000000B9`0gooo<03o
ool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo04h0oooo0P000?lk0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0CP3oool60000ocL0oooo00<000000?ooo`3oool0903oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`1?0?ooo`T0003o<`3oool00`000000
oooo0?ooo`0T0?ooo`00/`00001M0000oeP0000000080?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`8000006P3o000f0?oo00T0003o00<0
ool00000o`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool01`3oool002D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`14
0?ooo`030000003oool0000001T0o`00=@3oo`060000o`D0ool000<0003o0?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`040000003oool0oooo
000001P0o`00=@3oo`020000o`T0ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T
0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`040000003oool0oooo000001P0o`00@03oo`00
0`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00D000000?ooo`3oool0oooo0000000G0?l00400ool000<0003o0?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
0080oooo00<000000?l0003o0000503o00100?oo00030000o`3oool0oooo02l0oooo00<000000?oo
o`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`030?ooo`03
0000003o0000o`0001<0o`00@03oo`000`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0103oool00`000000o`00
0?l0000B0?l00400ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3o
ool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00D0oooo00<000000?l0003o0000403o
00110?oo00030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0903oool002D0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`050?ooo`030000003o0000o`000100o`00@@3oo`00
0`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool01P3oool00`000000o`000?l0000?0?l00440ool000<0003o0?oo
o`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo00L0oooo00<000000?l0003o00003@3o00120?oo00030000o`3oool0oooo02l0
oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`080?ooo`030000003o0000o`0000`0o`00@P3oo`000`000?l0oooo0?ooo`0_0?ooo`030000
003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo0P00000:0?ooo`030000003o
0000o`0000X0o`00@`3oo`000`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U
0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool02P3oool00`000000o`000?l00008
0?l004@0ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o00001`3o00140?oo
00030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`0;0?ooo`030000003o0000o`0000H0o`00A@3oo`000`000?l0
oooo0?ooo`0^0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo
00<000000?ooo`3oool0303oool00`000000o`000?l000050?l004D0ool000<0003o0?ooo`3oool0
;P3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo00d0oooo00<000000?l0003o00000`3o00160?oo00030000o`3oool0oooo02h0oooo00<0
00000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0>
0?ooo`040000003o0000o`000?l004L0ool000<0003o0?ooo`3oool0;P3oool00`000000oooo0?oo
o`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00l0oooo00<00000
0?l0003oo`00A`3oo`000`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo02D0oooo000V0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0403oool00`000000ool00?oo00160?oo
00030000o`3oool0oooo02h0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0@0?ooo`030000003oo`00ool004H0ool000<0003o0?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo0140oooo00<000000?oo003oo`00A@3oo`000`000?l0oooo0?ooo`0]0?ooo`030000
003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool04P3o
ool00`000000ool00?oo00140?oo00030000o`3oool0oooo02d0oooo00<000000?ooo`3oool09P3o
ool002L0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0C0?ooo`030000003oo`00
ool004<0ool000<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo01@0oooo00<000000?oo003oo`00@P3oo`000`00
0?l0oooo0?ooo`0]0?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0oooo08T0
oooo0P00000F0?ooo`030000003oo`00ool00440ool000<0003o0?ooo`3oool0;@3oool00`000000
oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo01D0oooo
00<000000?oo003oo`00@@3oo`000`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo02L0oooo
000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool05P3oool00`000000ool00?oo
00100?oo00030000o`3oool0oooo02`0oooo00<000000?ooo`3oool09`3oool002P0oooo00<00000
0?ooo`3oool0R03oool00`000000oooo0?ooo`0G0?ooo`030000003oo`00ool003l0ool000<0003o
0?ooo`3oool0;03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo01P0oooo00<000000?oo003oo`00?P3oo`000`000?l0oooo0?ooo`0/0?oo
o`030000003oool0oooo02L0oooo000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool06@3oool00`000000ool00?oo000m0?oo00030000o`3oool0oooo02/0oooo00<000000?ooo`3o
ool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oo`00ool003`0ool000<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0X0?ooo`00:@3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo01/0oooo00<000000?oo003oo`00>`3o
o`000`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool06`3oool00`000000ool00?oo000k0?oo00030000o`3oool0
oooo02/0oooo00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oo`00ool003X0ool000<0003o0?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo01d0
oooo00<000000?oo003oo`00>@3oo`000`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo02T0
oooo000Z0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool07P3oool00`000000ool0
0?oo000h0?oo00030000o`3oool0oooo02X0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0O0?ooo`030000003oo`00ool003L0ool000<0
003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0200oooo00<000000?oo003oo`00=P3oo`000`000?l0oooo0?ooo`0Y
0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool0803oool00`000000ool00?oo000f0?oo00030000o`3oool0oooo02T0oooo00<000000?oo
o`3oool0:P3oool002/0oooo00<000000?ooo`3oool0Q@3oool200000280oooo00<000000?oo003o
o`00=@3oo`000`000?l0oooo0?ooo`0Y0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool08P3oool00`000000ool00?oo000d0?oo00030000
o`3oool0oooo02T0oooo00<000000?ooo`3oool0:P3oool002`0oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`0S0?ooo`030000003oo`00ool003<0ool000<0003o0?ooo`3oool0:03o
ool00`000000oooo0?ooo`0[0?ooo`00;03oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo02@0oooo00<000000?oo003oo`00<P3oo`000`000?l0oooo0?ooo`0W0?ooo`030000003oool0
oooo02`0oooo000]0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool09@3oool00`00
0000ool00?oo000a0?oo00030000o`3oool0oooo02L0oooo00<000000?ooo`3oool0;03oool002d0
oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0V0?ooo`030000003oo`00ool00300
ool000<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000oooo
0?ooo`230?ooo`030000003oool0oooo02H0oooo00<000000?oo003oo`00<03oo`000`000?l0oooo
0?ooo`0W0?ooo`030000003oool0oooo02`0oooo000^0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool09`3oool00`000000ool00?oo000_0?oo00030000o`3oool0oooo02H0oooo00<0
00000?ooo`3oool0;@3oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0X
0?ooo`030000003oo`00ool002h0ool000<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`0]
0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo02T0oooo00<000000?oo
003oo`00;@3oo`000`000?l0oooo0?ooo`0V0?ooo`030000003oool0oooo02d0oooo000^0?ooo`03
0000003oool0oooo0880oooo00<000000?ooo`3oool0:P3oool00`000000ool00?oo000/0?oo0003
0000o`3oool0oooo02D0oooo00<000000?ooo`3oool0;P3oool002l0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`0[0?ooo`030000003oo`00ool002/0ool000<0003o0?ooo`3oool0
9@3oool00`000000oooo0?ooo`0^0?ooo`00<03oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo02/0oooo00<000000?oo003oo`00:`3oo`000`000?l0oooo0?ooo`0T0?ooo`030000003o
ool0oooo02l0oooo000`0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;03oool0
0`000000ool00?oo000Z0?oo00030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0;`3oool0
0300oooo00<000000?ooo`3oool0P03oool2000002h0oooo00<000000?oo003oo`00:@3oo`000`00
0?l0oooo0?ooo`0T0?ooo`030000003oool0oooo02l0oooo000`0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool0;P3oool00`000000ool00?oo000X0?oo00030000o`3oool0oooo02<0
oooo00<000000?ooo`3oool0<03oool00340oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`0_0?ooo`030000003oo`00ool002L0ool000<0003o0?ooo`3oool08`3oool00`000000oooo
0?ooo`0`0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0300oooo00<0
00000?oo003oo`009P3oo`000`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo0340oooo000b
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0<03oool00`000000ool00?oo000V
0?oo00030000o`3oool0oooo0240oooo00<000000?ooo`3oool0<P3oool003<0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`030000003oo`00ool002D0ool000<0003o0?oo
o`3oool08@3oool00`000000oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`03
0000003oool0oooo0380oooo00<000000?oo003oo`00903oo`000`000?l0oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0380oooo000c0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
<`3oool00`000000ool00?oo000S0?oo00030000o`3oool0oooo0200oooo00<000000?ooo`3oool0
<`3oool003@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0d0?ooo`030000003o
o`00ool00280ool000<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0c0?ooo`00=03oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo00<000000?oo003oo`008@3oo`00
0`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo000e0?ooo`030000003oool0oooo
07/0oooo00<000000?ooo`3oool0=P3oool00`000000ool00?oo000P0?oo00030000o`3oool0oooo
01l0oooo00<000000?ooo`3oool0=03oool003H0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`0f0?ooo`030000003oo`00ool00200ool000<0003o0?ooo`3oool07P3oool00`000000
oooo0?ooo`0e0?ooo`00=P3oool00`000000oooo0?ooo`1V0?ooo`0:0;md00000000001809cOo`3o
ool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool01@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oo`00ool001l0ool000<0003o0?ooo`3oool07@3oool00`000000oooo0?oo
o`0f0?ooo`00=`3oool00`000000oooo0?ooo`1T0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo
0`3oool01P3o_g@0B9cO0?ooo`3oool0gia807Boo`H0oooo00<000000?ooo`3oool0>03oool00`00
0000ool00?oo000N0?oo00030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0=P3oool003P0
oooo00<000000?ooo`3oool0H`3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0okmd
04RLg`3oool01@3oool3000003T0oooo00<000000?oo003oo`007@3oo`000`000?l0oooo0?ooo`0L
0?ooo`030000003oool0oooo03L0oooo000h0?ooo`030000003oool0oooo06<0oooo00H0gia807Bo
o`3oool0oooO09a8M02oool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo1P3oool00`000000
oooo0?ooo`0j0?ooo`030000003oo`00ool001`0ool000<0003o0?ooo`3oool06`3oool00`000000
oooo0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`1R0?ooo`060=nLB018W=l0oooo0?oo_`1d
07@0_ooo0`3oool01@3ookl0M4Q804P00000000007Bo00L0oooo00<000000?ooo`3oool0>`3oool0
0`000000ool00?oo000K0?oo00030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0>03oool0
03T0oooo00<000000?ooo`3oool0HP3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0
oooO09a8B02Lgol02@3oool00`000000oooo0?ooo`0k0?ooo`030000003oo`00ool001/0ool000<0
003o0?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`00>P3oool00`000000oooo0?ooo`1R
0?ooo`040;md00000000001809cOo`D0oooo00D0_g@0000000000000001809cOo`060?ooo`030000
003oool0oooo03`0oooo00<000000?oo003oo`006P3oo`000`000?l0oooo0?ooo`0J0?ooo`030000
003oool0oooo03T0oooo000j0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0?@3o
ool00`000000ool00?oo000I0?oo00030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0>@3o
ool003/0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0n0?ooo`030000003oo`00
ool001P0ool000<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`0j0?ooo`00?03oool00`00
0000oooo0?ooo`1d0?ooo`030000003oool0oooo03l0oooo00<000000?oo003oo`005`3oo`000`00
0?l0oooo0?ooo`0H0?ooo`030000003oool0oooo03/0oooo000l0?ooo`030000003oool0oooo07@0
oooo00<000000?ooo`3oool0@03oool00`000000ool00?oo000F0?oo00030000o`3oool0oooo01P0
oooo00<000000?ooo`3oool0>`3oool003d0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`110?ooo`030000003oo`00ool001D0ool000<0003o0?ooo`3oool05`3oool00`000000oooo
0?ooo`0l0?ooo`00?P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0440oooo00<0
00000?oo003oo`005@3oo`000`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo03d0oooo000n
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0@P3oool00`000000ool00?oo000D
0?oo00030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0?@3oool003l0oooo00<000000?oo
o`3oool0L@3oool00`000000oooo0?ooo`130?ooo`030000003oo`00ool001<0ool000<0003o0?oo
o`3oool05@3oool00`000000oooo0?ooo`0n0?ooo`00@03oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo04@0oooo00<000000?oo003oo`004P3oo`000`000?l0oooo0?ooo`0D0?ooo`03
0000003oool0oooo03l0oooo00100?ooo`030000003oool0oooo0700oooo0P0000160?ooo`030000
003oo`00ool00140ool000<0003o0?ooo`3oool0503oool00`000000oooo0?ooo`0o0?ooo`00@@3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo04H0oooo00<000000?oo003oo`00403o
o`000`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo0400oooo00120?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0AP3oool00`000000ool00?oo000@0?oo00030000o`3oool0
oooo0180oooo00<000000?ooo`3oool0@@3oool004<0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`170?ooo`030000003oo`00ool000l0ool000<0003o0?ooo`3oool04@3oool00`00
0000oooo0?ooo`120?ooo`00A03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo04P0
oooo00<000000?oo003oo`003P3oo`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo04<0
oooo00150?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0B@3oool00`000000ool0
0?oo000=0?oo00030000o`3oool0oooo00l0oooo00<000000?ooo`3oool0A03oool004D0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`1:0?ooo`030000003oo`00ool000`0ool000<0
003o0?ooo`3oool03`3oool00`000000oooo0?ooo`140?ooo`00AP3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo04/0oooo00<000000?oo003oo`002`3oo`000`000?l0oooo0?ooo`0>
0?ooo`030000003oool0oooo04D0oooo00170?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0B`3oool00`000000ool00?oo000;0?oo00030000o`3oool0oooo00d0oooo00<000000?oo
o`3oool0AP3oool004P0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1<0?ooo`03
0000003oo`00ool000X0ool000<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`170?ooo`00
B@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04d0oooo00<000000?oo003oo`00
2@3oo`000`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo04P0oooo001:0?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool0CP3oool00`000000ool00?oo00080?oo00030000o`3o
ool0oooo00X0oooo00<000000?ooo`3oool0B@3oool004/0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oo`00ool000L0ool000<0003o0?ooo`3oool02@3oool0
0`000000oooo0?ooo`1:0?ooo`00C03oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
0500oooo00<000000?oo003oo`000`3oo`020000o`040?oo00000?l0oooo0000o`P0oooo00<00000
0?ooo`3oool0B`3oool004d0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1A0?oo
o`030000003oo`00ool00080ool01P000?l70?ooo`030000003oool0oooo04`0oooo001>0?ooo`03
0000003oool0oooo0680oooo0P00001B0?ooo`030000003oo`00ool000<0ool01@000?l60?ooo`03
0000003oool0oooo04d0oooo001?0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0
DP3oool00`000000ool00?oo00020?oo00@0003o1P3oool00`000000oooo0?ooo`1>0?ooo`00D03o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo05<0oooo00@000000?oo003oo`00ool0
10000?l50?ooo`030000003oool0oooo04l0oooo001A0?ooo`030000003oool0oooo05l0oooo00<0
00000?ooo`3oool0E03oool00`000000ool00?oo00040000o`@0oooo00<000000?ooo`3oool0D03o
ool00580oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1E0?ooo`030000003oo`00
ool000<0003o0`3oool00`000000oooo0?ooo`1A0?ooo`00D`3oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo05H0oooo00<000000?oo00000?l00P000?l20?ooo`030000003oool0oooo
0580oooo001D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0EP3oool00`000000
ool00000o`020000o`030?ooo`000000oooo05@0oooo001E0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0E`3oool01@000000003o0000o`3oool0000005H0oooo001F0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0F03oool00`000000003o0000001G0?ooo`00E`3o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo05T0oooo00<0003o0?ooo`3oool0EP3o
ool005P0oooo0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?ooo`00FP3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0F@3oool005/0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05X0
oooo001L0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`1K0?ooo`00G@3oool00`000000oooo0?ooo`1C0?ooo`800000E03oool01@000000oooo0?oo
_`1d0000B9cO05X0oooo001N0?ooo`800000D`3oool00`000000oooo0?ooo`1A0?ooo`8000000P3o
ool00`3ookl0M00004RLg`1J0?ooo`00H03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool00P3oool00`3ookl0M00004RLg`1J0?ooo`00H@3oool20000
0500oooo00<000000?ooo`3oool0CP3oool2000000D0oooo00<0oono07@0000000000P0000000`00
M;l0oooo0?ooo`1E0?ooo`00H`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool01@3oool01`3ookl0M00004RLg`3oool0omnL04P00018W=l0EP3oool0
06@0oooo0P00001=0?ooo`030000003oool0oooo04/0oooo0P0000080?ooo`070?oo_`1d0000B9cO
0?ooo`3ookl0M000001d_`1F0?ooo`00IP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0203oool01`3ookl0M00004RLg`3oool0omnL04P00018W=l0
EP3oool006L0oooo0P00001:0?ooo`030000003oool0oooo04P0oooo0P00000;0?ooo`030?oo_`1d
000000000080000000<004RL0=ooo`3oool0E@3oool006T0oooo0P0000180?ooo`030000003oool0
oooo04H0oooo0P00001Z0?ooo`00J`3oool2000004H0oooo00<000000?ooo`3oool0A03oool20000
06`0oooo001]0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`1/0?ooo`00KP3oool2000004<0oooo00<000000?ooo`3oool0@@3oool2000006l0oooo
001`0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`1_0?ooo`00L@3oool200000400oooo00<000000?ooo`3oool0?P3oool200000780oooo001c0?oo
o`<00000?@3oool2000003`0oooo0`00001d0?ooo`00MP3oool2000003/0oooo00<000000?ooo`3o
ool0>@3oool2000007L0oooo001h0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`1g0?ooo`00N@3oool4000003H0oooo00<000000?ooo`3oool0=03o
ool4000007X0oooo001m0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`1l0?ooo`00OP3oool400000340oooo00<000000?ooo`3oool0;`3oool40000
07l0oooo00220?ooo`<00000;P3oool00`000000oooo0?ooo`0/0?ooo`<00000P`3oool008D0oooo
0P00000/0?ooo`030000003oool0oooo02X0oooo0P0000260?ooo`00Q`3oool3000002T0oooo00<0
00000?ooo`3oool09`3oool3000008P0oooo002:0?ooo`<000009P3oool00`000000oooo0?ooo`0T
0?ooo`<00000R`3oool008d0oooo1P00000P0?ooo`030000003oool0oooo01h0oooo1P00002>0?oo
o`00T`3oool3000001d0oooo00<000000?ooo`3oool06`3oool3000009@0oooo002F0?ooo`D00000
3@3oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo01H0oooo1@00002G0?ooo`00V`3o
ool7000000H0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`0?0?ooo`L00000W03o
ool00:80oooo8`00002S0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo
0;80oooo002V0?ooo`050?oog`2LW;l0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b0?oo
o`00Y`3oool0103o_g@000000000M02oool80?ooo`030000003oool0oooo0;80oooo002X0?ooo`03
0?oo_`1d07@0_ooo00P0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo
00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`00
0000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo0000\
\>"],
  ImageRangeCache->{{{100.063, 300.625}, {301.5, 100.938}} -> {-2.51728, \
0.00824565, 0.00879536, 0.00879536}},
  CellTags->"figura5"]
}, Closed]],

Cell[CellGroupData[{

Cell["Variazione del coseno", "Subsubsection"],

Cell[TextData[{
  "Un'analisi qualitativa dell'andamento della funzione ",
  Cell[BoxData[
      \(TraditionalForm\`y = cos(\[Alpha])\)]],
  " per  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[Element] \([0, 2  \[Pi]]\)\)]],
  " basata sull'animazione seguente"
}], "Text"],

Cell[BoxData[
    FormBox[Cell[TextData[Cell[BoxData[
          \(TraditionalForm\`\[Alpha] \[Element] \[DoubleStruckCapitalR]\ \
\[LongRightArrow]\ y = cos(\[Alpha])\)]]]], TraditionalForm]], "Theorem"],

Cell["\<\
permette di individuare gi\[AGrave] alcune interessanti caratteristiche.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(origine = {0, 0};\)\), "\[IndentingNewLine]", 
    \(\(\(Show[
            Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
                Line[{{0, \(-1.2\)}, {0, 1.2}}], 
                Line[{{Cos[#], Sin[#]}, 
                    origine}]}], \[IndentingNewLine]Graphics[{colBlu, 
                Arrow[origine, {Cos[#], 0}, stileVet], 
                Arrow[{Cos[#], 0}, {Cos[#], Sin[#]}, 
                  stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
                  origine, {1, 1}, TextStyle \[Rule] stileTesto], 
                Text["\<Q\>", {Cos[#], 0}, {0, 1}, 
                  TextStyle \[Rule] stileTesto], 
                Text["\<P\>", {Cos[#], Sin[#]}, {0, \(-1\)}, 
                  TextStyle \[Rule] stileTesto]}], 
            Prolog -> {{colGiallo, 
                  Polygon[{origine, {Cos[#], 0}, {Cos[#], 
                        Sin[#]}}]}, {colRosso, Disk[origine,  .2, {0, #}]}}, 
            AspectRatio \[Rule] Automatic, Axes \[Rule] True, 
            PlotRange \[Rule] {{\(-1.26\), 2.8}, {\(-1.26\), 1.26}}, 
            Epilog \[Rule] {{Text["\<cos(\>" <> ToString[#] <> "\<) = \>" <> 
                      ToString[N[Cos[#]]], {1.1, 0.5}, {\(-1\), 0}, 
                    TextStyle \[Rule] stileTesto]}}, 
            ImageSize \[Rule] {500, 300}] &\) /@ 
        Table[\[Alpha], {\[Alpha], 0, 360\ Degree, 
            10  Degree}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .62069 
%%ImageSize: 500 300 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.310345 0.246305 0.310345 0.246305 [
[.06404 .29784 -6.96875 -10.9375 ]
[.06404 .29784 6.96875 0 ]
[.55665 .29784 -4.21875 -10.9375 ]
[.55665 .29784 4.21875 0 ]
[.80296 .29784 -4.21875 -10.9375 ]
[.80296 .29784 4.21875 0 ]
[.29784 .06404 -13.9375 -5.46875 ]
[.29784 .06404 0 5.46875 ]
[.29784 .18719 -20.625 -5.46875 ]
[.29784 .18719 0 5.46875 ]
[.29784 .4335 -15.125 -5.46875 ]
[.29784 .4335 0 5.46875 ]
[.29784 .55665 -8.4375 -5.46875 ]
[.29784 .55665 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .62069 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06404 .31034 m
.06404 .31659 L
s
gsave
.06404 .29784 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.55665 .31034 m
.55665 .31659 L
s
gsave
.55665 .29784 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.80296 .31034 m
.80296 .31659 L
s
gsave
.80296 .29784 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.1133 .31034 m
.1133 .31409 L
s
.16256 .31034 m
.16256 .31409 L
s
.21182 .31034 m
.21182 .31409 L
s
.26108 .31034 m
.26108 .31409 L
s
.35961 .31034 m
.35961 .31409 L
s
.40887 .31034 m
.40887 .31409 L
s
.45813 .31034 m
.45813 .31409 L
s
.50739 .31034 m
.50739 .31409 L
s
.60591 .31034 m
.60591 .31409 L
s
.65517 .31034 m
.65517 .31409 L
s
.70443 .31034 m
.70443 .31409 L
s
.75369 .31034 m
.75369 .31409 L
s
.01478 .31034 m
.01478 .31409 L
s
.85222 .31034 m
.85222 .31409 L
s
.90148 .31034 m
.90148 .31409 L
s
.95074 .31034 m
.95074 .31409 L
s
.25 Mabswid
0 .31034 m
1 .31034 L
s
.31034 .06404 m
.31659 .06404 L
s
gsave
.29784 .06404 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.31034 .18719 m
.31659 .18719 L
s
gsave
.29784 .18719 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.31034 .4335 m
.31659 .4335 L
s
gsave
.29784 .4335 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.31034 .55665 m
.31659 .55665 L
s
gsave
.29784 .55665 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.31034 .08867 m
.31409 .08867 L
s
.31034 .1133 m
.31409 .1133 L
s
.31034 .13793 m
.31409 .13793 L
s
.31034 .16256 m
.31409 .16256 L
s
.31034 .21182 m
.31409 .21182 L
s
.31034 .23645 m
.31409 .23645 L
s
.31034 .26108 m
.31409 .26108 L
s
.31034 .28571 m
.31409 .28571 L
s
.31034 .33498 m
.31409 .33498 L
s
.31034 .35961 m
.31409 .35961 L
s
.31034 .38424 m
.31409 .38424 L
s
.31034 .40887 m
.31409 .40887 L
s
.31034 .45813 m
.31409 .45813 L
s
.31034 .48276 m
.31409 .48276 L
s
.31034 .50739 m
.31409 .50739 L
s
.31034 .53202 m
.31409 .53202 L
s
.31034 .03941 m
.31409 .03941 L
s
.31034 .01478 m
.31409 .01478 L
s
.31034 .58128 m
.31409 .58128 L
s
.31034 .60591 m
.31409 .60591 L
s
.25 Mabswid
.31034 0 m
.31034 .62069 L
s
0 0 m
1 0 L
1 .62069 L
0 .62069 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.31034 .31034 m
.18719 .31034 L
.18719 .09704 L
F
1 0 0 r
.31034 .31034 m
.31034 .31034 .04926 0 240 arc
F
0 g
.5 Mabswid
newpath
.31034 .31034 .24631 0 365.73 arc
s
.01478 .31034 m
.60591 .31034 L
s
.31034 .01478 m
.31034 .60591 L
s
.18719 .09704 m
.31034 .31034 L
s
0 0 1 r
.31034 .31034 m
.18719 .31034 L
s
% Start of user PostScript
0 0 -0.5 0 MAarrowhead1
% End of user PostScript
.18719 .31034 m
.18719 .09704 L
s
% Start of user PostScript
-0.5 0 -0.5 -0.866025 MAarrowhead1
% End of user PostScript
0 g
gsave
.31034 .31034 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18719 .31034 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.18719 .09704 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.58128 .4335 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(cos) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.500 13.375 moveto
(H) show
81.625 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(240) show
99.125 13.375 moveto
(Degree) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
129.500 13.375 moveto
(L) show
135.125 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
143.750 13.375 moveto
(-) show
149.875 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
162.375 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "",
  ImageSize->{499.813, 299.813},
  ImageMargins->{{47.125, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005M0000dB000`400?l00000o`00003oKP3oool0
0`000000oooo0?ooo`3/0?ooo`00KP3oool00`000000oooo0?ooo`3/0?ooo`00KP3oool00`000000
oooo0?ooo`3/0?ooo`00KP3oool00`000000oooo0?ooo`3/0?ooo`00KP3oool00`000000oooo0?oo
o`3/0?ooo`00KP3oool200000>d0oooo001^0?ooo`030000003oool0oooo0>`0oooo001^0?ooo`03
0000003oool0oooo0>`0oooo001^0?ooo`030000003oool0oooo0>`0oooo001^0?ooo`030000003o
ool0oooo0>`0oooo001^0?ooo`030000003oool0oooo0>`0oooo001^0?ooo`030000003oool0oooo
0>`0oooo001^0?ooo`030000003oool0oooo0>`0oooo001^0?ooo`800000k@3oool006h0oooo00<0
00000?ooo`3oool0k03oool006h0oooo00<000000?ooo`3oool0k03oool006h0oooo00<000000?oo
o`3oool0k03oool006h0oooo00<000000?ooo`3oool0k03oool006h0oooo00<000000?ooo`3oool0
k03oool006h0oooo00<000000?ooo`3oool0k03oool006h0oooo00<000000?ooo`3oool0k03oool0
0680oooo0`0000000`3oool000000?ooo`0=00000>P0oooo001P0?ooo`P000001P3oool00`000000
oooo0?ooo`040?ooo`T00000g`3oool005`0oooo100000060?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool03@3oool400000=/0oooo001H0?ooo`@000004P3oool00`000000oooo0?oo
o`0A0?ooo`@00000e`3oool005H0oooo0P00000F0?ooo`030000003oool0oooo01D0oooo0P00003E
0?ooo`00DP3oool4000001P0oooo00<000000?ooo`3oool05`3oool300000=80oooo001@0?ooo`80
0000703oool00`000000oooo0?ooo`0J0?ooo`800000d03oool004h0oooo0P00000N0?ooo`030000
003oool0oooo01`0oooo0P00003>0?ooo`00BP3oool400000200oooo00<000000?ooo`3oool07P3o
ool400000<X0oooo00180?ooo`800000903oool2000002<0oooo0P0000380?ooo`00AP3oool20000
02H0oooo00<000000?ooo`3oool0903oool200000<H0oooo00150?ooo`030000o`3oool0oooo02H0
oooo00<000000?ooo`3oool09P3oool200000<@0oooo00130?ooo`80000000<0003o0000003oool0
9P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0<40oooo00110?ooo`80000000@0
oooo0000o`000?l000009`3oool00`000000oooo0?ooo`0Y0?ooo`800000`@3oool00400oooo00@0
00000?ooo`3oool0oooo0`000?l00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool0_P3oool003l0oooo00D000000?ooo`3oool0oooo000000030000o`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2m0?ooo`00?P3o
ool00`000000oooo0?ooo`020?ooo`06000000000?l0003o0000o`3oo`0000009@3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo0;`0oooo000l0?ooo`8000001@3oool01P000000003o
0000o`000000ool0000002D0oooo0P00000_0?ooo`800000_03oool003X0oooo0P0000070?ooo`04
000000000?l0000000000080ool000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0`0?oo
o`800000^P3oool003T0oooo00<000000?ooo`3oool01`3oool50000o`80ool000<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0;P0oooo000i0?ooo`030000
003oool0oooo00H0oooo1P000?l20?oo00030000003oool0oooo0240oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`2g0?ooo`00=`3oool2000000T0oooo0P000?l0103oool0003o0000
o`000?l30?oo00030000003oool0oooo0200oooo00<000000?ooo`3oool0<`3oool200000;L0oooo
000f0?ooo`030000003oool0oooo00`0oooo00<0003o0?oo003oo`000`3oo`000`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0]03oool003D0oooo00<00000
0?ooo`3oool03@3oool00`000?l0ool00?oo00040?oo00030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`2c0?ooo`00=03oool00`000000oooo0?ooo`0>0?oo
o`030000o`3oo`00ool000@0ool000<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0;80oooo000c0?ooo`030000003oool0oooo00l0oooo00<0003o0?oo003o
o`001@3oo`000`000000oooo0?ooo`0N0?ooo`800000>@3oool00`000000oooo0?ooo`2a0?ooo`00
<P3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oo`00ool000H0ool000<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0;00oooo000a0?ooo`030000003o
ool0oooo0140oooo00<0003o0?oo003oo`001P3oo`000`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0[`3oool00300oooo00<000000?ooo`3oool04P3oool0
0`000?l0ool00?oo00070?oo00030000003oool0oooo01`0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`2^0?ooo`00;`3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oo`00ool0
00L0ool000<000000?ooo`3oool0703oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
0:d0oooo000_0?ooo`030000003oool0oooo01<0oooo00<0003o0?oo003oo`00203oo`000`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0[03oool002d0oooo
0P00000F0?ooo`030000o`3oo`00ool000P0ool000<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo0:/0oooo000/0?ooo`030000003oool0oooo01H0oooo00<0
003o0?oo003oo`002@3oo`000`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0Z`3oool002`0oooo00<000000?ooo`3oool05P3oool00`000?l0ool00?oo000:
0?oo00030000003oool0oooo01T0oooo0P0000100?ooo`030000003oool0oooo0:X0oooo000[0?oo
o`030000003oool0oooo01L0oooo00<0003o0?oo003oo`002P3oo`000`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0ZP3oool002/0oooo00<000000?ooo`3o
ool05`3oool00`000?l0ool00?oo000;0?oo00030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`2Y0?ooo`00:P3oool00`000000oooo0?ooo`0H0?ooo`030000
o`3oo`00ool000/0ool000<000000?ooo`3oool0603oool00`000000oooo0?ooo`110?ooo`800000
Z@3oool002T0oooo00<000000?ooo`3oool06@3oool00`000?l0ool00?oo000<0?oo00030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`2W0?ooo`00:@3oool0
0`000000oooo0?ooo`0I0?ooo`030000o`3oo`00ool000`0ool000<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo0:H0oooo000X0?ooo`030000003oool0oooo
01X0oooo00<0003o0?oo003oo`003@3oo`000`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool0YP3oool002L0oooo00<000000?ooo`3oool06`3oool00`000?l0
ool00?oo000>0?oo00030000003oool0oooo01D0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`2U0?ooo`009P3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oo`00ool000h0ool0
00<000000?ooo`3oool0203oool3000000030?ooo`0000000000008000001@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0:D0oooo000V0?ooo`030000003oool0oooo01`0oooo00<0
003o0?oo003oo`003`3oo`000`000000oooo0?ooo`030?ooo`<0000000@0oooo0000003oool00000
103oool00`000000oooo0?ooo`030?ooo`<00000A@3oool00`000000oooo0?ooo`2T0?ooo`009@3o
ool00`000000oooo0?ooo`0M0?ooo`030000o`3oo`00ool000l0ool000<000000?ooo`3oool01`3o
ool00`000000oooo000000020?ooo`<000001@3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo0:<0oooo000T0?ooo`030000003oool0oooo01h0oooo00<0003o0?oo003oo`00403oo`00
0`000000oooo0?ooo`060?ooo`<000000P3oool2000000H0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`2S0?ooo`00903oool00`000000oooo0?ooo`0N0?ooo`030000o`3oo`00ool0
0100ool000<000000?ooo`3oool04`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:80oooo000S0?ooo`030000003oool0oooo01l0oooo00<0003o0?oo003oo`004@3oo`000`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0XP3oool002<0oooo
00<000000?ooo`3oool07`3oool00`000?l0ool00?oo000A0?oo00030000003oool0oooo0180oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2Q0?ooo`008`3oool00`000000oooo0?oo
o`0O0?ooo`030000o`3oo`00ool00180ool000<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo0:40oooo000S0?ooo`030000003oool0oooo01l0oooo00<0003o
0?oo003oo`004`3oo`000`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0X03oool00280oooo00<000000?ooo`3oool0803oool00`000?l0ool00?oo000C0?oo
00030000003oool0oooo0100oooo0P00001:0?ooo`030000003oool0oooo0:00oooo000R0?ooo`03
0000003oool0oooo0200oooo00<0003o0?oo003oo`00503oo`000`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0X03oool00240oooo00<000000?ooo`3oool0
8@3oool00`000?l0ool00?oo000D0?oo00030000003oool0oooo00l0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`2P0?ooo`008@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3o
o`00ool001D0ool000<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo09l0oooo000P0?ooo`030000003oool0oooo0280oooo00<0003o0?oo003oo`005@3oo`00
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0W`3oool0
0200oooo00<000000?ooo`3oool08P3oool00`000?l0ool00?oo000F0?oo00030000003oool0oooo
00d0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2N0?ooo`00803oool00`000000
oooo0?ooo`0R0?ooo`030000o`3oo`00ool001L0ool000<000000?ooo`3oool0303oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo09h0oooo000P0?ooo`030000003oool0oooo0280oooo
00<0003o0?oo003oo`005`3oo`000`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0W@3oool001l0oooo00<000000?ooo`3oool08`3oool00`000?l0ool00?oo
000H0?oo00030000003oool0oooo00/0oooo0P00001=0?ooo`030000003oool0oooo09d0oooo000O
0?ooo`030000003oool0oooo02<0oooo00<0003o0?oo003oo`00603oo`000`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0W@3oool001h0oooo00<000000?oo
o`3oool0903oool00`000?l0ool00?oo000I0?oo00030000003oool0oooo00X0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`2M0?ooo`007P3oool00`000000oooo0?ooo`0T0?ooo`03
0000o`3oo`00ool001T0ool000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo09`0oooo000N0?ooo`030000003oool0oooo02@0oooo00<0003o0?oo003oo`00
6P3oo`000`000000oooo0?ooo`090?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
W03oool001h0oooo00<000000?ooo`3oool0903oool00`000?l0ool00?oo000K0?oo00030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`2L0?ooo`007@3oool0
0`000000oooo0?ooo`0U0?ooo`030000o`3oo`00ool001/0ool000<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo09`0oooo000M0?ooo`030000003oool0oooo
02D0oooo00<0003o0?oo003oo`00703oo`000`000000oooo0?ooo`070?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool0V`3oool001d0oooo00<000000?ooo`3oool09@3oool00`000?l0
ool00?oo000L0?oo00030000003oool0oooo00L0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`2K0?ooo`007@3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oo`00ool001d0ool0
00<000000?ooo`3oool01P3oool2000004l0oooo00<000000?ooo`3oool0V`3oool001d0oooo00<0
00000?ooo`3oool09@3oool00`000?l0ool00?oo000M0?oo00030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`2K0?ooo`007@3oool00`000000oooo0?ooo`0U
0?ooo`030000o`3oo`00ool001h0ool000<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo09X0oooo000L0?ooo`030000003oool0oooo02H0oooo00<0003o0?oo
003oo`00703oo`030?l000030000003oool0oooo00@0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`2J0?ooo`00703oool00`000000oooo0?ooo`0V0?ooo`030000o`3oo`00ool001X0
ool01@3o00000`000000oooo0?ooo`040?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0VP3oool001`0oooo00<000000?ooo`3oool09P3oool00`000?l0ool00?oo000J0?oo00H0o`00
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo09X0oooo
000L0?ooo`030000003oool0oooo02H0oooo00<0003o0?oo003oo`006@3oo`070?l000030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`2J0?ooo`00703oool0
0`000000oooo0?ooo`0V0?ooo`030000o`3oo`00ool001T0ool0203o00000`000000oooo0?ooo`02
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0C`3oool3000004P0oooo000H0?oo
o`<0000000<0oooo0000000000009`3oool00`000?l0ool00?oo000H0?oo00T0o`0000<000000?oo
o`3oool00P3oool200000500oooo0P00001A0?ooo`030000003oool0oooo04L0oooo000K0?ooo`03
0000003oool0000002L0oooo00<0003o0?oo003oo`00603oo`0:0?l000050000003oool0oooo0?oo
o`000000D@3oool200000580oooo00<000000?ooo`3oool0AP3oool001/0oooo00<000000?ooo`00
00009`3oool00`000?l0ool00?oo000G0?oo00`0o`0000@000000?ooo`3oool00000D@3oool20000
0500oooo0`0000180?ooo`006`3oool00`000000oooo0?ooo`0U0?ooo`<000006@3oo`0:0?l000<0
00000P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo09T0oooo000K0?ooo`030000
003oool0oooo02@0oooo00@000000?ooo`3oool00000603oo`0:0?l000030000003o0000o`000080
000000<0oooo0000003oool0D@3oool00`000000oooo0?ooo`2I0?ooo`006`3oool00`000000oooo
0?ooo`0T0?ooo`040000003oool0oooo0000oaP0ool02P3o00001`000000o`000?l0003o00000000
0?ooo`000000DP3oool00`000000oooo0?ooo`2I0?ooo`006`3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0000000L0ool00`000?l>0?oo00/0o`0000@000000?l000000000o`000P00001B
0?ooo`030000003oool0oooo09T0oooo000K0?ooo`030000003oool0oooo02L0oooo00<0003o0?oo
003oo`001`000?l?0?oo00l0o`000P00001B0?ooo`030000003oool0oooo09T0oooo00060?ooocl0
0000:P000?oX000000H0oooo000;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo20000?l?0?oooa00o`00
00<000000?l0003o00003P3o00000`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`006`3oool00`000000oooo0?oo
o`0/0?ooo`H0003o3P3oool@0?l000030000003o0000o`0000h0o`00@P3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo04H0oooo000K0?ooo`030000003oool0oooo0300oooo0P000?l>
0?oooa00o`0000<000000?l0003o00003P3o00120?ooo`030000003oool0oooo09T0oooo000K0?oo
o`030000003oool0oooo0400oooo403o00000`000000o`000?l0000=0?l004<0oooo00<000000?oo
o`3oool0V@3oool001/0oooo00<000000?ooo`3oool0@@3oool?0?l000030000003o0000o`0000d0
o`00@`3oool00`000000oooo0?ooo`2I0?ooo`006`3oool00`000000oooo0?ooo`110?ooo`l0o`00
00<000000?l0003o0000303o00140?ooo`030000003oool0oooo09T0oooo000K0?ooo`030000003o
ool0oooo0480oooo3P3o00000`000000o`000?l0000<0?l004@0oooo00<000000?ooo`3oool0V@3o
ool001`0oooo00<000000?ooo`3oool0@@3oool>0?l000030000003o0000o`0000/0o`00A@3oool0
0`000000oooo0?ooo`2I0?ooo`00703oool00`000000oooo0?ooo`120?ooo`d0o`0000<000000?l0
003o00002`3o00140?ooo`030000003oool0oooo09X0oooo000L0?ooo`030000003oool0oooo0480
oooo3@3o00000`000000o`000?l0000:0?l004D0oooo00<000000?ooo`3oool0VP3oool001`0oooo
00<000000?ooo`3oool0@`3oool<0?l000030000003o0000o`0000X0o`00A@3oool00`000000oooo
0?ooo`2J0?ooo`00703oool00`000000oooo0?ooo`130?ooo``0o`0000<000000?l0003o00002@3o
00160?ooo`030000003oool0oooo09X0oooo000L0?ooo`030000003oool0oooo04D0oooo2P3o0000
0`000000o`000?l000070?l004P0oooo00<000000?ooo`3oool0VP3oool001`0oooo00<000000?oo
o`3oool0A`3oool80?l000030000003o0000o`0000D0o`00BP3oool00`000000oooo0?ooo`2J0?oo
o`00703oool00`000000oooo0?ooo`190?ooo`H0o`0000<000000?l0003o00000`3o001<0?ooo`03
0000003oool0oooo09X0oooo000M0?ooo`030000003oool0oooo04X0oooo103o000010000000o`00
0?l0003o001=0?ooo`030000003oool0oooo09/0oooo000M0?ooo`030000003oool0oooo04`0oooo
0P3o00000`000000o`000?ooo`1>0?ooo`030000003oool0oooo09/0oooo000M0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`2K0?ooo`007@3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0V`3oool0
01d0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
09`0oooo000N0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`2L0?ooo`007P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0W03oool001h0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo09`0oooo000N0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2M0?ooo`007`3oool00`000000oooo0?ooo`1<0?oo
o`800000C@3oool00`000000oooo0?ooo`2M0?ooo`00803oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0W@3oool00200oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09h0oooo000P0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2N0?ooo`00803oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0W`3oool0
0240oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
09l0oooo000Q0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`2P0?ooo`008P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0X03oool00280oooo00<000000?ooo`3oool0B@3oool2000004X0oooo00<0
00000?ooo`3oool0X03oool002<0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0:00oooo000S0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`2Q0?ooo`008`3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0X@3oool002<0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0:80oooo000T0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`2R0?ooo`00903oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0HP3oool0
02D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
0180oooo0P000000103oool000000000003oool3000000030?ooo`000000oooo00<000000P3oool0
10000000oooo0000000000030?ooo`<0000000D0oooo00000000000000000?ooo`02000000030?oo
o`000000oooo00H000000P3oool00`000000oooo0?ooo`0<0?ooo`<0000000@0oooo000000000000
0000CP3oool002D0oooo00<000000?ooo`3oool0>@3oool3000000030?ooo`000000000000800000
1@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0
0000103oool2000000060?ooo`000000oooo0?ooo`000000oooo100000000`3oool000000?ooo`02
0?ooo`030000003oool0oooo00D0000000D0oooo0000003oool000000?ooo`0600000080oooo00@0
00000?ooo`3oool0oooo100000020?ooo`D0000000<0oooo0000003oool00`3oool00`000000oooo
0?ooo`1<0?ooo`009P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0000000@0oooo00<0
00000?ooo`3oool00`3oool3000004D0oooo00<000000?ooo`3oool04P3oool6000000060?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo0?ooo`02000000030?ooo`000000oooo0080
oooo00<000000?ooo`3oool00P0000000`3oool0000000000002000000050?ooo`00000000000000
003oool00P0000001@3oool000000?ooo`3oool0000000<0oooo100000060?ooo`030000003oool0
00000080oooo0`00001>0?ooo`009`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool00000
0080oooo0`0000050?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool07`3oool20000
00030?ooo`000000oooo00<0000000<0oooo0000003oool00P3oool010000000oooo0?ooo`00000@
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000`3oool2000004h0oooo000W0?oo
o`030000003oool0oooo03L0oooo0`0000020?ooo`8000001P3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo0:H0oooo000X0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`2V0?ooo`00:@3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0Y`3oool002X0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0:L0oooo000[0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0@03oool200000:X0oooo000[0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2Z0?ooo`00;03oool00`000000
oooo0?ooo`0o0?ooo`800000@03oool00`000000oooo0?ooo`2Z0?ooo`00;03oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0Z`3oool002d0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0:/0oooo000^
0?ooo`800000?P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0:`0oooo000_0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2]0?oo
o`00<03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0[P3oool00340oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo0:l0oooo000b0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`2`0?ooo`00<`3oool00`000000oooo0?ooo`0h0?ooo`800000>@3oool0
0`000000oooo0?ooo`2a0?ooo`00=03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0/P3oool003D0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo0;<0oooo000f0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2d0?ooo`00=`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0]@3oool003P0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0;H0oooo000i0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`2g0?oo
o`00>P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0^03oool003/0oooo0P00000a0?ooo`800000<03oool200000;/0oooo000m0?ooo`800000;`3o
ool00`000000oooo0?ooo`0]0?ooo`800000_@3oool003h0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0;d0oooo000o0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2m0?ooo`00@03oool2000002`0
oooo00<000000?ooo`3oool0:P3oool200000<00oooo00120?ooo`800000:P3oool00`000000oooo
0?ooo`0X0?ooo`800000`P3oool004@0oooo0P00000X0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0`P3oool004H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U
0?ooo`800000a@3oool004L0oooo0P00000U0?ooo`030000003oool0oooo02<0oooo0P0000370?oo
o`00B@3oool2000002<0oooo0P00000R0?ooo`800000b@3oool004/0oooo1000000O0?ooo`030000
003oool0oooo01d0oooo1000003;0?ooo`00C`3oool2000001d0oooo00<000000?ooo`3oool06`3o
ool200000<l0oooo001A0?ooo`8000006`3oool00`000000oooo0?ooo`0I0?ooo`800000d@3oool0
05<0oooo1000000G0?ooo`030000003oool0oooo01H0oooo0`00003C0?ooo`00E`3oool4000001<0
oooo00<000000?ooo`3oool04P3oool400000=H0oooo001K0?ooo`@000003`3oool00`000000oooo
0?ooo`0=0?ooo`D00000fP3oool005l0oooo1P0000090?ooo`030000003oool0oooo00L0oooo1P00
003O0?ooo`00I@3ooolC00000>D0oooo001V0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0k03oool006H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3/0?ooo`00
KP3oool00`000000oooo0?ooo`3/0?ooo`00KP3oool00`000000oooo0?ooo`3/0?ooo`00KP3oool0
0`000000oooo0?ooo`3/0?ooo`00KP3oool00`000000oooo0?ooo`3/0?ooo`00KP3oool00`000000
oooo0?ooo`3/0?ooo`00KP3oool200000>d0oooo001^0?ooo`030000003oool0oooo0>`0oooo001^
0?ooo`030000003oool0oooo0>`0oooo001^0?ooo`030000003oool0oooo0>`0oooo001^0?ooo`03
0000003oool0oooo0>`0oooo001^0?ooo`030000003oool0oooo0>`0oooo001^0?ooo`030000003o
ool0oooo0>`0oooo001^0?ooo`030000003oool0oooo0>`0oooo001^0?ooo`030000003oool0oooo
0>`0oooo001^0?ooo`800000k@3oool006h0oooo00<000000?ooo`3oool0k03oool006h0oooo00<0
00000?ooo`3oool0k03oool006h0oooo00<000000?ooo`3oool0k03oool006h0oooo00<000000?oo
o`3oool0k03oool00001\
\>"],
  ImageRangeCache->{{{94.5, 443.313}, {309.75, 100.938}} -> {-2.47527, \
-0.0418622, 0.00844787, 0.00844787}}],

Cell[TextData[{
  "Riconosciamo difatti che tale funzione risulta positiva quando ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Element] \([0, \(\[Pi]\/2\)[\[Union]] \(3\/2\) \
\[Pi], 2  \[Pi]]\)\)]],
  " e in particolare assume il valore ",
  Cell[BoxData[
      \(TraditionalForm\`\(+1\)\)]],
  " in corrispondenza di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 0\)]],
  " mentre vale ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  " quando ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \[Pi]\)]],
  ". Questi rappresentano pure il valore massimo e, rispettivamente, minimo \
del codominio che pertanto \[EGrave] l'intervallo ",
  Cell[BoxData[
      \(TraditionalForm\`\([\(-1\), 1]\)\)]],
  ". Appare inoltre decrescente in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(]\) \(0\)\), \(\(\[Pi]\)\([\)\)\)]],
  " e crescente in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(]\) \(\[Pi]\)\), 2 \( \(\[Pi]\)\([\)\)\)]],
  " mentre risulta ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\[Pi]\/2) = \(cos(\(3\/2\) \[Pi]) = 0\)\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico della funzione coseno e periodicit\[AGrave]", "Section"],

Cell[TextData[{
  "Per ottenere il grafico del coseno procediamo nello stesso modo seguito \
per il seno: trasliamo (ma solo a livello grafico) la circonferenza \
goniometrica di un'unit\[AGrave] negativa sull'asse orizzontale onde non \
interferire con lo sviluppo del grafico e codifichiamo con lo stesso colore \
(blu) l'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " percorso attorno all'origine e l'ascissa del punto (mobile) sul grafico \
del coseno. Poich\[EAcute] ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OP",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          StyleBox["1",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " la definizione si riduce a ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(cos(\[Alpha])\), "=", 
          RowBox[{
            StyleBox["OQ",
              FontSlant->"Italic"], 
            StyleBox["=",
              FontSlant->"Italic"], 
            SubscriptBox[
              StyleBox["x",
                FontSlant->"Italic"], "P"]}]}], TraditionalForm]]],
  " cio\[EGrave] il coseno risulta pari all'ascissa del punto (di color nero) \
sulla circonferenza goniometrica e individuato dal secondo lato dell'angolo. \
Dato che intendiamo riportare in ordinata tale valore, eseguiamo una \
simmetria rispetto alla bisettrice del I e III quadrante, simmetria \
rappresentata nell'animazione seguente dal segmento tratteggiato: in tal modo \
il punto di color verde possiede ordinata pari a ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\[Alpha])\)]],
  ". Con tale costruzione il punto mobile che descrive il grafico ha \
coordinate ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Alpha], cos(\[Alpha]))\)\)]],
  ": ne studiamo l'andamento per ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[Element] \([0, 2  \[Pi]]\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(numImmag = 100;\)\), "\n", 
    \(\(cosGraf = 
        Plot[Cos[x], {x, 0, 2  \[Pi]}, 
          Ticks \[Rule] {{\[Pi]/2, \[Pi], 3  \[Pi]/2, 2  \[Pi]}, Automatic}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(coordinateCos = 
        Table[{x, Cos[x]}, {x, 0, 2  \[Pi], 2  \[Pi]/numImmag}];\)\), "\n", 
    \(\(listaCos1 = \(Show[cosGraf, 
              If[#[\([1]\)] \[NotEqual] 0, 
                ParametricPlot[{Sign[t] t\ Cos[t] - 20  \[Pi], 
                        Sign[t]\ t\ Sin[t]}/200  \[Pi], {t, 
                    Sign[#[\([1]\)]] 2  \[Pi], 
                    Sign[#[\([1]\)]] 2\ \[Pi] + #[\([1]\)]}, 
                  Axes \[Rule] False, DisplayFunction \[Rule] Identity, 
                  PlotStyle \[Rule] {AbsoluteThickness[2], colBlu}], 
                Graphics[{Point[{Cos[#[\([1]\)]] - 1, 
                        Sin[#[\([1]\)]]}]}]], \[IndentingNewLine]Graphics[
                Circle[{\(-1\), 0}, 1]], 
              Graphics[{Line[{{\(-1\), 0}, {Cos[#[\([1]\)]] - 1, 
                        Sin[#[\([1]\)]]}, {Cos[#[\([1]\)]] - 1, 
                        0}}], {Dashing[{0.005, 0.005}], 
                    Line[{{Cos[#[\([1]\)]] - 1, 0}, {\(-1\), 
                          Cos[#[\([1]\)]]}}]}, 
                  Line[{{\(-1\), Cos[#[\([1]\)]]}, #, {#[\([1]\)], 0}}], 
                  Line[{{\(-1\), \(-1\)}, {\(-1\), 1}}], {AbsoluteThickness[
                      2], colBlu, 
                    Line[{{0, 0}, {#[\([1]\)], 
                          0}}]}}], \
\[IndentingNewLine]Graphics[{AbsolutePointSize[5], 
                  Point[#], {colVerde, Point[{\(-1\), Cos[#[\([1]\)]]}]}, 
                  Point[{Cos[#[\([1]\)]] - 1, Sin[#[\([1]\)]]}]}], 
              Epilog \[Rule] {{Text["\<cos(\>" <> 
                        ToString[N[#[\([1]\)]]/\[Pi]] <> "\< \[Pi]) = \>" <> 
                        ToString[N[#[\([2]\)]]], {2.3, 0.75}, {\(-1\), 0}, 
                      TextStyle \[Rule] 
                        stileTesto]}}, \[IndentingNewLine]DisplayFunction \
\[Rule] Identity] &\) /@ coordinateCos;\)\), "\n", 
    \(\(listaCos2 = \(If[#[\([1]\)] \[Equal] 0, 
              Show[Graphics[{AbsolutePointSize[5], Point[{0, 1}]}], 
                DisplayFunction \[Rule] Identity], 
              Plot[Cos[x], {x, 0, #[\([1]\)]}, Axes -> False, 
                PlotStyle \[Rule] {AbsoluteThickness[2], colRosso}, 
                DisplayFunction \[Rule] Identity]] &\) /@ 
          coordinateCos;\)\), "\n", 
    \(\(\(Show[#, DisplayFunction \[Rule] $DisplayFunction, 
            AspectRatio \[Rule] Automatic, ImageSize \[Rule] {600, 200}] &\) /@ 
        Thread[{listaCos1, listaCos2}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .24145 
%%ImageSize: 600 200 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.253765 0.114978 0.120727 0.114978 [
[.43437 .10823 -6.09375 -17.8125 ]
[.43437 .10823 6.09375 0 ]
[.61498 .10823 -4.09375 -10.9375 ]
[.61498 .10823 4.09375 0 ]
[.79558 .10823 -8.96875 -20 ]
[.79558 .10823 8.96875 0 ]
[.97619 .10823 -7.09375 -10.9375 ]
[.97619 .10823 7.09375 0 ]
[.24126 .00575 -13.9375 -5.46875 ]
[.24126 .00575 0 5.46875 ]
[.24126 .06324 -20.625 -5.46875 ]
[.24126 .06324 0 5.46875 ]
[.24126 .17822 -15.125 -5.46875 ]
[.24126 .17822 0 5.46875 ]
[.24126 .2357 -8.4375 -5.46875 ]
[.24126 .2357 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .24145 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.43437 .12073 m
.43437 .12698 L
s
gsave
.43437 .10823 -67.0938 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

65.000 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 14.500 moveto
(\\200\\200) show
66.188 14.500 moveto
(\\200\\200) show
68.313 14.500 moveto
(\\200) show
68.813 14.500 moveto
(\\200) show
64.875 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.61498 .12073 m
.61498 .12698 L
s
gsave
.61498 .10823 -65.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.79558 .12073 m
.79558 .12698 L
s
gsave
.79558 .10823 -69.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
70.875 10.750 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.688 moveto
(\\200\\200\\200\\200) show
68.313 16.688 moveto
(\\200\\200\\200\\200) show
72.563 16.688 moveto
(\\200\\200) show
74.563 16.688 moveto
(\\200) show
67.750 23.000 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 .12073 m
.97619 .12698 L
s
gsave
.97619 .10823 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 .12073 m
1 .12073 L
s
.25376 .00575 m
.26001 .00575 L
s
gsave
.24126 .00575 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.25376 .06324 m
.26001 .06324 L
s
gsave
.24126 .06324 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.25376 .17822 m
.26001 .17822 L
s
gsave
.24126 .17822 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.25376 .2357 m
.26001 .2357 L
s
gsave
.24126 .2357 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.25376 .01725 m
.25751 .01725 L
s
.25376 .02874 m
.25751 .02874 L
s
.25376 .04024 m
.25751 .04024 L
s
.25376 .05174 m
.25751 .05174 L
s
.25376 .07474 m
.25751 .07474 L
s
.25376 .08623 m
.25751 .08623 L
s
.25376 .09773 m
.25751 .09773 L
s
.25376 .10923 m
.25751 .10923 L
s
.25376 .13222 m
.25751 .13222 L
s
.25376 .14372 m
.25751 .14372 L
s
.25376 .15522 m
.25751 .15522 L
s
.25376 .16672 m
.25751 .16672 L
s
.25376 .18971 m
.25751 .18971 L
s
.25376 .20121 m
.25751 .20121 L
s
.25376 .21271 m
.25751 .21271 L
s
.25376 .22421 m
.25751 .22421 L
s
.25 Mabswid
.25376 0 m
.25376 .24145 L
s
0 0 m
1 0 L
1 .24145 L
0 .24145 L
closepath
clip
newpath
.5 Mabswid
.25376 .2357 m
.25466 .2357 L
.25547 .23569 L
.2564 .23567 L
.25729 .23565 L
.25886 .23559 L
.26057 .2355 L
.26246 .23538 L
.26445 .23521 L
.26803 .23482 L
.27173 .2343 L
.27519 .23371 L
.28307 .23199 L
.29111 .22969 L
.29847 .22712 L
.31503 .21976 L
.34515 .20126 L
.37412 .17825 L
.40496 .14982 L
.43464 .12046 L
.46618 .08932 L
.49657 .06152 L
.52581 .03862 L
.54064 .02895 L
.55692 .0201 L
.57241 .01354 L
.57934 .01123 L
.58687 .00917 L
.59099 .00824 L
.5948 .00752 L
.59837 .00695 L
.60231 .00645 L
.604 .00627 L
.60583 .00611 L
.60741 .006 L
.60913 .0059 L
.61098 .00582 L
.61198 .00579 L
.61292 .00577 L
.6138 .00575 L
.61459 .00575 L
.61551 .00575 L
.61638 .00576 L
.61726 .00577 L
.6182 .00579 L
.61909 .00582 L
.6199 .00585 L
.62188 .00596 L
.62376 .00608 L
.62749 .00643 L
Mistroke
.63157 .00694 L
.63883 .00821 L
.64556 .00979 L
.66116 .0149 L
.67528 .02121 L
.70572 .03973 L
.735 .06291 L
.76614 .0916 L
.79613 .12128 L
.82498 .1498 L
.85568 .17812 L
.88523 .20156 L
.90029 .21155 L
.91665 .22063 L
.93238 .22746 L
.93988 .23002 L
.94691 .232 L
.95362 .2335 L
.96084 .23468 L
.96474 .23513 L
.96671 .23531 L
.96885 .23547 L
.97069 .23557 L
.97172 .23562 L
.97266 .23565 L
.97353 .23567 L
.97448 .23569 L
.97537 .2357 L
.97619 .2357 L
Mfstroke
0 0 1 r
2 Mabswid
.15163 .12073 m
.15169 .12112 L
.15173 .12155 L
.15175 .12177 L
.15176 .12189 L
.15176 .12201 L
.15177 .12212 L
.15177 .12217 L
.15177 .12223 L
.15177 .12228 L
.15177 .12234 L
.15177 .12239 L
.15177 .12244 L
.15177 .12247 L
.15177 .1225 L
.15177 .12255 L
.15177 .12259 L
.15177 .12262 L
.15177 .12265 L
.15177 .12268 L
.15177 .12274 L
.15177 .1228 L
.15177 .12292 L
.15176 .12302 L
.15176 .12312 L
.15174 .12335 L
.15172 .12361 L
.1517 .12383 L
.15163 .12435 L
.15155 .1248 L
.15146 .12521 L
.15119 .12615 L
.15089 .12698 L
.15048 .12788 L
.14946 .12955 L
.14823 .13102 L
.14665 .13238 L
.14577 .13298 L
.14491 .13347 L
.14398 .13391 L
.14306 .13426 L
.14201 .13458 L
.14103 .1348 L
.14051 .13488 L
.14022 .13492 L
.13995 .13495 L
.1397 .13497 L
.13947 .13499 L
.13921 .13501 L
.13907 .13501 L
Mistroke
.13893 .13502 L
.13887 .13502 L
.13879 .13502 L
.13872 .13502 L
.13866 .13502 L
.1386 .13502 L
.13853 .13502 L
.13846 .13502 L
.1384 .13502 L
.13837 .13502 L
.13833 .13502 L
.13826 .13502 L
.13819 .13502 L
.13813 .13502 L
.13798 .13502 L
.13783 .13501 L
.13758 .135 L
.13734 .13498 L
.1368 .13492 L
.13625 .13485 L
.13567 .13475 L
.13464 .1345 L
.13355 .13416 L
.13256 .13376 L
.13054 .13267 L
.12855 .13117 L
.12686 .12941 L
.12549 .12745 L
.12489 .12635 L
.12435 .12514 L
.12393 .12394 L
.12362 .12282 L
.12349 .12223 L
.12338 .12158 L
.12332 .12122 L
.12328 .12088 L
.12325 .12056 L
.12322 .12022 L
.1232 .11989 L
.12319 .11974 L
.12318 .11959 L
.12318 .11944 L
.12317 .1193 L
.12317 .11922 L
.12317 .11915 L
.12317 .11907 L
.12317 .11899 L
.12317 .11891 L
.12317 .11882 L
.12317 .11878 L
Mistroke
.12317 .11873 L
.12317 .11865 L
.12317 .11857 L
.12318 .11849 L
.12318 .11833 L
.12319 .11816 L
.1232 .11799 L
.12322 .11762 L
.12325 .11728 L
.12329 .11692 L
.12338 .11626 L
.12362 .11502 L
.12398 .11371 L
.12446 .11235 L
.12457 .11209 L
Mfstroke
0 g
.5 Mabswid
newpath
.13879 .12073 .11498 0 365.73 arc
s
.13879 .12073 m
.03803 .06534 L
.03803 .12073 L
s
[ .005 .005 ] 0 setdash
.03803 .12073 m
.13879 .01997 L
s
[ ] 0 setdash
.13879 .01997 m
.67277 .01997 L
.67277 .12073 L
s
.13879 .00575 m
.13879 .2357 L
s
0 0 1 r
2 Mabswid
.25376 .12073 m
.67277 .12073 L
s
0 g
5 Mabswid
.67277 .01997 Mdot
0 1 0 r
.13879 .01997 Mdot
0 g
.03803 .06534 Mdot
1 0 0 r
2 Mabswid
.25376 .2357 m
.25428 .2357 L
.25475 .2357 L
.2553 .23569 L
.25581 .23569 L
.25672 .23567 L
.25771 .23564 L
.25881 .23559 L
.25996 .23554 L
.26204 .23541 L
.26418 .23523 L
.26619 .23503 L
.27076 .23445 L
.27543 .23367 L
.27969 .23279 L
.2893 .23026 L
.30677 .2237 L
.32357 .21515 L
.34146 .20385 L
.35867 .19107 L
.37697 .17578 L
.39459 .15972 L
.41155 .14339 L
.42959 .1255 L
.44697 .10816 L
.46367 .09174 L
.48146 .07495 L
.49858 .05981 L
.51677 .0452 L
.5343 .03291 L
.55117 .02301 L
.55969 .01879 L
.56911 .01478 L
.57812 .01161 L
.58638 .00929 L
.5949 .0075 L
.59937 .00681 L
.60183 .0065 L
.60407 .00627 L
.60609 .00609 L
.60827 .00594 L
.60947 .00588 L
.61058 .00583 L
.61164 .0058 L
.61222 .00578 L
.61276 .00577 L
.61325 .00576 L
.61372 .00576 L
.61421 .00575 L
.61474 .00575 L
Mistroke
.61521 .00575 L
.61571 .00575 L
.61618 .00576 L
.6166 .00576 L
.61715 .00577 L
.61765 .00578 L
.61879 .00581 L
.61978 .00585 L
.62084 .0059 L
.62303 .00603 L
.62502 .00619 L
.62949 .00666 L
.63364 .00726 L
.63757 .00796 L
.64634 .01 L
.65445 .01246 L
.67175 .01948 L
.67277 .01997 L
Mfstroke
0 g
gsave
.51821 .20696 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(cos) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.500 13.375 moveto
(H) show
81.625 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.16) show
101.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
106.625 13.375 moveto
(L) show
112.250 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
120.875 13.375 moveto
(-) show
127.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.876307) show
164.500 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{599.875, 199.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006S0000Rb000`400?l00000o`00003oo`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00JP3oool00`000000oooo0?ooo`3o0?ooocL0oooo
001Z0?ooo`030000003oool0oooo0?l0oooo=`3oool006X0oooo00<000000?ooo`3oool0o`3ooolg
0?ooo`00<`3oool>000001/0oooo0`0000020?ooo`030000003oool0oooo00H0oooo0`00002=0?oo
o`030000003o0000o`0000/0o`000P00002I0?ooo`00;`3oool4000000L0oooo00<000000?ooo`3o
ool0103oool5000001/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`270?ooo`L0
o`003@3oool50?l009H0oooo000Z0?ooo`D000002`3oool00`000000oooo0?ooo`090?ooo`@00000
5`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08@0oooo00<000000?l0003o0000
6@3oool30?l009<0oooo000X0?ooo`800000403oool00`000000oooo0?ooo`0=0?ooo`8000007P3o
ool00`000000oooo0?ooo`220?ooo`030000003o0000o`0001h0oooo103o002?0?ooo`009P3oool2
00000180oooo00<000000?ooo`3oool03`3oool3000001/0oooo00<000000?ooo`3oool0P03oool3
0?l002<0oooo00<000000?l0003o0000S@3oool002@0oooo0P00000C0?ooo`03003o00000000oooo
01<0oooo0P00000I0?ooo`800000OP3oool30?l002T0oooo0P3o0002000008T0oooo000R0?ooo`80
0000503oool3003o0:d000000P3o000^00000080o`0000<000000?ooo`3oool0QP3oool00240oooo
00<000000?ooo`3oool05@3oool00`00o`0000000?ooo`0G0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0N@3oool20?l000030000003oool0oooo02h0oooo00@000000?ooo`000000
0000QP3oool00200oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`00000I0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0M`3oool20?l000030000003oool0oooo0300
oooo00@000000?ooo`3oool0oooo0P0000240?ooo`007P3oool2000001H0oooo00D000000?ooo`3o
ool0oooo0000000J0?ooo`8000004`3oool00`000000oooo0?ooo`1e0?ooo`80o`0000<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0840oooo000L0?ooo`80
0000603oool01@000000oooo0?ooo`3oool0000001`0oooo0P00000A0?ooo`800000M03oool20?l0
00030000003oool0oooo03@0oooo00<000000?ooo`3oool0103oool200000840oooo000K0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0LP3oool00`3o000000000000000g0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0OP3oool001X0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1`0?ooo`80o`0000<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`070?ooo`800000OP3oool001T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`1_0?ooo`030?l000000000000003X0oooo00<000000?ooo`3oool02@3oool2000007`0oooo000H
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00`0oooo0P00001_0?ooo`030?l000000000oooo03/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1i0?ooo`005P3oool2000001P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0O0?ooo`800000303oool00`000000oooo0?ooo`1/0?oo
o`80o`0000<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
07P0oooo000E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0J`3oool00`3o0000
00000000000n0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0M`3oool001D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1Z0?ooo`030?l000000000oooo03l0oooo
00<000000?ooo`3oool03P3oool2000007L0oooo000D0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0J@3oool00`3o000000000?ooo`100?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0M03oool001<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool2000006T0oooo00<0o`00
0000003oool0@@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07<0oooo000B0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3oool20?l004@0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`1b0?ooo`004P3oool00`000000oooo0?ooo`0E0?ooo`80
00003P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0I@3oool00`3o000000000?ooo`140?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0L@3oool00140oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0I03oool00`3o000000000?ooo`150?ooo`030000
003oool0oooo01@0oooo0P00001a0?ooo`004@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool07P3oool3000000030?ooo`000000000000<000001P3o
ool00`000000oooo0?ooo`1S0?ooo`030?l0003oool0oooo04H0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`1^0?ooo`003`3oool2000001H0oooo0P00000A0?ooo`030000003oool0
oooo01X0oooo0`000000103oool000000?ooo`0000040?ooo`8000001P3oool300000680oooo00<0
o`000?ooo`3oool0A`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo06d0oooo000>
0?ooo`<00000:@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool000000080oooo0`000000
0`3oool000000?ooo`040?ooo`030000003oool0oooo0640oooo00<0o`000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06`0oooo000>0?ooo`@00000503oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo01h0oooo0`0000020?ooo`8000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo05l0oooo0P3o001;0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0J`3oool000h0oooo0P0000020?ooo`800000403oool2000001@0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo05h0
oooo00<0o`000000003oool0B`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo06X0
oooo000=0?ooo`030000003oool0000000@0oooo0P00000T0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1M0?ooo`030?l000000000oooo04`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1Y0?ooo`003@3oool00`000000oooo0000
00060?ooo`8000002`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02T0oooo00@0
00000?ooo`3oool0oooo0P00001M0?ooo`030?l000000000oooo04d0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1X0?ooo`003@3oool00`000000oooo000000080?ooo`8000001`3o
ool2000001L0oooo00<000000?ooo`3oool0:@3oool01@000000oooo0?ooo`3oool0000005d0oooo
00<0o`000?ooo`3oool0CP3oool00`000000oooo0?ooo`0M0?ooo`800000J03oool000`0oooo00@0
00000?ooo`3oool000002P3oool2000001h0oooo00<000000?ooo`3oool0:P3oool010000000oooo
0?ooo`00001L0?ooo`030?l0003oool0oooo04l0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0=0?ooo`<00000E@3oool000`0oooo00@000000?ooo`3oool00000303oool200000080
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo0000
04T0oooo0`00000?0?ooo`030?l0003oool0oooo0500oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo05@0oooo000<0?ooo`040000003oool0oooo0000
00h0oooo0P00000J0?ooo`030000003oool0oooo02X0oooo00@000000?ooo`3oool00000BP3oool0
0`000000oooo0?ooo`0=0?ooo`030?l0003oool0oooo0540oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05<0oooo000<0?ooo`040000003oool0oooo
000000l0oooo0P00000I0?ooo`030000003oool0oooo02/0oooo00@000000?ooo`0000000000BP3o
ool00`000000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0580oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0:0?ooo`<00000E@3oool000/0oooo00D000000?ooo`3oool0oooo0000
000=0?ooo`040000003oool0oooo0?ooo`8000005`3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0000004T0oooo0`00000<0?ooo`030?l0003oool0oooo05<0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`1Q0?ooo`002`3oool01@000000oooo0?ooo`3oool0000000/0oooo
0P0000060?ooo`8000005@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0000005L0oooo
00<0o`000?ooo`3oool0E03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo
2000001B0?ooo`002`3oool01@000000oooo0?ooo`3oool0000001D0oooo0P00000C0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`000000B03oool5000000T0oooo00<0o`000?ooo`3oool0
E@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo05l0oooo000:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`8000004@3o
ool00`000000oooo0?ooo`0/0?ooo`<00000E03oool00`3o0000oooo0?ooo`0m0?ooo`8000005`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0500oooo0`0000000`3oool000000000
00080?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo0P00000?
0?ooo`8000003`3oool00`000000oooo0?ooo`0/0?ooo`800000E03oool00`3o0000oooo0?ooo`10
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`03
0?ooo`<0000000<0oooo000000000000A`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00D0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02`0oooo0P00001C0?ooo`030?l0003oool0oooo
03l0oooo0`00000F0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00`3oool20000
00<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo00000002000000L0oooo000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`80
0000303oool00`000000oooo0?ooo`0/0?ooo`800000B@3oool2000000L0oooo00<0o`000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`0Y0?ooo`080000003oool0oooo0?ooo`000000oooo0000003o
ool3000004D0oooo0`00000;0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo0P00000G0?ooo`8000002P3oool00`000000oooo0?ooo`0/0?ooo`800000B`3oool0
0`000000oooo0?ooo`030?ooo`030?l0003oool0oooo05X0oooo00<000000?ooo`3oool0:P3oool2
000000040?ooo`0000000000000005L0oooo000:0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool07P3oool2000000P0oooo00<000000?ooo`3oool0;@3oool2000004P0oooo0`000004
0?ooo`030?l0003oool0oooo05/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1H
0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool06`3oool2000000030000o`3oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`1=0?ooo`030?l0003oool0oooo05`0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`1G0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
00007`3oool00`000?l00000000000040?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0C03oool00`3o0000oooo0?ooo`1M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0EP3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo008000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo04/0oooo
00<0o`000?ooo`3oool0GP3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo05D0oooo
00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000008@3oool00`000?l0oooo0?oo
o`020?ooo`<00000;`3oool00`000000oooo0?ooo`190?ooo`80o`00H@3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo05@0oooo000c000000030000o`000000000000T0000000<0003o
000000000000:000001;0000o`030?l000000?l0003o0680003oR@00000000T0oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0003o0?oo
o`3oool0:03oool00`000000oooo0?ooo`170?ooo`030?l000000000oooo04X0oooo00<000000?oo
o`3oool0B@3oool2000004T0oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3o
ool09`3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3o
ool0:03oool00`000000oooo0?ooo`160?ooo`030?l000000000000004/0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo000000180?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000
003oool0oooo02L0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
o`3oool0oooo02P0oooo00<000000?ooo`3oool0A@3oool0103o000000000?ooo`00001;0?ooo`03
0000003oool0oooo04T0oooo00@000000?ooo`3oool00000A`3oool00`000000oooo0?ooo`080?oo
o`002P3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0080oooo00D000000?ooo`3o
ool0oooo0000o`0[0?ooo`030000003oool0oooo04@0oooo00<0o`000000003oool0W@3oool00`00
0000oooo0?ooo`1?0?ooo`002P3oool00`000000oooo0?ooo`0Y0?ooo`060000o`3oool0oooo0000
o`000000oooo0P000?l/0?ooo`800000A03oool00`3o000000000?ooo`2O0?ooo`030000003oool0
oooo04h0oooo000:0?ooo`030000003oool0oooo02X0oooo0`000?l00`000000003o0000o`0/0?oo
o`800000A03oool00`3o000000000?ooo`2Q0?ooo`030000003oool0oooo04d0oooo000:0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0;03oool2000004<0oooo00<000000?l0003o
ool0X`3oool00`000000oooo0?ooo`1<0?ooo`002P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02`0oooo0P0000120?ooo`030000003o0000oooo0:D0oooo00<000000?ooo`3oool0
B`3oool000X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`800000@@3o
ool00`000000o`000?ooo`2W0?ooo`030000003oool0oooo04X0oooo000:0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0;03oool3000003l0oooo00<000000?l0003oool0Z@3oool0
0`000000oooo0?ooo`190?ooo`002P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`000000?`3oool00`000000o`000?ooo`2[0?ooo`030000003oool0oooo
04P0oooo000;0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0000000n0?ooo`030000003o0000oooo0:d0oooo00<000000?ooo`3oool0A`3oool000/0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0000003d0oooo
0P3o002`0?ooo`030000003oool0oooo04H0oooo000<0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0000000l0?ooo`030?l0003oool0oooo0;40oooo00<0
00000?ooo`3oool0A@3oool000`0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0[
0?ooo`040000003oool00000000003X0oooo00<0o`000?ooo`3oool0/`3oool00`000000oooo0?oo
o`140?ooo`00303oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02X0oooo00@00000
0?ooo`3oool00000>P3oool00`3o0000oooo0?ooo`2e0?ooo`030000003oool0oooo04<0oooo000<
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0:P3oool010000000oooo0?ooo`00
000i0?ooo`030?l0003oool0oooo0;L0oooo00<000000?ooo`3oool0@P3oool000`0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0Y0?ooo`050000003oool0oooo0?ooo`000000=`3o
ool00`000000o`000?ooo`2j0?ooo`800000@P3oool000d0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0Y0?ooo`040000003oool0oooo0?ooo`800000=@3oool00`000000o`000?oo
o`2m0?ooo`030000003oool0oooo03l0oooo000=0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03<0oooo0P3o0030
0?ooo`030000003oool0oooo03h0oooo000>0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0380oooo00<0o`000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0m0?ooo`003P3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0a0?ooo`03
0?l0003oool0oooo0<<0oooo00<000000?ooo`3oool0?03oool000l0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0N0?ooo`<0000000<0oooo0000000000000P0000000`3oool00000
0?ooo`040?ooo`030000003oool0oooo0300oooo00<0o`000?ooo`3oool0a@3oool00`000000oooo
0?ooo`0k0?ooo`00403oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`000000103oool2000000H0oooo0`00000_0?ooo`030?l0003oool0oooo0<L0oooo00<0
00000?ooo`3oool0>P3oool00140oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool000000080oooo100000060?ooo`030000003oool0oooo02h0oooo00<0o`00
0?ooo`3oool0b@3oool00`000000oooo0?ooo`0i0?ooo`004@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo01h0oooo0`0000020?ooo`<000001`3oool00`000000oooo0?ooo`0]0?oo
o`030?l0003oool0oooo0</0oooo00<000000?ooo`3oool0>03oool00180oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0:`3oool00`000000o`000?ooo`3>0?ooo`800000>03oool00180oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
:P3oool00`000000o`000?ooo`3A0?ooo`030000003oool0oooo03D0oooo000C0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`070?ooo`800000:P3o
ool00`000000o`000?ooo`3C0?ooo`030000003oool0oooo03@0oooo000D0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo02P0oooo00<000000?l0003oool0e@3oool00`000000oooo0?ooo`0c0?ooo`005@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0W0?ooo`80o`00f03oool00`000000oooo0?ooo`0b0?ooo`005@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0U0?ooo`030000003o0000oooo0=X0oooo0P00000b0?ooo`005P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0T0?ooo`030000003o0000oooo0=d0oooo00<000000?ooo`3oool0;`3oool001L0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00/0oooo0P00
000T0?ooo`80o`00E@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0;P3oool001P0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08@3oool00`000000o`000?ooo`1:
0?ooo`80000000@0oooo000000000000oooo0`0000020?ooo`050000003oool0oooo0?ooo`000000
1@3oool2000000<0oooo1000000?0?ooo`<0000000H0oooo00000000000000000?ooo`0000020?oo
o`D0000000D0oooo000000000000oooo0000001F0?ooo`800000;P3oool001T0oooo0P00000O0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0O0?oo
o`030000003o0000o`0004/0oooo00@000000?ooo`3oool00000103oool200000080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000030?ooo`040000003oool00000000000<0oooo1000
00020?ooo`@0000000@0oooo0000003oool000000P3oool02@000000oooo0000003oool000000?oo
o`000000oooo000000020?ooo`80000000@0oooo0000003oool00000F03oool2000002`0oooo000K
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo01h0oooo00<000000?l0003oool0C03oool6000000040?ooo`000000
oooo00000080oooo0P0000040?ooo`030000003oool0oooo00<000000`3oool4000000<0oooo1000
00070?ooo`030000003oool0000000<0oooo0P0000000`3oool000000?ooo`03000000080?ooo`00
000000000000003oool000000?ooo`00001J0?ooo`800000:P3oool001`0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0703oool00`000000o`000?l0001K0?ooo`800000103oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo000000020?ooo`030000003oool00000
00<000000P3oool2000000040?ooo`00000000000?ooo`@00000F`3oool00`000000oooo0?ooo`0W
0?ooo`007@3oool2000001/0oooo00<000000?ooo`3oool06@3oool200000180oooo0P00000L0?oo
o`80o`00l03oool2000002L0oooo000O0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo0P3o003d0?ooo`03
0000003oool0oooo02@0oooo000P0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01L0oooo0P3o003g0?ooo`800000
903oool00240oooo0P00000G0?ooo`030000003oool0oooo01D0oooo0P00000F0?ooo`030000003o
ool0oooo01D0oooo0P3o003k0?ooo`8000008P3oool002<0oooo0P00000E0?ooo`030000003oool0
oooo0180oooo0`00000H0?ooo`8000004`3oool30?l000030000003oool0oooo0?`0oooo0P00000P
0?ooo`009@3oool2000001<0oooo00<000000?ooo`3oool0403oool2000001/0oooo00<000000?oo
o`3oool0403oool20?l000800000o`3oool30?ooo`8000007P3oool002L0oooo0P00000A0?ooo`03
0000003oool0oooo00h0oooo0P00000M0?ooo`030000003oool0oooo00h0oooo0P3o000200000?l0
oooo1`3oool3000001/0oooo000Y0?ooo`D00000303oool00`000000oooo0?ooo`090?ooo`D00000
7`3oool00`000000oooo0?ooo`0;0?ooo`<0o`0000<000000?ooo`3oool0o`3oool;0?ooo`<00000
603oool002h0oooo1@0000070?ooo`030000003oool0oooo00D0oooo1000000T0?ooo`030000003o
ool0oooo00H0oooo1@3o003o0?oooa@0oooo1P00000B0?ooo`00<`3oool?000001l0oooo00<00000
0?ooo`3oool01P3oool90?l00?l0oooo7`3oool8000000X0oooo001Q0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`00H@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0?l0oooo=`3oool006X0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`00o`3o
oonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3o
oonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3o
oonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3o
oonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00\
\>"],
  ImageRangeCache->{{{94.4375, 513.313}, {557.125, 418.25}} -> {-4.16799, \
7.24263, 0.0145346, 0.0145346}}],

Cell[TextData[{
  "Per angoli esterni all'intervallo ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, 2  \[Pi]]\)\)]],
  " la configurazione geometrica appena studiata si ripete inalterata \
suggerendo la periodicit\[AGrave] pure della funzione coseno."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(numImmag = 100;\)\), "\[IndentingNewLine]", 
    \(\(cosGraf = 
        Plot[Cos[x], {x, 0, 4  \[Pi]}, 
          Ticks \[Rule] {{\[Pi]/2, \[Pi], 3  \[Pi]/2, 2  \[Pi], 5  \[Pi]/2, 
                3  \[Pi], 7  \[Pi]/2, 4  \[Pi]}, Automatic}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(coordinateCos = 
        Table[{x, Cos[x]}, {x, 0, 4  \[Pi], 2  \[Pi]/numImmag}];\)\), "\n", 
    \(\(listaCos1 = \(Show[cosGraf, 
              If[#[\([1]\)] \[NotEqual] 0, 
                ParametricPlot[{Sign[t] t\ Cos[t] - 20  \[Pi], 
                        Sign[t]\ t\ Sin[t]}/200  \[Pi], {t, 
                    Sign[#[\([1]\)]] 2  \[Pi], 
                    Sign[#[\([1]\)]] 2\ \[Pi] + #[\([1]\)]}, 
                  Axes \[Rule] False, DisplayFunction \[Rule] Identity, 
                  PlotStyle \[Rule] {AbsoluteThickness[2], colBlu}], 
                Graphics[{Point[{Cos[#[\([1]\)]] - 1, Sin[#[\([1]\)]]}]}]], 
              Graphics[
                Circle[{\(-1\), 0}, 
                  1]], \[IndentingNewLine]Graphics[{Line[{{\(-1\), 
                        0}, {Cos[#[\([1]\)]] - 1, 
                        Sin[#[\([1]\)]]}, {Cos[#[\([1]\)]] - 1, 
                        0}}], {Dashing[{0.005, 0.005}], 
                    Line[{{Cos[#[\([1]\)]] - 1, 0}, {\(-1\), 
                          Cos[#[\([1]\)]]}}]}, 
                  Line[{{\(-1\), Cos[#[\([1]\)]]}, #, {#[\([1]\)], 0}}], 
                  Line[{{\(-1\), \(-1\)}, {\(-1\), 1}}], {AbsoluteThickness[
                      2], colBlu, 
                    Line[{{0, 0}, {#[\([1]\)], 
                          0}}]}}], \
\[IndentingNewLine]Graphics[{AbsolutePointSize[5], 
                  Point[#], {colVerde, Point[{\(-1\), Cos[#[\([1]\)]]}]}, 
                  Point[{Cos[#[\([1]\)]] - 1, Sin[#[\([1]\)]]}]}], 
              Epilog \[Rule] {{Text["\<cos(\>" <> 
                        ToString[N[#[\([1]\)]/\[Pi]]] <> "\< \[Pi]) = \>" <> 
                        ToString[N[#[\([2]\)]]], {1.65, 0.75}, {\(-1\), 0}, 
                      TextStyle \[Rule] 
                        stileTesto]}}, \[IndentingNewLine]DisplayFunction \
\[Rule] Identity] &\) /@ coordinateCos;\)\), "\n", 
    \(\(listaCos2 = \(If[#[\([1]\)] \[Equal] 0, 
              Show[Graphics[{AbsolutePointSize[5], Point[{0, 1}]}], 
                DisplayFunction \[Rule] Identity], 
              Plot[Cos[x], {x, 0, #[\([1]\)]}, Axes -> False, 
                PlotStyle \[Rule] {AbsoluteThickness[2], colRosso}, 
                DisplayFunction \[Rule] Identity]] &\) /@ 
          coordinateCos;\)\), "\[IndentingNewLine]", 
    \(\(\(Show[#, DisplayFunction \[Rule] $DisplayFunction, 
            AspectRatio \[Rule] Automatic, ImageSize \[Rule] {600, 150}] &\) /@ 
        Thread[{listaCos1, listaCos2}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .1373 
%%ImageSize: 600 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.154574 0.0653822 0.0686513 0.0653822 [
[.25728 .05615 -6.09375 -17.8125 ]
[.25728 .05615 6.09375 0 ]
[.35998 .05615 -4.09375 -10.9375 ]
[.35998 .05615 4.09375 0 ]
[.46268 .05615 -8.96875 -20 ]
[.46268 .05615 8.96875 0 ]
[.56538 .05615 -7.09375 -10.9375 ]
[.56538 .05615 7.09375 0 ]
[.66808 .05615 -8.96875 -19.875 ]
[.66808 .05615 8.96875 0 ]
[.77079 .05615 -7.09375 -10.9375 ]
[.77079 .05615 7.09375 0 ]
[.87349 .05615 -8.96875 -19.875 ]
[.87349 .05615 8.96875 0 ]
[.97619 .05615 -7.09375 -10.9375 ]
[.97619 .05615 7.09375 0 ]
[.14207 .00327 -13.9375 -5.46875 ]
[.14207 .00327 0 5.46875 ]
[.14207 .03596 -20.625 -5.46875 ]
[.14207 .03596 0 5.46875 ]
[.14207 .10134 -15.125 -5.46875 ]
[.14207 .10134 0 5.46875 ]
[.14207 .13403 -8.4375 -5.46875 ]
[.14207 .13403 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .1373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25728 .06865 m
.25728 .0749 L
s
gsave
.25728 .05615 -67.0938 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

65.000 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 14.500 moveto
(\\200\\200) show
66.188 14.500 moveto
(\\200\\200) show
68.313 14.500 moveto
(\\200) show
68.813 14.500 moveto
(\\200) show
64.875 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.35998 .06865 m
.35998 .0749 L
s
gsave
.35998 .05615 -65.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.46268 .06865 m
.46268 .0749 L
s
gsave
.46268 .05615 -69.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
70.875 10.750 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.688 moveto
(\\200\\200\\200\\200) show
68.313 16.688 moveto
(\\200\\200\\200\\200) show
72.563 16.688 moveto
(\\200\\200) show
74.563 16.688 moveto
(\\200) show
67.750 23.000 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.56538 .06865 m
.56538 .0749 L
s
gsave
.56538 .05615 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.66808 .06865 m
.66808 .0749 L
s
gsave
.66808 .05615 -69.9688 -23.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
70.875 10.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.563 moveto
(\\200\\200\\200\\200) show
68.313 16.563 moveto
(\\200\\200\\200\\200) show
72.563 16.563 moveto
(\\200\\200) show
74.563 16.563 moveto
(\\200) show
67.750 22.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.77079 .06865 m
.77079 .0749 L
s
gsave
.77079 .05615 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.87349 .06865 m
.87349 .0749 L
s
gsave
.87349 .05615 -69.9688 -23.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
70.875 10.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.563 moveto
(\\200\\200\\200\\200) show
68.313 16.563 moveto
(\\200\\200\\200\\200) show
72.563 16.563 moveto
(\\200\\200) show
74.563 16.563 moveto
(\\200) show
67.750 22.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 .06865 m
.97619 .0749 L
s
gsave
.97619 .05615 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 .06865 m
1 .06865 L
s
.15457 .00327 m
.16082 .00327 L
s
gsave
.14207 .00327 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.15457 .03596 m
.16082 .03596 L
s
gsave
.14207 .03596 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.15457 .10134 m
.16082 .10134 L
s
gsave
.14207 .10134 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.15457 .13403 m
.16082 .13403 L
s
gsave
.14207 .13403 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.15457 .00981 m
.15832 .00981 L
s
.15457 .01635 m
.15832 .01635 L
s
.15457 .02288 m
.15832 .02288 L
s
.15457 .02942 m
.15832 .02942 L
s
.15457 .0425 m
.15832 .0425 L
s
.15457 .04904 m
.15832 .04904 L
s
.15457 .05557 m
.15832 .05557 L
s
.15457 .06211 m
.15832 .06211 L
s
.15457 .07519 m
.15832 .07519 L
s
.15457 .08173 m
.15832 .08173 L
s
.15457 .08827 m
.15832 .08827 L
s
.15457 .0948 m
.15832 .0948 L
s
.15457 .10788 m
.15832 .10788 L
s
.15457 .11442 m
.15832 .11442 L
s
.15457 .12096 m
.15832 .12096 L
s
.15457 .1275 m
.15832 .1275 L
s
.25 Mabswid
.15457 0 m
.15457 .1373 L
s
0 0 m
1 0 L
1 .1373 L
0 .1373 L
closepath
clip
newpath
.5 Mabswid
.15457 .13403 m
.15559 .13403 L
.15651 .134 L
.15758 .13396 L
.15858 .13391 L
.16037 .13378 L
.16232 .13358 L
.16446 .13329 L
.16673 .13291 L
.1708 .13203 L
.17894 .12955 L
.1879 .12572 L
.20667 .11435 L
.22425 .10029 L
.2577 .06822 L
.29327 .03445 L
.31103 .02075 L
.31968 .0153 L
.32752 .01116 L
.33574 .00771 L
.34347 .00534 L
.34772 .00441 L
.35164 .0038 L
.35369 .00357 L
.35486 .00347 L
.35593 .00339 L
.35707 .00333 L
.35769 .00331 L
.35828 .00329 L
.35933 .00327 L
.35992 .00327 L
.36047 .00327 L
.36149 .00329 L
.36256 .00332 L
.36347 .00336 L
.36447 .00342 L
.3667 .00361 L
.36878 .00386 L
.37255 .00447 L
.37657 .00536 L
.38136 .00674 L
.38589 .00834 L
.39435 .0121 L
.41161 .02262 L
.42753 .03517 L
.46152 .0675 L
.49421 .09897 L
.5124 .11371 L
.52901 .12418 L
.53723 .12807 L
Mistroke
.54157 .12975 L
.54619 .13124 L
.55063 .13238 L
.55466 .13316 L
.5566 .13344 L
.5587 .13369 L
.55967 .13378 L
.56068 .13386 L
.56163 .13393 L
.5625 .13397 L
.56356 .13401 L
.56412 .13402 L
.56471 .13403 L
.5657 .13403 L
.5668 .13402 L
.56777 .13399 L
.56881 .13394 L
.5698 .13388 L
.5707 .13382 L
.57275 .13362 L
.57498 .13333 L
.57948 .13252 L
.58345 .13155 L
.58768 .13027 L
.59531 .1273 L
.60417 .12286 L
.61376 .11694 L
.63115 .10365 L
.6665 .07024 L
.70054 .03752 L
.71765 .0237 L
.73327 .01374 L
.7419 .00955 L
.75008 .00652 L
.75456 .00527 L
.75871 .00438 L
.76088 .00402 L
.76327 .0037 L
.76447 .00357 L
.76577 .00346 L
.76699 .00338 L
.76811 .00332 L
.76921 .00329 L
.77025 .00327 L
.77118 .00327 L
.77219 .00328 L
.77329 .00332 L
.77385 .00334 L
.77446 .00337 L
.77556 .00344 L
Mistroke
.77656 .00352 L
.77851 .00373 L
.78062 .00401 L
.78442 .00469 L
.7888 .00573 L
.79357 .0072 L
.80227 .0107 L
.81925 .02043 L
.83735 .03433 L
.87324 .0684 L
.90782 .10143 L
.92369 .11406 L
.93269 .12009 L
.9411 .12484 L
.94934 .1286 L
.95357 .13016 L
.95817 .13156 L
.96068 .1322 L
.96301 .13271 L
.96519 .13311 L
.9676 .13347 L
.96975 .13372 L
.97176 .13388 L
.97288 .13395 L
.9739 .13399 L
.97501 .13402 L
.97558 .13403 L
.97619 .13403 L
Mfstroke
0 0 1 r
2 Mabswid
.0965 .06865 m
.09652 .06879 L
.09654 .06893 L
.09655 .06906 L
.09656 .06919 L
.09657 .06928 L
.09657 .06935 L
.09657 .06943 L
.09658 .06951 L
.09658 .06958 L
.09658 .06965 L
.09658 .06972 L
.09658 .0698 L
.09657 .06988 L
.09657 .06995 L
.09657 .07004 L
.09656 .07013 L
.09655 .07029 L
.09653 .07044 L
.09649 .07075 L
.09643 .07103 L
.09626 .07169 L
.09604 .07228 L
.09574 .07291 L
.09535 .07355 L
.09496 .07406 L
.09449 .07458 L
.0935 .07539 L
.09289 .07578 L
.09218 .07613 L
.09147 .0764 L
.09114 .0765 L
.09078 .07659 L
.09041 .07666 L
.09007 .07671 L
.08974 .07675 L
.08957 .07676 L
.08949 .07677 L
.08939 .07677 L
.08934 .07678 L
.08928 .07678 L
.08918 .07678 L
.08909 .07678 L
.089 .07678 L
.08895 .07678 L
.08889 .07678 L
.0888 .07678 L
.08874 .07678 L
.08868 .07677 L
.08858 .07677 L
Mistroke
.08839 .07676 L
.08821 .07674 L
.08781 .07669 L
.08742 .07662 L
.087 .07653 L
.08625 .0763 L
.08553 .07601 L
.08489 .07568 L
.08362 .07481 L
.08297 .0742 L
.08241 .07358 L
.08188 .07286 L
.08144 .07214 L
.0811 .07145 L
.0808 .07065 L
.08057 .06983 L
.08047 .06937 L
.0804 .06893 L
.08037 .06873 L
.08035 .06852 L
.08034 .06834 L
.08032 .06814 L
.08032 .06802 L
.08032 .06792 L
.08031 .0678 L
.08031 .06769 L
.08031 .06758 L
.08031 .06749 L
.08031 .06738 L
.08032 .06727 L
.08032 .06716 L
.08033 .06704 L
.08034 .06682 L
.08037 .0666 L
.08039 .0664 L
.08046 .06595 L
.08055 .06548 L
.08076 .06469 L
.08107 .06384 L
.08147 .06298 L
.08192 .06221 L
.08253 .06136 L
.08317 .06063 L
.08458 .0594 L
.08542 .05885 L
.08637 .05835 L
.08734 .05795 L
.08786 .05778 L
.08843 .05763 L
.08893 .05752 L
Mistroke
.0892 .05747 L
.0895 .05742 L
.08977 .05739 L
.09002 .05736 L
.09027 .05734 L
.0905 .05733 L
.09064 .05732 L
.0907 .05732 L
.09078 .05732 L
.09091 .05731 L
.09103 .05731 L
.09115 .05731 L
.09126 .05731 L
.09139 .05732 L
.09152 .05732 L
.09166 .05733 L
.09181 .05734 L
.09208 .05736 L
.09235 .05739 L
.0926 .05742 L
.09305 .05749 L
.09354 .05758 L
.09453 .05785 L
.09556 .05823 L
.09648 .05866 L
.09751 .05928 L
.09841 .05994 L
.09994 .06142 L
.10065 .06232 L
.10131 .06335 L
.10186 .06441 L
.10233 .06561 L
.10251 .06619 L
.10267 .0668 L
.10279 .06739 L
.10287 .06793 L
.10291 .06821 L
.10294 .06851 L
.10296 .06879 L
.10298 .06905 L
.10298 .06921 L
.10299 .06936 L
.10299 .0695 L
.10299 .06964 L
.10299 .06972 L
.10299 .0698 L
.10299 .06989 L
.10299 .06997 L
.10298 .07012 L
.10298 .07027 L
Mistroke
.10297 .07042 L
.10296 .07056 L
.10294 .07087 L
.10291 .07114 L
.10287 .07143 L
.10279 .07193 L
.10269 .07248 L
.10236 .07368 L
.10196 .07475 L
.10139 .07596 L
.10073 .07705 L
.10001 .07802 L
.09915 .07899 L
.09736 .08053 L
.09625 .08126 L
.09496 .08193 L
.09367 .08244 L
.09245 .0828 L
.09184 .08293 L
.09117 .08305 L
.09085 .08309 L
.09054 .08313 L
.09027 .08315 L
.08996 .08318 L
.0898 .08319 L
.08963 .08319 L
.08953 .0832 L
.08944 .0832 L
.08927 .0832 L
.08912 .08321 L
.08896 .08321 L
.08879 .0832 L
.08863 .0832 L
.08854 .0832 L
.08844 .0832 L
.08826 .08319 L
.08792 .08317 L
.08753 .08313 L
.08717 .08309 L
.08654 .08299 L
.08587 .08286 L
.08466 .08254 L
.08326 .08203 L
.08202 .08144 L
.07979 .07997 L
.07864 .07897 L
.07767 .07793 L
.07751 .07775 L
Mfstroke
0 g
.5 Mabswid
newpath
.08919 .06865 .06538 0 365.73 arc
s
.08919 .06865 m
.0363 .10708 L
.0363 .06865 L
s
[ .005 .005 ] 0 setdash
.0363 .06865 m
.08919 .01576 L
s
[ ] 0 setdash
.08919 .01576 m
.72971 .01576 L
.72971 .06865 L
s
.08919 .00327 m
.08919 .13403 L
s
0 0 1 r
2 Mabswid
.15457 .06865 m
.72971 .06865 L
s
0 g
5 Mabswid
.72971 .01576 Mdot
0 1 0 r
.08919 .01576 Mdot
0 g
.0363 .10708 Mdot
1 0 0 r
2 Mabswid
.15457 .13403 m
.15528 .13403 L
.15593 .13402 L
.15668 .134 L
.15738 .13397 L
.15863 .13391 L
.15999 .13381 L
.16149 .13367 L
.16308 .13348 L
.16593 .13305 L
.16887 .13248 L
.17163 .13182 L
.17791 .12991 L
.18431 .12739 L
.19016 .12458 L
.20335 .11667 L
.22733 .09756 L
.25039 .07552 L
.27494 .0512 L
.29857 .03005 L
.31063 .02102 L
.32368 .01309 L
.32981 .01011 L
.33628 .00752 L
.34181 .00578 L
.34471 .00504 L
.34788 .00439 L
.35104 .00388 L
.35249 .0037 L
.35404 .00354 L
.35543 .00343 L
.35616 .00338 L
.35696 .00334 L
.35768 .00331 L
.35835 .00329 L
.35899 .00328 L
.35966 .00327 L
.36045 .00327 L
.36117 .00328 L
.36157 .00329 L
.362 .0033 L
.36278 .00333 L
.36352 .00336 L
.36429 .00341 L
.36569 .00352 L
.36731 .00368 L
.36883 .00387 L
.37229 .00442 L
.37529 .00505 L
.37857 .0059 L
Mistroke
.38454 .00783 L
.39573 .0128 L
.40764 .01988 L
.42031 .02918 L
.44545 .05162 L
.46968 .07564 L
.49299 .09789 L
.50482 .10793 L
.51778 .11746 L
.53014 .12476 L
.54166 .12978 L
.54799 .13173 L
.5511 .13248 L
.55398 .13304 L
.55658 .13344 L
.55935 .13376 L
.56078 .13387 L
.56213 .13395 L
.5629 .13399 L
.5636 .13401 L
.56438 .13403 L
.56477 .13403 L
.56519 .13403 L
.56558 .13403 L
.56599 .13403 L
.56673 .13402 L
.56752 .134 L
.56797 .13398 L
.56839 .13396 L
.56985 .13388 L
.57141 .13376 L
.57293 .1336 L
.57436 .13342 L
.57706 .13299 L
.58312 .13164 L
.58972 .12956 L
.60164 .12423 L
.61432 .11656 L
.6371 .09849 L
.66136 .07536 L
.6847 .05221 L
.70953 .02993 L
.72971 .01576 L
Mfstroke
0 g
gsave
.26245 .11769 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(cos) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
78.500 13.375 moveto
(H) show
81.625 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
96.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
101.625 13.375 moveto
(L) show
107.250 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
115.875 13.375 moveto
(-) show
122.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.809017) show
159.500 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "",
  ImageSize->{599.875, 149.875},
  ImageMargins->{{36.125, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006S0000J2000`400?l00000o`00003oo`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00@03oool00`000000oooo0?ooo`3o0?ooof40oooo
000Q0?ooo`P000002P3oool3000000030?ooo`000000oooo00L0oooo1000001?0?ooo`P0o`00X`3o
ool9000005`0oooo000N0?ooo`<00000103oool010000000oooo0?ooo`3oool5000000T0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1;0?ooo`D0o`00203oool50?l009`0oooo0P00
00090?ooo`@00000F03oool001`0oooo0P0000070?ooo`030000003oool0oooo00H0oooo0P000007
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0B03oool00`000000o`000?l0000@
0?ooo`8000000P3o002G0?ooo`<000003`3oool3000005D0oooo000I0?ooo`<000002@3oool00`00
0000oooo0?ooo`080?ooo`8000003P3oool3000004H0oooo0`3o000F0?ooo`80o`00TP3oool30000
01D0oooo0`00001B0?ooo`005`3oool2000000`0oooo00<000000?ooo`3oool02P3oool2000000`0
oooo00<000000?ooo`3oool0A03oool20?l001/0oooo0P3o002>0?ooo`8000006`3oool200000500
oooo000E0?ooo`8000003P3oool00`00o`0000000000001N000000030?l000000000000001d00000
0P3o0029000000030?l0003oool0000001l0oooo0P00001>0?ooo`00503oool00`000000oooo0?oo
o`0=0?ooo`<00?l03P3oool2000000T0oooo0`0000100?ooo`030000003o0000o`000280oooo0P3o
00260?ooo`030?l00000000000000280oooo0P00001<0?ooo`004`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool00?l00140oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0o
0?ooo`030000003o0000oooo02D0oooo00<0o`000000003oool0P@3oool20?l0008000009@3oool0
0`000000oooo0?ooo`190?ooo`004P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo
00000180oooo00<000000?ooo`3oool01@3oool3000003h0oooo00<000000?l0003oool09`3oool2
0?l00800oooo00D0o`000000003oool0oooo0000000V0?ooo`030000003oool0oooo04P0oooo000A
0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`000000o`000?l0000[0?ooo`030?l0003o
ool0oooo07`0oooo00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo04L0oooo000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0>`3oool2
0?l002h0oooo0P3o000@0?ooo`<00000D`3oool300000140oooo0P3o00050?ooo`030000003oool0
oooo02H0oooo0P00000@0?ooo`<00000=03oool000l0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00`3oool30000
03X0oooo00<0o`000?ooo`3oool0;`3oool00`000000o`000?ooo`0?0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool03`3oool00`3o000000000?ooo`050?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0c0?ooo`003P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo0`00000>0?ooo`030000003o0000oooo03<0
oooo00<0o`000?ooo`3oool03P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00d0
oooo00<0o`000000003oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0<P3oool000d0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00X0oooo0`0000000`3oool000000000000200000080oooo
00D000000?ooo`3oool0oooo0000000Z0?ooo`030000003oool0oooo00`0oooo00<000000?l0003o
ool0=@3oool00`3o0000oooo0?ooo`0;0?ooo`<00000D`3oool3000000h0oooo00<0o`000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00/0oooo0`00000d0?ooo`00
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1P3oool3000000040?ooo`000000oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`@00000:03oool00`000000oooo0?ooo`0:0?ooo`030000003o0000oooo03L0oooo00<0o`000?oo
o`3oool0L03oool00`3o0000oooo0?ooo`080?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0@@3oool000`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`0000000P3oool3000000<0oooo00@000000?ooo`3o
ool00000:@3oool3000000/0oooo00<000000?l0003oool0>@3oool00`3o0000oooo0?ooo`060?oo
o`T00000G`3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0@03oool000`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00X0oooo0`0000020?ooo`8000001@3oool00`000000oooo0000000f0?ooo`80
o`00?03oool20?l005`0oooo2@0000070?ooo`80o`00303oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo00D0oooo2@00000a0?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo00000002000002H0oooo
100000090?ooo`030?l0003oool0oooo03d0oooo00<000000?l0003oool0J@3oool00`3o00000000
0?ooo`0<0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0?P3oool000/0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`000000=03oool00`3o0000oooo0?ooo`0M0?ooo`800000803oool00`000000o`000?oo
o`0_0?ooo`<0000000<0oooo000000000000<P3oool00`3o000000000?ooo`0=0?ooo`030000003o
ool0oooo00/0oooo0`0000000`3oool000000000000N0?ooo`030000003oool0oooo03<0oooo0P00
00080?ooo`002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool05`3oool400000340oooo00<0o`000?ooo`3oool0803oool00`000000oooo0?ooo`0N
0?ooo`030000003o0000oooo00<0oooo0`0000000`3oool000000000000V0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool08P3oool3000000030?ooo`000000000000H0oooo00<0o`00
0000003oool03P3oool00`000000oooo0?ooo`0<0?ooo`8000000`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00L0oooo0P00000U0?ooo`<000000`3oool00`000000oooo0?ooo`05
0?ooo`002P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool05`3oool2000002T0oooo0P0000060?ooo`030000003o0000oooo0200oooo0`00000Q0?oo
o`030000003o0000oooo00<0oooo0P0000030?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`0000000P00000V0?ooo`050000003oool0oooo0?ooo`000000103oool00`3o000000000?ooo`0?
0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`000000oooo0`00000O0?ooo`800000103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280oooo0P0000020?ooo`<000001`3o
ool000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`030000003o0000
oooo04H0oooo00P000000?l0003oool0oooo0000003oool000000?ooo`<00000903oool3000002P0
oooo0`000000103oool000000000000000030?ooo`030?l000000000oooo0100oooo00<000000?oo
o`3oool02`3oool3000002D0oooo00D000000?ooo`3oool0oooo000000020?ooo`<000009@3oool0
0`000000oooo0?ooo`0:0?ooo`002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0603oool3000002L0oooo0`0000030?ooo`030000003o0000oooo
04T0oooo00<0o`000?ooo`0000000P00001C0?ooo`8000001`3oool00`3o000000000?ooo`0A0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool00P00000f0?ooo`002P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo0P000?l010000000003o0000o`000?lG0?oo
o`030000003oool0oooo02`0oooo00<000000?l0003oool0B`3oool00`3o0000oooo0?ooo`1L0?oo
o`030?l0003oool0oooo0180oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0g0?oo
o`002P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo0P000?l0103oool0
00000?ooo`3oool20000oaH0oooo00<000000?ooo`3oool0:`3oool00`000000o`000?ooo`1=0?oo
o`030?l0003oool0oooo05X0oooo00<0o`000?ooo`3oool04`3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo03H0oooo000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03@3oool010000?l0oooo0?ooo`0000030?ooo`80003o5@3oool3000002X0oooo0P3o001@0?oo
o`030?l0003oool0oooo05P0oooo00<0o`000?ooo`3oool0503oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo03D0oooo000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03P3oool01@000?l0oooo0?ooo`3oool0000000@0oooo00<0003o0?ooo`3oool04`3oool00`00
0000oooo0?ooo`0Y0?ooo`030?l0003oool0oooo0540oooo00<0o`000?ooo`3oool0EP3oool00`3o
0000oooo0?ooo`0E0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0=03oool000X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`050000o`3oool0oooo0?oo
o`0000000P3oool010000?l0oooo0000o`000?lD0?ooo`030000003oool0oooo02P0oooo00<0o`00
0?ooo`3oool0D`3oool00`3o0000oooo0?ooo`1D0?ooo`030?l0003oool0oooo01H0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0c0?ooo`008@0000000`000?l00000000000040000
00040000o`00000000000000oa@00000:P000?l00`3o0000003o0000o`1E0000o`030?l000000?l0
003o0580003o00<0o`000000o`000?l060000?ma000000002P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo0P000?l300000080oooo00@0003o0?ooo`3oool0003o503oool0
0`000000oooo0?ooo`0V0?ooo`030?l0003oool0000002X0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?l0000X0?ooo`030000003oool0oooo02L0oooo00<0o`000000003oool0:@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0000002P0oooo00<000000?ooo`3oool0203oool0
00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`06000000000?l0003o
0000003oool0003o0P3oool00`000?l0oooo0?ooo`0C0?ooo`<000009@3oool0103o0000oooo0?oo
o`00000Z0?ooo`030000003oool0oooo02P0oooo00@000000?ooo`3oool0o`009`3oool00`000000
oooo0?ooo`0V0?ooo`030?l0003oool0000002X0oooo00<000000?ooo`3oool0:03oool010000000
oooo0?ooo`00000W0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03P3oool00`000?l000000?ooo`020000o`04000000000?l0oooo0?oo
o`80003o5@3oool00`000000oooo0?ooo`0T0?ooo`030?l0003oool0oooo05/0oooo00<0o`000?oo
o`3oool0C03oool00`3o0000oooo0?ooo`1J0?ooo`030000003oool0oooo02l0oooo000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool2000000050000o`3oool0oooo0?oo
o`0000000`3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo02<0oooo00<0o`000?oo
o`3oool0G@3oool00`3o0000oooo0?ooo`1:0?ooo`030?l0003oool0oooo05`0oooo00<000000?oo
o`3oool0;P3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`04
0000003oool0oooo0?ooo`80003o00<0oooo000000000?l00P000?lG0?ooo`<000008P3oool00`3o
0000oooo0?ooo`1O0?ooo`030?l0003oool0oooo04P0oooo00<0o`000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0]0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00`3oool20000o`03000000000?l0oooo01P0oooo00<000000?ooo`3o
ool08@3oool00`3o0000oooo0?ooo`1Q0?ooo`030?l000000000oooo04H0oooo00<0o`000?ooo`3o
ool0H03oool2000002d0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2@3oool2000000P0oooo00<000000?ooo`3oool05`3oool200000280oooo00<0o`000?ooo`3oool0
H`3oool00`3o000000000?ooo`130?ooo`80o`00I@3oool00`000000oooo0?ooo`0Z0?ooo`002`3o
ool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0G0?ooo`@000007`3oool00`000000o`000?ooo`1U0?ooo`030?l000000000oooo0440oooo
00<0o`000?ooo`3oool0IP3oool00`000000oooo0?ooo`0Y0?ooo`002`3oool01@000000oooo0?oo
o`3oool0000000P0oooo0P00000;0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`000000
803oool00`000000o`000?ooo`1W0?ooo`030?l000000000oooo03l0oooo00<0o`000?ooo`3oool0
J03oool00`000000oooo0?ooo`0X0?ooo`002`3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0000001l0oooo
00<000000?l0003oool0J@3oool00`3o000000000?ooo`0m0?ooo`030?l0003oool0oooo06X0oooo
00<000000?ooo`3oool09`3oool000`0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`0000000P00000L0?ooo`030000
003o0000oooo06/0oooo00<0o`000000003oool0>`3oool00`3o0000oooo0?ooo`1/0?ooo`030000
003oool0oooo02H0oooo000<0?ooo`040000003oool0oooo000000@0oooo0P00000?0?ooo`030000
003oool0oooo00X0oooo0`0000000`3oool0000000000002000000<0oooo00@000000?ooo`3oool0
00007@3oool00`000000o`000?ooo`1]0?ooo`030?l000000000oooo03T0oooo00<0o`000?ooo`3o
ool0KP3oool00`000000oooo0?ooo`0U0?ooo`003@3oool00`000000oooo000000030?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool4000001T0oooo00<000000?l0003oool0K`3oool00`3o0000
00000?ooo`0g0?ooo`030?l0003oool0oooo0700oooo00<000000?ooo`3oool0903oool000d0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`0000000P3oool300000080oooo00D000000?ooo`3oool0oooo0000000K0?ooo`80
o`00LP3oool20?l003H0oooo00<0o`000?ooo`3oool0LP3oool00`000000oooo0?ooo`0S0?ooo`00
3P3oool4000001<0oooo00<000000?ooo`3oool02P3oool300000080oooo0P0000020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`1d0?ooo`030?l0
00000000oooo0380oooo00<0o`000?ooo`3oool0M03oool00`000000oooo0?ooo`0R0?ooo`003@3o
ool3000001D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`030?ooo`<000005P3o
ool00`000000o`000?ooo`1g0?ooo`030?l000000000oooo02l0oooo0P3o001h0?ooo`030000003o
ool0oooo0240oooo000>0?ooo`030000003oool0000001@0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01D0oooo00<000000?l0003oool0N@3oool0
0`3o000000000?ooo`0]0?ooo`030?l000000000oooo07T0oooo00<000000?ooo`3oool0803oool0
0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0503oool20?l002<0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`190?ooo`80o`00;03oool00`3o0000oooo0?ooo`1k0?ooo`030000003oool0oooo
01l0oooo000B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`050?ooo`<000004`3oool00`3o0000oooo0?ooo`0G0?ooo`80000000@0oooo00000000
0000oooo0`0000020?ooo`D0000000@0oooo00000000000000000P3oool3000000030?ooo`000000
oooo00d0oooo0`0000001@3oool00000000000000000oooo00D0000000<0oooo000000000000103o
ool00`000000oooo0?ooo`0W0?ooo`030?l000000000oooo02P0oooo00<0o`000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`0N0?ooo`004`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?ooo`030000003o0000
oooo01P0oooo00@000000?ooo`3oool00000103oool200000080oooo00<000000?ooo`0000000`3o
ool00`000000oooo000000020?ooo`050000003oool000000?ooo`0000000`3oool400000080oooo
1@0000001P3oool000000?ooo`3oool000000?ooo`80000000<0oooo0000003oool00`0000000`3o
ool000000?ooo`030?ooo`030000003oool0oooo02P0oooo00<0o`000000003oool09P3oool00`3o
0000oooo0?ooo`1o0?ooo`8000007P3oool001@0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo0`00000?0?ooo`030000003o0000o`0001X0
oooo1P000000103oool000000?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P000002
0?ooo`<0000000<0oooo0000003oool00P3oool4000000H0oooo00<000000?ooo`0000000`3oool3
000000040?ooo`00000000000?ooo`80000000<0oooo0000000000000`3oool00`000000oooo0?oo
o`0Y0?ooo`80o`00903oool20?l008@0oooo0P00000L0?ooo`005@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=
0?ooo`030000003o0000o`0002T0oooo00<000000?ooo`0000000P3oool00`000000oooo00000005
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`0000000P3oool01@000000oooo00000000
0000oooo0080000000P0oooo000000000000oooo0000003oool000000?ooo`<00000;03oool20?l0
0200oooo0P3o00280?ooo`8000006P3oool001H0oooo0P00000=0?ooo`030000003oool0oooo00/0
oooo0P00000;0?ooo`030000003oool0oooo00/0oooo00<000000?l0003o0000S03oool20?l001`0
oooo0P3o002<0?ooo`800000603oool001P0oooo0P00000;0?ooo`030000003oool0oooo00T0oooo
0P00000=0?ooo`<000002@3oool30?l00900oooo0P3o00000`000000oooo0?ooo`0D0?ooo`030000
003o0000o`000900oooo0P00000F0?ooo`006P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00H0oooo0`00000?0?ooo`030000003oool0oooo00H0oooo0`3o002E0?ooo`<0o`004P3o
ool30?l009@0oooo0`00000C0?ooo`006`3oool5000000D0oooo00<000000?ooo`3oool0103oool2
00000180oooo00<000000?ooo`3oool00P3oool010000000o`000?l0003o002J0?ooo`040000003o
0000o`000?l000/0oooo00@000000?l0003o0000o`00VP3oool4000000l0oooo000P0?ooo``00000
2`3oool00`000000oooo0?ooo`060?ooo`H0o`00X@3oool<0?l00:40oooo1@00000:0?ooo`00=`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooH@3oool003L0oooo00<00000
0?ooo`3oool0o`3ooomZ0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3o
oonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3o
oonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3o
oonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3o
oonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00\
\>"],
  ImageRangeCache->{{{86.8125, 505.688}, {511, 407.125}} -> {-5.53412, \
12.9693, 0.0255599, 0.0255599}}],

Cell[TextData[{
  "Valgono di conseguenza le seguenti identit\[AGrave] (",
  ButtonBox["fig. 6",
    ButtonData:>"figura6",
    ButtonStyle->"Hyperlink"],
  ")"
}], "Text"],

Cell[BoxData[
    \(cos \((\[Alpha])\) = \(cos \((\[Alpha] - 
              2  \[Pi])\) = \(cos \((\[Alpha] + 
                2  \[Pi])\) = \[TripleDot]\)\)\)], "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Alpha] = \[Pi]/4;\)\), "\[IndentingNewLine]", 
    \(\(Show[
        Plot[Cos[x], {x, \(-2\) \[Pi], 3  \[Pi]}, 
          Ticks \[Rule] {Range[\(-2\), 3, 1/2] \[Pi], Automatic}, 
          DisplayFunction \[Rule] Identity], 
        Graphics[{colRosso, 
            Line[{{\(-2\) \[Pi] + \[Alpha], 0}, {\(-2\) \[Pi] + \[Alpha], 
                  Cos[\[Alpha]]}, {\[Alpha], Cos[\[Alpha]]}, {\[Alpha], 
                  0}, {\[Alpha], Cos[\[Alpha]]}, {\[Alpha] + 2  \[Pi], 
                  Cos[\[Alpha]]}, {\[Alpha] + 2  \[Pi], 
                  0}, {\[Alpha] + 2  \[Pi], Cos[\[Alpha]]}, {3  \[Pi], 
                  Cos[\[Alpha]]}}]}], 
        Graphics[{colRosso, 
            Text["\<\[Alpha]-2\[Pi]\>", {\[Alpha] - 2  \[Pi], \(- .25\)}, 
              TextStyle \[Rule] stileTesto], 
            Text["\<\[Alpha]\>", {\[Alpha], \(- .25\)}, 
              TextStyle \[Rule] stileTesto], 
            Text["\<\[Alpha]+2\[Pi]\>", {\[Alpha] + 2  \[Pi], \(- .25\)}, 
              TextStyle \[Rule] stileTesto]}], 
        DisplayFunction \[Rule] $DisplayFunction, 
        AspectRatio \[Rule] Automatic, 
        ImageSize \[Rule] {600, 150}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .12732 
%%ImageSize: 600 150 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.404762 0.0606305 0.063662 0.0606305 [
[.02381 .05116 -9.84375 -10.9375 ]
[.02381 .05116 9.84375 0 ]
[.11905 .05116 -11.7188 -20 ]
[.11905 .05116 11.7188 0 ]
[.21429 .05116 -6.84375 -10.9375 ]
[.21429 .05116 6.84375 0 ]
[.30952 .05116 -8.84375 -17.8125 ]
[.30952 .05116 8.84375 0 ]
[.5 .05116 -6.09375 -17.8125 ]
[.5 .05116 6.09375 0 ]
[.59524 .05116 -4.09375 -10.9375 ]
[.59524 .05116 4.09375 0 ]
[.69048 .05116 -8.96875 -20 ]
[.69048 .05116 8.96875 0 ]
[.78571 .05116 -7.09375 -10.9375 ]
[.78571 .05116 7.09375 0 ]
[.88095 .05116 -8.96875 -19.875 ]
[.88095 .05116 8.96875 0 ]
[.97619 .05116 -7.09375 -10.9375 ]
[.97619 .05116 7.09375 0 ]
[.39226 .00303 -13.9375 -5.46875 ]
[.39226 .00303 0 5.46875 ]
[.39226 .03335 -20.625 -5.46875 ]
[.39226 .03335 0 5.46875 ]
[.39226 .09398 -15.125 -5.46875 ]
[.39226 .09398 0 5.46875 ]
[.39226 .12429 -8.4375 -5.46875 ]
[.39226 .12429 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .12732 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .06366 m
.02381 .06991 L
s
gsave
.02381 .05116 -70.8438 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
74.500 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.11905 .06366 m
.11905 .06991 L
s
gsave
.11905 .05116 -72.7188 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 16.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.375 10.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
76.375 10.750 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.563 16.688 moveto
(\\200\\200\\200\\200) show
73.813 16.688 moveto
(\\200\\200\\200\\200) show
78.063 16.688 moveto
(\\200\\200) show
80.063 16.688 moveto
(\\200) show
73.250 23.000 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.21429 .06366 m
.21429 .06991 L
s
gsave
.21429 .05116 -67.8438 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.30952 .06366 m
.30952 .06991 L
s
gsave
.30952 .05116 -69.8438 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 14.500 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.500 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.563 14.500 moveto
(\\200\\200) show
71.688 14.500 moveto
(\\200\\200) show
73.813 14.500 moveto
(\\200) show
74.313 14.500 moveto
(\\200) show
70.375 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .06366 m
.5 .06991 L
s
gsave
.5 .05116 -67.0938 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

65.000 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 14.500 moveto
(\\200\\200) show
66.188 14.500 moveto
(\\200\\200) show
68.313 14.500 moveto
(\\200) show
68.813 14.500 moveto
(\\200) show
64.875 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.59524 .06366 m
.59524 .06991 L
s
gsave
.59524 .05116 -65.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.69048 .06366 m
.69048 .06991 L
s
gsave
.69048 .05116 -69.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
70.875 10.750 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.688 moveto
(\\200\\200\\200\\200) show
68.313 16.688 moveto
(\\200\\200\\200\\200) show
72.563 16.688 moveto
(\\200\\200) show
74.563 16.688 moveto
(\\200) show
67.750 23.000 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.78571 .06366 m
.78571 .06991 L
s
gsave
.78571 .05116 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.88095 .06366 m
.88095 .06991 L
s
gsave
.88095 .05116 -69.9688 -23.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 27.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
70.875 10.625 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.563 moveto
(\\200\\200\\200\\200) show
68.313 16.563 moveto
(\\200\\200\\200\\200) show
72.563 16.563 moveto
(\\200\\200) show
74.563 16.563 moveto
(\\200) show
67.750 22.875 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 .06366 m
.97619 .06991 L
s
gsave
.97619 .05116 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 .06366 m
1 .06366 L
s
.40476 .00303 m
.41101 .00303 L
s
gsave
.39226 .00303 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.40476 .03335 m
.41101 .03335 L
s
gsave
.39226 .03335 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40476 .09398 m
.41101 .09398 L
s
gsave
.39226 .09398 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.40476 .12429 m
.41101 .12429 L
s
gsave
.39226 .12429 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.40476 .00909 m
.40851 .00909 L
s
.40476 .01516 m
.40851 .01516 L
s
.40476 .02122 m
.40851 .02122 L
s
.40476 .02728 m
.40851 .02728 L
s
.40476 .03941 m
.40851 .03941 L
s
.40476 .04547 m
.40851 .04547 L
s
.40476 .05154 m
.40851 .05154 L
s
.40476 .0576 m
.40851 .0576 L
s
.40476 .06973 m
.40851 .06973 L
s
.40476 .07579 m
.40851 .07579 L
s
.40476 .08185 m
.40851 .08185 L
s
.40476 .08791 m
.40851 .08791 L
s
.40476 .10004 m
.40851 .10004 L
s
.40476 .1061 m
.40851 .1061 L
s
.40476 .11217 m
.40851 .11217 L
s
.40476 .11823 m
.40851 .11823 L
s
.25 Mabswid
.40476 0 m
.40476 .12732 L
s
0 0 m
1 0 L
1 .12732 L
0 .12732 L
closepath
clip
newpath
.5 Mabswid
.02381 .12429 m
.02499 .12428 L
.02605 .12425 L
.02729 .12419 L
.02846 .12411 L
.03053 .12392 L
.03279 .12363 L
.03527 .12321 L
.0379 .12266 L
.04262 .1214 L
.05205 .11783 L
.06244 .11239 L
.0842 .09662 L
.10458 .07799 L
.14335 .04 L
.16306 .02341 L
.17347 .01626 L
.18458 .01017 L
.19014 .00778 L
.19538 .00596 L
.20008 .00469 L
.20251 .00417 L
.20517 .00372 L
.20638 .00355 L
.20767 .00339 L
.20879 .00328 L
.21001 .00318 L
.21072 .00314 L
.21138 .0031 L
.21268 .00305 L
.21387 .00303 L
.21512 .00304 L
.2162 .00306 L
.21737 .00311 L
.21847 .00318 L
.21948 .00325 L
.22182 .0035 L
.22428 .00385 L
.22929 .00488 L
.23383 .00615 L
.24403 .01018 L
.25347 .01526 L
.26239 .02114 L
.30086 .05503 L
.32034 .07443 L
.34178 .09442 L
.35159 .10244 L
.36214 .10992 L
.37202 .11566 L
.38118 .11976 L
Mistroke
.38609 .12144 L
.39131 .12281 L
.3943 .12339 L
.39711 .12381 L
.39834 .12395 L
.39963 .12408 L
.40031 .12413 L
.40105 .12418 L
.40236 .12424 L
.403 .12427 L
.40371 .12428 L
.40499 .12429 L
.40623 .12427 L
.40738 .12424 L
.40862 .12417 L
.40999 .12407 L
.41142 .12393 L
.41276 .12377 L
.41743 .12297 L
.42005 .12237 L
.42246 .12173 L
.43229 .11815 L
.44142 .11354 L
.46213 .09911 L
.50123 .06243 L
.52118 .04291 L
.54278 .02434 L
.55291 .01721 L
.56362 .01109 L
.57277 .00715 L
.57796 .00548 L
.58282 .0043 L
.58541 .00383 L
.58781 .00349 L
.58917 .00333 L
.59045 .00322 L
.59178 .00313 L
.59249 .00309 L
.59325 .00306 L
.59445 .00304 L
.59576 .00303 L
.59642 .00304 L
.59713 .00306 L
.59841 .00311 L
.59968 .00319 L
.60089 .00329 L
.60314 .00355 L
.60539 .00388 L
.60777 .00432 L
.61204 .00534 L
Mistroke
.61663 .00677 L
.62169 .00871 L
.63184 .01375 L
.64112 .01958 L
.662 .03622 L
.70173 .07485 L
.72177 .09359 L
.73994 .10782 L
.7494 .11374 L
.75963 .11877 L
.76526 .12087 L
.77043 .12238 L
.77538 .12341 L
.77787 .12379 L
.77929 .12395 L
.78061 .12408 L
.78183 .12417 L
.78312 .12424 L
.78442 .12428 L
.78516 .12429 L
.78585 .12429 L
.7871 .12428 L
.78824 .12424 L
.7895 .12417 L
.79082 .12408 L
.79313 .12384 L
.79527 .12354 L
.80013 .12259 L
.80543 .12111 L
.81025 .1194 L
.82105 .11428 L
.84025 .10138 L
.86105 .08321 L
.90199 .04304 L
.92236 .0254 L
.93232 .01822 L
.94141 .01273 L
.95002 .00859 L
.95818 .00569 L
.96266 .00454 L
.9668 .00376 L
.96919 .00344 L
.97135 .00322 L
.97255 .00314 L
.97384 .00308 L
.97507 .00304 L
.97619 .00303 L
Mfstroke
1 0 0 r
.07143 .06366 m
.07143 .10653 L
.45238 .10653 L
.45238 .06366 L
.45238 .10653 L
.83333 .10653 L
.83333 .06366 L
.83333 .10653 L
.97619 .10653 L
s
gsave
.07143 .0485 -73.875 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(a) show
68.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(-) show
74.750 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(2) show
79.750 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(p) show
84.750 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.45238 .0485 -65.8125 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(a) show
68.625 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.83333 .0485 -73.875 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(a) show
68.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(+) show
74.750 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(2) show
79.750 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(p) show
84.750 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{599.875, 149.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006S0000J2000`400?l00000o`00003oo`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT
0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00Z@3oool0
0`000000oooo0?ooo`3g0?ooo`00E@3oool8000003h0oooo0`0000020?ooo`030000003oool0oooo
00H0oooo100000180?ooo`P00000U`3oool5000000X0oooo001A0?ooo`@00000203oool6000003d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`150?ooo`@00000203oool4000008l0
oooo1000000?0?ooo`00C`3oool200000180oooo0P00000k0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0@`3oool200000100oooo0P00002:0?ooo`<000004`3oool004d0oooo0P00
000F0?ooo`800000@P3oool300000440oooo0P00000D0?ooo`800000QP3oool2000001H0oooo001;
0?ooo`8000006P3oool200000400oooo00<000000?ooo`3oool0?`3oool2000001P0oooo0P000023
0?ooo`030000003oool0oooo01H0oooo00190?ooo`8000007P3oool2000003h0oooo0`00000m0?oo
o`800000703oool200000800oooo00<000000?ooo`3oool05`3oool004P0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo0P00000P0?ooo`80
0000O03oool2000001X0oooo00170?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0280oooo0P00001i0?ooo`030000
003oool0oooo01X0oooo000b0?ooo`<00000403oool2000002H0oooo00<000000?ooo`3oool0>@3o
ool3000003P0oooo0P00000W0?ooo`030000003oool0oooo00l0oooo0`00001=0?ooo`<000004`3o
ool00`000000oooo0?ooo`0K0?ooo`00<`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo02P0oooo0P00000@0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool2
000001h0oooo000d0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0:@3oool20000
0140oooo0`00000T0?ooo`<000008`3oool300000100oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0N0?ooo`00<P3oool3000000d0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02`3oool3000004d0
oooo0`00000?0?ooo`030000003oool0oooo01l0oooo00110?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?ooo`<0000000<0oooo000000000000
0P0000060?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0_0?ooo`800000J`3oool200000280oooo000[0?ooo`<0000000<0oooo0000000000001`00
00070?ooo`800000<P3oool00`000000oooo0?ooo`0<0?ooo`<000004P3oool3000000040?ooo`00
0000oooo000000@0oooo00<000000?ooo`3oool0103oool400000280oooo0`00000<0?ooo`800000
=03oool00`000000oooo0?ooo`060?ooo`P00000F@3oool00`000000oooo0?ooo`0R0?ooo`00?P3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`0000000P3o
ool3000000H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo05@0oooo2@0000080?ooo`030000003oool0oooo02<0oooo000m0?ooo`030000003oool0
oooo03D0oooo0P0000050?ooo`<000000P3oool4000001H0oooo0`0000020?ooo`8000001`3oool3
000002<0oooo100000090?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0HP3oool2
000002H0oooo00080?ooo`<0000000<0oooo000000000000;P3oool00`000000oooo0?ooo`0K0?oo
o`8000006`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool06@3oool2000001h0oooo00<000000?ooo`3oool0:`3oool3000000030?ooo`0000000000
02l0oooo00<000000?ooo`3oool0603oool3000000030?ooo`000000000000P0oooo00040?ooo`<0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01l0oooo0`0000000`3oool0
0000000000050?ooo`030000003oool0oooo01P0oooo0`0000030?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`<0000000<0oooo00000000
00008`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01l0oooo0`0000000`3oool0
0000000000060?ooo`030000003oool0oooo01X0oooo0P0000030?ooo`030000003oool0oooo00D0
oooo000:0?ooo`030000003oool00000008000001`3oool30?l000D0oooo0`3o0000103oool0o`00
0?l0003o000<0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000001l0oooo0`00000L0?oo
o`030000003oool0oooo00H0oooo0P00000U0?ooo`<000003`3oool30?l00140oooo0P0000080?oo
o`030000003oool0oooo01/0oooo0`00000O0?ooo`030000003oool0oooo0080oooo0P0000030?oo
o`030000003oool0oooo0240oooo00<000000?ooo`0000000P0000090?ooo`<0o`000`3oool00`3o
0000oooo0?l000020?l000040?ooo`3o0000o`000?l000/0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`030000003oool0oooo01X0oooo00@000000?ooo`000000oooo0`0000070?ooo`00203o
ool3000000/0oooo00@0o`000?ooo`3o0000oooo103o00001`3oool0o`000?ooo`3oool0o`000?oo
o`3o00002`3oool010000000oooo0000003oool300000080oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool0
0`3o0000oooo0?l0000C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool0
1`000000oooo0?ooo`000000oooo0000003oool00`00000Q0?ooo`<000003@3oool00`3o0000oooo
0?l000020?ooo`<0o`0000L0oooo0?l0003oool0oooo0?l0003oool0o`0000T0oooo0`000000103o
ool000000000000000030?ooo`030000003oool0oooo01/0oooo0`00000;0?ooo`005`3oool30?l0
00H0oooo00<0o`000?ooo`3o00000P3o000;0?ooo`<000001@3oool00`000000oooo0?ooo`100?oo
o`8000001@3oool3000002@0oooo0`00000@0?ooo`<0o`00403oool3000000D0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo00000002000003H0oooo0`3o00020?ooo`060?l0003oool0oooo
0?ooo`3o0000oooo0`3o00090?ooo`8000001`3oool00`000000oooo0?ooo`0Z0?ooo`007P3oool0
0`3o0000oooo0?l0000F0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0Y0?ooo`800000A@3oool00`000000oooo0?ooo`0n0?ooo`030?l0003oool0
o`0001D0oooo00<000000?ooo`3oool0:`3oool003H0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo02`0oooo000e0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool09`3oool3000002L0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo02d0oooo000c0?ooo`800000B`3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo02h0oooo000b0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`0_0?ooo`007@0000000`3o000000000000002M
000000030?l000000000000009d0000000<0o`00000000000000@`00000000T0oooo00<000000?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`8000009`3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0000002D0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0?0?oo
o`030000003oool0000002L0oooo00<000000?ooo`3oool09@3oool2000002H0oooo00<000000?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0?0?ooo`030000003oool0000002H0oooo00<000000?oo
o`3oool0203oool000T0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000003oool0000002L0oooo00<000000?ooo`3oool09@3oool010000000oooo0?ooo`00000T0?oo
o`<000004@3oool00`3o0000oooo0?ooo`0>0?ooo`040000003oool0oooo000002L0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0000000U0?ooo`030000003oool0oooo0140oooo00<0o`00
0?ooo`3oool03P3oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo00P0oooo000M
0?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo03H0oooo00<0o`000?ooo`3oool03@3oool00`000000oooo0?ooo`0c
0?ooo`007@3oool00`3o0000oooo0?ooo`0=0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00`0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0e0?ooo`030?l0003oool0oooo00`0oooo00<000000?oo
o`3oool0=03oool001d0oooo00<0o`000?ooo`3oool0303oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01l0oooo0`00000A0?ooo`030?l0003oool0oooo00/0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0d0?ooo`030?l0003oool0oooo00/0oooo00<000000?ooo`3o
ool0=@3oool001d0oooo00<0o`000?ooo`3oool02`3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0:0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool0<`3oool00`3o0000oooo0?ooo`0:0?ooo`030000
003oool0oooo03H0oooo000M0?ooo`030?l0003oool0oooo00X0oooo00<000000?ooo`3oool0G03o
ool00`000000oooo0?ooo`0M0?ooo`<000004@3oool00`3o0000oooo0?ooo`080?ooo`800000GP3o
ool00`000000oooo0?ooo`0b0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0=`3o
ool001d0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo0?ooo`1N0?ooo`8000007@3oool0
0`000000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0G`3oool2
00000380oooo00<0o`000?ooo`3oool0203oool00`000000oooo0?ooo`0h0?ooo`007@3oool00`3o
0000oooo0?ooo`080?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00H0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0_0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0>@3oool001d0
oooo00<0o`000?ooo`3oool01P3oool2000006D0oooo00<000000?ooo`3oool06@3oool300000140
oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo02h0
oooo00<0o`000?ooo`3oool01@3oool2000003`0oooo000M0?ooo`030?l0003oool0oooo00D0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0:0?ooo`<0000000<0oooo000000000000
0P0000060?ooo`030000003oool0oooo0140oooo00<0o`000?ooo`3oool0103oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo02d0oooo00<0o`000?ooo`3oool0103oool00`000000oooo
0?ooo`0l0?ooo`007@3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo000000040?ooo`030000003oool0oooo00@0oooo1000
000@0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?oo
o`0/0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool0?@3oool001d0oooo00<0o`00
0?ooo`3oool00`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`0000000P3oool3000000H0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?ooo`02
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0:`3oool0103o0000oooo0?ooo`3o
ool200000400oooo000M0?ooo`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0K03oool0
0`000000oooo0?ooo`070?ooo`<000000P3oool2000000L0oooo00<000000?ooo`3oool04@3oool0
1@3o0000oooo0?ooo`3oool0000006h0oooo00<000000?ooo`3oool0:P3oool0103o0000oooo0?oo
o`0000120?ooo`007@3oool00`3o0000oooo0?ooo`0200000700oooo00<000000?ooo`3oool0503o
ool300000140oooo00@0o`000?ooo`0000000000L03oool2000002X0oooo00<0o`000?ooo`000000
@`3oool001d0oooo00<0o`000?ooo`000000L`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo0140oooo00<0o`000000003oool0L`3oool00`000000oooo0?ooo`0W0?ooo`030?l00000
0000oooo04<0oooo000M0?ooo`030?l000000000oooo07@0oooo00<000000?ooo`3oool04P3oool3
00000100oooo00<000000?l0003oool0M@3oool00`000000oooo0?ooo`0U0?ooo`030000003o0000
oooo04@0oooo000L0?ooo`030000003o0000o`000?l0o`00N`3o000:0?ooo`006`3oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool2000007/0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`160?ooo`006@3oool2000007d0oooo
0P00000?0?ooo`<00000303oool00`000000oooo0?ooo`1l0?ooo`8000007`3oool2000004T0oooo
000G0?ooo`800000P@3oool2000000d0oooo00<000000?ooo`3oool02P3oool200000840oooo0P00
000L0?ooo`030000003oool0oooo04T0oooo000E0?ooo`800000Q@3oool2000000/0oooo0`000008
0?ooo`800000Q@3oool2000001P0oooo0P00001<0?ooo`004`3oool2000008T0oooo0P0000090?oo
o`030000003oool0oooo00H0oooo0P0000290?ooo`800000503oool2000004h0oooo000?0?ooo`@0
0000S@3oool4000000D0oooo00<000000?ooo`3oool00P3oool4000008d0oooo1000000<0?ooo`@0
0000D03oool000T0oooo1P00002A0?ooo`040000003oool0oooo0?ooo`X00000U@3oool<000005@0
oooo002P0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0m`3oool00:00oooo00<0
00000?ooo`3oool0o`3oool10?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00
o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00
o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00
o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00
o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00o`3ooonT0?ooo`00
o`3ooonT0?ooo`00\
\>"],
  ImageRangeCache->{{{100.063, 518.938}, {204.813, 100.938}} -> {-10.616, \
1.92938, 0.027563, 0.027563}},
  CellTags->"figura6"],

Cell["che sono casi particolari della pi\[UGrave] generale identit\[AGrave]", \
"Text"],

Cell[BoxData[
    \(cos \((\[Alpha])\) = 
      cos \((\[Alpha] + 
              2  k\ \[Pi])\)\ \ \ \ \ \ \ \ \ \(\[ForAll] \[Alpha] \[Element] \
\[DoubleStruckCapitalR]\) \[And] 
        k \[Element] \[DoubleStruckCapitalZ]\)], "DisplayFormula"],

Cell[TextData[{
  "che codifica la periodicit\[AGrave] della funzione coseno con periodo ",
  Cell[BoxData[
      \(TraditionalForm\`T = 2  \[Pi]\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Definizione della funzione tangente di un angolo e periodicit\[AGrave]\
\>", "Section"],

Cell[TextData[{
  "Sempre in riferimento alla circonferenza ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " associata ad un sistema cartesiano di origine ",
  Cell[BoxData[
      \(TraditionalForm\`O\)]],
  " (",
  ButtonBox["fig. 7",
    ButtonData:>"figura7",
    ButtonStyle->"Hyperlink"],
  "), definiamo la tangente di un angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " come il rapporto"
}], "Text"],

Cell[TextData[{
  "Definizione della tangente di un angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`tg(\[Alpha]) = QP\/OQ\)]]
}], "Definition",
  CellTags->"deftangente"],

Cell[TextData[{
  "dove entrambi i segmenti coinvolti vanno interpretati come segmenti \
orientati ossia come le componenti del vettore ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontWeight->"Bold"], TraditionalForm]]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Alpha] = 50  Degree;\)\), "\n", 
    \(pP = {Cos[\[Alpha]], Sin[\[Alpha]]}; pQ = {Cos[\[Alpha]], 0}; 
    origine = {0, 0};\), "\n", 
    \(\(Show[
        Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
            Line[{{0, \(-1.2\)}, {0, 1.2}}], 
            Line[{pP, origine}]}], \[IndentingNewLine]Graphics[{colBlu, 
            Arrow[origine, pQ, stileVet], 
            Arrow[pQ, pP, 
              stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
              origine, {1, 1}, TextStyle \[Rule] stileTesto], 
            Text["\<Q\>", pQ, {0, 1}, TextStyle \[Rule] stileTesto], 
            Text["\<P\>", pP, {0, \(-1\)}, TextStyle \[Rule] stileTesto]}], 
        Prolog -> {{colGiallo, Polygon[{origine, pQ, pP}]}, {colRosso, 
              Disk[origine,  .2, {0, \[Alpha]}]}}, 
        AspectRatio \[Rule] Automatic, Axes \[Rule] True];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 .5 m
.75507 .5 L
.75507 .80399 L
F
1 0 0 r
.5 .5 m
.5 .5 .07937 0 50 arc
F
0 g
.5 Mabswid
newpath
.5 .5 .39683 0 365.73 arc
s
.02381 .5 m
.97619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.75507 .80399 m
.5 .5 L
s
0 0 1 r
.5 .5 m
.75507 .5 L
s
% Start of user PostScript
0 0 0.642788 0 MAarrowhead1
% End of user PostScript
.75507 .5 m
.75507 .80399 L
s
% Start of user PostScript
0.642788 0 0.642788 0.766044 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 .5 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .5 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .80399 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{287.75, 287.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000390000bB000`400?l00000o`00003oI03oool0
0`000000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`000000
oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?oo
o`1R0?ooo`00I03oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`1R0?oo
o`00I03oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`1R0?ooo`00I03o
ool00`000000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`00
0000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo
0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`1R
0?ooo`00I03oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`1R0?ooo`00
I03oool00`000000oooo0?ooo`1R0?ooo`00I03oool00`000000oooo0?ooo`1R0?ooo`00I03oool0
0`000000oooo0?ooo`1R0?ooo`00F@3ooolF000005X0oooo001D0?ooo`H00000103oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo1@00001E0?ooo`00D03oool4000000X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`@00000D@3oool004`0oooo1000
000D0?ooo`030000003oool0oooo0140oooo1000001=0?ooo`00BP3oool2000001P0oooo00<00000
0?ooo`3oool05@3oool2000004/0oooo00170?ooo`<000006P3oool00`000000oooo0?ooo`0G0?oo
o`@00000A`3oool004D0oooo0P00000M0?ooo`030000003oool0oooo01/0oooo0P0000150?ooo`00
@`3oool2000001l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`120?ooo`00@@3o
ool200000240oooo00<000000?ooo`3oool07P3oool200000480oooo000n0?ooo`<000008`3oool0
0`000000oooo0?ooo`0P0?ooo`@00000?P3oool003`0oooo0P00000V0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0>`3oool003X0oooo0P00000X0?ooo`030000003oool0oooo02D0
oooo0P00000k0?ooo`00>@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0>03oool003T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo03L0oooo000g0?ooo`800000:`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo03H0oooo000e0?ooo`800000;@3oool00`000000oooo0?ooo`0Z0?oo
o`800000=P3oool003@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0/0?ooo`80
0000=03oool00380oooo0P00000`0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
<@3oool00340oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0_0?ooo`800000<@3o
ool00300oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo02l0oooo000_0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0^0?ooo`00;@3oool2000003D0oooo00<000000?ooo`3oool0<P3oool2000002h0
oooo000/0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0[0?ooo`00:`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0:P3oool002X0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo02T0oooo000Y0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0X0?ooo`00:03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0U0?ooo`009P3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool09@3oool0
02H0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
02@0oooo000T0?ooo`800000?P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02<0
oooo000S0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0S0?ooo`008`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool08P3oool00280oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo0280oooo000R0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0Q0?ooo`008@3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0803oool00200oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01l0oooo000P0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0N0?ooo`007`3oool0
0`000000oooo0?ooo`0f0?ooo`<0000000<0oooo0000000000000P0000040?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool07P3oool001l0oooo00<000000?ooo`3oool0<P3oool30000
00040?ooo`000000oooo000000@0oooo00<000000?ooo`3oool00P3oool2000004<0oooo00<00000
0?ooo`3oool07@3oool001h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo000000020?oo
o`<00000103oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01`0oooo000M0?ooo`03
0000003oool0oooo03P0oooo0`0000020?ooo`8000001@3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo01`0oooo000M0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0L0?ooo`00703oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0703oool001`0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo01/0oooo000K0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0K0?ooo`006`3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool06P3oool001X0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01T0oooo
000J0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0I0?ooo`006P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool0603oool001T0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo01P0oooo000I0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0H0?ooo`00603oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0603oool001P0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo01L0oooo000H0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0G0?ooo`00603oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool05P3oool001L0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo01H0
oooo000G0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0F0?ooo`005`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool05P3oool001L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo01D0oooo000F0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool05@3oool001H0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo01D0oooo000F0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0D0?ooo`005@3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0503oool0
01D0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
01@0oooo000E0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`0D0?ooo`005@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo01<0oooo000E0?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`0C0?ooo`005@3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool04`3oool001@0oooo00<000000?ooo`3o
ool08`3oool3000000030?ooo`0000000000008000008P3oool00`000000oooo0?ooo`0Q0?ooo`<0
000000<0oooo0000000000000P00000S0?ooo`030000003oool0oooo01<0oooo000A0?ooo`@00000
00<0oooo0000003oool07P3oool3000000040?ooo`000000oooo000000@0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0000000S0?ooo`030000
003oool000000080oooo0`00000L0?ooo`<000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool000000080oooo0`0000050?ooo`<000006`3oool00`000000oooo0?ooo`0C0?ooo`00503o
ool00`000000oooo0000000S0?ooo`<000000P3oool2000001`0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0Q0?ooo`<000000P3oool2000000D0oooo00@000000?ooo`3oool0
00006`3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01<0oooo000D0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool04`3o
ool001@0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0Z0?ooo`<0003o7`3oool0
0`000000oooo0?ooo`0C0?ooo`00I000000d0000oc40000000040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`8000003P3o000M0?oo00D0
003o00<0ool00000o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool001@0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0000000`0o`007P3oo`020000o`@0ool000<0003o0?ooo`3oool0
6@3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`1=0?ooo`040000003o
ool0oooo000000/0o`00903oo`000`000?l0oooo0?ooo`0I0?ooo`030000003oool0oooo01<0oooo
000D0?ooo`030000003oool0oooo04d0oooo00@000000?ooo`3oool000002`3o000T0?oo00030000
o`3oool0oooo01T0oooo00<000000?ooo`3oool04`3oool001@0oooo00<000000?ooo`3oool0C@3o
ool01@000000oooo0?ooo`3oool0000000X0o`00903oo`000`000?l0oooo0?ooo`0I0?ooo`030000
003oool0oooo01<0oooo000D0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool00P3o
ool00`000000o`000?l000070?l002@0ool000<0003o0?ooo`3oool06@3oool00`000000oooo0?oo
o`0C0?ooo`00503oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00<0oooo00<00000
0?l0003o00001@3o000U0?oo00030000o`3oool0oooo01T0oooo00<000000?ooo`3oool04`3oool0
01D0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`040?ooo`030000003o0000o`00
00@0o`009@3oo`000`000?l0oooo0?ooo`0I0?ooo`030000003oool0oooo01<0oooo000E0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool01@3oool00`000000o`000?l000020?l002H0
ool000<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`0C0?ooo`005@3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo00D0oooo00@000000?l0003o0000o`009`3oo`000`000?l0
oooo0?ooo`0I0?ooo`030000003oool0oooo01<0oooo000E0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool01P3oool00`000000o`000?oo000W0?oo00030000o`3oool0oooo01P0oooo
00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`070?ooo`030000003oo`00ool002H0ool000<0003o0?ooo`3oool0603oool00`000000oooo0?oo
o`0D0?ooo`005@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00P0oooo00<00000
0?oo003oo`009@3oo`000`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo01@0oooo000E0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool02@3oool00`000000ool00?oo000T0?oo
00030000o`3oool0oooo01P0oooo00<000000?ooo`3oool0503oool001D0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`0:0?ooo`030000003oo`00ool002<0ool000<0003o0?ooo`3o
ool0603oool00`000000oooo0?ooo`0D0?ooo`005P3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo00X0oooo00<000000?oo003oo`008`3oo`000`000?l0oooo0?ooo`0H0?ooo`030000
003oool0oooo01@0oooo000F0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool02`3o
ool00`000000ool00?oo000R0?oo00030000o`3oool0oooo01L0oooo00<000000?ooo`3oool05@3o
ool001H0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0<0?ooo`030000003oo`00
ool00240ool000<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo00d0oooo00<000000?oo003oo`00803oo`000`00
0?l0oooo0?ooo`0G0?ooo`030000003oool0oooo01D0oooo000G0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool03P3oool00`000000ool00?oo000O0?oo00030000o`3oool0oooo01L0
oooo00<000000?ooo`3oool05@3oool001L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`0?0?ooo`030000003oo`00ool001h0ool000<0003o0?ooo`3oool05P3oool00`000000oooo
0?ooo`0F0?ooo`005`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo00<0
00000?oo003oo`007P3oo`000`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo01H0oooo000G
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00`000000ool00?oo000M
0?oo00030000o`3oool0oooo01H0oooo00<000000?ooo`3oool05P3oool001P0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`0A0?ooo`030000003oo`00ool001`0ool000<0003o0?oo
o`3oool05P3oool00`000000oooo0?ooo`0F0?ooo`00603oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0180oooo00<000000?oo003oo`006`3oo`000`000?l0oooo0?ooo`0E0?ooo`03
0000003oool0oooo01L0oooo000H0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
4`3oool00`000000ool00?oo000J0?oo00030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0
5`3oool001T0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0D0?ooo`030000003o
o`00ool001T0ool000<0003o0?ooo`3oool0503oool00`000000oooo0?ooo`0H0?ooo`006@3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo01@0oooo00<000000?oo003oo`006@3oo`00
0`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo01P0oooo000J0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool05@3oool00`000000ool00?oo000H0?oo00030000o`3oool0oooo
01@0oooo00<000000?ooo`3oool0603oool001X0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oo`00ool001L0ool000<0003o0?ooo`3oool04`3oool00`000000
oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01L0oooo
00<000000?oo003oo`005P3oo`000`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo01T0oooo
000J0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0603oool00`000000ool00?oo
000E0?oo00030000o`3oool0oooo0180oooo00<000000?ooo`3oool06P3oool001/0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0I0?ooo`030000003oo`00ool001@0ool000<0003o
0?ooo`3oool04P3oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo01T0oooo00<000000?oo003oo`00503oo`000`000?l0oooo0?ooo`0A0?oo
o`030000003oool0oooo01/0oooo000L0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool06P3oool00`000000ool00?oo000C0?oo00030000o`3oool0oooo0140oooo00<000000?ooo`3o
ool06`3oool001`0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oo`00ool00180ool000<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`0L0?ooo`007@3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01`0oooo00<000000?oo003oo`004@3o
o`000`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo01`0oooo000N0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool07@3oool00`000000ool00?oo000@0?oo00030000o`3oool0
oooo0100oooo00<000000?ooo`3oool0703oool001h0oooo00<000000?ooo`3oool0=`3oool30000
00030?ooo`000000000000800000103oool00`000000oooo0?ooo`0N0?ooo`030000003oo`00ool0
00l0ool000<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0M0?ooo`007`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool2000001l0
oooo00<000000?oo003oo`003`3oo`000`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo01d0
oooo000O0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`0000000P3oool3000000@0oooo
00<000000?ooo`3oool07`3oool00`000000ool00?oo000>0?oo00030000o`3oool0oooo00h0oooo
00<000000?ooo`3oool07P3oool00200oooo00<000000?ooo`3oool0=@3oool300000080oooo0P00
00050?ooo`030000003oool0oooo0200oooo00<000000?oo003oo`003@3oo`000`000?l0oooo0?oo
o`0>0?ooo`030000003oool0oooo01h0oooo000Q0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool08@3oool00`000000ool00?oo000<0?oo00030000o`3oool0oooo00`0oooo0P00000Q
0?ooo`008@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0280oooo00<000000?oo
003oo`002`3oo`000`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo0240oooo000R0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool08`3oool00`000000ool00?oo000:0?oo0003
0000o`3oool0oooo00/0oooo00<000000?ooo`3oool08@3oool00280oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0S0?ooo`030000003oo`00ool000X0ool000<0003o0?ooo`3oool0
2P3oool00`000000oooo0?ooo`0R0?ooo`008`3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo02@0oooo00<000000?oo003oo`002@3oo`000`000?l0oooo0?ooo`0:0?ooo`030000003o
ool0oooo0280oooo000T0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool09@3oool0
0`000000ool00?oo00080?oo00030000o`3oool0oooo00T0oooo00<000000?ooo`3oool08`3oool0
02D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0V0?ooo`030000003oo`00ool0
00L0ool000<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`0T0?ooo`009P3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo02L0oooo00<000000?oo003oo`001P3oo`000`000?l0
oooo0?ooo`080?ooo`030000003oool0oooo02@0oooo000W0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0:03oool00`000000ool00?oo00050?oo00030000o`3oool0oooo00L0oooo
00<000000?ooo`3oool09@3oool002P0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0X0?ooo`030000003oo`00ool000D0ool000<0003o0?ooo`3oool01P3oool00`000000oooo0?oo
o`0V0?ooo`00:03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02T0oooo00<00000
0?oo003oo`00103oo`000`000?l0oooo0?ooo`050?ooo`030000003oool0oooo02L0oooo000Y0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0:P3oool00`000000ool00?oo00030?oo
00030000o`3oool0oooo00@0oooo00<000000?ooo`3oool0:03oool002X0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0[0?ooo`050000003oo`00ool00000o`3oo`000P000?l40?oo
o`030000003oool0oooo02T0oooo000[0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0;03oool00`000000ool00000o`030000o`<0oooo00<000000?ooo`3oool0:P3oool002`0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0]0?ooo`030000003oo`00003o0080003o
0P3oool00`000000oooo0?ooo`0[0?ooo`00;@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo02d0oooo00@000000?oo00000?l0003o0P3oool00`000000oooo0?ooo`0/0?ooo`00;P3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02h0oooo00D000000000o`000?l0oooo
0000000_0?ooo`00;`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02l0oooo00<0
00000000o`000000<03oool00300oooo0P00000b0?ooo`030000003oool0oooo02l0oooo00<00000
0000o`3oool0<03oool00380oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0340oooo000c0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0b0?ooo`00=03oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo02d0oooo0P00000c0?ooo`00=@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo02/0oooo0P0000000`3oool000000?ooo`0b0?ooo`00=P3oool2000002`0oooo00<00000
0?ooo`3oool0:@3oool2000000<0oooo00@000000?ooo`3oool00000<03oool003P0oooo0P00000Z
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00`3oool010000000oooo00000000
000`0?ooo`00>P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo0P00000j
0?ooo`00>`3oool2000002L0oooo00<000000?ooo`3oool0903oool2000003`0oooo000m0?ooo`80
00009@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03`0oooo000o0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool08@3oool2000003l0oooo00100?ooo`8000008P3o
ool00`000000oooo0?ooo`0O0?ooo`800000@@3oool00480oooo0P00000P0?ooo`030000003oool0
oooo01d0oooo0P0000130?ooo`00A03oool4000001`0oooo00<000000?ooo`3oool06P3oool30000
04D0oooo00180?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool2000004P0
oooo00190?ooo`@000005`3oool00`000000oooo0?ooo`0D0?ooo`@00000BP3oool004d0oooo1000
000C0?ooo`030000003oool0oooo0100oooo1000001>0?ooo`00D@3oool4000000l0oooo00<00000
0?ooo`3oool0303oool400000580oooo001E0?ooo`P000001`3oool00`000000oooo0?ooo`050?oo
o`L00000EP3oool005d0oooo3`00001M0?ooo`00GP3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0680oooo001N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0HP3o
ool006@0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool0HP3oool006@0
oooo00<000000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<0
00000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<000000?oo
o`3oool0HP3oool006@0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool0
HP3oool006@0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool0HP3oool0
06@0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool0HP3oool006@0oooo
00<000000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<00000
0?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3oool0HP3oool006@0oooo00<000000?ooo`3o
ool0HP3oool00001\
\>"],
  ImageRangeCache->{{{100.063, 300.438}, {301.313, 100.938}} -> {-2.51846, \
0.00943242, 0.00880359, 0.00880359}},
  CellTags->"figura7"],

Cell[TextData[{
  "Da tale definizione discende immediatamente che la tangente non \[EGrave] \
definita quando ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OQ",
            FontSlant->"Italic"], "=", "0"}], TraditionalForm]]],
  ": i valori di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " che individuano le posizioni del punto ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " con ascissa nulla sono: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \(\[Pi]\/2 + 
              2  k\ \[Pi]\  \[Or] \ \[Alpha] = \(-\(\[Pi]\/2\)\) + 
            2  k\ \[Pi]\)\)]],
  " che si possono riassumere in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \[Pi]\/2 + k\ \[Pi]\)]],
  ". Pertanto il dominio della funzione tangente \[EGrave] l'insieme "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[Cell[TextData[Cell[BoxData[
          \(TraditionalForm\`\[Alpha] \[Element] \[DoubleStruckCapitalR] - {\
\[Pi]\/2 + k\ \[Pi], \ 
                    k \[Element] \[DoubleStruckCapitalZ]}\ \[LongRightArrow]\ 
                  y = tg(\[Alpha])\)]]]], TraditionalForm]]]], "Theorem"],

Cell[TextData[{
  "Poich\[EAcute] inoltre si pu\[OGrave] dividere numeratore e denominatore \
del secondo membro della ",
  ButtonBox["definizione",
    ButtonData:>"deftangente",
    ButtonStyle->"Hyperlink"],
  " per ",
  Cell[BoxData[
      FormBox[
        StyleBox["OP",
          FontSlant->"Italic"], TraditionalForm]]],
  ", la tangente si pu\[OGrave] riscrivere identicamente come"
}], "Text"],

Cell[BoxData[
    \(tg \((\[Alpha])\) = \(QP\/OQ = \(\((QP\/OP)\)\/\((OQ\/OP)\) = \(sen \((\
\[Alpha])\)\)\/\(cos \((\[Alpha])\)\)\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "non appena si siano tenute presenti le definizioni di ",
  Cell[BoxData[
      \(TraditionalForm\`sen(\[Alpha])\)]],
  " e ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\[Alpha])\)]],
  ". Ne segue che ",
  Cell[BoxData[
      \(TraditionalForm\`tg(\[Alpha])\)]],
  " risulta pure definita dal rapporto del seno e del coseno del medesimo \
angolo."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Periodicit\[AGrave]", "Subsection"],

Cell[TextData[{
  "Una seconda importante propriet\[AGrave] discende sempre dalla \
definizione. Per dimostrarla analizziamo la configurazione geometrica che si \
presenta quando si considerino angoli che differiscono per ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  ": per esempio, in ",
  ButtonBox["figura 8",
    ButtonData:>"figura8",
    ButtonStyle->"Hyperlink"],
  " , all'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 50  \[Degree]\)]],
  " (in rosso) si associ l'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`50  \[Degree] + 180  \[Degree] = 230  \[Degree]\)]],
  " (in verde). "
}], "Text"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\[Alpha] = 50  Degree; \[Beta] = \[Pi] + \[Alpha];\), "\n", 
    \(pP = {Cos[\[Alpha]], Sin[\[Alpha]]}; pQ = {Cos[\[Alpha]], 0}; 
    origine = {0, 0}; pR = {Cos[\[Beta]], Sin[\[Beta]]}; 
    pS = {Cos[\[Beta]], 0};\), "\n", 
    \(Show[
      Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
          Line[{{0, \(-1.2\)}, {0, 1.2}}], 
          Line[{pP, origine, pR}]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pQ, stileVet], 
          Arrow[pQ, pP, stileVet]}], \[IndentingNewLine]Graphics[{colBlu, 
          Arrow[origine, pS, stileVet], 
          Arrow[pS, pR, 
            stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
            origine, {1, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<Q\>", pQ, {0, 1}, TextStyle \[Rule] stileTesto], 
          Text["\<P\>", pP, {0, \(-1\)}, TextStyle \[Rule] stileTesto], 
          Text["\<S\>", pS, {0, \(-1\)}, TextStyle \[Rule] stileTesto], 
          Text["\<R\>", pR, {0, 1}, TextStyle \[Rule] stileTesto]}], 
      Prolog -> {{colGiallo, Polygon[{origine, pQ, pP}], 
            Polygon[{origine, pS, pR}]}, {colVerde, 
            Disk[origine,  .3, {0, \[Beta]}]}, {colRosso, 
            Disk[origine,  .2, {0, \[Alpha]}]}}, 
      AspectRatio \[Rule] Automatic, 
      Axes \[Rule] True]; \[Alpha] =. ;\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.5 0.396825 [
[.10317 .4875 -6.96875 -10.9375 ]
[.10317 .4875 6.96875 0 ]
[.30159 .4875 -10.3125 -10.9375 ]
[.30159 .4875 10.3125 0 ]
[.69841 .4875 -7.5625 -10.9375 ]
[.69841 .4875 7.5625 0 ]
[.89683 .4875 -4.21875 -10.9375 ]
[.89683 .4875 4.21875 0 ]
[.4875 .10317 -13.9375 -5.46875 ]
[.4875 .10317 0 5.46875 ]
[.4875 .30159 -20.625 -5.46875 ]
[.4875 .30159 0 5.46875 ]
[.4875 .69841 -15.125 -5.46875 ]
[.4875 .69841 0 5.46875 ]
[.4875 .89683 -8.4375 -5.46875 ]
[.4875 .89683 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .5 m
.10317 .50625 L
s
gsave
.10317 .4875 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .5 m
.30159 .50625 L
s
gsave
.30159 .4875 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .5 m
.69841 .50625 L
s
gsave
.69841 .4875 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .5 m
.89683 .50625 L
s
gsave
.89683 .4875 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .5 m
.14286 .50375 L
s
.18254 .5 m
.18254 .50375 L
s
.22222 .5 m
.22222 .50375 L
s
.2619 .5 m
.2619 .50375 L
s
.34127 .5 m
.34127 .50375 L
s
.38095 .5 m
.38095 .50375 L
s
.42063 .5 m
.42063 .50375 L
s
.46032 .5 m
.46032 .50375 L
s
.53968 .5 m
.53968 .50375 L
s
.57937 .5 m
.57937 .50375 L
s
.61905 .5 m
.61905 .50375 L
s
.65873 .5 m
.65873 .50375 L
s
.7381 .5 m
.7381 .50375 L
s
.77778 .5 m
.77778 .50375 L
s
.81746 .5 m
.81746 .50375 L
s
.85714 .5 m
.85714 .50375 L
s
.06349 .5 m
.06349 .50375 L
s
.02381 .5 m
.02381 .50375 L
s
.93651 .5 m
.93651 .50375 L
s
.97619 .5 m
.97619 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .10317 m
.50625 .10317 L
s
gsave
.4875 .10317 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30159 m
.50625 .30159 L
s
gsave
.4875 .30159 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .69841 m
.50625 .69841 L
s
gsave
.4875 .69841 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .89683 m
.50625 .89683 L
s
gsave
.4875 .89683 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .14286 m
.50375 .14286 L
s
.5 .18254 m
.50375 .18254 L
s
.5 .22222 m
.50375 .22222 L
s
.5 .2619 m
.50375 .2619 L
s
.5 .34127 m
.50375 .34127 L
s
.5 .38095 m
.50375 .38095 L
s
.5 .42063 m
.50375 .42063 L
s
.5 .46032 m
.50375 .46032 L
s
.5 .53968 m
.50375 .53968 L
s
.5 .57937 m
.50375 .57937 L
s
.5 .61905 m
.50375 .61905 L
s
.5 .65873 m
.50375 .65873 L
s
.5 .7381 m
.50375 .7381 L
s
.5 .77778 m
.50375 .77778 L
s
.5 .81746 m
.50375 .81746 L
s
.5 .85714 m
.50375 .85714 L
s
.5 .06349 m
.50375 .06349 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .93651 m
.50375 .93651 L
s
.5 .97619 m
.50375 .97619 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
1 1 0 r
.5 .5 m
.75507 .5 L
.75507 .80399 L
F
.5 .5 m
.24493 .5 L
.24493 .19601 L
F
.5 1 .5 r
.5 .5 m
.5 .5 .11905 0 230 arc
F
1 0 0 r
.5 .5 m
.5 .5 .07937 0 50 arc
F
0 g
.5 Mabswid
newpath
.5 .5 .39683 0 365.73 arc
s
.02381 .5 m
.97619 .5 L
s
.5 .02381 m
.5 .97619 L
s
.75507 .80399 m
.5 .5 L
.24493 .19601 L
s
0 0 1 r
.5 .5 m
.75507 .5 L
s
% Start of user PostScript
0 0 0.642788 0 MAarrowhead1
% End of user PostScript
.75507 .5 m
.75507 .80399 L
s
% Start of user PostScript
0.642788 0 0.642788 0.766044 MAarrowhead1
% End of user PostScript
.5 .5 m
.24493 .5 L
s
% Start of user PostScript
0 0 -0.642788 0 MAarrowhead1
% End of user PostScript
.24493 .5 m
.24493 .19601 L
s
% Start of user PostScript
-0.642788 0 -0.642788 -0.766044 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 .5 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .5 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .80399 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.24493 .5 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.24493 .19601 -66.2188 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
69.438 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00:P0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?ooo`2b
0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002P0?ooo`03
0?noM000000000000080000000H004RL0=ooo`3oool0oooO09a8M02oool80?ooo`030000003oool0
oooo0;80oooo002S0?ooob400000Y03oool009`0oooo1`0000030?ooo`050?oog`2LW;l0oooO09a8
M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000W@3oool009L0oooo1@00000;0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool05@3oool5000009P0oooo002C0?ooo`@0
00004@3oool00`3ookl0M01d0;ooo`080?ooo`030000003oool0oooo01X0oooo1000002D0?ooo`00
SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000008l0oooo002;0?ooo`<000009@3o
ool00`000000oooo0?ooo`0S0?ooo`<00000S03oool008L0oooo1000000X0?ooo`030000003oool0
oooo02H0oooo100000280?ooo`00QP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0Q@3oool00880oooo1000000]0?ooo`030000003oool0oooo02/0
oooo100000230?ooo`00O`3oool300000340oooo00<000000?ooo`3oool0;`3oool300000800oooo
001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000OP3oool007X0oooo0`00000f
0?ooo`030000003oool0oooo03@0oooo0`00001k0?ooo`00N03oool2000003T0oooo00<000000?oo
o`3oool0=`3oool2000007T0oooo001g0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1f0?ooo`00M03oool3000003`0oooo0P00000k0?ooo`<00000
M@3oool00780oooo0P00000o0?ooo`030000003oool0oooo03d0oooo0P00001c0?ooo`00L03oool2
00000440oooo00<000000?ooo`3oool0?`3oool200000740oooo001_0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1^0?ooo`00K@3oool2000004@0
oooo00<000000?ooo`3oool0@P3oool2000006h0oooo001/0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1[0?ooo`00J@3oool3000004L0oooo00<0
00000?ooo`3oool0A@3oool3000006X0oooo001W0?ooo`800000BP3oool00`000000oooo0?ooo`18
0?ooo`800000J03oool005<0oooo00L0omnL04P0001d_ol0oooo0?oo_`1d000007Bo00`0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo06D0oooo001C
0?ooo`070?oOW0180000M;oo0?ooo`3OW4P0001809cOo`0:0?ooo`800000C@3oool00`000000oooo
0?ooo`1;0?ooo`800000I@3oool005<0oooo00H0omnL04P0001d_ol0omnL04P00018W=l:0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1R0?ooo`00
D`3oool00`3ogi`0B000000000020000000304RLg`3oool0oooo00H0oooo0P00001@0?ooo`030000
003oool0oooo04h0oooo0P00001R0?ooo`00D`3oool01`3ogi`0B00007Boo`3oool0okmd0000001d
_ol01P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool0G`3oool005<0oooo00L0omnL04P0001d_ol0oooo0?oOW0180000B9cO00@0oooo0P00001C0?oo
o`030000003oool0oooo0540oooo0P00001O0?ooo`00D`3oool01`3ogi`0B00007Boo`3oool0okmd
0000001d_ol00`3oool00`000000oooo0?ooo`1C0?ooo`800000E03oool00`000000oooo0?ooo`1L
0?ooo`00D`3oool00`3ogi`0B0000000000200000005001d_`3oool0oooo0?ooo`000000EP3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo001K0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1J0?ooo`00FP3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0F@3oool005P0oooo
0P00001I0?ooo`030000003oool0oooo05L0oooo0P00001I0?ooo`00E`3oool00`000?l0oooo0?oo
o`1I0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0EP3oool005H0oooo00<00000
0000o`000000FP3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo05D0oooo001E0?oo
o`050000003oool0003o0000o`000000F@3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo05@0oooo001D0?ooo`030000003oool0003o0080003o00<0ool00000003oool0E`3oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo05<0oooo001C0?ooo`030000003oool0oooo00<0
003o00<0ool00000003oool0E`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0580
oooo001B0?ooo`040000003oool0oooo0?ooo`<0003o0P3oo`000`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool0D@3oool00540oooo00<000000?ooo`3oool0
0P3oool40000o`80ool000<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1O0?ooo`030000
003oool0oooo0500oooo001@0?ooo`030000003oool0oooo00<0oooo10000?l30?oo00030000003o
ool0oooo05<0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1?0?ooo`00C`3oool0
0`000000oooo0?ooo`040?ooo`@0003o103oo`000`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo0640oooo00<000000?ooo`3oool0CP3oool004h0oooo00<000000?ooo`3oool0103oool50000
o`D0ool000<000000?ooo`3oool0D@3oool2000006<0oooo00<000000?ooo`3oool0C@3oool004d0
oooo00<000000?ooo`3oool01@3oool60000o`@0ool000<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo04`0oooo001<0?ooo`030000003oool0oooo00H0oooo
0`000?l00`3oo`00003o0000o`050?oo00030000003oool0oooo0500oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`1;0?ooo`00B`3oool00`000000oooo0?ooo`090?ooo`030000o`3o
o`00ool000L0ool000<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo04X0oooo001:0?ooo`030000003oool0oooo00X0oooo00<0003o0?oo003oo`00203oo`00
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0B@3oool0
04T0oooo00<000000?ooo`3oool02`3oool00`000?l0ool00?oo00090?oo00030000003oool0oooo
04d0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`180?ooo`00B03oool00`000000
oooo0?ooo`0<0?ooo`030000o`3oo`00ool000X0ool000<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`1X0?ooo`030000003oool0oooo04L0oooo00170?ooo`030000003oool0oooo00d0oooo
00<0003o0?oo003oo`002`3oo`000`000000oooo0?ooo`1;0?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool0AP3oool004H0oooo00<000000?ooo`3oool03P3oool00`000?l0ool00?oo
000;0?oo00030000003oool0oooo04/0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`150?ooo`00A@3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oo`00ool000`0ool000<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo04@0oooo00150?oo
o`030000003oool0oooo00l0oooo00<0003o0?oo003oo`003@3oo`000`000000oooo0?ooo`190?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0A03oool004@0oooo00<000000?ooo`3o
ool0403oool00`000?l0ool00?oo000>0?oo00030000003oool0oooo04P0oooo00<000000?ooo`3o
ool0K03oool00`000000oooo0?ooo`130?ooo`00@`3oool00`000000oooo0?ooo`0A0?ooo`030000
o`3oo`00ool000l0ool000<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo0480oooo00120?ooo`030000003oool0oooo0180oooo00<0003o0?oo003oo`00403o
o`000`000000oooo0?ooo`160?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0@@3o
ool00440oooo00<000000?ooo`3oool04`3oool00`000?l0ool00?oo000@0?oo00030000003oool0
oooo04H0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`100?ooo`00@03oool00`00
0000oooo0?ooo`0D0?ooo`030000o`3oo`00ool00140ool000<000000?ooo`3oool0A@3oool20000
0740oooo00<000000?ooo`3oool0?`3oool00400oooo00<000000?ooo`3oool0503oool00`000?l0
ool00?oo000B0?oo00030000003oool0oooo04@0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`0o0?ooo`00?`3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oo`00ool001<0ool0
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo03h0oooo
000n0?ooo`030000003oool0oooo01H0oooo00<0003o0?oo003oo`00503oo`000`000000oooo0?oo
o`120?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0?@3oool003h0oooo00<00000
0?ooo`3oool05P3oool00`000?l0ool00?oo000E0?oo00030000003oool0oooo0440oooo00<00000
0?ooo`3oool0LP3oool00`000000oooo0?ooo`0m0?ooo`00?@3oool00`000000oooo0?ooo`0G0?oo
o`030000o`3oo`00ool001D0ool000<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo03`0oooo000l0?ooo`030000003oool0oooo01P0oooo00<0003o0?oo003o
o`005P3oo`000`000000oooo0?ooo`100?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool0>`3oool003`0oooo00<000000?ooo`3oool0603oool00`000?l0ool00?oo000G0?oo00030000
003oool0oooo03l0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0k0?ooo`00>`3o
ool00`000000oooo0?ooo`0I0?ooo`030000o`3oo`00ool001P0ool000<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03X0oooo000j0?ooo`030000003oool0
oooo01X0oooo00<0003o0?oo003oo`006@3oo`000`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0>@3oool003X0oooo00<000000?ooo`3oool06P3oool00`00
0?l0ool00?oo000J0?oo00030000003oool0oooo03`0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0i0?ooo`00>@3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oo`00ool001/0
ool000<000000?ooo`3oool09`3oool02P2oM00000000000B02Lgol0oooo0?oo_`1dB9`0gooo0?oo
o`2oM0020000000304RLg`3oool0oooo00D0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`0h0?ooo`00>@3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oo`00ool001/0ool000<0
00000?ooo`3oool09P3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3o
ool0oooo0=nLB01d_ol60?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0>03oool0
03P0oooo00<000000?ooo`3oool0703oool00`000?l0ool00?oo000L0?oo00030000003oool0oooo
01h0oooo00<0okmd0000000000000P0000002000B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo
1`3oool00`3o_g@0B9cO0?ooo`050?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
>03oool003P0oooo00<000000?ooo`3oool0703oool00`000?l0ool00?oo000M0?oo00030000003o
ool0oooo02@0oooo00H0gia807Boo`3oool0oooO09a8M02oool30?ooo`060?noM00007@0_ooo0?oo
o`3OW4P0M;oo1P3oool3000007P0oooo00<000000?ooo`3oool0=`3oool003L0oooo00<000000?oo
o`3oool07@3oool00`000?l0ool00?oo000N0?oo00030000003oool0oooo02<0oooo00H0gia804RL
g`3oool0oono07@0M02oool30?ooo`050?oo_`1dB4P0B00000000000M;l01`3oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo03H0oooo000f0?ooo`030000003oool0oooo01h0oooo00<0
003o0?oo003oo`007`3oo`000`000000oooo0?ooo`0R0?ooo`060?noM000B9`0gooo0?noM000B9`0
gooo0`3oool00`3ooml0W4Q809cOo`090?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0=P3oool003H0oooo00<000000?ooo`3oool07P3oool00`000?l0ool00?oo000P0?oo00030000
003oool0oooo0280oooo00@0_g@00000000004P0W=oo1@3oool01@2oM00000000000000004P0W=oo
00H0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0e0?ooo`00=@3oool00`000000
oooo0?ooo`0O0?ooo`030000o`3oo`00ool00200ool000<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`1k0?ooo`030000003oool0oooo03@0oooo000d0?ooo`030000003oool0oooo0200oooo
00<0003o0?oo003oo`008@3oo`000`000000oooo0?ooo`0e0?ooo`030000003oool0oooo07/0oooo
00<000000?ooo`3oool0=03oool003@0oooo00<000000?ooo`3oool0803oool00`000?l0ool00?oo
000R0?oo00030000003oool0oooo03@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`0c0?ooo`00<`3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oo`00ool002<0ool000<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo000c0?oo
o`030000003oool0oooo0240oooo00<0003o0?oo003oo`00903oo`000`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo07d0oooo00<000000?ooo`3oool0<P3oool003<0oooo00<000000?ooo`3o
ool08@3oool00`000?l0ool00?oo000U0?oo00030000003oool0oooo0340oooo00<000000?ooo`3o
ool0O@3oool00`000000oooo0?ooo`0b0?ooo`00<P3oool00`000000oooo0?ooo`0R0?ooo`030000
o`3oo`00ool002H0ool000<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1m0?ooo`030000
003oool0oooo0380oooo000b0?ooo`030000003oool0oooo0280oooo00<0003o0?oo003oo`009P3o
o`000`000000oooo0?ooo`0`0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0<@3o
ool00340oooo00<000000?ooo`3oool08`3oool00`000?l0ool00?oo000W0?oo00030000003oool0
oooo02l0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0`0?ooo`00<03oool00`00
0000oooo0?ooo`0T0?ooo`030000o`3oo`00ool002P0ool000<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`1o0?ooo`030000003oool0oooo0300oooo000`0?ooo`030000003oool0oooo02@0
oooo00<0003o0?oo003oo`00:@3oo`000`000000oooo0?ooo`0]0?ooo`800000P@3oool00`000000
oooo0?ooo`0_0?ooo`00<03oool00`000000oooo0?ooo`0T0?ooo`030000o`3oo`00ool002X0ool0
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo02l0oooo
000`0?ooo`030000003oool0oooo02@0oooo00<0003o0?oo003oo`00:`3oo`000`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;`3oool002l0oooo00<00000
0?ooo`3oool09@3oool00`000?l0ool00?oo000[0?oo00030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0P@3oool00`000000oooo0?ooo`0^0?ooo`00;P3oool00`000000oooo0?ooo`0V0?oo
o`030000o`3oo`00ool002`0ool000<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo02h0oooo000^0?ooo`030000003oool0oooo02H0oooo00<0003o0?oo003o
o`00;@3oo`000`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3o
ool0;@3oool002h0oooo00<000000?ooo`3oool09P3oool00`000?l0ool00?oo000^0?oo00030000
003oool0oooo02P0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`0]0?ooo`00;P3o
ool00`000000oooo0?ooo`0V0?ooo`030000o`3oo`00ool002l0ool000<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`220?ooo`030000003oool0oooo02d0oooo000]0?ooo`030000003oool0
oooo02L0oooo00<0003o0?oo003oo`00<03oo`000`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo08<0oooo00<000000?ooo`3oool0;03oool002d0oooo00<000000?ooo`3oool09`3oool00`00
0?l0ool00?oo000`0?oo00030000003oool0oooo02H0oooo00<000000?ooo`3oool0P`3oool00`00
0000oooo0?ooo`0/0?ooo`00;@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oo`00ool00340
ool000<000000?ooo`3oool09@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02`0
oooo000/0?ooo`030000003oool0oooo02P0oooo00<0003o0?oo003oo`00<P3oo`000`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0;03oool002`0oooo00<0
00000?ooo`3oool0:03oool00`000?l0ool00?oo000c0?oo00030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`0[0?ooo`00:`3oool00`000000oooo0?ooo`0Y
0?ooo`030000o`3oo`00ool003@0ool000<000000?ooo`3oool08P3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo02X0oooo000[0?ooo`030000003oool0oooo02T0oooo00<0003o0?oo
003oo`00=@3oo`000`000000oooo0?ooo`0Q0?ooo`800000QP3oool00`000000oooo0?ooo`0Z0?oo
o`00:`3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oo`00ool003H0ool000<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo02X0oooo000Z0?ooo`030000
003oool0oooo02X0oooo00<0003o0?oo003oo`00=P3oo`000`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0:P3oool002X0oooo00<000000?ooo`3oool0:P3o
ool00`000?l0ool00?oo000g0?oo00030000003oool0oooo01l0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oo`00
ool003P0ool000<000000?ooo`3oool07P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo02T0oooo000Y0?ooo`030000003oool0oooo02/0oooo00<0003o0?oo003oo`00>@3oo`000`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0:@3oool002T0
oooo00<000000?ooo`3oool0:`3oool00`000?l0ool00?oo000j0?oo00030000003oool0oooo01`0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo
0?ooo`0[0?ooo`030000o`3oo`00ool003/0ool000<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`270?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003oool0oooo02/0oooo00<0
003o0?oo003oo`00>`3oo`000`000000oooo0?ooo`0K0?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool0:`3oool00`000?l0ool00?oo000l
0?oo00030000003oool0oooo01X0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0X
0?ooo`00:@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oo`00ool003d0ool000<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo02P0oooo000X0?ooo`03
0000003oool0oooo02`0oooo00<0003o0?oo003oo`00?@3oo`000`1oogl000000?ooo`0I0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0
;03oool00`000?l0ool00?oo000l0?oo00<0Oomo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo02`0oooo00<0
003o0?oo003oo`00>`3oo`0507ooO`030000003oool0oooo01H0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`0W0?ooo`009`3oool00`000000oooo0?ooo`0]0?ooo`030000o`3oo`00
ool003X0ool01`1oogl00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool09`3oool002L0oooo00<000000?ooo`3oool0;@3oool00`000?l0ool00?oo000i0?oo
00P0Oomo00<0000007ooO`3oool05@3oool2000008X0oooo00<000000?ooo`3oool09P3oool002L0
oooo00<000000?ooo`3oool0;@3oool00`000?l0ool00?oo000h0?oo00X0Oomo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000
003oool0oooo02d0oooo00<0003o0?oo003oo`00=`3oo`0<07ooO`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?oo
o`0]0?ooo`030000o`3oo`00ool003H0ool03P1oogl00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool0;P3oool0
0`000?l0ool00?oo000f0?oo00l0Oomo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo02H0oooo000V0?ooo`030000003oool0oooo02h0oooo00<0003o0?oo
003oo`00=@3oo`0A07ooO`030000003oool0oooo0100oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oo`00ool003D0
ool04@1oogl00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool09@3oool002H0oooo00<000000?ooo`3oool0;P3oool00`000?l0ool00?oo000d0?oo01<0Oomo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0oooo
000V0?ooo`030000003oool0oooo02h0oooo00<0003o0?oo003oo`00<`3oo`0E07ooO`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0U0?ooo`009P3oool0
0`000000oooo0?ooo`0^0?ooo`030000o`3oo`00ool003<0ool05P1oogl00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool09@3oool002H0oooo00<000000?oo
o`3oool0;P3oool00`000?l0ool00?oo000b0?oo01P0Oomo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo02D0oooo000U0?ooo`030000003oool0oooo02l0
oooo00<0003o0?oo003oo`00<P3oo`0I07ooO`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0U0?ooo`009@3oool00`000000oooo0?ooo`0_0?ooo`030000
o`3oo`00ool00380ool06@1oogl00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo08/0oooo
00<000000?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0;`3oool00`000?l0ool00?oo
000a0?oo01/0Oomo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo02@0oooo000U0?ooo`050000003oool0oooO09a8M02oool0;@3oool00`000?l0ool00?oo
000a0?oo01`0Oomo00<000000?ooo`3oool02@3oool2000003l0oooo00X0_g@00000000004P0W=oo
0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`0n0?ooo`030000002LB7@0
_ooo02@0oooo000U0?ooo`050000003oool0oooO09a8M02oool0;@3oool00`000?l0ool00?oo000`
0?oo01h0Oomo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0m0?ooo`060?noM000B9`0
gooo0?noM000B9`0gooo0`3oool01P3o_g@0B9cO0?ooo`3oool0gia807Boocl0oooo00<0000009a8
M02oool0903oool001h0oooo00<0okmd0000000000000P0000001`00B9`0gooo0000003oool0oooO
09a8M02oool0;@3oool00`000?l0ool00?oo000`0?oo01l0Oomo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO
0?ooo`0=0?ooo`030?noM000M;l0oooo02h0oooo00<0000009a8M02oool0903oool002D0oooo00D0
00000?ooo`3ooml0W4Qd0;ooo`0]0?ooo`030000o`3oo`00ool00300ool07`1oogl01P1ooel00000
000000000000001d0;ooo`@0oooo00<000000?ooo`3oool0?@3oool01P3OW4P0M;oo0?ooo`3ooml0
W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol90?ooo`030?oo_`1d000000000080
000000<0001d0;ooo`3oool0;P3oool00`000000W4Qd0;ooo`0T0?ooo`009@3oool01@000000W9bo
0?oog`2LB7@0_ooo02d0oooo00<0003o0?oo003oo`00<03oo`0N07ooO`0807ooG`0j000004Q=0000
003ooml0W4P00000M02oool30?ooo`030000003oool0oooo03d0oooo00H0gia804RLg`3oool0oono
07@0M02oool30?ooo`050?oo_`1dB4P0B00000000000M;l02@3oool0203ookl0M0000018W03Oool0
_g@00000000004P0W=oo;@3oool01@3ooml0W9bo0000002LB7@0_ooo02@0oooo000U0?ooo`050000
003o_g@000000000M02oool0;@3oool00`000?l0ool00?oo000`0?oo01h0Oomo00P0Oklj00008`1=
ggl000000?ooo`3ogi`0B00007Boo`<0oooo00<000000?ooo`3oool0?@3oool01P3o_g@004RL0=oo
o`3o_g@004RL0=ooo`<0oooo00<0oooO09a8B02Lgol02`3oool0203o_g@0001809cOo`3ogi`0B4RL
0=oOW0180000B9cO;P3oool0103o_g@000000000M02ooolT0?ooo`009@3oool01@000000oooo0?oo
_`1d07@0_ooo02d0oooo00<0003o0?oo003oo`00;`3oo`0O07ooO`0806nL8`0003X0Gomo07ooO`00
0000oono07@00018W=l30?ooo`030000003oool0oooo03h0oooo00@0_g@00000000004P0W=oo1@3o
ool01@2oM00000000000000004P0W=oo00P0oooo00<0gia80000M02oool00P3oool00`3ookl0M000
04RLg`0_0?ooo`030000001d07@0_ooo02@0oooo000U0?ooo`030000003oool0oooo02l0oooo00<0
003o0?oo003oo`00;`3oo`0O07ooO`0306nL8`0003X0Gomo0080Oomo00<0000007@00018W=l00`3o
ool00`000000oooo0?ooo`1D0?ooo`030=nLB00007@0_ooo0080oooo00<0oono07@00018W=l0;`3o
ool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oo`00
ool002l0ool07`1oogl00`1o_cX0000S04gOO`0207ooO`0307oOC@000000M;oo00<0oooo00<00000
0?ooo`3oool0E03oool00`3o_g@0001809cOo`020?ooo`030?oOW0180000M;oo02l0oooo00<00000
0?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0;`3oool00`000?l0ool00?oo000_0?oo
01l0Oomo00<0OomO03X00000M5l00P1oogl00`1OM000000j000000030?ooo`030000003oool0oooo
05@0oooo00P0oono07@00000B9`0gooo0?ooo`2oM00004RL0=ooobl0oooo00<000000?ooo`3oool0
903oool002D0oooo00<000000?ooo`3oool0;`3oool00`000?l0ool00?oo000_0?oo0200Oomo00P0
OomO03X00000000000000000>P1Oogl0Oomo00000080oooo00<000000?ooo`3oool0E@3oool01P3o
okl0M00000000000000004RL0=oooc00oooo00<000000?ooo`3oool0903oool002D0oooo00<00000
0?ooo`3oool0;`3oool00`000?l0ool00?oo00070?oo0080003o9P3oo`0W07ooO`040000003oool0
oooo00000500oooo0P000?lk0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0
oooo02l0oooo00<0003o0?oo003oo`000`3oo`060000obD0ool0:@1oogl00`000000oooo0000001@
0?ooo`H0003o=`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0_0?oo
o`030000o`3oo`00003o00P0003o9P3oo`0Z07ooO`800000D@3oool90000oc<0oooo00<000000?oo
o`3oool0903oool005L00000^@000?mH00000000203oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool90000o`X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0;0?ooob/0Oomo0P00000J0?l000l0Oomo9`3oo`090000o`030?oo
00000?l0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00L0oooo000U0?ooo`030000003oool0oooo03D0oooo1P000?l90?ooo`030000003o
ool0oooo01T0oooo:`1oogl00`000000Oomo0000000I0?l000l0Oomo9P3oo`060000o`D0ool000<0
003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0i
0?ooo`80003o9@3oool[07ooO`040000001oogl0Oomo000001P0o`003`1ooglV0?oo0080003o2@3o
o`000`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0
oooo0640oooo:P1oogl010000000Oomo07ooO`00000H0?l000l0Oomo<@3oo`000`000?l0oooo0?oo
o`0_0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo02d0oooo00H0oono
07@00000000000000018W03Oool^0?ooobX0Oomo00D0000007ooO`1oogl0Oomo0000000G0?l000h0
Oomo<P3oo`000`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000
003oool0oooo02d0oooo00H0_g@00000M02oool0omnL04P00018W=l^0?ooobX0Oomo00<0000007oo
O`1oogl00P1oogl00`000000o`000?l0000D0?l000h0Oomo<P3oo`000`000?l0oooo0?ooo`0_0?oo
o`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo0300oooo00<0oono07@00018
W=l0;P3ooolZ07ooO`030000001oogl0Oomo00<0Oomo00<000000?l0003o00004`3o000>07ooOc80
ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo
0?ooo`0_0?ooo`040;md00000000001809cOobh0oooo:P1oogl00`000000Oomo07ooO`0407ooO`03
0000003o0000o`000180o`003P1ooglb0?oo00030000o`3oool0oooo02l0oooo00<000000?ooo`3o
ool0903oool002D0oooo00<000000?ooo`3oool0;@3oool0103ookl0M00000000000M;la0?ooobT0
Oomo00<0000007ooO`1oogl01@1oogl00`000000o`000?l0000@0?l000l0Oomo<P3oo`000`000?l0
oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo02d0oooo
00<0okmd0000B02Lgol0<P3ooolY07ooO`030000001oogl0Oomo00D0Oomo00<000000?l0003o0000
403o000?07ooOc80ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3o
ool00`000000oooo0?ooo`0]0?ooo`060?noM00004P0W=oo0=nLB00004P0W=oo;`3ooolY07ooO`03
0000001oogl0Oomo00H0Oomo00<000000?l0003o00003`3o000>07ooOc<0ool000<0003o0?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0^0?ooo`040;md
00000000000004RLgc00oooo:@1oogl00`000000Oomo07ooO`0707ooO`030000003o0000o`0000d0
o`003`1ooglc0?oo00030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0903oool002D0oooo
00<000000?ooo`3oool0HP3ooolY07ooO`030000001oogl0Oomo00P0Oomo00<000000?l0003o0000
303o000?07ooOc<0ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?ooo`009@3o
ool00`000000oooo0?ooo`1S0?ooobP0Oomo00<0000007ooO`1oogl02@1oogl00`000000o`000?l0
000:0?l00100Oomo<`3oo`000`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo02@0oooo000U
0?ooo`030000003oool0oooo06<0oooo:01oogl00`000000Oomo07ooO`0:07ooO`030000003o0000
o`0000P0o`004@1ooglc0?oo00030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0903oool0
02D0oooo00<000000?ooo`3oool0H`3ooolX07ooO`030000001oogl0Oomo00/0Oomo00<000000?l0
003o00001`3o000@07ooOc@0ool000<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`0T0?oo
o`009@3oool00`000000oooo0?ooo`1T0?ooobL0Oomo00<0000007ooO`1oogl02`1oogl00`000000
o`000?l000060?l00140Oomo=03oo`000`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo02D0
oooo000V0?ooo`030000003oool0oooo06<0oooo9`1oogl00`000000Oomo07ooO`0<07ooO`030000
003o0000o`0000D0o`00401oogle0?oo00030000o`3oool0oooo02h0oooo00<000000?ooo`3oool0
9@3oool002H0oooo00<000000?ooo`3oool0I03ooolV07ooO`030000001oogl0Oomo00d0Oomo00<0
00000?l0003o00000`3o000A07ooOcD0ool000<0003o0?ooo`3oool0;P3oool00`000000oooo0?oo
o`0U0?ooo`009P3oool00`000000oooo0?ooo`1U0?ooobD0Oomo00<0000007ooO`1oogl03P1oogl0
10000000o`000?l0003o000A07ooOcH0ool000<0003o0?ooo`3oool0;P3oool00`000000oooo0?oo
o`0U0?ooo`009P3oool00`000000oooo0?ooo`1U0?ooobD0Oomo00<0000007ooO`1oogl03`1oogl0
0`000000o`0007ooO`0@07ooOcL0ool000<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0U
0?ooo`009P3oool00`000000oooo0?ooo`1V0?ooob@0Oomo00<0000007ooO`1oogl0401oogl00`00
0000Oomo07ooO`0?07ooOcL0ool000<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0U0?oo
o`009P3oool00`000000oooo0?ooo`1V0?ooob@0Oomo00<0000007ooO`1oogl0401oogl00`000000
Oomo07ooO`0>07ooOcP0ool000<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0U0?ooo`00
9P3oool00`000000oooo0?ooo`1W0?ooob<0Oomo00<0000007ooO`1oogl04@1oogl00`000000Oomo
07ooO`0=07ooOcP0ool000<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`009`3o
ool00`000000oooo0?ooo`1W0?ooob80Oomo00<0000007ooO`1oogl04P1oogl00`000000Oomo07oo
O`0;07ooOcT0ool000<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`009`3oool0
0`000000oooo0?ooo`1X0?ooob40Oomo00<0000007ooO`1oogl04`1oogl00`000000Oomo07ooO`09
07ooOcX0ool000<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`00
0000oooo0?ooo`1X0?ooob40Oomo00<0000007ooO`1oogl0501oogl00`000000Oomo07ooO`0707oo
Oc/0ool000<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000
oooo0?ooo`1Y0?ooob00Oomo00<0000007ooO`1oogl05@1oogl00`000000Oomo07ooO`0507ooOc`0
ool000<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`0V0?ooo`009`3oool00`000000oooo
0?ooo`1Z0?oooal0Oomo00<0000007ooO`1oogl05@1oogl00`000000Oomo07ooO`0407ooOcd0ool0
00<0003o0?ooo`3oool0;03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?oo
o`1Z0?oooah0Oomo00<0000007ooO`1oogl05P1oogl00`000000Oomo07ooO`0207ooOch0ool000<0
003o0?ooo`3oool0;03oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`1[
0?oooad0Oomo00<0000007ooO`1oogl05`1oogl00`000000Oomo07ooO`0o0?oo00030000o`3oool0
oooo02`0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool0K03ooolL07oo
O`030000001oogl0Oomo01P0Oomo00<000000?oo003oo`00?P3oo`000`000?l0oooo0?ooo`0/0?oo
o`030000003oool0oooo02L0oooo000Y0?ooo`030000003oool0oooo06`0oooo6`1oogl00`000000
Oomo07ooO`0H07ooO`030?ooo`000000ool003h0ool000<0003o0?ooo`3oool0:`3oool00`000000
oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`1]0?oooaX0Oomo00<0000007ooO`1oogl0
5`1oogl30?ooo`030000003oo`00ool003`0ool000<0003o0?ooo`3oool0:`3oool00`000000oooo
0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`1^0?oooaT0Oomo00<0000007ooO`1oogl05P1o
ogl50?ooo`030000003oo`00ool003/0ool000<0003o0?ooo`3oool0:`3oool00`000000oooo0?oo
o`0X0?ooo`00:@3oool00`000000oooo0?ooo`1`0?oooaL0Oomo00<0000007ooO`1oogl0501oogl7
0?ooo`030000003oo`00ool003/0ool000<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0X
0?ooo`00:@3oool00`000000oooo0?ooo`1b0?oooaD0Oomo00<0000007ooO`1oogl04P1oogl:0?oo
o`030000003oo`00ool003X0ool000<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`0X0?oo
o`00:@3oool00`000000oooo0?ooo`1c0?oooa@0Oomo00<0000007ooO`1oogl04@1oogl<0?ooo`03
0000003oo`00ool003T0ool000<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`00
:P3oool00`000000oooo0?ooo`1d0?oooa80Oomo00<0000007ooO`1oogl03`1oogl?0?ooo`030000
003oo`00ool003P0ool000<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`00:P3o
ool00`000000oooo0?ooo`1f0?oooa00Oomo00<0000007ooO`1oogl03@1ooglB0?ooo`030000003o
o`00ool003L0ool000<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0Y0?ooo`00:P3oool0
0`000000oooo0?ooo`1i0?ooo`d0Oomo00<0000007ooO`1oogl02P1ooglF0?ooo`030000003oo`00
ool003H0ool000<0003o0?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`00
0000oooo0?ooo`1m0?ooo`P0Oomo00<0000007ooO`1oogl01@1ooglK0?ooo`030000003oo`00ool0
03H0ool000<0003o0?ooo`3oool0:@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3oool00`000000
oooo0?ooo`220?ooo`<0Oomo00<0000007ooO`1oogl08@3oool00`000000ool00?oo000e0?oo0003
0000o`3oool0oooo02T0oooo00<000000?ooo`3oool0:P3oool002/0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0R0?ooo`030000003oo`00ool003@0ool000<0003o0?ooo`3oool0
:@3oool00`000000oooo0?ooo`0Z0?ooo`00;03oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo02<0oooo00<000000?oo003oo`00<`3oo`000`000?l0oooo0?ooo`0X0?ooo`030000003o
ool0oooo02/0oooo000/0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0903oool0
0`000000ool00?oo000b0?oo00030000o`3oool0oooo02L0oooo00<000000?ooo`3oool0;03oool0
02d0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0U0?ooo`030000003oo`00ool0
0340ool000<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`0/0?ooo`00;@3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo02H0oooo00<000000?oo003oo`00<03oo`000`000?l0
oooo0?ooo`0W0?ooo`030000003oool0oooo02`0oooo000]0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool09P3oool00`000000ool00?oo000`0?oo00030000o`3oool0oooo02L0oooo
00<000000?ooo`3oool0;03oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?oo
o`0W0?ooo`030000003oo`00ool002l0ool000<0003o0?ooo`3oool09P3oool00`000000oooo0?oo
o`0]0?ooo`00;P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo02P0oooo00<00000
0?oo003oo`00;P3oo`000`000?l0oooo0?ooo`0V0?ooo`030000003oool0oooo02d0oooo000^0?oo
o`030000003oool0oooo0880oooo00<000000?ooo`3oool0:@3oool00`000000ool00?oo000]0?oo
00030000o`3oool0oooo02H0oooo00<000000?ooo`3oool0;@3oool002h0oooo00<000000?ooo`3o
ool0PP3oool00`000000oooo0?ooo`0Z0?ooo`030000003oo`00ool002`0ool000<0003o0?ooo`3o
ool09@3oool00`000000oooo0?ooo`0^0?ooo`00;`3oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo02/0oooo00<000000?oo003oo`00:`3oo`000`000?l0oooo0?ooo`0U0?ooo`030000
003oool0oooo02h0oooo000`0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0:`3o
ool00`000000ool00?oo000[0?oo00030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0;`3o
ool00300oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0/0?ooo`030000003oo`00
ool002X0ool000<0003o0?ooo`3oool0903oool00`000000oooo0?ooo`0_0?ooo`00<03oool00`00
0000oooo0?ooo`200?ooo`800000;P3oool00`000000ool00?oo000Y0?oo00030000o`3oool0oooo
02@0oooo00<000000?ooo`3oool0;`3oool00300oooo00<000000?ooo`3oool0P03oool00`000000
oooo0?ooo`0^0?ooo`030000003oo`00ool002P0ool000<0003o0?ooo`3oool08`3oool00`000000
oooo0?ooo`0`0?ooo`00<@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02l0oooo
00<000000?oo003oo`009`3oo`000`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo0300oooo
000b0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0<03oool00`000000ool00?oo
000V0?oo00030000o`3oool0oooo0280oooo00<000000?ooo`3oool0<@3oool00380oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`0`0?ooo`030000003oo`00ool002H0ool000<0003o
0?ooo`3oool08@3oool00`000000oooo0?ooo`0b0?ooo`00<`3oool00`000000oooo0?ooo`1m0?oo
o`030000003oool0oooo0340oooo00<000000?oo003oo`009@3oo`000`000?l0oooo0?ooo`0Q0?oo
o`030000003oool0oooo0380oooo000c0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool0<P3oool00`000000ool00?oo000T0?oo00030000o`3oool0oooo0240oooo00<000000?ooo`3o
ool0<P3oool003<0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0c0?ooo`030000
003oo`00ool002<0ool000<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0c0?ooo`00=03o
ool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03@0oooo00<000000?oo003oo`008P3o
o`000`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo03<0oooo000d0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool0=@3oool00`000000ool00?oo000Q0?oo00030000o`3oool0
oooo01l0oooo00<000000?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool0N`3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oo`00ool00200ool000<0003o0?ooo`3oool07`3oool00`00
0000oooo0?ooo`0d0?ooo`00=P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03H0
oooo00<000000?oo003oo`00803oo`000`000?l0oooo0?ooo`0N0?ooo`030000003oool0oooo03D0
oooo000f0?ooo`030000003oool0oooo06H0oooo00X0_g@00000000004P0W=oo0?ooo`3ookl0M4RL
0=ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`050?ooo`030000003oool0oooo03L0oooo00<0
00000?oo003oo`007`3oo`000`000?l0oooo0?ooo`0M0?ooo`030000003oool0oooo03H0oooo000g
0?ooo`030000003oool0oooo06@0oooo00H0okmd0018W03Oool0okmd0018W03Oool30?ooo`060?no
M018W=l0oooo0?ooo`3OW4P0M;oo1P3oool00`000000oooo0?ooo`0h0?ooo`030000003oo`00ool0
01h0ool000<0003o0?ooo`3oool07@3oool00`000000oooo0?ooo`0f0?ooo`00>03oool00`000000
oooo0?ooo`1S0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?ooo`05
0?ooo`<00000>@3oool00`000000ool00?oo000M0?oo00030000o`3oool0oooo01`0oooo00<00000
0?ooo`3oool0=`3oool003P0oooo00<000000?ooo`3oool0H`3oool01P3OW4P0M;oo0?ooo`3ooml0
W4Qd0;ooo`<0oooo00H0okmd0000M02oool0oooo0=nLB01d_ol60?ooo`030000003oool0oooo03X0
oooo00<000000?oo003oo`00703oo`000`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo03P0
oooo000i0?ooo`030000003oool0oooo0680oooo00H0gia804RLg`3oool0oono07@0M02oool30?oo
o`050?oo_`1dB4P0B00000000000M;l01`3oool00`000000oooo0?ooo`0k0?ooo`030000003oo`00
ool001/0ool000<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`0h0?ooo`00>@3oool00`00
0000oooo0?ooo`1R0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cO
o`090?ooo`030000003oool0oooo03/0oooo00<000000?oo003oo`006`3oo`000`000?l0oooo0?oo
o`0K0?ooo`030000003oool0oooo03P0oooo000j0?ooo`030000003oool0oooo0680oooo00@0_g@0
0000000004P0W=oo1@3oool01@2oM00000000000000004P0W=oo00H0oooo00<000000?ooo`3oool0
?03oool00`000000ool00?oo000J0?oo00030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0
>@3oool003X0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0m0?ooo`030000003o
o`00ool001T0ool000<0003o0?ooo`3oool06P3oool00`000000oooo0?ooo`0i0?ooo`00>`3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03h0oooo00<000000?oo003oo`00603oo`00
0`000?l0oooo0?ooo`0I0?ooo`030000003oool0oooo03X0oooo000l0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool0?`3oool00`000000ool00?oo000G0?oo00030000o`3oool0oooo
01P0oooo00<000000?ooo`3oool0>`3oool003`0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`100?ooo`030000003oo`00ool001H0ool000<0003o0?ooo`3oool0603oool00`000000
oooo0?ooo`0k0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0440oooo
00<000000?oo003oo`005@3oo`000`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo03`0oooo
000n0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0@@3oool00`000000ool00?oo
000E0?oo00030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0?@3oool003h0oooo00<00000
0?ooo`3oool0LP3oool00`000000oooo0?ooo`120?ooo`030000003oo`00ool001@0ool000<0003o
0?ooo`3oool05P3oool00`000000oooo0?ooo`0m0?ooo`00?`3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo04<0oooo00<000000?oo003oo`004`3oo`000`000?l0oooo0?ooo`0E0?oo
o`030000003oool0oooo03h0oooo00100?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0A03oool00`000000ool00?oo000B0?oo00030000o`3oool0oooo01@0oooo00<000000?ooo`3o
ool0?`3oool00400oooo00<000000?ooo`3oool0L03oool2000004H0oooo00<000000?oo003oo`00
4@3oo`000`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo03l0oooo00110?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0AP3oool00`000000ool00?oo000@0?oo00030000o`3o
ool0oooo01<0oooo00<000000?ooo`3oool0@03oool00480oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`160?ooo`030000003oo`00ool00100ool000<0003o0?ooo`3oool04P3oool0
0`000000oooo0?ooo`110?ooo`00@`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
04L0oooo00<000000?oo003oo`003`3oo`000`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo
0480oooo00140?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0B03oool00`000000
ool00?oo000>0?oo00030000o`3oool0oooo0100oooo00<000000?ooo`3oool0@`3oool004D0oooo
00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`190?ooo`030000003oo`00ool000d0ool0
00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`140?ooo`00A@3oool00`000000oooo0?oo
o`1[0?ooo`030000003oool0oooo04X0oooo00<000000?oo003oo`00303oo`000`000?l0oooo0?oo
o`0?0?ooo`030000003oool0oooo04@0oooo00160?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool0B`3oool00`000000ool00?oo000;0?oo00030000o`3oool0oooo00h0oooo00<00000
0?ooo`3oool0A@3oool004L0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1;0?oo
o`030000003oo`00ool000/0ool000<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`160?oo
o`00B03oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo04`0oooo00<000000?oo003o
o`002P3oo`000`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo04L0oooo00190?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool0C@3oool00`000000ool00?oo00090?oo00030000
o`3oool0oooo00/0oooo00<000000?ooo`3oool0B03oool004X0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`1>0?ooo`030000003oo`00ool000P0ool000<0003o0?ooo`3oool02P3o
ool00`000000oooo0?ooo`190?ooo`00B`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo04l0oooo00<000000?oo003oo`001`3oo`000`000?l0oooo0?ooo`090?ooo`030000003oool0
oooo04X0oooo001<0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0D03oool00`00
0000ool00?oo00030?oo0080003o00@0ool00000o`3oool0003o203oool00`000000oooo0?ooo`1;
0?ooo`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0540oooo00<000000?oo
003oo`000P3oo`060000o`L0oooo00<000000?ooo`3oool0C03oool004h0oooo00<000000?ooo`3o
ool0HP3oool200000580oooo00<000000?oo003oo`000`3oo`050000o`H0oooo00<000000?ooo`3o
ool0C@3oool004l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1B0?ooo`030000
003oo`00ool00080ool010000?l60?ooo`030000003oool0oooo04h0oooo001@0?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool0D`3oool010000000ool00?oo003oo`040000o`D0oooo
00<000000?ooo`3oool0C`3oool00540oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`1D0?ooo`030000003oo`00ool000@0003o103oool00`000000oooo0?ooo`1@0?ooo`00DP3oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo05D0oooo00<000000?oo003oo`000`000?l3
0?ooo`030000003oool0oooo0540oooo001C0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool0EP3oool00`000000ool00000o`020000o`80oooo00<000000?ooo`3oool0DP3oool005@0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1F0?ooo`030000003oo`00003o0080
003o00<0oooo0000003oool0E03oool005D0oooo00<000000?ooo`3oool0F`3oool00`000000oooo
0?ooo`1G0?ooo`05000000000?l0003o0?ooo`000000EP3oool005H0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`1H0?ooo`03000000000?l0000005L0oooo001G0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`1F0?ooo`00F03oool2
000005T0oooo00<000000?ooo`3oool0E`3oool2000005T0oooo001J0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1I0?ooo`00F`3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0FP3oool005`0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05/0oooo
001M0?ooo`030000003oool0oooo05<0oooo0P00001D0?ooo`050000003oool0oono07@00018W=l0
FP3oool005h0oooo0P00001C0?ooo`030000003oool0oooo0540oooo0P0000020?ooo`030?oo_`1d
0000B9cO05X0oooo001P0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`020?ooo`030?oo_`1d0000B9cO05X0oooo001Q0?ooo`800000D03oool00`00
0000oooo0?ooo`1>0?ooo`8000001@3oool00`3ookl0M0000000000200000003001d_`3oool0oooo
05D0oooo001S0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`050?ooo`070?oo_`1d0000B9cO0?ooo`3ogi`0B00004RLg`1F0?ooo`00I03oool20000
04d0oooo00<000000?ooo`3oool0B`3oool2000000P0oooo00L0oono07@00018W=l0oooo0?oo_`1d
000007Bo05H0oooo001V0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`080?ooo`070?oo_`1d0000B9cO0?ooo`3ogi`0B00004RLg`1F0?ooo`00I`3o
ool2000004X0oooo00<000000?ooo`3oool0B03oool2000000/0oooo00<0oono07@0000000000P00
00000`00B9`0gooo0?ooo`1E0?ooo`00J@3oool2000004P0oooo00<000000?ooo`3oool0AP3oool2
000006X0oooo001[0?ooo`800000AP3oool00`000000oooo0?ooo`140?ooo`800000K03oool006d0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo06`0
oooo001^0?ooo`800000@`3oool00`000000oooo0?ooo`110?ooo`800000K`3oool00700oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo06l0oooo001a
0?ooo`800000@03oool00`000000oooo0?ooo`0n0?ooo`800000LP3oool007<0oooo0`00000m0?oo
o`800000?03oool3000007@0oooo001f0?ooo`800000>`3oool00`000000oooo0?ooo`0i0?ooo`80
0000M`3oool007P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo07L0oooo001i0?ooo`@00000=P3oool00`000000oooo0?ooo`0d0?ooo`@00000NP3o
ool007d0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo07`0oooo001n0?ooo`@00000<@3oool00`000000oooo0?ooo`0_0?ooo`@00000O`3oool00880
oooo0`00000^0?ooo`030000003oool0oooo02`0oooo0`0000230?ooo`00Q@3oool2000002`0oooo
00<000000?ooo`3oool0:P3oool2000008H0oooo00270?ooo`<00000:@3oool00`000000oooo0?oo
o`0W0?ooo`<00000R03oool008X0oooo0`00000V0?ooo`030000003oool0oooo02@0oooo0`00002;
0?ooo`00S@3oool600000200oooo00<000000?ooo`3oool07P3oool6000008h0oooo002C0?ooo`<0
00007@3oool00`000000oooo0?ooo`0K0?ooo`<00000U03oool009H0oooo1@00000=0?ooo`030?oo
g`2LB7@0_ooo00P0oooo00<000000?ooo`3oool05P3oool5000009L0oooo002K0?ooo`L000001P3o
ool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo00l0oooo1`00002L0?ooo`00XP3ooolS
00000:<0oooo002X0?ooo`030?oog`2LB7@0_ooo00P0oooo00<000000?ooo`3oool0/P3oool00:H0
oooo00D0oooO09bL_`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo0;80oooo002W0?ooo`04
0?noM0000000001d0;ooo`P0oooo00<000000?ooo`3oool0/P3oool00:P0oooo00<0oono07@0M02o
ool0203oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`00
0000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c
0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`03
0000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003o
ool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0001\
\>"],
  ImageRangeCache->{{{100.063, 300.625}, {474.188, 273.625}} -> {-2.51728, \
2.17803, 0.00879536, 0.00879536}},
  CellTags->"figura8"],

Cell[TextData[{
  "\[CapitalEGrave] evidente che i triangoli rettangoli ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[EmptyUpTriangle]", 
            StyleBox["OQP",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[EmptyUpTriangle]", 
            StyleBox["OSR",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " sono congruenti (",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[Angle]", 
              StyleBox["ROS",
                FontSlant->"Italic"]}]], "=", 
          StyleBox[
            RowBox[{"\[Angle]", 
              StyleBox["POQ",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ") ma che ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OS",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          RowBox[{
            StyleBox["-",
              FontSlant->"Plain"], 
            StyleBox["OQ",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["SR",
            FontSlant->"Italic"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          RowBox[{
            StyleBox["-",
              FontSlant->"Plain"], 
            StyleBox["QP",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  ". Pertanto la tangente dell'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] + \[Pi]\)]],
  " che, per definizione, \[EGrave]"
}], "Text"],

Cell[BoxData[
    \(tg \((\[Alpha] + \[Pi])\) = SR\/OS\)], "DisplayFormula"],

Cell["si pu\[OGrave] riscrivere come", "Text"],

Cell[BoxData[
    \(tg \((\[Alpha] + \[Pi])\) = \(SR\/OS = \(\((\(-QP\))\)\/\((\(-OQ\))\) = \
\(QP\/OQ = tg \((\[Alpha])\)\)\)\)\)], "DisplayFormula",
  CellTags->"dimpertan"],

Cell[TextData[{
  "Poich\[EAcute] tale relazione rimane valida qualsiasi sia l'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " potremo studiare la funzione tangente per valori appartenenti \
all'intervallo aperto ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(]\)\(-\)\(\[Pi]\/2\)\), \
\(\(\[Pi]\/2\)\([\)\)\)]],
  " e poi estenderla, in base ad essa, in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(]\)\(\ \)\(\[Pi]\/2\)\), \(3\/2\) \(\(\[Pi]\)\([\
\)\)\)]],
  ". Ma pi\[UGrave] importante appaiono due osservazioni: "
}], "Text"],

Cell[TextData[{
  "la prima consiste nel tener conto che ad ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " e agli angoli che differiscono da esso per multipli pari di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] + 2\ k\ \[Pi]\)]],
  ", si pu\[OGrave] associare la medesima configurazione (e ci\[OGrave], come \
oramai sappiamo, equivale a ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " rotazioni complete attorno all'origine) per cui, di conseguenza, risulta \
",
  Cell[BoxData[
      \(TraditionalForm\`tg(\[Alpha]) = tg(\[Alpha] + 2\ k\ \[Pi])\)]],
  "."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{50, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "Seconda osservazione: a ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] + \[Pi]\)]],
  " si possono associare i valori ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Alpha] + \[Pi])\) + 
          2\ k\ \[Pi] = \[Alpha] + \((2  k + 1)\) \[Pi]\)]],
  " tali da differire da ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " per multipli ",
  StyleBox["dispari",
    FontSlant->"Italic"],
  " di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  " (difatti ",
  Cell[BoxData[
      \(TraditionalForm\`2  k + 1\)]],
  "\[EGrave] un numero dispari se ",
  Cell[BoxData[
      \(TraditionalForm\`k \[Element] \[DoubleStruckCapitalZ]\)]],
  ") e pure questi, per quanto dimostrato ",
  ButtonBox["sopra",
    ButtonData:>"dimpertan",
    ButtonStyle->"Hyperlink"],
  ", conducono ad una configurazione geometrica che fornisce lo stesso valore \
della tangente."
}], "Text",
  CellDingbat->"\[FilledSmallCircle]",
  CellMargins->{{50, Inherited}, {Inherited, Inherited}}],

Cell[TextData[{
  "In definitiva qualsiasi sia il multiplo di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  " (pari o dispari) che lega ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " con ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] + k\ \[Pi]\)]],
  ", risulta valida l'identit\[AGrave]   "
}], "Text"],

Cell[BoxData[
    \(tg \((\[Alpha])\) = 
      tg \((\[Alpha] + 
              k\ \[Pi])\)\ \ \ \ \ \ \ \ \(\[ForAll] \[Alpha] \[Element] \
\[DoubleStruckCapitalR] - {\[Pi]\/2 + k\ \[Pi]}\) \[And] 
        k \[Element] \(\(\[DoubleStruckCapitalZ]\)\(.\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "Quest'ultima indentit\[AGrave] stabilisce la periodicit\[AGrave] della \
funzione tangente che pertanto, diversamente dal seno e coseno, possiede un \
periodo ",
  Cell[BoxData[
      \(TraditionalForm\`T = \[Pi]\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico della funzione tangente", "Section"],

Cell[TextData[{
  "Per lo studio del grafico della tangente in funzione di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " manca ancora un elemento che ci permetter\[AGrave] di disporre di un \
significato pi\[UGrave] intuitivo e diretto del rapporto dato nella ",
  ButtonBox["definizione",
    ButtonData:>"deftangente",
    ButtonStyle->"Hyperlink"],
  ". Costruiamo a tale scopo la retta tangente nel punto ",
  Cell[BoxData[
      \(TraditionalForm\`A(1, 0)\)]],
  " alla circonferenza goniometrica (",
  ButtonBox["fig. 9",
    ButtonData:>"figura9",
    ButtonStyle->"Hyperlink"],
  ") e prolunghiamo il secondo lato dell'angolo fino ad intersecare questa \
retta. Sia ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " il loro punto di intersezione. "
}], "Text"],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(\(\[Alpha] = 50  Degree;\)\), "\n", 
    \(pP = {Cos[\[Alpha]], Sin[\[Alpha]]}; pQ = {Cos[\[Alpha]], 0}; 
    origine = {0, 0}; pA = {1, 0}; pB = {1, Tan[\[Alpha]]};\), "\n", 
    \(\(Show[
        Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
            Line[{{0, \(-1.2\)}, {0, 1.2}}], Line[{pB, origine}], 
            Line[{{1, \(-1.4\)}, {1, 
                  1.4}}]}], \[IndentingNewLine]Graphics[{colBlu, 
            Arrow[pA, pB, stileVet], Arrow[origine, pA, stileVet], 
            Arrow[origine, pQ, stileVet], 
            Arrow[pQ, pP, 
              stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
              origine, {1, 1}, TextStyle \[Rule] stileTesto], 
            Text["\<Q\>", pQ, {0, 1}, TextStyle \[Rule] stileTesto], 
            Text["\<P\>", pP, {0, \(-1\)}, TextStyle \[Rule] stileTesto], 
            Text["\<B\>", pB, {\(-1\), 0}, TextStyle \[Rule] stileTesto], 
            Text["\<A\>", pA, {\(-1\), 1}, TextStyle \[Rule] stileTesto]}], 
        Prolog -> {{RGBColor[ .85, \  .65, \ 0], 
              Polygon[{origine, pA, pB}]}, {colGiallo, 
              Polygon[{origine, pQ, pP}]}, {colRosso, 
              Disk[origine,  .2, {0, \[Alpha]}]}}, 
        AspectRatio \[Rule] Automatic, Axes \[Rule] True];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.16667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 0.583333 0.396825 [
[.10317 .57083 -6.96875 -10.9375 ]
[.10317 .57083 6.96875 0 ]
[.30159 .57083 -10.3125 -10.9375 ]
[.30159 .57083 10.3125 0 ]
[.69841 .57083 -7.5625 -10.9375 ]
[.69841 .57083 7.5625 0 ]
[.89683 .57083 -4.21875 -10.9375 ]
[.89683 .57083 4.21875 0 ]
[.4875 .18651 -13.9375 -5.46875 ]
[.4875 .18651 0 5.46875 ]
[.4875 .38492 -20.625 -5.46875 ]
[.4875 .38492 0 5.46875 ]
[.4875 .78175 -15.125 -5.46875 ]
[.4875 .78175 0 5.46875 ]
[.4875 .98016 -8.4375 -5.46875 ]
[.4875 .98016 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1.16667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .58333 m
.10317 .58958 L
s
gsave
.10317 .57083 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 .58333 m
.30159 .58958 L
s
gsave
.30159 .57083 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 .58333 m
.69841 .58958 L
s
gsave
.69841 .57083 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 .58333 m
.89683 .58958 L
s
gsave
.89683 .57083 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 .58333 m
.14286 .58708 L
s
.18254 .58333 m
.18254 .58708 L
s
.22222 .58333 m
.22222 .58708 L
s
.2619 .58333 m
.2619 .58708 L
s
.34127 .58333 m
.34127 .58708 L
s
.38095 .58333 m
.38095 .58708 L
s
.42063 .58333 m
.42063 .58708 L
s
.46032 .58333 m
.46032 .58708 L
s
.53968 .58333 m
.53968 .58708 L
s
.57937 .58333 m
.57937 .58708 L
s
.61905 .58333 m
.61905 .58708 L
s
.65873 .58333 m
.65873 .58708 L
s
.7381 .58333 m
.7381 .58708 L
s
.77778 .58333 m
.77778 .58708 L
s
.81746 .58333 m
.81746 .58708 L
s
.85714 .58333 m
.85714 .58708 L
s
.06349 .58333 m
.06349 .58708 L
s
.02381 .58333 m
.02381 .58708 L
s
.93651 .58333 m
.93651 .58708 L
s
.97619 .58333 m
.97619 .58708 L
s
.25 Mabswid
0 .58333 m
1 .58333 L
s
.5 .18651 m
.50625 .18651 L
s
gsave
.4875 .18651 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .38492 m
.50625 .38492 L
s
gsave
.4875 .38492 -81.625 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .78175 m
.50625 .78175 L
s
gsave
.4875 .78175 -76.125 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .98016 m
.50625 .98016 L
s
gsave
.4875 .98016 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .22619 m
.50375 .22619 L
s
.5 .26587 m
.50375 .26587 L
s
.5 .30556 m
.50375 .30556 L
s
.5 .34524 m
.50375 .34524 L
s
.5 .4246 m
.50375 .4246 L
s
.5 .46429 m
.50375 .46429 L
s
.5 .50397 m
.50375 .50397 L
s
.5 .54365 m
.50375 .54365 L
s
.5 .62302 m
.50375 .62302 L
s
.5 .6627 m
.50375 .6627 L
s
.5 .70238 m
.50375 .70238 L
s
.5 .74206 m
.50375 .74206 L
s
.5 .82143 m
.50375 .82143 L
s
.5 .86111 m
.50375 .86111 L
s
.5 .90079 m
.50375 .90079 L
s
.5 .94048 m
.50375 .94048 L
s
.5 .14683 m
.50375 .14683 L
s
.5 .10714 m
.50375 .10714 L
s
.5 .06746 m
.50375 .06746 L
s
.5 .02778 m
.50375 .02778 L
s
.5 1.01984 m
.50375 1.01984 L
s
.5 1.05952 m
.50375 1.05952 L
s
.5 1.09921 m
.50375 1.09921 L
s
.5 1.13889 m
.50375 1.13889 L
s
.25 Mabswid
.5 0 m
.5 1.16667 L
s
0 0 m
1 0 L
1 1.16667 L
0 1.16667 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.85 .65 0 r
.5 .58333 m
.89683 .58333 L
.89683 1.05625 L
F
1 1 0 r
.5 .58333 m
.75507 .58333 L
.75507 .88732 L
F
1 0 0 r
.5 .58333 m
.5 .58333 .07937 0 50 arc
F
0 g
.5 Mabswid
newpath
.5 .58333 .39683 0 365.73 arc
s
.02381 .58333 m
.97619 .58333 L
s
.5 .10714 m
.5 1.05952 L
s
.89683 1.05625 m
.5 .58333 L
s
.89683 .02778 m
.89683 1.13889 L
s
0 0 1 r
.89683 .58333 m
.89683 1.05625 L
s
% Start of user PostScript
1. 0 1. 1.19175 MAarrowhead1
% End of user PostScript
.5 .58333 m
.89683 .58333 L
s
% Start of user PostScript
0 0 1. 0 MAarrowhead1
% End of user PostScript
.5 .58333 m
.75507 .58333 L
s
% Start of user PostScript
0 0 0.642788 0 MAarrowhead1
% End of user PostScript
.75507 .58333 m
.75507 .88732 L
s
% Start of user PostScript
0.642788 0 0.642788 0.766044 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 .58333 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .58333 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.75507 .88732 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.89683 1.05625 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
69.438 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.89683 .58333 -61 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.375 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "NumberedFigure",
  ImageSize->{288, 336},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Y2000`400?l00000o`00003oo`3ooomY
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool2000008`0oooo00<000000?oo
o`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00
/`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo002c0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
02@0oooo002c0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool00;<0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo02@0oooo002c0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?oo
o`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo002c0?ooo`030000
003oool0oooo08/0oooo00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0?ooo`0T0?ooo`00/`3oool2000008`0oooo00<000000?ooo`3oool0903oool0
0;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo002c0?ooo`030000003oool0oooo08/0oooo
00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo002c0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000
003oool0oooo02@0oooo002c0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903o
ool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo002c0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0T0?ooo`00/`3oool2000008`0oooo00<000000?ooo`3oool0903oool00;<0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo02@0oooo002c0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3o
ool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo002c0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0
oooo002c0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool00;<0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo02@0oooo002c0?ooo`030000003oool0oooo08/0oooo00<000000?oo
o`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00
/`3oool2000008`0oooo00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo02@0oooo002c0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool00;<0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo02@0oooo002c0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T
0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo002c0?ooo`03
0000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo02@0oooo002X0?ooo`030?oog`2LB7@0_ooo00P0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`0T0?ooo`00Z03oool00`3ooml0W4Qd0;ooo`080?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0903oool00:00oooo00<0okmd0000000000000P0000001P00B9`0
gooo0?ooo`3ooml0W4Qd0;ooo`P0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T
0?ooo`00X`3ooolQ000007d0oooo00<000000?ooo`3oool0903oool009`0oooo1`0000030?ooo`05
0?oog`2LW;l0oooO09a8M02oool0203oool00`000000oooo0?ooo`0>0?ooo`L00000MP3oool00`00
0000oooo0?ooo`0T0?ooo`00U`3oool5000000/0oooo00@0okmd0000000007@0_ooo203oool00`00
0000oooo0?ooo`0E0?ooo`D00000L@3oool00`000000oooo0?ooo`0T0?ooo`00T`3oool400000140
oooo00<0oono07@0M02oool0203oool00`000000oooo0?ooo`0J0?ooo`@00000K@3oool00`000000
oooo0?ooo`0T0?ooo`00SP3oool500000200oooo00<000000?ooo`3oool07P3oool5000006P0oooo
00<000000?ooo`3oool0903oool008/0oooo0`00000U0?ooo`030000003oool0oooo02<0oooo0`00
001U0?ooo`030000003oool0oooo02@0oooo00270?ooo`@00000:03oool00`000000oooo0?ooo`0V
0?ooo`@00000H@3oool00`000000oooo0?ooo`0T0?ooo`00QP3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0T0?oo
o`00PP3oool4000002d0oooo00<000000?ooo`3oool0:`3oool4000005`0oooo00<000000?ooo`3o
ool0903oool007l0oooo0`00000a0?ooo`030000003oool0oooo02l0oooo0`00001I0?ooo`030000
003oool0oooo02@0oooo001m0?ooo`800000=03oool00`000000oooo0?ooo`0b0?ooo`800000E`3o
ool00`000000oooo0?ooo`0T0?ooo`00NP3oool3000003H0oooo00<000000?ooo`3oool0=03oool3
000005@0oooo00<000000?ooo`3oool0903oool007P0oooo0P00000i0?ooo`030000003oool0oooo
03L0oooo0P00001B0?ooo`030000003oool0oooo02@0oooo001g0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02@0
oooo001d0?ooo`<00000?03oool2000003/0oooo0`00001>0?ooo`030000003oool0oooo02@0oooo
001b0?ooo`800000?`3oool00`000000oooo0?ooo`0m0?ooo`800000C03oool00`000000oooo0?oo
o`0T0?ooo`00L03oool200000440oooo00<000000?ooo`3oool0?`3oool2000004X0oooo00<00000
0?ooo`3oool0903oool006l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0903oool006d0oooo0P0000140?ooo`03
0000003oool0oooo0480oooo0P0000170?ooo`030000003oool0oooo02@0oooo001/0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo02@0oooo001Y0?ooo`<00000A`3oool00`000000oooo0?ooo`150?ooo`<00000@`3o
ool00`000000oooo0?ooo`0T0?ooo`00I`3oool2000004X0oooo00<000000?ooo`3oool0B03oool2
00000440oooo00<000000?ooo`3oool0903oool006H0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0903oool006@0
oooo0P00001=0?ooo`030000003oool0oooo04/0oooo0P00000n0?ooo`030000003oool0oooo02@0
oooo001S0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo02@0oooo001Q0?ooo`800000D03oool00`000000oooo0?oo
o`1>0?ooo`800000>`3oool00`000000oooo0?ooo`0T0?ooo`00H03oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0T
0?ooo`00GP3oool2000005<0oooo00<000000?ooo`3oool0D@3oool2000003P0oooo00<000000?oo
o`3oool0903oool005d0oooo00<000000?ooo`3oool0D`3oool2000005@0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0T0?ooo`00G03oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0T0?ooo`00F`3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0T0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0T0?ooo`00F03oool20000
05T0oooo00<000000?ooo`3oool0E`3oool200000380oooo00<000000?ooo`3oool0903oool005L0
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool0903oool005H0oooo00<000000?ooo`3oool0FP3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0903oool005D0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool0903oool005@0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0903oool005<0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0903oool00580oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0903oool00540oooo00<000000?ooo`3oool0
G`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
903oool00500oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool0903oool004l0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0903oool0
04h0oooo00<000000?ooo`3oool0HP3oool2000006<0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0T0?ooo`00C@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06<0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T0?ooo`00C03oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`0T0?ooo`00B`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0T0?ooo`00BP3oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0T
0?ooo`00B@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0T0?ooo`00B03oool00`000000oooo0?ooo`1X0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0T0?ooo`00
A`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0T0?ooo`00AP3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0T0?ooo`00A@3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0T0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0T0?ooo`00A03oool00`000000
oooo0?ooo`1/0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0T0?ooo`00@`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06d0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0T0?ooo`00@P3oool00`000000oooo0?oo
o`1^0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0T0?ooo`00@@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0T0?ooo`00@03oool00`000000oooo0?ooo`1`0?oo
o`800000L@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02@0oooo00100?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo02@0oooo000o0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02@0oooo000n0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo02@0oooo000n0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02@0oooo000m0?ooo`030000003oool0oooo
07<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
02@0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo02@0oooo000l0?ooo`030000003oool0oooo07@0oooo
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02@0oooo
000k0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo02@0oooo000j0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02@0oooo000j0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo02@0oooo000i0?ooo`030000003oool0oooo06<0oooo00X0_g@000000000
04P0W=oo0?ooo`3ookl0M4RL0=ooo`3oool0_g@00P0000000`18W=l0oooo0?ooo`050?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0T0?ooo`00>@3o
ool00`000000oooo0?ooo`1R0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool01P3o_g@0
B9cO0?ooo`3oool0gia807Boo`H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo02@0oooo000h0?ooo`030000003oool0oooo05`0oooo00<0okmd0000
000000000P0000002000B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO
0?ooo`050?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0T0?ooo`00>03oool00`000000oooo0?ooo`1S0?ooo`060=nLB01d_ol0oooo0?oog`2LB7@0
_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia807Boo`H0oooo0`00001h0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0903oool003L0oooo00<000000?ooo`3oool0I03oool01P3O
W4P0B9cO0?ooo`3ookl0M01d0;ooo`<0oooo00D0oono07A8B01800000000001d_`070?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0T0?ooo`00=P3o
ool00`000000oooo0?ooo`1U0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0
W4Q809cOo`090?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0T0?ooo`00=P3oool00`000000oooo0?ooo`1V0?ooo`040;md00000000001809cOo`D0
oooo00D0_g@0000000000000001809cOo`060?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0T0?ooo`00=@3oool00`000000oooo0?ooo`1k0?ooo`03
0000003oool0oooo07/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?ooo`00
=03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0T0?ooo`00=03oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0T0?ooo`00<`3oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0T0?ooo`00<`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
07d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0T0?ooo`00<`3oool00`000000
oooo0?ooo`1m0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0T0?ooo`00<P3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0T0?ooo`00<P3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0T0?ooo`00<@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo07l0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0T0?ooo`00<03oool00`000000oooo0?ooo`200?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0T0?oo
o`00<03oool00`000000oooo0?ooo`200?ooo`800000P@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo02@0oooo000`0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0
P03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02@0oooo000`0?ooo`030000003o
ool0oooo0800oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo02@0oooo000_0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02@0oooo000^0?ooo`030000003oool0oooo
0880oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02@0oooo000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0PP3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02@0oooo000^0?ooo`030000003oool0oooo0880oooo
00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02@0oooo
000^0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo02@0oooo000]0?ooo`030000003oool0oooo08<0oooo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo000]0?oo
o`030000003oool0oooo08<0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02@0oooo000]0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02@0oooo000/0?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02@0oooo000/0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02@0oooo000[0?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02@0oooo000[0?ooo`030000003oool0oooo08D0oooo0P0000260?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0903oool002/0oooo00<000000?ooo`3oool0Q@3oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool002X0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0903oool002X0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0903oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0903oool002T0oooo00<000000?ooo`3o
ool0Q`3oool00`000000oooo0?ooo`270?ooo`050000003oool0oooo0?ooo`0000009P3oool002T0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?ooo`050000003oool0oooo0?oo
o`0000009P3oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`270?ooo`05
0000003oool0oooo0?ooo`0000009P3oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`270?ooo`050000003oool0oooo0?ooo`0000009P3oool002T0oooo00<000000?ooo`3o
ool0Q`3oool00`000000oooo0?ooo`270?ooo`050000003oool0oooo0?ooo`0000009P3oool002P0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`280?ooo`040000003oool0oooo0000
02H0oooo000X0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0R03oool010000000
oooo0?ooo`00000V0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo08P0
oooo00@000000?ooo`3oool000009P3oool002L0oooo00<000000?ooo`3oool0R@3oool00`000000
oooo0?ooo`280?ooo`040000003oool0oooo000002H0oooo000W0?ooo`030000003oool0oooo08T0
oooo0P00002:0?ooo`030000003oool0000002H0oooo000W0?ooo`030000003oool0oooo08T0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0000000V0?ooo`009`3oool00`000000oooo0?oo
o`290?ooo`030000003oool0oooo08T0oooo00<000000?ooo`0000009P3oool002L0oooo00<00000
0?ooo`3oool0R@3oool00`000000oooo0?ooo`290?ooo`030000003oool0000002H0oooo000V0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0000000V0?oo
o`009P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo0P00000V0?ooo`00
9P3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo0P00000V0?ooo`009P3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo0P00000V0?ooo`009P3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo0P00000V0?ooo`009P3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo0P00000V0?ooo`009P3oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo08X0oooo0P00000V0?ooo`009@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo08X0oooo0P00000V0?ooo`009@3oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool002D0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo000U0?oo
o`050000003oool0oooO09a8M02oool0?`3oool02P2oM00000000000B02Lgol0oooo0?oo_`1dB9`0
gooo0?ooo`2oM0020000000304RLg`3oool0oooo03/0oooo0P00000o0?ooo`0:0;md000000000018
09cOo`3oool0oono07A8W03Oool0oooo0;md0080000000<0B9cO0?ooo`3oool0?P3oool00`000000
W4Qd0;ooo`0T0?ooo`009@3oool01@000000oooo0?oog`2LB7@0_ooo03h0oooo00H0okmd0018W03O
ool0okmd0018W03Oool30?ooo`060?noM018W=l0oooo0?ooo`3OW4P0M;oo?03oool00`000000oooo
0?ooo`0m0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool01P3o_g@0B9cO0?ooo`3oool0
gia807Boocl0oooo00<0000009a8M02oool0903oool001h0oooo00<0okmd0000000000000P000000
1`00B9`0gooo0000003oool0oooO09a8M02oool0=`3oool00`3o_g@0000000000002000000080018
W03Oool0gia804RLg`3oool0oono07@0M02oool70?ooo`030?noM018W=l0oooo03/0oooo00<00000
0?ooo`3oool0?@3oool01P3OW4P0B9cO0?ooo`3ookl0M01d0;ooo`L0oooo00<0okmd04RLg`3oool0
3@3oool00`3o_g@007Bo0?ooo`0^0?ooo`030000002LB7@0_ooo02@0oooo000U0?ooo`050000003o
ool0oooO09a8M02oool0?P3oool01P3OW4P0M;oo0?ooo`3ooml0W4Qd0;ooo`<0oooo00H0okmd0000
M02oool0oooo0=nLB01d_olb0?ooo`060?oo_`1d000000000000000007@0_ooo103oool00`000000
oooo0?ooo`0m0?ooo`060=nLB01d_ol0oooo0?oog`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3o
ool0gia807Boo`T0oooo00<0oono07@0000000000P0000000`0007@0_ooo0?ooo`0^0?ooo`060000
002LB7@0_ooO09a80000B9`0gooo0P3oool00`3o_g@0000004RLg`0L0?ooo`009@3oool01@000000
W9bo0?oog`2LB7@0_ooo03h0oooo00H0gia804RLg`3oool0oono07@0M02oool30?ooo`050?oo_`1d
B4P0B00000000000M;l0<P3oool0203ookl0M0000018W03Oool0oooO09a8000007@0_ooo0`3oool0
0`000000oooo0?ooo`0m0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q8
04P00000000007Bo00T0oooo00P0oono07@00000B9`0gooo0;md00000000001809cOobd0oooo00P0
oooO09bL_`000000W4Qd0;ooo`3OW4P0001809cOo`80oooo00<0_g@00000M02oool0703oool002D0
oooo00D000000?noM0000000001d0;ooo`0n0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3o
ool00`3ooml0W4Q809cOo`0d0?ooo`030?noM00004P0W=oo0080oooo00<0omnL04P0001d_ol00`3o
ool00`000000oooo0?ooo`0m0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0
W4Q809cOo`0;0?ooo`080?noM00004P0W=oo0?oOW018B9`0gmnL04P00018W=l^0?ooo`060?noM000
0000001d0;ooo`3ookl0M000100000000`00M;l0oooo0?ooo`0K0?ooo`009@3oool01@000000oooo
0?oo_`1d07@0_ooo03l0oooo00@0_g@00000000004P0W=oo1@3oool01@2oM00000000000000004P0
W=oo0340oooo00<0gia80000M02oool00P3oool00`3ookl0M00004RLg`030?ooo`030000003oool0
oooo03h0oooo00@0_g@00000000004P0W=oo1@3oool01@2oM00000000000000004P0W=oo00P0oooo
00<0gia80000M02oool00P3oool00`3ookl0M00004RLg`0_0?ooo`0:0000001d07@0_ooo0?ooo`2o
M00004RL0=ooo`3ogi`0B00007Booad0oooo000U0?ooo`030000003oool0oooo0800oooo00<0gia8
0000M02oool00P3oool00`3ookl0M00004RLg`030?ooo`030000003oool0oooo05@0oooo00<0gia8
0000M02oool00P3oool00`3ookl0M00004RLg`0_0?ooo`0:0000003oool0oooo0?ooo`3o_g@00018
09cOo`3OW4P0001d0;oooad0oooo000U0?ooo`030000003oool0oooo0800oooo00<0okmd0000B02L
gol00P3oool00`3ogi`0B00007Boo`030?ooo`030000003oool0oooo05@0oooo00<0okmd0000B02L
gol00P3oool00`3ogi`0B00007Boo`0_0?ooo`090000003oool0oooo0?ooo`3ookl0M00004RL_`2L
B000B9cO01h0oooo000U0?ooo`030000003oool0oooo0800oooo00<0oono07@00000M;l00P3oool0
0`2oM000001d0;ooo`030?ooo`030000003oool0oooo05@0oooo00P0oono07@00000B9`0gooo0?oo
o`2oM00004RL0=ooobl0oooo00<000000?ooo`3oool00P3oool0103OW4P004Q804P0B02LgolN0?oo
o`009@3oool00`000000oooo0?ooo`210?ooo`060?oo_`1d000000000000000007@0_ooo103oool0
0`000000oooo0?ooo`1E0?ooo`060?oo_`1d0000000000000000B9`0gooo<03oool00`000000oooo
0?ooo`020?ooo`040?oOW018000004RL0=oooah0oooo000U0?ooo`030000003oool0oooo08/0oooo
00<000000?ooo`3oool0CP3oool20000oc40oooo0P000?l80?ooo`030000003oool0oooo02@0oooo
000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0CP3oool60000obd0oooo1@00
0?l50?ooo`030000003oool0oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool0C`3oool90000obX0oooo20000?l00`3oool000000?ooo`0U0?ooo`00/`00002?0000
obH0000000080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0;0?ooo`8000006P3o000f0?oo00T0003o00<0ool00000o`3IYP009`3IYP080000o`03
0=VV00000?l0oooo00d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`00
9@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04@0oooo00<000000?ooo`000000
6@3o000e0?oo00H0003o1@3oo`000`000?l0fJH00=VV000U0=VV00H0003o103IYP000`000?l0oooo
0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`040000003oool0oooo000001P0o`00
=@3oo`020000o`T0ool000<0003o0=VV003IYP009@3IYP020000o`P0fJH000<0003o0?ooo`3oool0
903oool002D0oooo00<000000?ooo`3oool0R`3oool010000000oooo0?ooo`00000H0?l00400ool0
00<0003o0=VV003IYP00;`3IYP000`000?l0oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?oo
o`2;0?ooo`050000003oool0oooo0?ooo`0000005`3o00100?oo00030000o`3IYP00fJH002l0fJH0
00<0003o0?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`020?ooo`030000003o0000o`0001@0o`00@03oo`000`000?l0fJH00=VV000_0=VV00030000o`3o
ool0oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`3oool0
0`000000o`000?l0000C0?l00400ool000<0003o0=VV003IYP00;`3IYP000`000?l0oooo0?ooo`0T
0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00@0oooo00<000000?l0
003o00004P3o00100?oo00030000o`3IYP00fJH002l0fJH000<0003o0?ooo`3oool0903oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`050?ooo`030000003o0000o`000100
o`00@@3oo`000`000?l0fJH00=VV000_0=VV00030000o`3oool0oooo02@0oooo000U0?ooo`030000
003oool0oooo08/0oooo00<000000?ooo`3oool01@3oool00`000000o`000?l0000@0?l00440ool0
00<0003o0=VV003IYP00;`3IYP000`000?l0oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo00H0oooo00<000000?l0003o00003`3o00110?oo00030000o`3I
YP00fJH002l0fJH000<0003o0?ooo`3oool0903oool002D0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`070?ooo`030000003o0000o`0000d0o`00@P3oo`000`000?l0fJH00=VV000_
0=VV00030000o`3oool0oooo02@0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?oo
o`3oool0203oool00`000000o`000?l0000<0?l00480ool000<0003o0=VV003IYP00;`3IYP000`00
0?l0oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`8000002P3oool00`000000
o`000?l0000:0?l004<0ool000<0003o0=VV003IYP00;`3IYP000`000?l0oooo0?ooo`0T0?ooo`00
9@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00X0oooo00<000000?l0003o0000
203o00140?oo00030000o`3IYP00fJH002l0fJH000<0003o0?ooo`3oool0903oool002D0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`0:0?ooo`030000003o0000o`0000P0o`00A03o
o`000`000?l0fJH00=VV000_0=VV00030000o`3oool0oooo02@0oooo000U0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool02`3oool00`000000o`000?l000060?l004D0ool000<0003o
0=VV003IYP00;P3IYP000`000000003o0?ooo`0U0?ooo`009P3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo00`0oooo00<000000?l0003o00001@3o00150?oo00030000o`3IYP00fJH0
02h0fJH000<000000000o`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000
oooo0?ooo`0=0?ooo`030000003o0000o`0000<0o`00AP3oo`000`000?l0fJH00=VV000^0=VV0003
000000000?l0oooo02D0oooo000V0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
3P3oool010000000o`000?l0003o00170?oo00030000o`3IYP00fJH002h0fJH000<000000000o`3o
ool09@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0?0?ooo`030000
003o0000ool004L0ool000<0003o0=VV003IYP00;P3IYP000`000000003o0?ooo`0U0?ooo`009P3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00l0oooo00<000000?oo003oo`00A`3o
o`000`000?l0fJH00=VV000^0=VV0003000000000?l0oooo02D0oooo000V0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0403oool00`000000ool00?oo00160?oo00030000o`3IYP00
fJH002h0fJH000<000000000o`3oool09@3oool002H0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oo`00ool004D0ool000<0003o0=VV003IYP00;@3IYP000`00
0000fJH00000o`0V0?ooo`009`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0180
oooo00<000000?oo003oo`00A03oo`000`000?l0fJH00=VV000]0=VV00030000003IYP00003o02H0
oooo000W0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool04`3oool00`000000ool0
0?oo00130?oo00030000o`3IYP00fJH002d0fJH000<000000=VV00000?l09P3oool002L0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`0D0?ooo`030000003oo`00ool00480ool000<0
003o0=VV003IYP00;@3IYP000`000000fJH00000o`0V0?ooo`009`3oool00`000000oooo0?ooo`29
0?ooo`8000005@3oool00`000000ool00?oo00120?oo00030000o`3IYP00fJH002d0fJH000<00000
0=VV00000?l09P3oool002L0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oo`00ool00440ool000<0003o0=VV003IYP00;03IYP0010000000fJH00=VV00000?lV
0?ooo`00:03oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo01H0oooo00<000000?oo
003oo`00@03oo`000`000?l0fJH00=VV000/0=VV00040000003IYP00fJH00000obH0oooo000X0?oo
o`030000003oool0oooo08P0oooo00<000000?ooo`3oool05`3oool00`000000ool00?oo000o0?oo
00030000o`3IYP00fJH002`0fJH000@000000=VV003IYP00003o9P3oool002P0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`0H0?ooo`030000003oo`00ool003h0ool000<0003o0=VV
003IYP00;03IYP0010000000fJH00=VV00000?lV0?ooo`00:@3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo01T0oooo00<000000?oo003oo`00?@3oo`000`000?l0fJH00=VV000[0=VV
00050000003IYP00fJH00=VV00000?l09P3oool002T0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oo`00ool003d0ool000<0003o0=VV003IYP00:`3IYP001@00
0000fJH00=VV003IYP00003o02H0oooo000Y0?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool06P3oool00`000000ool00?oo000l0?oo00030000o`3IYP00fJH002/0fJH000D000000=VV
003IYP00fJH00000o`0V0?ooo`00:@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo
01/0oooo00<000000?oo003oo`00>`3oo`000`000?l0fJH00=VV000[0=VV00050000003IYP00fJH0
0=VV00000?l09P3oool002T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oo`00ool003X0ool000<0003o0=VV003IYP00:`3IYP001@000000fJH00=VV003IYP00
003o02H0oooo000Y0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool07@3oool00`00
0000ool00?oo000i0?oo00030000o`3IYP00fJH002X0fJH000<000000=VV003IYP000P3IYP000`00
0?l0oooo0?ooo`0T0?ooo`00:P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01h0
oooo00<000000?oo003oo`00>03oo`000`000?l0fJH00=VV000Z0=VV00030000003IYP00fJH00080
fJH000<0003o0?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`0N0?ooo`030000003oo`00ool003P0ool000<0003o0=VV003IYP00:P3IYP000`000000fJH0
0=VV00020=VV00030000o`3oool0oooo02@0oooo000Z0?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool07`3oool00`000000ool00?oo000g0?oo00030000o`3IYP00fJH002T0fJH000<0
00000=VV003IYP000`3IYP000`000?l0oooo0?ooo`0T0?ooo`00:`3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo0200oooo00<000000?oo003oo`00=P3oo`000`000?l0fJH00=VV000Y
0=VV00030000003IYP00fJH000<0fJH000<0003o0?ooo`3oool0903oool002/0oooo00<000000?oo
o`3oool0Q@3oool200000280oooo00<000000?oo003oo`00=@3oo`000`000?l0fJH00=VV000Y0=VV
00030000003IYP00fJH000<0fJH000<0003o0?ooo`3oool0903oool002/0oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`0R0?ooo`030000003oo`00ool003@0ool000<0003o0=VV003I
YP00:@3IYP000`000000fJH00=VV00030=VV00030000o`3oool0oooo02@0oooo000/0?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool08`3oool00`000000ool00?oo000c0?oo00030000
o`3IYP00fJH002P0fJH000<000000=VV003IYP00103IYP000`000?l0oooo0?ooo`0T0?ooo`00;03o
ool00`000000oooo0?ooo`240?ooo`030000003oool0oooo02<0oooo00<000000?oo003oo`00<`3o
o`000`000?l0fJH00=VV000W0=VV00030000003IYP00fJH000D0fJH000<0003o0?ooo`3oool0903o
ool002d0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0T0?ooo`030000003oo`00
ool00380ool000<0003o0=VV003IYP009`3IYP000`000000fJH00=VV00050=VV00030000o`3oool0
oooo02@0oooo000]0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool09@3oool00`00
0000ool00?oo000a0?oo00030000o`3IYP00fJH002L0fJH000<000000=VV003IYP001@3IYP000`00
0?l0oooo0?ooo`0T0?ooo`00;@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo02H0
oooo00<000000?oo003oo`00<03oo`000`000?l0fJH00=VV000W0=VV00030000003IYP00fJH000D0
fJH000<0003o0?ooo`3oool0903oool002h0oooo00<000000?ooo`3oool0PP3oool00`000000oooo
0?ooo`0W0?ooo`030000003oo`00ool002l0ool000<0003o0=VV003IYP009P3IYP000`000000fJH0
0=VV00060=VV00030000o`3oool0oooo02@0oooo000^0?ooo`030000003oool0oooo0880oooo00<0
00000?ooo`3oool0:03oool00`000000ool00?oo000^0?oo00030000o`3IYP00fJH002H0fJH000<0
00000=VV003IYP001P3IYP000`000?l0oooo0?ooo`0T0?ooo`00;P3oool00`000000oooo0?ooo`22
0?ooo`030000003oool0oooo02P0oooo00<000000?oo003oo`00;P3oo`000`000?l0fJH00=VV000V
0=VV00030000003IYP00fJH000H0fJH000<0003o0?ooo`3oool0903oool002h0oooo00<000000?oo
o`3oool0PP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oo`00ool002d0ool000<0003o0=VV
003IYP009@3IYP000`000000fJH00=VV00070=VV00030000o`3oool0oooo02@0oooo000_0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool0:P3oool00`000000ool00?oo000/0?oo0003
0000o`3IYP00fJH002D0fJH000<000000=VV003IYP001`3IYP000`000?l0oooo0?ooo`0T0?ooo`00
<03oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo02/0oooo00<000000?oo003oo`00
:`3oo`000`000?l0fJH00=VV000T0=VV00030000003IYP00fJH000P0fJH000<0003o0?ooo`3oool0
903oool00300oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`0/0?ooo`030000003o
o`00ool002X0ool000<0003o0=VV003IYP00903IYP000`000000fJH00=VV00080=VV00030000o`3o
ool0oooo02@0oooo000`0?ooo`030000003oool0oooo0800oooo0P00000^0?ooo`030000003oo`00
ool002T0ool000<0003o0=VV003IYP00903IYP000`000000fJH00=VV00080=VV00030000o`3oool0
oooo02@0oooo000`0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0;@3oool00`00
0000ool00?oo000Y0?oo00030000o`3IYP00fJH002<0fJH000<000000=VV003IYP002@3IYP000`00
0?l0oooo0?ooo`0T0?ooo`00<@3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02h0
oooo00<000000?oo003oo`00:03oo`000`000?l0fJH00=VV000S0=VV00030000003IYP00fJH000T0
fJH000<0003o0?ooo`3oool0903oool00380oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0_0?ooo`030000003oo`00ool002L0ool000<0003o0=VV003IYP008P3IYP000`000000fJH0
0=VV000:0=VV00030000o`3oool0oooo02@0oooo000b0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool0<03oool00`000000ool00?oo000V0?oo00030000o`3IYP00fJH00240fJH000<0
00000=VV003IYP002`3IYP000`000?l0oooo0?ooo`0T0?ooo`00<`3oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo0340oooo00<000000?oo003oo`009@3oo`000`000?l0fJH00=VV000Q
0=VV00030000003IYP00fJH000/0fJH000<0003o0?ooo`3oool0903oool003<0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`0b0?ooo`030000003oo`00ool002@0ool000<0003o0=VV
003IYP008@3IYP000`000000fJH00=VV000;0=VV00030000o`3oool0oooo02@0oooo000c0?ooo`03
0000003oool0oooo07d0oooo00<000000?ooo`3oool0<P3oool00`000000fJH00?oo000T0?oo0003
0000o`3IYP00fJH00200fJH000<000000=VV003IYP00303IYP000`000?l0oooo0?ooo`0T0?ooo`00
=03oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo00<000000?oo003oo`00
8`3oo`000`000?l0fJH00=VV000P0=VV00030000003IYP00fJH000`0fJH000<0003o0?ooo`3oool0
903oool003@0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0d0?ooo`030000003o
o`00ool00280ool000<0003o0=VV003IYP007`3IYP000`000000fJH00=VV000=0=VV00030000o`3o
ool0oooo02@0oooo000e0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0=@3oool0
0`000000ool00?oo000Q0?oo00030000o`3IYP00fJH001l0fJH000<000000=VV003IYP003@3IYP00
0`000?l0oooo0?ooo`0T0?ooo`00=P3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
03H0oooo00<000000?oo003oo`00803oo`000`000?l0fJH00=VV000N0=VV00030000003IYP00fJH0
00h0fJH000<0003o0?ooo`3oool0903oool003H0oooo00<000000?ooo`3oool0IP3oool02P2oM000
00000000B02Lgol0oooo0?oo_`1dB9`0gooo0?ooo`2oM0020000000304RLg`3oool0oooo00D0oooo
00<000000?ooo`3oool0=`3oool00`000000ool00?oo000O0?oo00030000o`3IYP00fJH001d0fJH0
00<000000=VV003IYP003`3IYP000`000?l0oooo0?ooo`0T0?ooo`00=`3oool00`000000oooo0?oo
o`1T0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool01P3o_g@0B9cO0?ooo`3oool0gia8
07Boo`H0oooo00<000000?ooo`3oool0=`3oool00`000000fJH00?oo000O0?oo00030000o`3IYP00
fJH001d0fJH000<000000=VV003IYP003`3IYP000`000?l0oooo0?ooo`0T0?ooo`00>03oool00`00
0000oooo0?ooo`1S0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3oool00`3o_g@0B9cO0?oo
o`050?ooo`<00000>03oool00`000000ool00?oo000N0?oo00030000o`3IYP00fJH001`0fJH000<0
00000=VV003IYP00403IYP000`000?l0oooo0?ooo`0T0?ooo`00>03oool00`000000oooo0?ooo`1S
0?ooo`060=nLB01d_ol0oooo0?oog`2LB7@0_ooo0`3oool01P3o_g@0001d0;ooo`3oool0gia807Bo
o`H0oooo00<000000?ooo`3oool0>@3oool00`000000ool00?oo000M0?oo00030000o`3IYP00fJH0
01`0fJH000<000000=VV003IYP00403IYP000`000?l0oooo0?ooo`0T0?ooo`00>@3oool00`000000
oooo0?ooo`1R0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000
000007Bo00L0oooo00<000000?ooo`3oool0>P3oool00`000000ool00?oo000L0?oo00030000o`3I
YP00fJH001/0fJH000<000000=VV003IYP004@3IYP000`000?l0oooo0?ooo`0T0?ooo`00>@3oool0
0`000000oooo0?ooo`1R0?ooo`060?noM000B9`0gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q8
09cOo`090?ooo`030000003oool0oooo03/0oooo00<000000?oo003oo`006`3oo`000`000?l0fJH0
0=VV000K0=VV00030000003IYP00fJH00140fJH000<0003o0?ooo`3oool0903oool003X0oooo00<0
00000?ooo`3oool0HP3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02L
gol01P3oool00`000000oooo0?ooo`0l0?ooo`030000003oo`00ool001X0ool000<0003o0=VV003I
YP006P3IYP000`000000fJH00=VV000B0=VV00030000o`3oool0oooo02@0oooo000j0?ooo`030000
003oool0oooo07H0oooo00<000000?ooo`3oool0?03oool00`000000fJH00?oo000J0?oo00030000
o`3IYP00fJH001X0fJH000<000000=VV003IYP004P3IYP000`000?l0oooo0?ooo`0T0?ooo`00>`3o
ool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo03d0oooo00<000000?oo003oo`006@3o
o`000`000?l0fJH00=VV000I0=VV00030000003IYP00fJH001<0fJH000<0003o0?ooo`3oool0903o
ool003`0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`0n0?ooo`030000003oo`00
ool001P0ool000<0003o0=VV003IYP00603IYP000`000000fJH00=VV000D0=VV00030000o`3oool0
oooo02@0oooo000l0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0?`3oool00`00
0000ool00?oo000G0?oo00030000o`3IYP00fJH001P0fJH000<000000=VV003IYP00503IYP000`00
0?l0oooo0?ooo`0T0?ooo`00?@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0400
oooo00<000000?oo003oo`005P3oo`000`000?l0fJH00=VV000G0=VV00030000003IYP00fJH001D0
fJH000<0003o0?ooo`3oool0903oool003h0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`110?ooo`030000003oo`00ool001D0ool000<0003o0=VV003IYP005P3IYP000`000000fJH0
0=VV000F0=VV00030000o`3oool0oooo02@0oooo000n0?ooo`030000003oool0oooo0780oooo00<0
00000?ooo`3oool0@@3oool00`000000fJH00?oo000E0?oo00030000o`3IYP00fJH001H0fJH000<0
00000=VV003IYP005P3IYP000`000?l0oooo0?ooo`0T0?ooo`00?`3oool00`000000oooo0?ooo`1a
0?ooo`030000003oool0oooo0480oooo00<000000=VV003oo`00503oo`000`000?l0fJH00=VV000E
0=VV00030000003IYP00fJH001L0fJH000<0003o0?ooo`3oool0903oool00400oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`130?ooo`030000003oo`00ool001<0ool000<0003o0=VV
003IYP00503IYP000`000000fJH00=VV000H0=VV00030000o`3oool0oooo02@0oooo00100?ooo`03
0000003oool0oooo0700oooo0P0000150?ooo`030000003oo`00ool00180ool000<0003o0=VV003I
YP00503IYP000`000000fJH00=VV000H0=VV00030000o`3oool0oooo02@0oooo00110?ooo`030000
003oool0oooo06l0oooo00<000000?ooo`3oool0A@3oool00`000000ool00?oo000A0?oo00030000
o`3IYP00fJH001<0fJH000<000000=VV003IYP006@3IYP000`000?l0oooo0?ooo`0T0?ooo`00@P3o
ool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo04H0oooo00<000000?oo003oo`00403o
o`000`000?l0fJH00=VV000B0=VV00030000003IYP00fJH001X0fJH000<0003o0?ooo`3oool0903o
ool004<0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`170?ooo`030000003oo`00
ool000l0ool000<0003o0=VV003IYP004@3IYP000`000000fJH00=VV000K0=VV00030000o`3oool0
oooo02@0oooo00140?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0A`3oool00`00
0000fJH00?oo000?0?oo00030000o`3IYP00fJH00100fJH000<000000=VV003IYP00703IYP000`00
0?l0oooo0?ooo`0T0?ooo`00A@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo04P0
oooo00<000000?oo003oo`003P3oo`000`000?l0fJH00=VV000?0=VV00030000003IYP00fJH001d0
fJH000<0003o0?ooo`3oool0903oool004D0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`190?ooo`030000003oo`00ool000d0ool000<0003o0=VV003IYP003`3IYP000`000000fJH0
0=VV000M0=VV00030000o`3oool0oooo02@0oooo00160?ooo`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool0BP3oool00`000000ool00?oo000<0?oo00030000o`3IYP00fJH000h0fJH000<0
00000=VV003IYP007P3IYP000`000?l0oooo0?ooo`0T0?ooo`00A`3oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo04/0oooo00<000000?oo003oo`002`3oo`000`000?l0fJH00=VV000=
0=VV00030000003IYP00fJH001l0fJH000<0003o0?ooo`3oool0903oool004P0oooo00<000000?oo
o`3oool0J03oool00`000000oooo0?ooo`1<0?ooo`030000003oo`00ool000X0ool000<0003o0=VV
003IYP00303IYP000`000000fJH00=VV000P0=VV00030000o`3oool0oooo02@0oooo00190?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool0C03oool00`000000fJH00?oo000:0?oo0003
0000o`3IYP00fJH000/0fJH000<000000=VV003IYP008@3IYP000`000?l0oooo0?ooo`0T0?ooo`00
BP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo04d0oooo00<000000=VV003oo`00
2@3oo`000`000?l0fJH00=VV000:0=VV00030000003IYP00fJH00280fJH000<0003o0?ooo`3oool0
903oool004/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1>0?ooo`030000003o
o`00ool000P0ool000<0003o0=VV003IYP002@3IYP000`000000fJH00=VV000S0=VV00030000o`3o
ool0oooo02@0oooo001<0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0C`3oool0
0`000000ool00?oo00040?oo0080003o00@0ool00000o`3IYP00003o203IYP000`000000fJH00=VV
000T0=VV00030000o`3oool0oooo02@0oooo001=0?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool0D03oool00`000000ool00?oo00030?oo00H0003o1`3IYP000`000000fJH00=VV000U
0=VV00030000o`3oool0oooo02@0oooo001>0?ooo`030000003oool0oooo0680oooo0P00001B0?oo
o`030000003oo`00ool000<0ool01@000?l60=VV00030000003IYP00fJH002H0fJH000<0003o0?oo
o`3oool0903oool004l0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1A0?ooo`03
0000003IYP00ool000<0ool010000?l60=VV00030000003IYP00fJH002L0fJH000<0003o0?ooo`3o
ool0903oool00500oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1B0?ooo`030000
003IYP00ool00080ool010000?l50=VV00030000003IYP00fJH002P0fJH000<0003o0?ooo`3oool0
903oool00540oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`1C0?ooo`040000003o
o`00ool00?oo00@0003o103IYP000`000000fJH00=VV000Y0=VV00030000o`3oool0oooo02@0oooo
001B0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0E03oool010000000ool00?oo
003oo`030000o`<0fJH000<000000=VV003IYP00:P3IYP000`000?l0oooo0?ooo`0T0?ooo`00D`3o
ool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05D0oooo00<000000?oo003oo`000`00
0?l20=VV00030000003IYP00fJH002/0fJH000<0003o0?ooo`3oool0903oool005@0oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`1F0?ooo`030000003oo`00003o0080003o00<0fJH0
0000003IYP00;@3IYP000`000?l0oooo0?ooo`0T0?ooo`00E@3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo05H0oooo00H000000=VV00000?l0003o0=VV0000000_0=VV00030000o`3o
ool0oooo02@0oooo001F0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0E`3oool0
10000000fJH00000o`00000`0=VV00030000o`3oool0oooo02@0oooo001G0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0F03oool00`000000003o0=VV000`0=VV00030000o`3oool0
oooo02@0oooo001H0?ooo`800000F@3oool00`000000oooo0?ooo`1G0?ooo`<00000<@3IYP000`00
0?l0oooo0?ooo`0T0?ooo`00FP3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo05H0
oooo00D000000?ooo`3oool0oooo0000000`0=VV00030000o`3oool0oooo02@0oooo001K0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`030?ooo`03
0000003IYP00fJH002d0fJH000<0003o0?ooo`3oool0903oool005`0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo00@0oooo00<000000=VV003IYP00
;@3IYP000`000?l0oooo0?ooo`0T0?ooo`00G@3oool00`000000oooo0?ooo`1C0?ooo`800000E03o
ool01@000000oooo0?oo_`1d0000B9cO00@0oooo00<000000=VV003IYP00;03IYP000`000?l0oooo
0?ooo`0T0?ooo`00GP3oool2000005<0oooo00<000000?ooo`3oool0D@3oool200000080oooo00<0
oono07@00018W=l01@3oool00`000000fJH00=VV000[0=VV00030000o`3oool0oooo02@0oooo001P
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`02
0?ooo`030?oo_`1d0000B9cO00H0oooo00<000000=VV003IYP00:P3IYP000`000?l0oooo0?ooo`0T
0?ooo`00H@3oool200000500oooo00<000000?ooo`3oool0CP3oool2000000D0oooo00<0oono07@0
000000000P0000000`00M;l0oooo0?ooo`020?ooo`030000003IYP00fJH002T0fJH000<0003o0?oo
o`3oool0903oool006<0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo00D0oooo00L0oono07@00018W=l0oooo0?oOW0180000B9cO00@0oooo00<00000
0=VV003IYP00:03IYP000`000?l0oooo0?ooo`0T0?ooo`00I03oool2000004d0oooo00<000000?oo
o`3oool0B`3oool2000000P0oooo00L0oono07@00018W=l0oooo0?oo_`1d000007Bo00@0oooo00<0
00000=VV003IYP00:03IYP000`000?l0oooo0?ooo`0T0?ooo`00IP3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0203oool01`3ookl0M00004RLg`3o
ool0omnL04P00018W=l01@3oool00`000000fJH00=VV000W0=VV00030000o`3oool0oooo02@0oooo
001W0?ooo`800000BP3oool00`000000oooo0?ooo`180?ooo`8000002`3oool00`3ookl0M0000000
0002000000030018W03Oool0oooo00D0oooo00<000000=VV003IYP009P3IYP000`000?l0oooo0?oo
o`0T0?ooo`00J@3oool2000004P0oooo00<000000?ooo`3oool0AP3oool2000001/0oooo00<00000
0=VV003IYP009@3IYP000`000?l0oooo0?ooo`0T0?ooo`00J`3oool2000004H0oooo00<000000?oo
o`3oool0A03oool2000001h0oooo00<000000=VV003IYP00903IYP000`000?l0oooo0?ooo`0T0?oo
o`00K@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool07`3oool00`000000fJH00=VV000S0=VV00030000o`3oool0oooo02@0oooo001^0?ooo`800000
@`3oool00`000000oooo0?ooo`110?ooo`8000008P3oool00`000000fJH00=VV000S0=VV00030000
o`3oool0oooo02@0oooo001`0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0S0?ooo`030000003IYP00fJH00280fJH000<0003o0?ooo`3oool0903o
ool00740oooo0P0000100?ooo`030000003oool0oooo03h0oooo0P00000W0?ooo`030000003IYP00
fJH00240fJH000<0003o0?ooo`3oool0903oool007<0oooo0`00000m0?ooo`800000?03oool30000
02X0oooo00<000000=VV003IYP00803IYP000`000?l0oooo0?ooo`0T0?ooo`00MP3oool2000003/0
oooo00<000000?ooo`3oool0>@3oool2000002h0oooo00<000000=VV003IYP007`3IYP000`000?l0
oooo0?ooo`0T0?ooo`00N03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0;`3oool00`000000fJH00=VV000N0=VV00030000o`3oool0oooo02@0oooo
001i0?ooo`@00000=P3oool00`000000oooo0?ooo`0d0?ooo`@00000<P3oool00`000000fJH00=VV
000N0=VV00030000o`3oool0oooo02@0oooo001m0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0e0?ooo`030000003IYP00fJH001d0fJH000<0003o
0?ooo`3oool0903oool007h0oooo1000000a0?ooo`030000003oool0oooo02l0oooo1000000i0?oo
o`030000003IYP00fJH001`0fJH000<0003o0?ooo`3oool0903oool00880oooo0`00000^0?ooo`03
0000003oool0oooo02`0oooo0`00000n0?ooo`030000003IYP00fJH001/0fJH000<0003o0?ooo`3o
ool0903oool008D0oooo0P00000/0?ooo`030000003oool0oooo02X0oooo0P0000120?ooo`030000
003IYP00fJH001X0fJH000<0003o0?ooo`3oool0903oool008L0oooo0`00000Y0?ooo`030000003o
ool0oooo02L0oooo0`0000150?ooo`030000003IYP00fJH001T0fJH000<0003o0?ooo`3oool0903o
ool008X0oooo0`00000V0?ooo`030000003oool0oooo02@0oooo0`0000180?ooo`030000003IYP00
fJH001T0fJH000<0003o0?ooo`3oool0903oool008d0oooo1P00000P0?ooo`030000003oool0oooo
01h0oooo1P00001<0?ooo`030000003IYP00fJH001P0fJH000<0003o0?ooo`3oool0903oool009<0
oooo0`00000M0?ooo`030000003oool0oooo01/0oooo0`00001C0?ooo`030000003IYP00fJH001L0
fJH000<0003o0?ooo`3oool0903oool009H0oooo1@00000=0?ooo`030?oog`2LB7@0_ooo00P0oooo
00<000000?ooo`3oool05P3oool5000005L0oooo00<000000=VV003IYP005P3IYP000`000?l0oooo
0?ooo`0T0?ooo`00V`3oool7000000H0oooo00<0oooO09a8M02oool0203oool00`000000oooo0?oo
o`0?0?ooo`L00000G@3oool00`000000fJH00=VV000E0=VV00030000o`3oool0oooo02@0oooo002R
0?ooob<00000I@3oool00`000000fJH00=VV000D0=VV00030000o`3oool0oooo02@0oooo002X0?oo
o`030?oog`2LB7@0_ooo00P0oooo00<000000?ooo`3oool0M03oool00`000000fJH00=VV000D0=VV
00030000o`3oool0oooo02@0oooo002V0?ooo`050?oog`2LW;l0oooO09a8M02oool0203oool00`00
0000oooo0?ooo`1e0?ooo`030000003IYP00fJH001<0fJH000<0003o0?ooo`3oool0903oool00:L0
oooo00@0okmd0000000007@0_ooo203oool00`000000oooo0?ooo`1f0?ooo`030000003IYP00fJH0
0180fJH000<0003o0?ooo`3oool0903oool00:P0oooo00<0oono07@0M02oool0203oool00`000000
oooo0?ooo`1g0?ooo`030000003IYP00fJH00140fJH000<0003o0?ooo`3oool0903oool00;<0oooo
00<000000?ooo`3oool0N03oool00`000000fJH00=VV000@0=VV00030000o`3oool0oooo02@0oooo
002c0?ooo`030000003oool0oooo07T0oooo00<000000=VV003IYP003`3IYP000`000?l0oooo0?oo
o`0T0?ooo`00/`3oool00`000000oooo0?ooo`1i0?ooo`030000003IYP00fJH000l0fJH000<0003o
0?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0NP3oool00`000000fJH00=VV000>0=VV
00030000o`3oool0oooo02@0oooo002c0?ooo`030000003oool0oooo07/0oooo00<000000=VV003I
YP003@3IYP000`000?l0oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`1l0?ooo`030000
003IYP00fJH000`0fJH000<0003o0?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0O@3o
ool00`000000fJH00=VV000;0=VV00030000o`3oool0oooo02@0oooo002c0?ooo`030000003oool0
oooo07h0oooo00<000000=VV003IYP002P3IYP000`000?l0oooo0?ooo`0T0?ooo`00/`3oool00`00
0000oooo0?ooo`1n0?ooo`030000003IYP00fJH000X0fJH000<0003o0?ooo`3oool0903oool00;<0
oooo00<000000?ooo`3oool0O`3oool00`000000fJH00=VV00090=VV00030000o`3oool0oooo02@0
oooo002c0?ooo`800000P@3oool00`000000fJH00=VV00080=VV00030000o`3oool0oooo02@0oooo
002c0?ooo`030000003oool0oooo0840oooo00<000000=VV003IYP001`3IYP000`000?l0oooo0?oo
o`0T0?ooo`00/`3oool00`000000oooo0?ooo`220?ooo`030000003IYP00fJH000@0fJH000@0003o
0=VV00000?l0oooo0P000?lS0?ooo`00/`3oool00`000000oooo0?ooo`230?ooo`030000003IYP00
fJH000<0fJH01P000?lS0?ooo`00/`3oool00`000000oooo0?ooo`230?ooo`030000003IYP00fJH0
00<0fJH01@000?lT0?ooo`00/`3oool00`000000oooo0?ooo`240?ooo`030000003IYP00fJH000<0
fJH010000?lT0?ooo`00/`3oool00`000000oooo0?ooo`250?ooo`030000003IYP00fJH00080fJH0
10000?lT0?ooo`00/`3oool00`000000oooo0?ooo`260?ooo`040000003IYP00fJH00=VV00@0003o
903oool00;<0oooo00<000000?ooo`3oool0Q`3oool00`000000fJH00=VV00030000obD0oooo002c
0?ooo`030000003oool0oooo08P0oooo00<000000=VV00000?l00P000?lU0?ooo`00/`3oool00`00
0000oooo0?ooo`280?ooo`030000003IYP00003o0080003o00<0oooo0?oOW01800000`0000000`00
B9`0gooo0?ooo`0L0?ooo`00/`3oool00`000000oooo0?ooo`290?ooo`0<0000003IYP00003o0000
o`3oool0omnL04P0001d_ol0oooo0?oOW0180000B9cO7@3oool00;<0oooo00<000000?ooo`3oool0
RP3oool02`000000003o0?ooo`3oool0omnL04P0001d_ol0oooo0?oog`2LB00007Bo01d0oooo002c
0?ooo`030000003oool0oooo08/0oooo00X0003o0?ooo`3oool0omnL04P0001d_ol0oooo0?oOW018
000007Bo7@3oool00;<0oooo0P00002<0?ooo`050000003oool0oooo0?oOW01800000`0000000`00
M;l0oooo0?ooo`0L0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`0:0000003oool0oooo0?oO
W0180000M;oo0?ooo`3o_g@0001809cOoad0oooo002c0?ooo`030000003oool0oooo08/0oooo00X0
00000?ooo`3oool0omnL04P0001d_ol0oooo0?noM0000000M;oo7@3oool00;<0oooo00<000000?oo
o`3oool0R`3oool01@000000oooo0?ooo`3ogi`0B00000<0000000<004RL0=ooo`3oool0703oool0
0;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo002c0?ooo`030000003oool0oooo08/0oooo
00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo002c0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000
003oool0oooo02@0oooo002c0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903o
ool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool20000
08`0oooo00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000
oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo
002c0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool00;<0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo02@0oooo002c0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3o
ool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0oooo002c0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`0T0?ooo`00/`3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo02@0
oooo002c0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0903oool00;<0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`0T0?ooo`00/`3oool2000008`0oooo00<00000
0?ooo`3oool0903oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00001\
\>"],
  ImageRangeCache->{{{100.063, 300.625}, {722.875, 488.688}} -> {-2.51728, \
4.66901, 0.00879536, 0.00879536}},
  CellTags->"figura9"],

Cell[TextData[{
  "Data la similitudine tra ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[EmptyUpTriangle]", 
              StyleBox["OQP",
                FontSlant->"Italic"]}]], "\[Tilde]", 
          StyleBox[
            RowBox[{"\[EmptyUpTriangle]", 
              StyleBox["OAB",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " e il fatto che ",
  Cell[BoxData[
      FormBox[
        StyleBox["OQ",
          FontSlant->"Italic"], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        StyleBox["OA",
          FontSlant->"Italic"], TraditionalForm]]],
  " siano concordi come ",
  Cell[BoxData[
      FormBox[
        StyleBox["QP",
          FontSlant->"Italic"], TraditionalForm]]],
  " e ",
  Cell[BoxData[
      FormBox[
        StyleBox["AB",
          FontSlant->"Italic"], TraditionalForm]]],
  ", risulta"
}], "Text"],

Cell[BoxData[
    \(tg \((\[Alpha])\) = \(QP\/OQ = \(AB\/OA = \(AB\/1 = 
            AB\)\)\)\)], "DisplayFormula"],

Cell[TextData[{
  "dove si \[EGrave] considerato che nella circonferenza goniometrica ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["OA",
            FontSlant->"Italic"], "=", "1"}], TraditionalForm]]],
  ". Possiamo pertanto reinterpretare la ",
  Cell[BoxData[
      \(TraditionalForm\`tg(\[Alpha])\)]],
  " come la lunghezza del segmento orientato ",
  Cell[BoxData[
      FormBox[
        StyleBox["AB",
          FontSlant->"Italic"], TraditionalForm]]],
  " oppure anche come l'ordinata del punto ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " (oppure come la componente \"verticale\" del vettore ",
  Cell[BoxData[
      FormBox[
        StyleBox["OB",
          FontWeight->"Bold"], TraditionalForm]]],
  "). \[CapitalEGrave] ora immediato rappresentarci qualitativamente la \
variazione della tangente in funzione dell'angolo: a partire da ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(\[Pi]\/2\)\)\)]],
  "(dove non \[EGrave] definita) all'aumentare di ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " aumenta pure la tangente che risulta un valore negativo per ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(]\)\(-\)\(\[Pi]\/2\)\), \(\(0\)\([\)\)\)]],
  ". \[CapitalEGrave] poi ",
  Cell[BoxData[
      \(TraditionalForm\`tg(0) = 0\)]],
  " e quindi la funzione assume valori positivi sempre maggiori quando ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", aumentando, si avvicina a ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(origine = {0, 0}; pA = {1, 0};\), "\n", 
    \(\(\(Show[
            Graphics[{Circle[origine, 1], Line[{{\(-1.2\), 0}, {1.2, 0}}], 
                Line[{{0, \(-1.2\)}, {0, 1.2}}], 
                Line[{{1, Tan[#]}, origine}], 
                Line[{{1, \(-2.8\)}, {1, 
                      2.8}}]}], \[IndentingNewLine]Graphics[{colBlu, 
                Arrow[pA, {1, Tan[#]}, stileVet], 
                Arrow[origine, pA, stileVet], 
                Arrow[origine, {Cos[#], 0}, stileVet], 
                Arrow[{Cos[#], 0}, {Cos[#], Sin[#]}, 
                  stileVet]}], \[IndentingNewLine]Graphics[{Text["\<O\>", 
                  origine, {1, 1}, TextStyle \[Rule] stileTesto], 
                Text["\<Q\>", {Cos[#], 0}, {0, 1}, 
                  TextStyle \[Rule] stileTesto], 
                Text["\<P\>", {Cos[#], Sin[#]}, {0, \(-1\)}, 
                  TextStyle \[Rule] stileTesto], 
                Text["\<B\>", {1, Tan[#]}, {\(-1\), 0}, 
                  TextStyle \[Rule] stileTesto], 
                Text["\<A\>", pA, {\(-1\), 1}, TextStyle \[Rule] stileTesto], 
                Text["\<tg(\>" <> 
                    ToString[N[#]/Degree] <> "\<\[Degree]) = \>" <> 
                    ToString[N[Tan[#]]], {\(-1.1\), 1.85}, {\(-1\), 1}, 
                  TextStyle \[Rule] stileTesto]}], 
            Prolog -> {{RGBColor[ .85, \  .65, \ 0], 
                  Polygon[{origine, pA, {1, Tan[#]}}]}, {colGiallo, 
                  Polygon[{origine, {Cos[#], 0}, {Cos[#], 
                        Sin[#]}}]}, {colRosso, 
                  Disk[origine,  .2, If[# > 0, {0, #}, {#, 0}]]}}, 
            AspectRatio \[Rule] Automatic, Axes \[Rule] True, 
            PlotRange \[Rule] {Automatic, {\(-2.8\), 2.8}}, 
            ImageSize \[Rule] {200, 400}] &\) /@ 
        Table[\[Alpha], {\[Alpha], \(-70\)\ Degree, 70\ Degree, 
            10  Degree}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.22222 
%%ImageSize: 200 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.396825 1.11111 0.396825 [
[.10317 1.09861 -6.96875 -10.9375 ]
[.10317 1.09861 6.96875 0 ]
[.30159 1.09861 -10.3125 -10.9375 ]
[.30159 1.09861 10.3125 0 ]
[.69841 1.09861 -7.5625 -10.9375 ]
[.69841 1.09861 7.5625 0 ]
[.89683 1.09861 -4.21875 -10.9375 ]
[.89683 1.09861 4.21875 0 ]
[.4875 .31746 -13.9375 -5.46875 ]
[.4875 .31746 0 5.46875 ]
[.4875 .71429 -13.9375 -5.46875 ]
[.4875 .71429 0 5.46875 ]
[.4875 1.50794 -8.4375 -5.46875 ]
[.4875 1.50794 0 5.46875 ]
[.4875 1.90476 -8.4375 -5.46875 ]
[.4875 1.90476 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 2.22222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 1.11111 m
.10317 1.11736 L
s
gsave
.10317 1.09861 -67.9688 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.30159 1.11111 m
.30159 1.11736 L
s
gsave
.30159 1.09861 -71.3125 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.69841 1.11111 m
.69841 1.11736 L
s
gsave
.69841 1.09861 -68.5625 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.89683 1.11111 m
.89683 1.11736 L
s
gsave
.89683 1.09861 -65.2188 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.14286 1.11111 m
.14286 1.11486 L
s
.18254 1.11111 m
.18254 1.11486 L
s
.22222 1.11111 m
.22222 1.11486 L
s
.2619 1.11111 m
.2619 1.11486 L
s
.34127 1.11111 m
.34127 1.11486 L
s
.38095 1.11111 m
.38095 1.11486 L
s
.42063 1.11111 m
.42063 1.11486 L
s
.46032 1.11111 m
.46032 1.11486 L
s
.53968 1.11111 m
.53968 1.11486 L
s
.57937 1.11111 m
.57937 1.11486 L
s
.61905 1.11111 m
.61905 1.11486 L
s
.65873 1.11111 m
.65873 1.11486 L
s
.7381 1.11111 m
.7381 1.11486 L
s
.77778 1.11111 m
.77778 1.11486 L
s
.81746 1.11111 m
.81746 1.11486 L
s
.85714 1.11111 m
.85714 1.11486 L
s
.06349 1.11111 m
.06349 1.11486 L
s
.02381 1.11111 m
.02381 1.11486 L
s
.93651 1.11111 m
.93651 1.11486 L
s
.97619 1.11111 m
.97619 1.11486 L
s
.25 Mabswid
0 1.11111 m
1 1.11111 L
s
.5 .31746 m
.50625 .31746 L
s
gsave
.4875 .31746 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .71429 m
.50625 .71429 L
s
gsave
.4875 .71429 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 1.50794 m
.50625 1.50794 L
s
gsave
.4875 1.50794 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 1.90476 m
.50625 1.90476 L
s
gsave
.4875 1.90476 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .39683 m
.50375 .39683 L
s
.5 .47619 m
.50375 .47619 L
s
.5 .55556 m
.50375 .55556 L
s
.5 .63492 m
.50375 .63492 L
s
.5 .79365 m
.50375 .79365 L
s
.5 .87302 m
.50375 .87302 L
s
.5 .95238 m
.50375 .95238 L
s
.5 1.03175 m
.50375 1.03175 L
s
.5 1.19048 m
.50375 1.19048 L
s
.5 1.26984 m
.50375 1.26984 L
s
.5 1.34921 m
.50375 1.34921 L
s
.5 1.42857 m
.50375 1.42857 L
s
.5 1.5873 m
.50375 1.5873 L
s
.5 1.66667 m
.50375 1.66667 L
s
.5 1.74603 m
.50375 1.74603 L
s
.5 1.8254 m
.50375 1.8254 L
s
.5 .2381 m
.50375 .2381 L
s
.5 .15873 m
.50375 .15873 L
s
.5 .07937 m
.50375 .07937 L
s
.5 1.98413 m
.50375 1.98413 L
s
.5 2.06349 m
.50375 2.06349 L
s
.5 2.14286 m
.50375 2.14286 L
s
.25 Mabswid
.5 0 m
.5 2.22222 L
s
0 0 m
1 0 L
1 2.22222 L
0 2.22222 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto fill
-0.03 0.0075 moveto 0 0 lineto
-0.03 -0.0075 lineto
-0.027 0 lineto
-0.03 0.0075 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.85 .65 0 r
.5 1.11111 m
.89683 1.11111 L
.89683 2.20138 L
F
1 1 0 r
.5 1.11111 m
.63572 1.11111 L
.63572 1.48401 L
F
1 0 0 r
.5 1.11111 m
.5 1.11111 .07937 0 70 arc
F
0 g
.5 Mabswid
newpath
.5 1.11111 .39683 0 365.73 arc
s
.02381 1.11111 m
.97619 1.11111 L
s
.5 .63492 m
.5 1.5873 L
s
.89683 2.20138 m
.5 1.11111 L
s
.89683 0 m
.89683 2.22222 L
s
0 0 1 r
.89683 1.11111 m
.89683 2.20138 L
s
% Start of user PostScript
1. 0 1. 2.74748 MAarrowhead1
% End of user PostScript
.5 1.11111 m
.89683 1.11111 L
s
% Start of user PostScript
0 0 1. 0 MAarrowhead1
% End of user PostScript
.5 1.11111 m
.63572 1.11111 L
s
% Start of user PostScript
0 0 0.34202 0 MAarrowhead1
% End of user PostScript
.63572 1.11111 m
.63572 1.48401 L
s
% Start of user PostScript
0.34202 0 0.34202 0.939693 MAarrowhead1
% End of user PostScript
0 g
gsave
.5 1.11111 -71.9375 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.63572 1.11111 -66.4688 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Q) show
69.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.63572 1.48401 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(P) show
69.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.89683 2.20138 -61 -10.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
69.438 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.89683 1.11111 -61 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(A) show
69.375 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.06349 1.84524 -61 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(tg) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.500 13.375 moveto
(H) show
74.625 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(70.) show
87.125 13.375 moveto
(\\260) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
90.688 13.375 moveto
(L) show
96.313 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
104.938 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.74748) show
137.438 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{200, 400},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003j0001m2000`400?l00000o`00003onP3oool0
07`0oooo00<000000?ooo`3oool0N`3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo
001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280
oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00
O03oool2000005L0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R
0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool0
07`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?oo
o`800000E`3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
8P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo
001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280
oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo0P00
001G0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?oo
o`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R
0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0R0?ooo`00L@3oool00`2oM0000000000000020000000304RLg`3o
ool0oooo00<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00L@3oool0
0`3ooml0W4P007Boo`080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool0
06X0oooo00<0okmd0000000000000P0000001P00B9`0gooo0?ooo`3oool0_g@0001d_`L0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00M03oool00`3o_g@007Bo0?ooo`05
0?ooo`800000E`3oool00`000000oooo0?ooo`0R0?ooo`00M@3oool00`3OW4P0M;oo0?ooo`040?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool00740oooo00H0okmd001d_`3o
ool0oooo0;md001d_ol50?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool0
0740oooo00H0oooO09a80000000000000018W03Oool50?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R
0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool0
07`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0280oooo001l0?ooo`800000E`3oool00`000000oooo0?ooo`0R0?ooo`00O03oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo
001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280
oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo0280oooo001l0?ooo`800000E`3oool00`000000oooo0?ooo`0R0?oo
o`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R
0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool0
07`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool08P3oool007`0oooo0P00001G0?ooo`030000003oool0oooo0280oooo001l
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
8P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo
001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0R0?ooo`00O03oool2000005L0oooo00<000000?ooo`3oool08P3oool007`0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?oo
o`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool08P3oool007`0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00O03oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0280oooo001l0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R
0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001c0?ooo`03
0?oog`2LB7@0_ooo00H0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0R0?ooo`00
L`3oool00`3ooml0W4Qd0;ooo`060?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
8P3oool006X0oooo00<0okmd0000000000000P0000001`00B9`0gooo0?ooo`3oool0oooO09a8M02o
ool01P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0280oooo001c0?oooa<00000
C`3oool00`000000oooo0?ooo`0R0?ooo`00K03oool7000000030?oog`2LB7@0_ooo00H0oooo00<0
00000?ooo`3oool01`3oool7000004P0oooo00<000000?ooo`3oool08P3oool006P0oooo10000006
0?ooo`040?noM0000000001d0;ooo`H0oooo00<000000?ooo`3oool03P3oool4000004@0oooo00<0
00000?ooo`3oool08P3oool006@0oooo1000000;0?ooo`030?oo_`1d07@0_ooo00H0oooo00<00000
0?ooo`3oool04P3oool400000400oooo00<000000?ooo`3oool08P3oool00680oooo0P00000H0?oo
o`030000003oool0oooo01H0oooo0P00000n0?ooo`030000003oool0oooo0280oooo001M0?ooo`D0
00006P3oool00`000000oooo0?ooo`0H0?ooo`D00000>@3oool00`000000oooo0?ooo`0R0?ooo`00
F`3oool2000001l0oooo00<000000?ooo`3oool07@3oool2000003L0oooo00<000000?ooo`3oool0
8P3oool005T0oooo0P00000Q0?ooo`030000003oool0oooo01l0oooo0P00000e0?ooo`030000003o
ool0oooo0280oooo001G0?ooo`8000008`3oool00`000000oooo0?ooo`0Q0?ooo`800000<`3oool0
0`000000oooo0?ooo`0R0?ooo`00E@3oool2000002D0oooo00<000000?ooo`3oool08`3oool20000
0340oooo00<000000?ooo`3oool08P3oool005<0oooo0P00000W0?ooo`030000003oool0oooo02D0
oooo0P00000_0?ooo`030000003oool0oooo0280oooo001A0?ooo`800000:@3oool00`000000oooo
0?ooo`0W0?ooo`800000;@3oool00`000000oooo0?ooo`0R0?ooo`00C`3oool2000002/0oooo00<0
00000?ooo`3oool0:@3oool2000002/0oooo00<000000?ooo`3oool08P3oool004h0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool08P3oool004`0oooo0P00000^0?ooo`030000003oool0oooo02`0oooo0P00000X0?oo
o`030000003oool0oooo0280oooo001:0?ooo`800000<03oool00`000000oooo0?ooo`0^0?ooo`80
00009P3oool00`000000oooo0?ooo`0R0?ooo`00B@3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0R0?ooo`00B03o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0R0?ooo`00AP3oool2000003@0oooo0P00000c0?ooo`8000008P3oool0
0`000000oooo0?ooo`0R0?ooo`00A03oool2000003H0oooo00<000000?ooo`3oool0=03oool20000
0200oooo00<000000?ooo`3oool08P3oool004<0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool08P3oool004<0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool08P3oool00440oooo0P00000i0?ooo`030000003oool0oooo03L0oooo0P00
000M0?ooo`030000003oool0oooo0280oooo00100?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0280oooo000o0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0280oooo000n0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0280oooo000m0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0280oooo000l0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0280oooo000k0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0280oooo000j0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0280oooo000i0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0280
oooo000h0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0280oooo000h0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0280oooo000f
0?ooo`800000A03oool00`000000oooo0?ooo`120?ooo`8000004P3oool00`000000oooo0?ooo`0R
0?ooo`00=@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0R0?ooo`00=@3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0R0?ooo`00
=03oool00`000000oooo0?ooo`150?ooo`800000A@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0280oooo000d0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0280oooo000c0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0280oooo000b0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0280
oooo000a0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0280oooo000`0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0280oooo000`
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0280oooo000_0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0280oooo000^0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0280oooo000^0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0280oooo000]0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0280oooo000]0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0280oooo000/0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0280oooo000/0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0280oooo000[0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo
000[0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0280oooo000Z0?ooo`030000003oool0oooo04l0oooo0P00001?
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool002X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool08P3oool002T0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool002T0oooo00<000000?ooo`3oool0
D03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
8P3oool002T0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool08P3oool002P0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool0
02P0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool08P3oool002P0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool002P0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool08P3oool002L0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool002L0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`1B0?ooo`050000003oool0oooo0?ooo`000000903o
ool002H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1B0?ooo`050000003oool0
oooo0?ooo`000000903oool002H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1C
0?ooo`040000003oool0oooo000002@0oooo000V0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool0D`3oool010000000oooo0?ooo`00000T0?ooo`009P3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo05<0oooo00@000000?ooo`3oool00000903oool002D0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`1C0?ooo`040000003oool0oooo000002@0oooo000U
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool00`000000oooo0000000T
0?ooo`009@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`000000903oool002D0oooo00<000000?ooo`3oool0E03oool2000005D0oooo00<000000?ooo`00
0000903oool002D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0000002@0oooo000T0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3o
ool2000002@0oooo000T0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool2
000002@0oooo000T0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool20000
02@0oooo000T0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E@3oool2000002@0
oooo000T0?ooo`050000003oool0oooO09a8M02oool0903oool02P2oM00000000000B02Lgol0oooo
0?oo_`1dB9`0gooo0?ooo`2oM0020000000304RLg`3oool0oooo0200oooo00<000000?ooo`3oool0
7@3oool00`3o_g@007Bo0?ooo`040?ooo`0:0;md00000000001809cOo`3oool0oono07A8W03Oool0
oooo0;md0080000000<0B9cO0?ooo`3oool08P3oool2000000030;ooo`3oool0oooo0240oooo000T
0?ooo`050000003oool0oooO09a8M02oool08`3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0
oooo00H0okmd04RLg`3oool0oooo0=nLB01d_olG0?ooo`060?oo_`1d000000000000000007@0_ooo
103oool00`000000oooo0?ooo`0H0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool0
0`3oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00H0okmd04RLg`3oool0oooo0=nLB01d
_olS0?ooo`80000000D0_ooo0?oog`2LB00004RL0=ooo`020?ooo`030?noM0000000B9cO01X0oooo
000M0?ooo`030?noM000000000000080000000L004RL0000003oool0oooo0?oog`2LB7@0_ooo01`0
oooo00<0okmd0000000000000P0000002000B9`0gooo0=nLB018W=l0oooo0?oo_`1d07@0_ooo1`3o
ool00`3o_g@0B9cO0?ooo`0E0?ooo`080?oo_`1d000004RL0=ooo`3ooml0W4P00000M02oool30?oo
o`030000003oool0oooo01L0oooo00P0oono07@00000B9`0gooo0;md00000000001809cOo`@0oooo
00H0gia804RLg`3oool0oono07@0M02oool70?ooo`030?noM018W=l0oooo0280oooo0P0000001@2o
ool0oooo0=nLB00004P0W=oo0080oooo00<0_g@00000M02oool06P3oool002<0oooo00H000000?oo
o`3oool0oooO09a8M02ooolS0?ooo`060=nLB01d_ol0oooo0?oog`2LB7@0_ooo0`3oool01P3o_g@0
001d0;ooo`3oool0gia807BooaH0oooo00<0okmd0000B02Lgol00P3oool00`3ogi`0B00007Boo`03
0?ooo`030000003oool0oooo01L0oooo00P0okmd0000B02Lgol0omnL04Q8W03Ogi`0B00004RLg`@0
oooo00H0gia807Boo`3oool0oooO09a8M02oool30?ooo`060?noM00007@0_ooo0?ooo`3OW4P0M;oo
8`3oool01P3ooml000000;ooo`3oool0oono07@000@0000000<007Bo0?ooo`3oool06@3oool002<0
oooo00H000000?oog`2LW;l0oooO09a8M02ooolS0?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo
0`3oool01@3ookl0M4Q804P00000000007Bo01L0oooo00<0gia80000M02oool00P3oool00`3ookl0
M00004RLg`030?ooo`030000003oool0oooo01L0oooo00<0gia80000M02oool00P3oool00`3ookl0
M00004RLg`040?ooo`060=nLB018W=l0oooo0?oo_`1d07@0_ooo0`3oool01@3ookl0M4Q804P00000
000007Bo0280oooo00D0oooO09bL_`3ooml000000;ooo`020?ooo`060;md0000B9`0gooo0?oOW018
0000M;oo6`3oool002<0oooo00H000000?ooo`3o_g@000000000M02ooolS0?ooo`060?noM000B9`0
gooo0?noM000B9`0gooo0`3oool00`3ooml0W4Q809cOo`0I0?ooo`030=nLB00007@0_ooo0080oooo
00<0oono07@00018W=l00`3oool00`000000oooo0?ooo`0G0?ooo`030=nLB00007@0_ooo0080oooo
00<0oono07@00018W=l0103oool01P3o_g@004RL0=ooo`3o_g@004RL0=ooo`<0oooo00<0oooO09a8
B02Lgol09@3oool0103o_g@000000000002oool20?ooo`060?noM00004P0W=oo0=nLB00007@0_ooo
6`3oool002<0oooo00H000000?ooo`3oool0oono07@0M02ooolT0?ooo`040;md00000000001809cO
o`D0oooo00D0_g@0000000000000001809cOo`0F0?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol00`3oool00`000000oooo0?ooo`0G0?ooo`030?noM00004P0W=oo0080oooo00<0omnL
04P0001d_ol01@3oool0102oM00000000000B02Lgol50?ooo`050;md0000000000000000B02Lgol0
8`3oool00`3ookl000000;ooo`020?ooo`050?oo_`1d0000B9bo09a80018W=l0703oool002<0oooo
00<000000?ooo`3oool0B`3oool00`3ookl0M000001d_`020?ooo`030;md000007@0_ooo00<0oooo
00<000000?ooo`3oool05`3oool0203ookl0M0000018W03Oool0oooo0;md0000B9`0gooo=`3oool0
0`000000oooo0?ooo`020?ooo`040=nLB000B4P0B01809cOoa`0oooo000S0?ooo`030000003oool0
oooo04`0oooo00H0oono07@00000000000000000M02oool40?ooo`030000003oool0oooo01P0oooo
00H0oono07@00000000000000018W03Ooolh0?ooo`030000003oool0oooo0080oooo00@0omnL04P0
0000B9`0gooo703oool002<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0280oooo000S0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05@3oool20000ocP0oooo0P000?l50?ooo`030000003oool0oooo0280oooo000S0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05@3oool50000ocD0oooo1P000?l00`3oool00000
0?ooo`0S0?ooo`00303ooom`000005X0003o5`00000=0?ooo`004@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000o`000?l0000?
0?l000H0ool01@000?l00`3oo`00003o0=VV000b0=VV00H0003o00<0fJH00000o`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0100oooo000S0?ooo`030000003oool0oooo
05H0oooo0P00000@0?l000H0ool00P000?l40?oo00030000o`3IYP00fJH00340fJH00P000?l50=VV
00030000o`3oool0oooo0280oooo000S0?ooo`030000003oool0oooo05H0oooo0P00000@0?l000`0
ool000<0003o0=VV003IYP00>03IYP000`000?l0oooo0?ooo`0R0?ooo`008`3oool00`000000oooo
0?ooo`1F0?ooo`800000403o000<0?oo00030000o`3IYP00fJH003P0fJH000<0003o0?ooo`3oool0
8P3oool002<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0000000>0?l000d0ool000<0
003o0=VV003IYP00>03IYP000`000?l0oooo0?ooo`0R0?ooo`008`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0000000h0o`003@3oo`000`000?l0fJH00=VV000h0=VV00030000o`3oool0
oooo0280oooo000S0?ooo`030000003oool0oooo05H0oooo00@000000?ooo`3oool000003@3o000=
0?oo00030000o`3IYP00fJH003P0fJH000<0003o0?ooo`3oool08P3oool002<0oooo00<000000?oo
o`3oool0EP3oool010000000oooo0?ooo`00000<0?l000h0ool000<0003o0=VV003IYP00>03IYP00
0`000?l0oooo0?ooo`0R0?ooo`008`3oool00`000000oooo0?ooo`1F0?ooo`040000003oool0oooo
000000`0o`003P3oo`000`000?l0fJH00=VV000h0=VV00030000o`3oool0oooo0280oooo000S0?oo
o`030000003oool0oooo05H0oooo00D000000?ooo`3oool0oooo0000000:0?l000l0ool000<0003o
0=VV003IYP00=`3IYP000`000000003o0?ooo`0S0?ooo`00903oool00`000000oooo0?ooo`1E0?oo
o`050000003oool0oooo0?ooo`0000002@3o000@0?oo00030000o`3IYP00fJH003L0fJH000<00000
0000o`3oool08`3oool002@0oooo00<000000?ooo`3oool0E@3oool01@000000oooo0?ooo`3oool0
000000P0o`004@3oo`000`000?l0fJH00=VV000g0=VV0003000000000?l0oooo02<0oooo000T0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool00P3oool00`000000o`000?l000040?l0
0180ool000<0003o0=VV003IYP00=`3IYP000`000000003o0?ooo`0S0?ooo`00903oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo0080oooo00<000000?l0003o00000`3o000C0?oo0003
0000o`3IYP00fJH003L0fJH000<000000000o`3oool08`3oool002@0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`020?ooo`030000003o0000o`000080o`00503oo`000`000?l0fJH0
0=VV000g0=VV0003000000000?l0oooo02<0oooo000T0?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool00`3oool00`000000o`000?l0000E0?oo00030000o`3IYP00fJH003L0fJH000<0
00000000o`3oool08`3oool002D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`03
0?ooo`030000003oo`00ool001D0ool000<0003o0=VV003IYP00=P3IYP000`000000fJH00000o`0T
0?ooo`009@3oool00`000000oooo0?ooo`1D0?ooo`8000001@3oool00`000000ool00?oo000D0?oo
00030000o`3IYP00fJH003H0fJH000<000000=VV00000?l0903oool002D0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`040?ooo`030000003oo`00ool001@0ool000<0003o0=VV003I
YP00=P3IYP000`000000fJH00000o`0T0?ooo`009@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo00@0oooo00<000000?oo003oo`00503oo`000`000?l0fJH00=VV000f0=VV00030000
003IYP00003o02@0oooo000U0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool01@3o
ool00`000000ool00?oo000C0?oo00030000o`3IYP00fJH003D0fJH000@000000=VV003IYP00003o
903oool002H0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`050?ooo`030000003o
o`00ool001<0ool000<0003o0=VV003IYP00=@3IYP0010000000fJH00=VV00000?lT0?ooo`009P3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00D0oooo00<000000?oo003oo`004`3o
o`000`000?l0fJH00=VV000e0=VV00040000003IYP00fJH00000ob@0oooo000V0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool01P3oool00`000000ool00?oo000B0?oo00030000o`3I
YP00fJH003D0fJH000@000000=VV003IYP00003o903oool002H0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`060?ooo`030000003oo`00ool00180ool000<0003o0=VV003IYP00=03I
YP001@000000fJH00=VV003IYP00003o02@0oooo000W0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool01P3oool00`000000ool00?oo000B0?oo00030000o`3IYP00fJH003@0fJH000D0
00000=VV003IYP00fJH00000o`0T0?ooo`009`3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo00L0oooo00<000000?oo003oo`004@3oo`000`000?l0fJH00=VV000c0=VV00030000003I
YP00fJH00080fJH000<0003o0?ooo`3oool08P3oool002P0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`070?ooo`030000003oo`00ool00140ool000<0003o0=VV003IYP00<`3IYP00
0`000000fJH00=VV00020=VV00030000o`3oool0oooo0280oooo000X0?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool0203oool00`000000ool00?oo000@0?oo00030000o`3IYP00fJH0
03<0fJH000<000000=VV003IYP000P3IYP000`000?l0oooo0?ooo`0R0?ooo`00:03oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo00P0oooo00<000000?oo003oo`00403oo`000`000?l0
fJH00=VV000c0=VV00030000003IYP00fJH00080fJH000<0003o0?ooo`3oool08P3oool002P0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`080?ooo`030000003oo`00ool00100ool0
00<0003o0=VV003IYP00<`3IYP000`000000fJH00=VV00020=VV00030000o`3oool0oooo0280oooo
000Y0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool02@3oool00`000000ool00?oo
000?0?oo00030000o`3IYP00fJH00380fJH000<000000=VV003IYP000`3IYP000`000?l0oooo0?oo
o`0R0?ooo`00:@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00T0oooo00<00000
0?oo003oo`003`3oo`000`000?l0fJH00=VV000b0=VV00030000003IYP00fJH000<0fJH000<0003o
0?ooo`3oool08P3oool002T0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`090?oo
o`030000003oo`00ool000l0ool000<0003o0=VV003IYP00<@3IYP000`000000fJH00=VV00040=VV
00030000o`3oool0oooo0280oooo000Z0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool02P3oool00`000000ool00?oo000>0?oo00030000o`3IYP00fJH00340fJH000<000000=VV003I
YP00103IYP000`000?l0oooo0?ooo`0R0?ooo`00:P3oool00`000000oooo0?ooo`1?0?ooo`800000
2`3oool00`000000ool00?oo000>0?oo00030000o`3IYP00fJH00300fJH000<000000=VV003IYP00
1@3IYP000`000?l0oooo0?ooo`0R0?ooo`00:`3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo00X0oooo00<000000?oo003oo`003P3oo`000`000?l0fJH00=VV000`0=VV00030000003I
YP00fJH000D0fJH000<0003o0?ooo`3oool08P3oool002/0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oo`00ool000d0ool000<0003o0=VV003IYP00;`3IYP00
0`000000fJH00=VV00060=VV00030000o`3oool0oooo0280oooo000/0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool02`3oool00`000000ool00?oo000=0?oo00030000o`3IYP00fJH0
02l0fJH000<000000=VV003IYP001P3IYP000`000?l0oooo0?ooo`0R0?ooo`00;03oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo00`0oooo00<000000?oo003oo`00303oo`000`000?l0
fJH00=VV000^0=VV00030000003IYP00fJH000L0fJH000<0003o0?ooo`3oool08P3oool002d0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0<0?ooo`030000003oo`00ool000`0ool0
00<0003o0=VV003IYP00;P3IYP000`000000fJH00=VV00070=VV00030000o`3oool0oooo0280oooo
000]0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0303oool00`000000ool00?oo
000<0?oo00030000o`3IYP00fJH002d0fJH000<000000=VV003IYP00203IYP000`000?l0oooo0?oo
o`0R0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00d0oooo00<00000
0?oo003oo`002`3oo`000`000?l0fJH00=VV000]0=VV00030000003IYP00fJH000P0fJH000<0003o
0?ooo`3oool08P3oool002h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oo`00ool000/0ool000<0003o0=VV003IYP00;03IYP000`000000fJH00=VV00090=VV
00030000o`3oool0oooo0280oooo000_0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool03@3oool00`000000ool00?oo000;0?oo00030000o`3IYP00fJH002`0fJH000<000000=VV003I
YP002@3IYP000`000?l0oooo0?ooo`0R0?ooo`00<03oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00h0oooo00<000000?oo003oo`002P3oo`000`000?l0fJH00=VV000[0=VV00030000
003IYP00fJH000X0fJH000<0003o0?ooo`3oool08P3oool00300oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oo`00ool000X0ool000<0003o0=VV003IYP00:P3I
YP000`000000fJH00=VV000;0=VV00030000o`3oool0oooo0280oooo000a0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool03P3oool00`000000ool00?oo000:0?oo00030000o`3IYP00
fJH002X0fJH000<000000=VV003IYP002`3IYP000`000?l0oooo0?ooo`0R0?ooo`00<@3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo00<000000?oo003oo`002@3oo`000`00
0?l0fJH00=VV000Y0=VV00030000003IYP00fJH000`0fJH000<0003o0?ooo`3oool08P3oool00380
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`030000003oo`00ool000T0
ool000<0003o0=VV003IYP00:@3IYP000`000000fJH00=VV000<0=VV00030000o`3oool0oooo0280
oooo000c0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0403oool00`000000ool0
0?oo00080?oo00030000o`3IYP00fJH002P0fJH000<000000=VV003IYP003@3IYP000`000?l0oooo
0?ooo`0R0?ooo`00=03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0100oooo00<0
00000?oo003oo`00203oo`000`000?l0fJH00=VV000W0=VV00030000003IYP00fJH000h0fJH000<0
003o0?ooo`3oool08P3oool003@0oooo00<000000?ooo`3oool0A@3oool200000140oooo00<00000
0?oo003oo`00203oo`000`000?l0fJH00=VV000V0=VV00030000003IYP00fJH000l0fJH000<0003o
0?ooo`3oool08P3oool003D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0A0?oo
o`030000003oo`00ool000L0ool000<0003o0=VV003IYP009P3IYP000`000000fJH00=VV000?0=VV
00030000o`3oool0oooo0280oooo000e0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool04@3oool00`000000ool00?oo00070?oo00030000o`3IYP00fJH002D0fJH000<000000=VV003I
YP00403IYP000`000?l0oooo0?ooo`0R0?ooo`00=P3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo0140oooo00<000000?oo003oo`001`3oo`000`000?l0fJH00=VV000U0=VV00030000
003IYP00fJH00100fJH000<0003o0?ooo`3oool08P3oool003L0oooo0P0000130?ooo`030000003o
ool0oooo0180oooo00<000000?oo003oo`001P3oo`000`000?l0fJH00=VV000S0=VV008000004`3I
YP000`000?l0oooo0?ooo`0R0?ooo`00>03oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0180oooo00<000000?oo003oo`001P3oo`000`000?l0fJH00=VV000R0=VV00030000003IYP00
fJH001<0fJH000<0003o0?ooo`3oool08P3oool003T0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0B0?ooo`030000003oo`00ool000H0ool000<0003o0=VV003IYP008P3IYP000`00
0000fJH00=VV000C0=VV00030000o`3oool0oooo0280oooo000j0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool04`3oool00`000000ool00?oo00050?oo00030000o`3IYP00fJH00240
fJH000<000000=VV003IYP00503IYP000`000?l0oooo0?ooo`0R0?ooo`00>`3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo01<0oooo00<000000?oo003oo`001@3oo`000`000?l0fJH0
0=VV000P0=VV00030000003IYP00fJH001D0fJH000<0003o0?ooo`3oool08P3oool003`0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0D0?ooo`030000003oo`00ool000@0ool000<0
003o0=VV003IYP007`3IYP000`000000fJH00=VV000F0=VV00030000o`3oool0oooo0280oooo000m
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0503oool00`000000ool00?oo0004
0?oo00030000o`3IYP00fJH001h0fJH000<000000=VV003IYP005`3IYP000`000?l0oooo0?ooo`0R
0?ooo`00?P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01@0oooo00<000000?oo
003oo`00103oo`000`000?l0fJH00=VV000M0=VV00030000003IYP00fJH001P0fJH000<0003o0?oo
o`3oool08P3oool003l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oo`00ool000<0ool000<0003o0=VV003IYP00703IYP000`000000fJH00=VV000I0=VV0003
0000o`3oool0oooo0280oooo00100?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
5@3oool00`000000ool00?oo00030?oo00030000o`3IYP00fJH001/0fJH000<000000=VV003IYP00
6P3IYP000`000?l0oooo0?ooo`0R0?ooo`00@@3oool00`000000oooo0?ooo`0h0?ooo`030000003o
ool0oooo01D0oooo00<000000?oo003oo`000`3oo`000`000?l0fJH00=VV000J0=VV00030000003I
YP00fJH001/0fJH000<0003o0?ooo`3oool08P3oool00480oooo0P00000h0?ooo`030000003oool0
oooo01H0oooo00<000000?oo003oo`000P3oo`000`000?l0fJH00=VV000H0=VV008000007P3IYP00
0`000?l0oooo0?ooo`0R0?ooo`00@`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
01H0oooo00<000000?oo003oo`000P3oo`000`000?l0fJH00=VV000G0=VV00030000003IYP00fJH0
01h0fJH000<0003o0?ooo`3oool08P3oool004@0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oo`00ool00080ool000<0003o0=VV003IYP005`3IYP000`000000
fJH00=VV000N0=VV00030000o`3oool0oooo0280oooo00150?ooo`800000=@3oool2000001P0oooo
00D000000?oo003oo`00ool00000o`0G0=VV008000008@3IYP000`000?l0oooo0?ooo`0R0?ooo`00
A`3oool2000003<0oooo00<000000?ooo`3oool05`3oool01@000000ool00?oo003oo`00003o01D0
fJH00P00000S0=VV00030000o`3oool0oooo0280oooo00190?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool0603oool010000000ool00?oo00000?lD0=VV00030000003IYP00fJH002<0
fJH000<0003o0?ooo`3oool08P3oool004X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0H0?ooo`040000003oo`00ool00000oa<0fJH000<000000=VV003IYP00903IYP000`000?l0
oooo0?ooo`0R0?ooo`00B`3oool2000002l0oooo00<000000?ooo`3oool0603oool010000000ool0
0?oo00000?lA0=VV008000009`3IYP000`000?l0oooo0?ooo`0R0?ooo`00C@3oool2000002d0oooo
00<000000?ooo`3oool06@3oool00`000000ool00000o`0?0=VV00800000:@3IYP000`000?l0oooo
0?ooo`0R0?ooo`00C`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01T0oooo00D0
00000000o`000?l0fJH00000o`0<0=VV00030000003IYP00fJH002T0fJH000<0003o0?ooo`3oool0
8P3oool00500oooo0P00000Z0?ooo`030000003oool0oooo01T0oooo00<000000000o`000?l00P00
0?l:0=VV00800000;03IYP000`000?l0oooo0?ooo`0R0?ooo`00DP3oool2000002P0oooo00<00000
0?ooo`3oool06P3oool30000o`T0fJH00P00000^0=VV00030000o`3oool0oooo0280oooo001D0?oo
o`8000009P3oool00`000000oooo0?ooo`0J0?ooo`<0003o1`3IYP0200000300fJH000<0003o0?oo
o`3oool08P3oool005H0oooo0P00000T0?ooo`030000003oool0oooo01X0oooo00<000000000o`00
0?l01@3IYP0200000380fJH000<0003o0?ooo`3oool08P3oool005P0oooo0P00000R0?ooo`030000
003oool0oooo01/0oooo0P000?l30=VV00800000=03IYP000`000?l0oooo0?ooo`0R0?ooo`00FP3o
ool3000001l0oooo00<000000?ooo`3oool06`3oool00`000?l0fJH000000002000003H0fJH000<0
003o0?ooo`3oool08P3oool005d0oooo1000000K0?ooo`030000003oool0oooo01T0oooo0P000000
0`000?l000000=VV000h0=VV00030000o`3oool0oooo0280oooo001Q0?ooo`8000006@3oool00`00
0000oooo0?ooo`0G0?ooo`8000000`3oool00`000000fJH00=VV000g0=VV00030000o`3oool0oooo
0280oooo001S0?ooo`@000005@3oool00`000000oooo0?ooo`0C0?ooo`@000001@3oool00`000000
fJH00=VV000g0=VV00030000o`3oool0oooo0280oooo001W0?ooo`D000001`3oool00`3ooml0W4Qd
0;ooo`060?ooo`030000003oool0oooo00h0oooo1@00000:0?ooo`030000003IYP00fJH003H0fJH0
00<0003o0?ooo`3oool08P3oool006`0oooo1P000000103oool0oooO09a8M02oool60?ooo`030000
003oool0oooo00P0oooo1P00000?0?ooo`030000003IYP00fJH003H0fJH000<0003o0?ooo`3oool0
8P3oool00780oooo5@00000@0?ooo`030?oo_`1d0000B9cO0080oooo00<000000=VV003IYP00=P3I
YP000`000?l0oooo0?ooo`0R0?ooo`00L`3oool00`3ooml0W4Qd0;ooo`060?ooo`030000003oool0
oooo01P0oooo00<0oono07@00018W=l00`3oool00`000000fJH00=VV000e0=VV00030000o`3oool0
oooo0280oooo001a0?ooo`050?oog`2LW;l0oooO09a8M02oool01P3oool00`000000oooo0?ooo`0H
0?ooo`030?oo_`1d0000B9cO00<0oooo00<000000=VV003IYP00=@3IYP000`000?l0oooo0?ooo`0R
0?ooo`00LP3oool0103o_g@000000000M02oool60?ooo`030000003oool0oooo01P0oooo00<0oono
07@0000000000P0000000`00M;l000000=VV000f0=VV00030000o`3oool0oooo0280oooo001c0?oo
o`030?oo_`1d07@0_ooo00H0oooo00<000000?ooo`3oool0603oool0203ookl0M00004RLg`3oool0
omnL04P00018W=l00000=P3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?oo
o`0H0?ooo`080?oo_`1d0000B9cO0?ooo`3ookl0M000001d_`00000f0=VV00030000o`3oool0oooo
0280oooo001l0?ooo`030000003oool0oooo01P0oooo00T0oono07@00018W=l0oooo0?oOW0180000
B9cO0?ooo`000000=@3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0H
0?ooo`030?oo_`1d000000000080000000@004RL0=ooo`3oool00000=@3IYP000`000?l0oooo0?oo
o`0R0?ooo`00O03oool00`000000oooo0?ooo`0P0?ooo`030000003IYP00fJH003<0fJH000<0003o
0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool08@3oool00`000000fJH00=VV000b0=VV
00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo0240oooo00<000000=VV003I
YP00<P3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0Q0?ooo`030000
003IYP00fJH00380fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool08P3o
ool00`000000fJH00=VV000a0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0
oooo0280oooo00<000000=VV003IYP00<@3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`00
0000oooo0?ooo`0R0?ooo`030000003IYP00fJH00340fJH000<0003o0?ooo`3oool08P3oool007`0
oooo00<000000?ooo`3oool08`3oool00`000000fJH00=VV000`0=VV00030000o`3oool0oooo0280
oooo001l0?ooo`030000003oool0oooo02<0oooo00<000000=VV003IYP00<03IYP000`000?l0oooo
0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0T0?ooo`030000003IYP00fJH002l0fJH000<0
003o0?ooo`3oool08P3oool007`0oooo0P00000U0?ooo`030000003IYP00fJH002l0fJH000<0003o
0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0903oool00`000000fJH00=VV000_0=VV
00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo02D0oooo00<000000=VV003I
YP00;P3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0U0?ooo`030000
003IYP00fJH002h0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool09@3o
ool00`000000fJH00=VV000^0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0
oooo02H0oooo00<000000=VV003IYP00;@3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`00
0000oooo0?ooo`0V0?ooo`030000003IYP00fJH002d0fJH000<0003o0?ooo`3oool08P3oool007`0
oooo00<000000?ooo`3oool09P3oool00`000000fJH00=VV000]0=VV00030000o`3oool0oooo0280
oooo001l0?ooo`030000003oool0oooo02L0oooo00<000000=VV003IYP00;03IYP000`000?l0oooo
0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0W0?ooo`030000003IYP00fJH002`0fJH000<0
003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0:03oool00`000000fJH00=VV000[
0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo02P0oooo00<000000=VV
003IYP00:`3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0X0?ooo`03
0000003IYP00fJH002/0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0
:@3oool00`000000fJH00=VV000Z0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003o
ool0oooo02T0oooo00<000000=VV003IYP00:P3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003IYP00fJH002X0fJH000<0003o0?ooo`3oool08P3oool0
07`0oooo00<000000?ooo`3oool0:P3oool00`000000fJH00=VV000Y0=VV00030000o`3oool0oooo
0280oooo001l0?ooo`030000003oool0oooo02X0oooo00<000000=VV003IYP00:@3IYP000`000?l0
oooo0?ooo`0R0?ooo`00O03oool2000002/0oooo00<000000=VV003IYP00:@3IYP000`000?l0oooo
0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0[0?ooo`030000003IYP00fJH002P0fJH000<0
003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0:`3oool00`000000fJH00=VV000X
0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo02/0oooo00<000000=VV
003IYP00:03IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0/0?ooo`03
0000003IYP00fJH002L0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0
;03oool00`000000fJH00=VV000W0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003o
ool0oooo02d0oooo00<000000=VV003IYP009P3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool0
0`000000oooo0?ooo`0]0?ooo`030000003IYP00fJH002H0fJH000<0003o0?ooo`3oool08P3oool0
07`0oooo00<000000?ooo`3oool0;@3oool00`000000fJH00=VV000V0=VV00030000o`3oool0oooo
0280oooo001l0?ooo`030000003oool0oooo02h0oooo00<000000=VV003IYP009@3IYP000`000?l0
oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0^0?ooo`030000003IYP00fJH002D0fJH0
00<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0;P3oool00`000000fJH00=VV
000U0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo02l0oooo00<00000
0=VV003IYP00903IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0_0?oo
o`030000003IYP00fJH002@0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3o
ool0;`3oool00`000000fJH00=VV000T0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000
003oool0oooo0300oooo00<000000=VV003IYP008`3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03o
ool00`000000oooo0?ooo`0`0?ooo`030000003IYP00fJH002<0fJH000<0003o0?ooo`3oool08P3o
ool007`0oooo00<000000?ooo`3oool0<@3oool00`000000fJH00=VV000R0=VV00030000o`3oool0
oooo0280oooo001l0?ooo`800000<P3oool00`000000fJH00=VV000R0=VV00030000o`3oool0oooo
0280oooo001l0?ooo`030000003oool0oooo0340oooo00<000000=VV003IYP008P3IYP000`000?l0
oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0b0?ooo`030000003IYP00fJH00240fJH0
00<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0<P3oool00`000000fJH00=VV
000Q0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo0380oooo00<00000
0=VV003IYP008@3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0c0?oo
o`030000003IYP00fJH00200fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3o
ool0<`3oool00`000000fJH00=VV000P0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000
003oool0oooo03<0oooo00<000000=VV003IYP00803IYP000`000?l0oooo0?ooo`0R0?ooo`00O03o
ool00`000000oooo0?ooo`0d0?ooo`030000003IYP00fJH001l0fJH000<0003o0?ooo`3oool08P3o
ool00240oooo00<0omnL04P0000000000P0000001@18W=l0oooo0?ooo`3OW4P0M;oo01@0oooo00<0
okmd04RLg`3oool0>P3oool00`000000oooo0?ooo`0d0?ooo`030000003IYP00fJH001l0fJH000<0
003o0?ooo`3oool08P3oool002D0oooo00D0okmd0000B02Lgol0omnL07BLg`0F0?ooo`030=nLB01d
_ol0oooo03T0oooo00<000000?ooo`3oool0=@3oool00`000000fJH00=VV000N0=VV00030000o`3o
ool0oooo0280oooo000N0?ooo`050;md0000000004RL0=ooo`3OW4P00P0000001@1dW9`0B00007Bo
g`2LB4P0W=oo0080oooo00<0_g@00000M02oool00`3oool0203OW4P000000000001d_ol0oooo0?oO
W0180000M;oo1P3oool00`3ogi`0B4RL0=ooo`0>0?ooo`030=nLB000000000000080000000P0B9cO
0?oOW0180000M;oo0?ooo`2oM000001d0;ooo`@0oooo00P0oooO09a80000B9`0gooo0?ooo`2oM000
001d0;ooo`@0oooo00H0oooO09a80000B9`0gooo0?ooo`2oM00200000003001d_`3oool0oooo00<0
oooo00<000000?ooo`3oool0=@3oool00`000000fJH00=VV000N0=VV00030000o`3oool0oooo0280
oooo000M0?ooo`0=0?oog`2LB00007Bo0?ooo`3o_g@0000007Boo`3oool0_g@00000001dZ9`0B01d
0;ooo`020?ooo`030=nLB00007@0_ooo0080oooo00T0omnL04P0001d_ol0okmd0000B02Lgol0omnL
04P0001d_ol01P3oool00`3ookl0M00007Boo`030?ooo`030?noM0000000000000<0000000<004RL
0=ooo`3oool00P3oool0103ookl0M0000018W03Oool20?ooo`070?oOW0180000M;oo0?ooo`3OW4P0
001d0;ooo`040?ooo`080?oog`2LB00004RL0=ooo`3oool0gia80000M02oool40?ooo`0:0?oog`2L
B00004RL0=ooo`3OW4P0001809cOo`3o_g@0000007Boo`@0oooo00<000000?ooo`3oool0=@3oool0
0`000000fJH00=VV000N0=VV00030000o`3oool0oooo0280oooo000M0?ooo`0=0?oog`2LB00007Bo
0?ooo`3OW4P0001d0;ooo`3oool0omnL04P0001dSg@0001d0;ooo`020?ooo`030?noM0000000M;oo
0080oooo00H0gia80000M02oool0omnL04P0001d_ol90?ooo`030?oog`2LB000M;oo00l0oooo00<0
omnL04P00000M;l01P3oool01P3o_g@0000007Boo`3oool0oooO09a800@0000000P004RL0=ooo`3o
_g@0000007Boo`3oool0oooO09a800@0000000L004RL09ad000007@0_ooo0?oo_`1d0000B9cO00@0
oooo00<000000?ooo`3oool0=P3oool00`000000fJH00=VV000M0=VV00030000o`3oool0oooo0280
oooo000M0?ooo`0=0?oog`2LB00007Bo0?ooo`3OW4P0001d0;ooo`3oool0omnL04P0001dSg@0001d
0;ooo`020?ooo`030?oo_`1d0000B9cO0080oooo00H0_g@00000M02oool0omnL04P00018W=l90?oo
o`030?oog`2LB000M;oo0100oooo00<0okmd00000018W=l01@3oool00`3ookl0M00004RLg`020?oo
o`0:0=nLB000B9`0gooO09a80000B9`0gooo0?ooo`3ookl0M00004RLg`80oooo00`0gia80018W03O
oml0W4P00018W03Oool0okmd0000B02Lgol0omnL04P0001d_ol40?ooo`030000003oool0oooo03H0
oooo00<000000=VV003IYP007@3IYP000`000?l0oooo0?ooo`0R0?ooo`007@3oool03@3ooml0W4P0
001d_`3oool0okmd0000001d_ol0oooo0;md00000000M:RL04P0M02oool00`3oool02P2oM000001d
0;ooo`3oool0_g@00000M02oool0omnL04P00018W=l40?ooo`080?oOW0180000001d0;ooo`3oool0
oono07@0001d_ol30?ooo`030?noM0000000000000<0000000<004RL0=ooo`3oool01@3oool00`3O
W4P0001809cOo`050?ooo`0:0;md000007@0_ooo0?ooo`3ooml0W4P007Bog`2LB00004RL0=ooo`80
oooo00l0_g@00000M02oool0oooo0?oog`2LB000M;oO09a80000B9`0gooo0?ooo`3o_g@000000000
B02Lgol01@3oool00`000000oooo0?ooo`0f0?ooo`030000003IYP00fJH001d0fJH000<0003o0?oo
o`3oool08P3oool001`0oooo00L0oooO09a80000000000000018W03Oool0gia80080000000D0B7Ad
04P0001d_ml0W4Q809cOo`030?ooo`0:0?oOW0180000B9cO0?ooo`3OW4P0001d0;ooo`3ogi`0B000
07Boo`@0oooo00P0_g@007Boo`3o_g@0B9cO0?ooo`3ogi`0B4RL0=oooa40oooo00<0omnL04P00018
W=l01@3oool00`3ogi`0B00004RLg`020?ooo`050?oOW018B7@0M4P00018W03Oool00P3oool00`3o
gi`0B00004RLg`020?ooo`0;0?oOW018B7@0M4P00018W03Oool0okmd0000B02Lgol0okmd0000B02L
gol0103oool00`000000oooo0?ooo`0g0?ooo`030000003IYP00fJH001`0fJH000<0003o0?ooo`3o
ool08P3oool001d0oooo00<0oooO09a80000M;l0203oool00`3ogi`0B4RL0=ooo`030?ooo`090=nL
B00004P0W=oo0?oOW01804P0W=oo0?noM00004P0W=oo00@0oooo00L0_g@007Boo`3o_g@0B9cO0?oo
o`2oM000M;oo00l0oooo00H0okmd0000001d_ol0omnL04P0001d_ol60?ooo`030=nLB00004P0W=oo
0080oooo00@0gia800000000B9`0gooo0`3oool00`3OW4P0001809cOo`020?ooo`0:0=nLB0000000
04RL0=ooo`3o_g@0001809cOo`3o_g@0000007Boo`@0oooo0P00000h0?ooo`030000003IYP00fJH0
01`0fJH000<0003o0?ooo`3oool08P3oool001h0oooo00<0omnL04Qd_`3oool0203oool00`3ogi`0
W;oo0=nLB0040000000304RLg`3oool0gia80080000000<0M;oo0?ooo`3oool00`3oool01P3ogi`0
B0000000M02oool0okmd07Booa40oooo00@0_g@000000000000007Bo103oool00`3OW4P000000000
00020000000804RLg`3oool0oooo0?oog`2LB00004RL0=ooo`3OW4P40000000904RLg`3oool0oooo
0?oog`2LB00004RL0=ooo`3oool0_g@00080000000<007Bo0?ooo`3oool00`3oool00`000000oooo
0?ooo`0g0?ooo`030000003IYP00fJH001`0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<0
00000?ooo`3oool0>03oool00`000000fJH00=VV000K0=VV00030000o`3oool0oooo0280oooo001l
0?ooo`030000003oool0oooo03P0oooo00<000000=VV003IYP006`3IYP000`000?l0oooo0?ooo`0R
0?ooo`00O03oool00`000000oooo0?ooo`0i0?ooo`030000003IYP00fJH001X0fJH000<0003o0?oo
o`3oool08P3oool007`0oooo00<000000?ooo`3oool0>@3oool00`000000fJH00=VV000J0=VV0003
0000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo03T0oooo00<000000=VV003IYP00
6P3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`0j0?ooo`030000003I
YP00fJH001T0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0>P3oool0
0`000000fJH00=VV000I0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo
03X0oooo00<000000=VV003IYP006@3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000
oooo0?ooo`0k0?ooo`030000003IYP00fJH001P0fJH000<0003o0?ooo`3oool08P3oool007`0oooo
00<000000?ooo`3oool0>`3oool00`000000fJH00=VV000H0=VV00030000o`3oool0oooo0280oooo
001l0?ooo`030000003oool0oooo03/0oooo00<000000=VV003IYP00603IYP000`000?l0oooo0?oo
o`0R0?ooo`00O03oool00`000000oooo0?ooo`0l0?ooo`030000003IYP00fJH001L0fJH000<0003o
0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0?03oool00`000000fJH00=VV000G0=VV
00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo03d0oooo00<000000=VV003I
YP005P3IYP000`000?l0oooo0?ooo`0R0?ooo`00L@3oool00`2oM0000000000000020000000304RL
g`3oool0oooo00<0oooo00<000000?ooo`3oool0?@3oool00`000000fJH00=VV000F0=VV00030000
o`3oool0oooo0280oooo001a0?ooo`030?oog`2LB000M;oo00P0oooo00<000000?ooo`3oool0?@3o
ool00`000000fJH00=VV000F0=VV00030000o`3oool0oooo0280oooo001c0?ooo`030;md0000M;l0
oooo00H0oooo0P00000o0?ooo`030000003IYP00fJH001D0fJH000<0003o0?ooo`3oool08P3oool0
07@0oooo00<0okmd001d_`3oool01@3oool00`000000oooo0?ooo`0n0?ooo`030000003IYP00fJH0
01D0fJH000<0003o0?ooo`3oool08P3oool007D0oooo00<0gia807Boo`3oool0103oool00`000000
oooo0?ooo`0n0?ooo`030000003IYP00fJH001D0fJH000<0003o0?ooo`3oool08P3oool00740oooo
00H0okmd001d_`3oool0oooo0;md001d_ol50?ooo`030000003oool0oooo03l0oooo00<000000=VV
003IYP00503IYP000`000?l0oooo0?ooo`0R0?ooo`00L@3oool01P3ooml0W4P000000000000004RL
0=ooo`D0oooo00<000000?ooo`3oool0?`3oool00`000000fJH00=VV000D0=VV00030000o`3oool0
oooo0280oooo001l0?ooo`030000003oool0oooo03l0oooo00<000000=VV003IYP00503IYP000`00
0?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`100?ooo`030000003IYP00fJH001<0
fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0@03oool00`000000fJH0
0=VV000C0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo0440oooo00<0
00000=VV003IYP004P3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`11
0?ooo`030000003IYP00fJH00180fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?oo
o`3oool0@@3oool00`000000fJH00=VV000B0=VV00030000o`3oool0oooo0280oooo001l0?ooo`03
0000003oool0oooo0480oooo00<000000=VV003IYP004@3IYP000`000?l0oooo0?ooo`0R0?ooo`00
O03oool00`000000oooo0?ooo`120?ooo`030000003IYP00fJH00140fJH000<0003o0?ooo`3oool0
8P3oool007`0oooo00<000000?ooo`3oool0@P3oool00`000000fJH00=VV000A0=VV00030000o`3o
ool0oooo0280oooo001l0?ooo`030000003oool0oooo04<0oooo00<000000=VV003IYP00403IYP00
0`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`130?ooo`030000003IYP00fJH0
0100fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0@`3oool00`000000
fJH00=VV000@0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo04@0oooo
00<000000=VV003IYP003`3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool2000004D0oooo00<0
00000=VV003IYP003`3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`15
0?ooo`030000003IYP00fJH000h0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?oo
o`3oool0A@3oool00`000000fJH00=VV000>0=VV00030000o`3oool0oooo0280oooo001l0?ooo`03
0000003oool0oooo04D0oooo00<000000=VV003IYP003P3IYP000`000?l0oooo0?ooo`0R0?ooo`00
O03oool00`000000oooo0?ooo`160?ooo`030000003IYP00fJH000d0fJH000<0003o0?ooo`3oool0
8P3oool007`0oooo00<000000?ooo`3oool0AP3oool00`000000fJH00=VV000=0=VV00030000o`3o
ool0oooo0280oooo001l0?ooo`030000003oool0oooo04H0oooo00<000000=VV003IYP003@3IYP00
0`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`170?ooo`030000003IYP00fJH0
00`0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0A`3oool00`000000
fJH00=VV000<0=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo04L0oooo
00<000000=VV003IYP00303IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?oo
o`180?ooo`030000003IYP00fJH000/0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<00000
0?ooo`3oool0B03oool00`000000fJH00=VV000;0=VV00030000o`3oool0oooo0280oooo001l0?oo
o`030000003oool0oooo04T0oooo00<000000=VV003IYP002P3IYP000`000?l0oooo0?ooo`0R0?oo
o`00O03oool00`000000oooo0?ooo`190?ooo`030000003IYP00fJH000X0fJH000<0003o0?ooo`3o
ool08P3oool007`0oooo00<000000?ooo`3oool0B@3oool00`000000fJH00=VV000:0=VV00030000
o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo04X0oooo00<000000=VV003IYP002@3I
YP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1:0?ooo`030000003IYP00
fJH000T0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0BP3oool00`00
0000fJH00=VV00090=VV00030000o`3oool0oooo0280oooo001l0?ooo`800000C03oool00`000000
fJH00=VV00080=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo04/0oooo
00<000000=VV003IYP00203IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?oo
o`1;0?ooo`030000003IYP00fJH000P0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<00000
0?ooo`3oool0C03oool00`000000fJH00=VV00070=VV00030000o`3oool0oooo0280oooo001l0?oo
o`030000003oool0oooo04`0oooo00<000000=VV003IYP001`3IYP000`000?l0oooo0?ooo`0R0?oo
o`00O03oool00`000000oooo0?ooo`1=0?ooo`030000003IYP00fJH000H0fJH000<0003o0?ooo`3o
ool08P3oool007`0oooo00<000000?ooo`3oool0C@3oool00`000000fJH00=VV00060=VV00030000
o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo04d0oooo00<000000=VV003IYP001P3I
YP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1>0?ooo`030000003IYP00
fJH000D0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0CP3oool00`00
0000fJH00=VV00050=VV00030000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo04h0
oooo00<000000=VV003IYP001@3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo
0?ooo`1?0?ooo`030000003IYP00fJH000@0fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<0
00000?ooo`3oool0C`3oool00`000000fJH00=VV00040=VV00030000o`3oool0oooo0280oooo001l
0?ooo`030000003oool0oooo04l0oooo00<000000=VV003IYP00103IYP000`000?l0oooo0?ooo`0R
0?ooo`00O03oool00`000000oooo0?ooo`1@0?ooo`030000003IYP00fJH000<0fJH000<0003o0?oo
o`3oool08P3oool007`0oooo00<000000?ooo`3oool0D03oool00`000000fJH00=VV00030=VV0003
0000o`3oool0oooo0280oooo001l0?ooo`030000003oool0oooo0540oooo00<000000=VV003IYP00
0P3IYP000`000?l0oooo0?ooo`0R0?ooo`00O03oool00`000000oooo0?ooo`1A0?ooo`030000003I
YP00fJH00080fJH000<0003o0?ooo`3oool08P3oool007`0oooo0P00001B0?ooo`030000003IYP00
fJH00080fJH000<0003o0?ooo`3oool08P3oool007`0oooo00<000000?ooo`3oool0DP3oool01@00
0000fJH00=VV003IYP00003o02@0oooo001l0?ooo`030000003oool0oooo0580oooo00D000000=VV
003IYP00fJH00000o`0T0?ooo`00O03oool00`000000oooo0?ooo`1B0?ooo`050000003IYP00fJH0
0=VV00000?l0903oool007`0oooo00<000000?ooo`3oool0D`3oool010000000fJH00=VV00000?lT
0?ooo`00O03oool00`000000oooo0?ooo`1C0?ooo`040000003IYP00fJH00000ob@0oooo001l0?oo
o`030000003oool0oooo05<0oooo00H000000000o`3IYP00003o0?ooo`000?lR0?ooo`00O03oool0
0`000000oooo0?ooo`1D0?ooo`D0003o8P3oool007`0oooo00<000000?ooo`3oool0E03oool01000
0000003o0000o`000?lS0?ooo`00O03oool00`000000oooo0?ooo`1E0?ooo`<0003o8`3oool007`0
oooo00<000000?ooo`3oool0E@3oool30000o`030?ooo`3ogi`0B00000<0000000<004RL0=ooo`3o
ool06P3oool007`0oooo00<000000?ooo`3oool0E@3oool30000o`080?ooo`3ogi`0B00007Boo`3o
ool0omnL04P00018W=lK0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`0:0000o`3oool0oooo
0?oOW0180000M;oo0?ooo`3ooml0W4P0001d_a/0oooo001l0?ooo`030000003oool0oooo05H0oooo
00X0003o0?ooo`3oool0omnL04P0001d_ol0oooo0?oOW018000007Bo6`3oool007`0oooo00<00000
0?ooo`3oool0EP3oool01@000000oooo0?ooo`3ogi`0B00000<0000000<007Bo0?ooo`3oool06P3o
ool007`0oooo00<000000?ooo`3oool0EP3oool02P000000oooo0?ooo`3ogi`0B00007Boo`3oool0
okmd0000B02LgolK0?ooo`00O03oool00`000000oooo0?ooo`1F0?ooo`0:0000003oool0oooo0?oO
W0180000M;oo0?ooo`3o_g@0000007Booa/0oooo001l0?ooo`030000003oool0oooo05H0oooo00D0
00000?ooo`3oool0omnL04P00003000000030018W03Oool0oooo01X0oooo0000\
\>"],
  ImageRangeCache->{{{94.4375, 233.375}, {736.875, 457.938}} -> {-3.29064, \
6.3937, 0.0140535, 0.0140535}}],

Cell[TextData[{
  "Sfruttando l'interpretazione precedente possiamo ottenere un grafico pi\
\[UGrave] preciso non appena si disponga in ascissa l'angolo ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " in modo del tutto analogo a quanto fatto per le funzioni seno e coseno. \
In ordinata poniamo quindi ",
  Cell[BoxData[
      \(TraditionalForm\`tg(\[Alpha])\)]],
  " cio\[EGrave], geometricamente, riportiamo il segmento orientato ",
  Cell[BoxData[
      FormBox[
        StyleBox["AB",
          FontSlant->"Italic"], TraditionalForm]]],
  ". Per riconoscere pi\[UGrave] facilmente tale costruzione riportiamo in \
colore verde il punto ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " della precedente discussione e, in tratteggio, la retta tangente in ",
  Cell[BoxData[
      \(TraditionalForm\`\((1, 0)\)\)]],
  " alla circonferenza goniometrica. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(numImmag = 100; angoloMax = 72\ Degree;\), "\n", 
    \(\(tanGraf = 
        Plot[Tan[x], {x, \(-angoloMax\), angoloMax}, 
          Ticks \[Rule] {{\(-\[Pi]\)/2, 0, \[Pi]/2}, Automatic}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(coordinateTan = 
        Table[{x, Tan[x]}, {x, \(-angoloMax\), angoloMax, 
            2  angoloMax/numImmag}];\)\), "\n", 
    \(\(listaTan1 = \(Show[tanGraf, 
              Graphics[{colBlu, AbsoluteThickness[2], 
                  Circle[{0, 0},  .3, 
                    If[#[\([1]\)] \[LessEqual] 0, {#[\([1]\)], 
                        0}, {0, #[\([1]\)]}]]}], 
              Graphics[
                Circle[{0, 0}, 
                  1]], \[IndentingNewLine]Graphics[{Line[{{0, 0}, {1, 
                        Tan[#[\([1]\)]]}, #, {#[\([1]\)], 0}}], 
                  Line[{{Cos[#[\([1]\)]], Sin[#[\([1]\)]]}, {Cos[#[\([1]\)]], 
                        0}}], {AbsoluteThickness[2], colBlu, 
                    Line[{{0, 0}, {#[\([1]\)], 0}}]}, {Dashing[{0.025, 
                        0.025}], Line[{{1, \(-3\)}, {1, 3}}]}, 
                  Line[{{\[Pi]/2, \(-3\)}, {\[Pi]/2, 3}}], 
                  Line[{{\(-\[Pi]\)/2, \(-3\)}, {\(-\[Pi]\)/2, 3}}]}], 
              Graphics[{Text["\<tg(\>" <> 
                      ToString[N[#[\([1]\)]]/Degree] <> "\<\[Degree]) = \>" <> 
                      ToString[N[#[\([2]\)]]], {\(-1.4\), 2.3}, {\(-1\), 1}, 
                    TextStyle \[Rule] 
                      stileTesto]}], \
\[IndentingNewLine]Graphics[{AbsolutePointSize[5], Point[#], 
                  Point[{Cos[#[\([1]\)]], Sin[#[\([1]\)]]}], {colVerde, 
                    Point[{1, 
                        Tan[#[\([1]\)]]}]}}], \
\[IndentingNewLine]DisplayFunction \[Rule] Identity] &\) /@ 
          coordinateTan;\)\), "\n", 
    \(\(listaTan2 = \(If[#[\([1]\)] \[Equal] \(-angoloMax\), 
              Show[Graphics[{AbsolutePointSize[5], 
                    Point[{#[\([1]\)], Tan[#[\([1]\)]]}]}], 
                DisplayFunction \[Rule] Identity], 
              Plot[Tan[x], {x, \(-angoloMax\), #[\([1]\)]}, Axes -> False, 
                PlotStyle \[Rule] {AbsoluteThickness[2], colRosso}, 
                DisplayFunction \[Rule] Identity]] &\) /@ 
          coordinateTan;\)\), "\n", 
    \(\(\(Show[#, DisplayFunction \[Rule] $DisplayFunction, 
            AspectRatio \[Rule] Automatic, ImageSize \[Rule] {300, 500}] &\) /@ 
        Thread[{listaTan1, listaTan2}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.95931 
%%ImageSize: 300 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.303152 0.979657 0.303152 [
[.02381 .96716 -8.84375 -17.8125 ]
[.02381 .96716 8.84375 0 ]
[.97619 .96716 -6.09375 -17.8125 ]
[.97619 .96716 6.09375 0 ]
[.4875 .0702 -13.9375 -5.46875 ]
[.4875 .0702 0 5.46875 ]
[.4875 .37335 -13.9375 -5.46875 ]
[.4875 .37335 0 5.46875 ]
[.4875 .6765 -13.9375 -5.46875 ]
[.4875 .6765 0 5.46875 ]
[.4875 1.28281 -8.4375 -5.46875 ]
[.4875 1.28281 0 5.46875 ]
[.4875 1.58596 -8.4375 -5.46875 ]
[.4875 1.58596 0 5.46875 ]
[.4875 1.88911 -8.4375 -5.46875 ]
[.4875 1.88911 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 1.95931 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .97966 m
.02381 .98591 L
s
gsave
.02381 .96716 -69.8438 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 14.500 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.500 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.563 14.500 moveto
(\\200\\200) show
71.688 14.500 moveto
(\\200\\200) show
73.813 14.500 moveto
(\\200) show
74.313 14.500 moveto
(\\200) show
70.375 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 .97966 m
.97619 .98591 L
s
gsave
.97619 .96716 -67.0938 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

65.000 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 14.500 moveto
(\\200\\200) show
66.188 14.500 moveto
(\\200\\200) show
68.313 14.500 moveto
(\\200) show
68.813 14.500 moveto
(\\200) show
64.875 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
0 .97966 m
1 .97966 L
s
.5 .0702 m
.50625 .0702 L
s
gsave
.4875 .0702 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 .37335 m
.50625 .37335 L
s
gsave
.4875 .37335 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .6765 m
.50625 .6765 L
s
gsave
.4875 .6765 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 1.28281 m
.50625 1.28281 L
s
gsave
.4875 1.28281 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 1.58596 m
.50625 1.58596 L
s
gsave
.4875 1.58596 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 1.88911 m
.50625 1.88911 L
s
gsave
.4875 1.88911 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .13083 m
.50375 .13083 L
s
.5 .19146 m
.50375 .19146 L
s
.5 .25209 m
.50375 .25209 L
s
.5 .31272 m
.50375 .31272 L
s
.5 .43398 m
.50375 .43398 L
s
.5 .49461 m
.50375 .49461 L
s
.5 .55524 m
.50375 .55524 L
s
.5 .61587 m
.50375 .61587 L
s
.5 .73714 m
.50375 .73714 L
s
.5 .79777 m
.50375 .79777 L
s
.5 .8584 m
.50375 .8584 L
s
.5 .91903 m
.50375 .91903 L
s
.5 1.04029 m
.50375 1.04029 L
s
.5 1.10092 m
.50375 1.10092 L
s
.5 1.16155 m
.50375 1.16155 L
s
.5 1.22218 m
.50375 1.22218 L
s
.5 1.34344 m
.50375 1.34344 L
s
.5 1.40407 m
.50375 1.40407 L
s
.5 1.4647 m
.50375 1.4647 L
s
.5 1.52533 m
.50375 1.52533 L
s
.5 1.64659 m
.50375 1.64659 L
s
.5 1.70722 m
.50375 1.70722 L
s
.5 1.76785 m
.50375 1.76785 L
s
.5 1.82848 m
.50375 1.82848 L
s
.5 .00957 m
.50375 .00957 L
s
.5 1.94974 m
.50375 1.94974 L
s
.25 Mabswid
.5 0 m
.5 1.95931 L
s
0 0 m
1 0 L
1 1.95931 L
0 1.95931 L
closepath
clip
newpath
.5 Mabswid
.11905 .04665 m
.13409 .18343 L
.14996 .29367 L
.16741 .38826 L
.18366 .45905 L
.21411 .56189 L
.2453 .64134 L
.27846 .70793 L
.3104 .76075 L
.34113 .80445 L
.37383 .84566 L
.40531 .88176 L
.43558 .91425 L
.46781 .94734 L
.49882 .97848 L
.5318 1.01158 L
.56357 1.04418 L
.59413 1.07693 L
.62664 1.11422 L
.65795 1.15364 L
.69121 1.20103 L
.72326 1.25451 L
.7541 1.31665 L
.78691 1.40038 L
.80324 1.45211 L
.8185 1.5089 L
.84887 1.65855 L
.86516 1.76999 L
.88 1.9028 L
.88095 1.91266 L
s
0 0 1 r
2 Mabswid
newpath
.5 .97966 .09095 -66.24 0 arc
s
0 g
.5 Mabswid
newpath
.5 .97966 .30315 0 365.73 arc
s
.5 .97966 m
.80315 .29102 L
.14952 .29102 L
.14952 .97966 L
s
.62214 .7022 m
.62214 .97966 L
s
0 0 1 r
2 Mabswid
.5 .97966 m
.14952 .97966 L
s
0 g
.5 Mabswid
[ .025 .025 ] 0 setdash
.80315 .0702 m
.80315 1.88911 L
s
[ ] 0 setdash
.97619 .0702 m
.97619 1.88911 L
s
.02381 .0702 m
.02381 1.88911 L
s
gsave
.07559 1.67691 -61 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(tg) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.500 13.375 moveto
(H) show
74.625 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
80.750 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(66.24) show
103.250 13.375 moveto
(\\260) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
106.813 13.375 moveto
(L) show
112.438 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
121.063 13.375 moveto
(-) show
127.188 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2716) show
154.688 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
5 Mabswid
.14952 .29102 Mdot
.62214 .7022 Mdot
0 1 0 r
.80315 .29102 Mdot
1 0 0 r
2 Mabswid
.11905 .04665 m
.12028 .05944 L
.12163 .07303 L
.1229 .08546 L
.12412 .09714 L
.12541 .10927 L
.12666 .12067 L
.12799 .1325 L
.12926 .14362 L
.13049 .15408 L
.1318 .16496 L
.13306 .1752 L
.13427 .18483 L
.13556 .19487 L
.1368 .20433 L
.13812 .21417 L
.13939 .22344 L
.14061 .23218 L
.14191 .24129 L
.14317 .24989 L
.1445 .25883 L
.14578 .26728 L
.14701 .27525 L
.14832 .28356 L
.14952 .29102 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{300, 500},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005g0002LB000`400?l00000o`00003oo`3ooomh
0?ooo`00_03oool00`000000oooo0?ooo`2h0?ooo`00_03oool00`000000oooo0?ooo`2h0?ooo`00
_03oool00`000000oooo0?ooo`2h0?ooo`00_03oool200000;T0oooo002l0?ooo`030000003oool0
oooo0;P0oooo002l0?ooo`030000003oool0oooo0;P0oooo002l0?ooo`030000003oool0oooo0;P0
oooo002l0?ooo`030000003oool0oooo0;P0oooo002l0?ooo`030000003oool0oooo0;P0oooo002l
0?ooo`030000003oool0oooo0;P0oooo002l0?ooo`030000003oool0oooo0;P0oooo002l0?ooo`03
0000003oool0oooo0;P0oooo002l0?ooo`030000003oool0oooo0;P0oooo002l0?ooo`030000003o
ool0oooo0;P0oooo00120?ooo`80o`00N03oool00`000000oooo0?ooo`2h0?ooo`00@P3oool20?l0
07P0oooo00<000000?ooo`3oool0^03oool00480oooo0P3o001h0?ooo`030000003oool0oooo0;P0
oooo00120?ooo`80o`00N03oool00`000000oooo0?ooo`2h0?ooo`00@P3oool20?l007P0oooo00<0
00000?ooo`3oool0^03oool004<0oooo0P3o001/0?ooo`040;md000000000000001d_`L0oooo00<0
00000?ooo`3oool0^03oool004<0oooo0P3o001[0?ooo`060?noM018W=l0oooo0?ooo`3OW4P0B9cO
1P3oool00`000000oooo0?ooo`2h0?ooo`00@`3oool20?l006@0oooo00<0okmd0000000000000P00
00000`00B9`0gooo0?ooo`030?ooo`030=nLB018W=l0oooo00D0oooo00<000000?ooo`3oool0^03o
ool002D0oooo00<000000?ooo`3oool06`3oool20?l006d0oooo00<0_g@000000018W=l01`3oool3
000005h0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`00
0000oooo0?ooo`0K0?ooo`80o`00KP3oool00`3ookl0M01d0;ooo`060?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000
oooo0?ooo`0K0?ooo`80o`00J`3oool01P3o_g@007Bo0?ooo`3ookl0M01d0;ooo`H0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo01/0oooo0P3o001/0?ooo`040;md00000000000007Boo`L0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo01/0oooo0P3o001g0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0K0?ooo`<0
o`00MP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0803oool002D0oooo00<000000?ooo`3oool0703oool20?l007H0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo01`0oooo0P3o001f0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0L0?ooo`80o`00MP3oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool0703oool20?l007H0oooo00<000000?ooo`3oool0U@3oool00`00
0000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0L0?ooo`80o`00MP3oool00`000000
oooo0?ooo`2E0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo01`0oooo
0P3o001f0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool0703oool20?l007H0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?oo
o`0P0?ooo`009@3oool00`000000oooo0?ooo`0L0?ooo`80o`00MP3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo01`0oooo0P3o001f0?oo
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3o
ool0703oool20?l000030000003oool0oooo07<0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0L0?ooo`<0o`00M@3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool07@3oool20?l007D0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo01d0oooo0P3o001e
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P
0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`80o`00M@3oool2000005l0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`80
o`00M@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0803oool002D0oooo00<000000?ooo`3oool07@3oool20?l007D0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo01d0oooo0P3o001e0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0M0?ooo`<0o`00M03oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool07P3oool20?l007@0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo01h0
oooo0P3o001d0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0803oool002D0oooo
00<000000?ooo`3oool07P3oool20?l007@0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0N0?ooo`80o`00M03oool00`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo01h0oooo0P3o001d
0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?oo
o`3oool07P3oool20?l007@0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0P0?oo
o`009@3oool00`000000oooo0?ooo`0N0?ooo`80o`00M03oool00`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo01h0oooo0P3o001d0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool07P3o
ool20?l000030000003oool0oooo0740oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo01h0oooo0`3o001c
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P
0?ooo`009@3oool00`000000oooo0?ooo`0O0?ooo`80o`00L`3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3o
ool07`3oool20?l007<0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo01l0oooo0P3o001c0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3o
ool00`000000oooo0?ooo`0O0?ooo`80o`00L`3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool07`3oool2
0?l007<0oooo0P00001O0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool07`3oool20?l007<0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo01l0
oooo0`3o001b0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0P0?ooo`80o`00LP3oool00`000000oooo
0?ooo`2E0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0200oooo0P3o
001b0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0803oool002D0oooo00<00000
0?ooo`3oool0803oool20?l00780oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0P
0?ooo`009@3oool00`000000oooo0?ooo`0P0?ooo`80o`00LP3oool00`000000oooo0?ooo`2E0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0200oooo0P3o001b0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0
803oool20?l00780oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0P0?ooo`009@3o
ool00`000000oooo0?ooo`0P0?ooo`80o`0000<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0200oooo0P3o0000
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0Q0?ooo`030?l000000000oooo
0700oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0200oooo000U0?ooo`030000003oool0oooo0240oooo0P3o001a0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo
0?ooo`0R0?ooo`030?l0003oool0oooo06l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0240oooo0P3o
001a0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0P0?ooo`009@3oool00`000000oooo0?ooo`0Q0?ooo`80o`00L@3oool00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?oo
o`3oool08@3oool30?l00700oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0280oooo0P3o001`0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`00
9@3oool00`000000oooo0?ooo`0R0?ooo`80o`00L03oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool08P3o
ool20?l00700oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool0
0`000000oooo0?ooo`0R0?ooo`80o`00L03oool2000009H0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool08P3oool20?l00700oooo00<000000?ooo`3oool0U@3oool00`00
0000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0R0?ooo`80o`00L03oool00`000000
oooo0?ooo`2E0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0280oooo
0P3o00000`000000oooo0?ooo`1]0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0
803oool002D0oooo00<000000?ooo`3oool08P3oool20?l000030000003oool0oooo06d0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0S
0?ooo`030?l000000000oooo06h0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0P
0?ooo`009@3oool00`000000oooo0?ooo`0S0?ooo`80o`00K`3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3o
ool0903oool00`3o0000oooo0?ooo`1]0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0S0?ooo`80o`00
K`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
803oool002D0oooo00<000000?ooo`3oool08`3oool20?l006l0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo02@0oooo00<0o`000000003oool0K@3oool00`000000oooo0?ooo`1M0?ooo`800?l0=P3oool0
0`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0S0?ooo`040000003o0000o`00
000006d0oooo00<000000?ooo`3oool0G03oool4003o03D0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool08P3oool3000000030?l00000000000000<X000001P00o`0d0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0280oooo0`0000000`3o0000
00000000001/0?ooo`030000003oool0oooo05/0oooo1P00o`0d0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo02<0oooo1000001]0?ooo`030000003oool0oooo05`0oooo
1000o`0e0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02@0oooo0P00
001^0?ooo`030000003oool0oooo05d0oooo0P00o`0f0?ooo`030000003oool0oooo0200oooo000U
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?oo
o`3oool09@3oool2000006d0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo0P00001]0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`00
9@3oool00`000000oooo0?ooo`0U0?ooo`800000K@3oool2000005`0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`800000K@3o
ool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool09@3oool2000006d0oooo00<000000?ooo`3oool0FP3oool0
1@000000oooo0?ooo`3oool0000003H0oooo00<000000?ooo`3oool0803oool002D0oooo00<00000
0?ooo`3oool09@3oool2000006d0oooo00<000000?ooo`3oool0FP3oool01@000000oooo0?ooo`3o
ool0000003H0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0000001/0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`000000K03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0000006`0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0000001/0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`000000K03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0000006`0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool010000000oooo0?ooo`00001[
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00@000000?oo
o`3oool00000J`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool010000000oooo0?ooo`00001[
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0P
0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`040000003oool0oooo000006/0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo02D0oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?oo
o`3oool09@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?oo
o`050000003oool0oooo0?ooo`000000JP3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool01@00
0000oooo0?ooo`3oool0000005h0oooo00<0_g@00000000000000P0000000`18W=l0oooo0?ooo`04
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0P
0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`000000GP3oool0
0`3ooml0W4P007Boo`090?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo
02D0oooo00D000000?ooo`3oool0oooo0000001G0?ooo`030?noM000000000000080000000H004RL
0=ooo`3oool0oooo0;md0000M;l80?ooo`<00000DP3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3o
ool01@000000oooo0?ooo`3oool000000640oooo00<0okmd001d_`3oool01P3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`000000
HP3oool00`3OW4P0M;oo0?ooo`050?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1K0?ooo`060?noM000
M;l0oooo0?ooo`2oM000M;oo1P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0F`3oool01P3ooml0W4P0
00000000000004RL0=ooo`H0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0200oooo000U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`1T0?ooo`800000B`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0200oooo000U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1S0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0P0?ooo`00
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`1O0?ooo`800000@P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0803oool002D0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1M0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0P0?oo
o`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0G@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo05`0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05T0oooo0P00000j0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0200oooo000U
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?oo
o`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0600oooo00<00000
0?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1A0?ooo`800000<@3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0803oool002D0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo06P0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0J@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0?`3oool00`3ooml0W4Qd0;ooo`070?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0o0?ooo`030?oog`2LB7@0_ooo00L0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo03D0oooo00<0okmd0000000000000P0000001000B9`0gooo0?ooo`3ooolE00000200oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0g0?ooo`L0000000<0oooO09a8M02oool01`3oool00`000000oooo0?ooo`080?ooo`L00000603o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0340oooo1@0000050?ooo`050?oog`2LW;l0oooO09a8M02oool01`3oool00`000000oooo0?oo
o`0?0?ooo`D000004`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo02l0oooo0P00000;0?ooo`040?noM0000000001d0;ooo`L0oooo00<0
00000?ooo`3oool0503oool200000100oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0Y0?ooo`D000003P3oool00`3ookl0M01d0;ooo`07
0?ooo`030000003oool0oooo01H0oooo1@00000;0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool09`3oool2000001d0oooo00<000000?oo
o`3oool06`3oool2000000P0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0T0?ooo`8000007`3oool00`000000oooo0?ooo`0M0?ooo`<0
00000`3oool3000003P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`00
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
8P3oool200000240oooo00<000000?ooo`3oool0803oool6000006l0oooo00<000000?ooo`3oool0
803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo01d0oooo1000000S0?ooo`030000003oool0oooo0240oooo1P00001^0?ooo`030000003o
ool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0K0?ooo`8000009`3oool00`000000oooo0?ooo`0Q0?ooo`H00000KP3oool0
0`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
0280oooo1P00001]0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0F0?ooo`800000:P3oool00`000000
oooo0?ooo`0S0?ooo`8000000`3oool2000006/0oooo00<000000?ooo`3oool0803oool002D0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01@0oooo
0P00000/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`0000001@3oool3000006P0oooo
00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0140oooo0P00000^0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`000000203oool2000006H0oooo00<000000?ooo`3oool0803oool002D0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo0P00000`
0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3oool000002P3oool2000002d0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0303oool200000380oooo00<00000
0?ooo`3oool08@3oool010000000oooo0?ooo`00000<0?ooo`800000:`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0803oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool0803oool01@000000oooo0?ooo`3oool0000000l0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`06
0?ooo`800000=P3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`000000403o
ool2000002L0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0f0?ooo`800000803oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`3oool2000003X0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0000000l0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`00
9@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0;03oool3000003d0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo0P00001G0?ooo`030000003o
ool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0:`3oool0
1@000000oooo0?ooo`3oool0000003`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02/0oooo00D00000
0?ooo`3oool0oooo0000000l0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Y0?ooo`8000001@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0I0?ooo`800000D`3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0803oool002D0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0<03oool2000001L0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0803oool002D0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool08@3oool2000000l0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0803oool002D0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`040000o`000000003o0000oaP0
oooo00<000000?ooo`3oool0<`3oool01@000000oooo0?ooo`3oool0000003H0oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`03
000000000?l0003o00<0003o5P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0003o5@3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0803oool002D0oooo1@0000000`18W=l0oooo0?oo
o`0P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool40000oa<0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0d0?ooo`030;md0000000000000080000000<0
B9cO0?ooo`3oool07P3oool002D0oooo00<0000009a8001d_ol09@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00@0oooo10000?lB0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0=03oool0103ooml0W4P007Boo`00000R0?ooo`009@3oool010000000oooo0;md0000
M;lT0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool30000oa40oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0f0?ooo`030;md00000000oooo0240oooo000U
0?ooo`050000003oool0oooo0?noM000M;l08`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00P0oooo0`000?l@0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0=`3o
ool00`00000007Bo0?ooo`0P0?ooo`009@3oool01P000000oooo0?ooo`3oool0gia807Boob80oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0100oooo
0P0000060?ooo`030000003oool0oooo00X0oooo0P000?l@0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0=P3oool00`000000gia807Boo`0P0?ooo`009@3oool01P00000007Bo0?oo
o`3oool0_g@007Boob80oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`80
003o3`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0000003<0oooo00H0okmd001d_`3o
ool000000;md001d_olP0?ooo`009@3oool01P000000W4P000000000000004RL0=ooob80oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0000000c0?ooo`060?oog`2LB000000000000000B9`0
gooo803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00d0oooo0P000?l>0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`000000
=P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03@3oool40000o``0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0000000f0?ooo`030000003oool0oooo0200oooo000L0?ooo`030?noM0000000
00000080000000/004RL0=ooo`3ookl0M0000000001d00000000001dM01d00000000000eS`0Q0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool30000o``0oooo00<000000?oo
o`3oool0=P3oool200000340oooo00@0oono07@00000M7@0M0000P0000000`0e00000000001d_`0O
0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool04@3oool20000o`/0oooo00<000000?ooo`3oool0=P3oool2000003H0oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01<0oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`0f0?ooo`80
0000=P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04P3oool20000o`/0oooo00<000000?ooo`3oool0
=P3oool2000003H0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool01`3o
ool01@000000oooo0?ooo`3oool0000001H0oooo00<0003o0?ooo`3oool02@3oool00`000000oooo
0?ooo`0f0?ooo`800000=P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`060?ooo`050000003oool0oooo0?ooo`0000005P3oool20000o`X0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0200oooo000T0?ooo`060?oo_`00
0000W=oo0?oOW01807@0_ooo8`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000001L0oooo00<0003o0?oo
o`3oool0203oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0340oooo00H0oono07@0
B02Lgol0omnL0000002ooolQ0?ooo`009@3oool010000000M7Bo0?oOW01dW=lT0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo000001P0oooo0P000?l90?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
<P3oool0103ookl0M7Bo0?oOW000000R0?ooo`009@3oool010000000_gAd0;oog`2LW;lT0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000001T0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo03<0oooo00<0_gAd0;oog`0000008P3oool002D0oooo00D000000=noM01d
_ol0_ibL0=ooo`0S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000001T0oooo0P000?l90?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0<@3oool01@2oW9`0gkmd07Boo`000000gooo0240oooo000U0?oo
o`0600000018000000000000000004P0W=oo8P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo05T0oooo00L000000?ooo`3oool0oooo0000003oool0000001T0oooo0P000?l90?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0<@3oool01P3ogi`0B0000000000000000018
09cOob00oooo000U0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo008000006P3oool20000o`T0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1K0?ooo`04
0000003oool00000000001X0oooo0P000?l90?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0G03oool2000001/0oooo0P000?l90?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`00
7@3oool_00000740003o6`0000020000oh8000006`3oool002D0oooo00<000000?ooo`3oool0903o
ooma0000o`030000003oool0oooo01P0oooo0P000?m30?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0000005h0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P
0?ooo`009@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo05d0oooo00@000000?oo
o`3oool00000G@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0G@3oool01@000000oooo0?ooo`3oool0
000005`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`1I0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo05d0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0G@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0540oooo0P00000f0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0500oooo0P00000f0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
04l0oooo0P00000f0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`000000=P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0000003H0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0000000f0?ooo`030000003oool0oooo0200oooo000U
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`000000=P3oool00`000000oooo0?ooo`0P
0?ooo`009@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05/0oooo0P00000A0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`000000=P3oool00`000000oooo0?ooo`0P0?oo
o`009@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`170?ooo`040000003oool0oooo000003H0oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`1K0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo05X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0803oool002D0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0F@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo0200oooo000U0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo05H0oooo0P00
000S0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0P0?ooo`009@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
0200oooo000U0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo04/0oooo
0P00000b0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo
0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo04/0oooo0P0000170?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0580oooo0P0000100?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool00P3oool2000005@0oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo03/0oooo00@000000?ooo`3oool00000EP3oool00`000000oooo0?ooo`0P0?oo
o`009@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0000001G0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000
003oool0oooo05D0oooo0P00000m0?ooo`030000003oool0oooo03/0oooo0P00001H0?ooo`030000
003oool0oooo0200oooo000U0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0000005P0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo03T0oooo00D000000?ooo`3oool0oooo0000001G0?ooo`030000003oool0oooo0200oooo000U
0?ooo`030000003oool0oooo05T0oooo0P00000i0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0f0?oo
o`800000>03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`1L0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`00
9@3oool00`000000oooo0?ooo`1M0?ooo`800000=@3oool00`000000oooo0?ooo`0d0?ooo`800000
2@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
803oool002D0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool0H@3oool200000340oooo00<000000?ooo`3oool0;`3oool30000
00l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0200oooo000U0?ooo`030000003oool0oooo06<0oooo0P00000_0?ooo`030000003oool0oooo02d0
oooo0P00000C0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`1U0?ooo`800000;@3oool00`000000oooo
0?ooo`0[0?ooo`8000005@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0I`3oool2000002/0oooo00<0
00000?ooo`3oool0:@3oool2000001P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0P0?ooo`009@3oool00`000000oooo0?ooo`1Y0?ooo`<00000:03oool00`000000oooo0?ooo`0W
0?ooo`8000006P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo06`0oooo0P00000V0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0200oooo000U0?ooo`03
0000003oool0oooo06h0oooo0P00000T0?ooo`030000003oool0oooo0280oooo1000000N0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0
L03oool200000280oooo00<000000?ooo`3oool0803oool2000002<0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`1b0?ooo`800000803o
ool00`000000oooo0?ooo`0N0?ooo`8000009@3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0200oooo000U0?ooo`030000003oool0oooo07@0oooo0`00000M0?ooo`030000003oool0
oooo01`0oooo0P00000X0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool0M`3oool4000001T0oooo00<000000?ooo`3oool05`3oool50000
02X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
0200oooo000U0?ooo`030000003oool0oooo07/0oooo0`00000F0?ooo`030000003oool0oooo01D0
oooo0P00000`0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`1n0?ooo`@00000203oool00`3ooml0W4Qd
0;ooo`070?ooo`030000003oool0oooo0100oooo1@00000b0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?oo
o`220?ooo`P0000000<0oooO09a8M02oool01`3oool00`000000oooo0?ooo`090?ooo`L00000>03o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool0RP3ooolF000003l0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo
08X0oooo00<0oooO09a8M02oool01`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000
oooo0?ooo`280?ooo`050?oog`2LW;l0oooO09a8M02oool01`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?oo
o`009@3oool00`000000oooo0?ooo`290?ooo`040?noM0000000001d0;ooo`L0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool0RP3oool00`3ookl0M01d0;ooo`070?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo09@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo
09@0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?oo
o`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0
oooo00<000000?ooo`3oool0U03oool200000580oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0803oool002D0oooo00<00000
0?ooo`3oool0U03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3o
ool0U03oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`00
9@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo09@0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool2000005/0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo
0?ooo`2D0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0P
0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`03
0000003oool0oooo05/0oooo00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`0P0?oo
o`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05/0oooo00@000000?ooo`3o
ool00000=P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`03
0000003oool0oooo05`0oooo00<000000?ooo`000000=P3oool00`000000oooo0?ooo`0P0?ooo`00
9@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`000000
=P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`000000=P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05d0oooo0P00000f0?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0G@3oool20000
03H0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`1M0?ooo`800000=P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo
0?ooo`2D0?ooo`030000003oool0oooo05d0oooo0P00000f0?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo09@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0G`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo0P00001P0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool0
0`000000oooo0?ooo`1O0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0803oool0
02D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`030000003oool00000
03@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`1N0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0803oool002D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0000003@0oooo
00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0803oool002D0oooo00<00000
0?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`040000003oool0oooo000003<0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N
0?ooo`040000003oool0oooo000003<0oooo00<000000?ooo`3oool0803oool002D0oooo00<00000
0?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`040000003oool0oooo000003<0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N
0?ooo`050000003oool0oooo0?ooo`000000<P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05h0oooo00D000000?ooo`3oool0oooo0000
000b0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo09@0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool2000005l0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0803oool002D0oooo00<00000
0?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`009@3o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0803oool002D0
oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?oo
o`3oool0U03oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0
U03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo0200oooo000U0?ooo`030000003oool0oooo08P0oooo00<0_g@00000000000000P000000
0`18W=l0oooo0?ooo`040?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo
08P0oooo00<0oooO09a8001d_ol02@3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000
oooo0?ooo`2:0?ooo`030;md0000M;l0oooo00L0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0803oool002D0oooo
00<000000?ooo`3oool0R`3oool00`3o_g@007Bo0?ooo`060?ooo`<00000GP3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool0S03oool00`3OW4P0M;oo0?ooo`050?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0200oooo000U
0?ooo`030000003oool0oooo08P0oooo00H0okmd001d_`3oool0oooo0;md001d_ol60?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0200oooo000U0?ooo`030000003oool0oooo08P0oooo00H0oooO09a8000000000000
0018W03Oool60?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo
00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0200oooo000U0?oo
o`030000003oool0oooo09@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0D
0?ooo`030?oOW018000000000080000000D0B9cO0?ooo`3oool0gia807Boo`0X0?ooo`030?noM018
W=l0oooo04/0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0603oool0
1@3o_g@0001809cOo`3ogi`0M9cO02X0oooo00<0gia807Boo`3oool0BP3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0P0?ooo`009@3oool00`000000oooo0?ooo`0A0?ooo`050;md0000000004RL0=ooo`3OW4P00P00
00001@1dW9`0B00007Bog`2LB4P0W=oo00X0oooo00@0okmd00000000000007Bo0P3oool02@3o_g@0
000000000000M;l0oooo0?oOW0180000M;oo0=nLB0040000000704RLg`3oool0oooo0?oog`2LB000
04RL0=ooo`060?ooo`030?oOW018B9`0gooo01H0oooo00<0gia80000000000000P0000001@18W=l0
omnL04P0001d_ol0gia800@0000000D0B9cO0?ooo`2oM000001d0;ooo`040?ooo`030?noM0000000
M;oo0080oooo00@0okmd00000000000007Bo503oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0P0?ooo`009@3oool0
0`000000oooo0?ooo`0@0?ooo`0=0?oog`2LB00007Bo0?ooo`3o_g@0000007Boo`3oool0_g@00000
001dZ9`0B01d0;ooo`090?ooo`0C0?oOW01804P0W=oo0?oOW0180000M;oo0?oOW01804P0W=oo0?oO
W0180000M;oo0?oOW0180000M;oo0?oo_`1d000004RL0=ooo`040?ooo`040?oog`2LB00004RL0=oo
o`H0oooo00<0oono07@0001d_ol00`3oool00`3o_g@0000000000003000000030018W03Oool0oooo
00X0oooo00@0oono07@00000B9`0gooo0P3oool01`3ogi`0B00007Boo`3ookl0M0000018W03Oool0
0`3oool00`3OW4P0001d0;ooo`040?ooo`0:0?noM0000000M;oo0?ooo`3ogi`0B01809cOo`3ogi`0
B00007Booa<0oooo0P00001/0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool0403oool03`3ooml0W4P0001d_`3oool0gia80000M02oool0
oooo0?oOW0180000M8md0000M02oool0oooo0?noM0050000000>0018W03Oool0gia80000M02oool0
oono07@00000M;l0gia80000M02oool0oono07@00000M;l40?ooo`060?oOW018000007Bo0?ooo`3o
oml0W4P0100000000`00B9`0gooo0?ooo`040?ooo`030?oog`2LB000M;oo00h0oooo00<0okmd0000
000000000`0000001P00B9`0gooo0?ooo`3ogi`0B000001d_`H0oooo00<0omnL04P00000M;l00`3o
ool00`3o_g@0000007Boo`040?ooo`0:0?noM0000000M;oo0?ooo`3OW4P0001d0;ooo`3ookl0M000
001d_a<0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo0100oooo00d0oooO09a80000M;l0oooo0=nLB000
07@0_ooo0?ooo`3ogi`0B00007B?M00007@0_ooo00T0oooo00`0_g@00000B02Lgol0omnL04P00018
W=l0_g@00000B02Lgol0omnL04P00018W=l50?ooo`0:0?noM0000000B9cO0?ooo`3OW4P004RL0=oo
g`2LB00004RL0=ooo`H0oooo00<0oooO09a8001d_ol0603oool00`3o_g@0000004RLg`060?ooo`03
0?noM0000000B9cO0080oooo00<0oono07@00018W=l0103oool02P3o_g@0000007Boo`3oool0_g@0
0000B02Lgol0omnL04P00018W=lC0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0@0?ooo`0=0?oog`2L
B00007Bo0?ooo`3o_g@0000007Boo`3oool0_g@00000001dZ9`0B01d0;ooo`090?ooo`0;0=nLB000
B4P0B00000000000M;l0oooo0=nLB000B4P0B00000000000M;l01`3oool04P3OW4P0001809cOo`3o
oml0W4P007Bog`2LB00004RL0=ooo`3oool0omnL04P0000007@0_ooo0?ooo`3ookl0M00007Boo`<0
oooo00<0okmd0000000000000`0000000`00B9`0gooo0?ooo`0=0?ooo`030=nLB00004P0W=oo00H0
oooo00<0gia80000B02Lgol00P3oool03`2oM000001d0;ooo`3oool0omnL04Qd_`3o_g@0000007Bo
o`3oool0gia80018B01800000000001d_`0D0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0?0?ooo`07
0?oog`2LB000000000000000B9`0gooo0=nLB0020000000504QdM0180000M;oO09a8B02Lgol02@3o
ool00`3OW4P0001d0;ooo`030?ooo`030=nLB00007@0_ooo00T0oooo0180omnL04P00018W=l0oooo
0?oOW018B7@0M4P00018W03Oool0oooo0;md001d_ol0okmd04RLg`3oool0omnL04Q8W03OoolI0?oo
o`030?oOW0180000B9cO00H0oooo00<0omnL04P00018W=l00P3oool01P3ogi`0B00004RLg`3oool0
omnL04P00080000000D0M;oo0?ooo`3OW4P0001d0;ooo`0F0?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?oo
o`0@0?ooo`030?oog`2LB00007Bo00P0oooo00<0omnL04Q8W03Oool0203oool0303ogi`0B00007Bo
o`3o_g@0000007Boo`3ogi`0B00007Boo`3o_g@0000007Boo`<0oooo00H0okmd0000001d_ol0omnL
04P0001d_ol20?ooo`0<0=nLB000000004RL0=ooo`3oool0_g@007Boo`3o_g@0B9cO0?ooo`2oM000
M;oo5`3oool01P3o_g@0000007Boo`3ogi`0B00007Boo`<0oooo00H0okmd0000001d_ol0omnL04P0
001d_ol30?ooo`0?0=nLB00004P0W=oo0?ooo`3ogi`0B0000000001d_ol0oooo0?oOW0180000M;oo
0?noM0000000M;oo01<0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo0140oooo00<0omnL04Qd_`3oool0
203oool00`3ogi`0W;oo0?ooo`080?ooo`040?noM00000000000001d_`80oooo00@0okmd00000000
000007Bo1@3oool0102oM000000000000000M;l30?ooo`0;0?oog`2LB00004RL0=ooo`3oool0omnL
04P0000007@0_ooo0?noM01d_ol06@3oool0102oM000000000000000M;l50?ooo`060;md00000000
0000001d_`3oool0gia8100000001P18W=l0oooo0?ooo`3ogi`0B00007Boo`80oooo00@0okmd0000
0000000007Bo503oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0P0?oo
o`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0
oooo05h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0803oool002D0
oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo
0?ooo`2D0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?oo
o`3oool0U03oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1^0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0
U03oool200000700oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0P0?ooo`009@3o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0P0?ooo`00
9@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003o
ool0oooo09@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
0740oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000
oooo0?ooo`2D0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?oo
o`2D0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?oo
o`030000003oool0oooo0780oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?oo
o`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`800000
G`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0P0?ooo`009@3oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo
09@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo
000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0803oool002D0oooo00<00000
0?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0L`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0L`3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0200
oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0P
0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0200oooo000U0?ooo`03
0000003oool0oooo09@0oooo0P00001O0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0803o
ool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo0200oooo000U0?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`1d0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1e
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?oo
o`3oool0U03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1e0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0
U03oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
803oool002D0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1e0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool0U03oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0200oooo000U0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0803oool002D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?oo
o`290?ooo`040;md000000000000001d_`L0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0803oool002D0oooo00<0
00000?ooo`3oool0R03oool01P3o_g@0B9cO0?ooo`3oool0gia804RLg`H0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0803oool002D0oooo00<000000?ooo`3oool0S03oool00`3OW4P0B9cO0?ooo`050?ooo`<00000
GP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
803oool00;80oooo00<0_g@000000018W=l01`3oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo03l0oooo002c0?ooo`030?oo_`1d07@0_ooo00H0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`0o0?ooo`00/03oool01P3o_g@007Bo0?ooo`3ookl0M01d0;ooo`H0oooo00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`0o0?ooo`00/@3oool0102oM00000000000001d
_ol70?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0?`3oool00;`0oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`0o0?ooo`00_03oool00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo03l0oooo002l0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0?P3oool00;`0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0n0?ooo`00_03o
ool00`000000oooo0?ooo`2h0?ooo`00_03oool00`000000oooo0?ooo`2h0?ooo`00_03oool00`00
0000oooo0?ooo`2h0?ooo`00_03oool00`000000oooo0?ooo`2h0?ooo`00_03oool00`000000oooo
0?ooo`2h0?ooo`00_03oool00`000000oooo0?ooo`2h0?ooo`00_03oool00`000000oooo0?ooo`2h
0?ooo`00_03oool00`000000oooo0?ooo`2h0?ooo`00_03oool00`000000oooo0?ooo`2h0?ooo`00
_03oool00`000000oooo0?ooo`2h0?ooo`00_03oool200000;T0oooo002l0?ooo`030000003oool0
oooo0;P0oooo002l0?ooo`030000003oool0oooo0;P0oooo002l0?ooo`030000003oool0oooo0;P0
oooo0000\
\>"],
  ImageRangeCache->{{{94.4375, 303.375}, {449.875, 100.938}} -> {-3.70207, \
-1.36199, 0.0129657, 0.0129657}}],

Cell[TextData[{
  "Appare quindi che il grafico della tangente tra ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(]\)\(-\)\(\[Pi]\/2\)\), \
\(\(\[Pi]\/2\)\([\)\)\)]],
  " \[EGrave] sempre crescente e possiede due asintoti verticali dati dalle \
rette ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]\(\[Pi]\/2\)\)\)]],
  ". Osserviamo inoltre che, se ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " si avvicina a ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/2\)]],
  " assumendo valori sempre inferiori di tale valore (o anche \"da \
sinistra\"), la tangente assume valori positivi sempre maggiori: esprimiamo \
tale andamento con la scrittura informale"
}], "Text"],

Cell[BoxData[
    \(\[Alpha]\[LongRightArrow]\(\[Pi]\/2\) - \ \ \ \ \ tg \((\[Alpha])\)\
\[LongRightArrow]\(+\[Infinity]\)\)], "DisplayFormula"],

Cell[TextData[{
  "Allo stesso modo se ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " si avvicina a ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(\[Pi]\/2\)\)\)]],
  "essendo sempre maggiore di tale valore (o \"da destra\"), la tangente \
assume valori negativi sempre minori: informalmente esprimiamo ancora ci\
\[OGrave] con la scrittura"
}], "Text"],

Cell[BoxData[
    \(\[Alpha]\[LongRightArrow]\(-\(\[Pi]\/2\)\) + \ \ \ \ \ tg \
\((\[Alpha])\)\[LongRightArrow]\(-\[Infinity]\)\)], "DisplayFormula"],

Cell[TextData[{
  "In base allo studio del grafico emerge pure il codominio di tale funzione: \
dato che il punto ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " (di color verde) pu\[OGrave] assumere qualsiasi posizione sulla retta \
tratteggiata, in corrispondenza la sua ordinata (cio\[EGrave] ",
  Cell[BoxData[
      \(TraditionalForm\`tg(\[Alpha])\)]],
  ") pu\[OGrave] assumere qualsiasi valore reale. Il codominio della funzione \
tangente coincide pertanto con ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\)]],
  ".\nVisualizziamo infine il grafico della tangente in insiemi pi\[UGrave] \
estesi di ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(]\)\(-\)\(\[Pi]\/2\)\), \
\(\(\[Pi]\/2\)\([\)\)\)]],
  " cos\[IGrave] da rendere evidente la sua (gi\[AGrave] dimostrata) \
periodicit\[AGrave]. Si tenga presente che in corrispondenza dei valori ",
  Cell[BoxData[
      \(TraditionalForm\`x = \ \[Pi]\/2 + k\ \[Pi]\)]],
  " la funzione tangente non esiste (nella animazione seguente pertanto, gli \
asintoti ",
  Cell[BoxData[
      \(TraditionalForm\`x = \ \[Pi]\/2 + k\ \[Pi]\)]],
  " non appartengono al grafico della tangente). "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Istruzioni grafiche", "Subsubsection"],

Cell[BoxData[{
    \(numImmag = 100; angoloMax = 2  \[Pi];\), "\n", 
    \(\(tanGraf = 
        Plot[Tan[x], {x, \(-angoloMax\), angoloMax}, 
          Ticks \[Rule] {Range[\(-2\) \[Pi], 2  \[Pi], \[Pi]/2], Automatic}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(coordinateTan = 
        Table[{x, Tan[x]}, {x, \(-angoloMax\), angoloMax, 
            2  angoloMax/numImmag}];\)\), "\n", 
    \(\(listaTan1 = \(Show[tanGraf, 
              If[#[\([1]\)] \[NotEqual] 0, 
                ParametricPlot[{Sign[t] t\ Cos[t], Sign[t]\ t\ Sin[t]}/
                      200  \[Pi], {t, Sign[#[\([1]\)]] 2  \[Pi], 
                    Sign[#[\([1]\)]] 2\ \[Pi] + #[\([1]\)]}, 
                  Axes \[Rule] False, DisplayFunction \[Rule] Identity, 
                  PlotStyle \[Rule] {AbsoluteThickness[2], colBlu}], 
                Graphics[{Point[{Cos[#[\([1]\)]] - 1, Sin[#[\([1]\)]]}]}]], 
              Graphics[
                Circle[{0, 0}, 
                  1]], \[IndentingNewLine]Graphics[{Line[{{0, 0}, {1, 
                        Tan[#[\([1]\)]]}, #, {#[\([1]\)], 0}}], 
                  Line[{{0, 0}, {Cos[#[\([1]\)]], 
                        Sin[#[\([1]\)]]}, {Cos[#[\([1]\)]], 
                        0}}], {AbsoluteThickness[2], colBlu, 
                    Line[{{0, 0}, {#[\([1]\)], 0}}]}, {Dashing[{0.025, 
                        0.025}], Line[{{1, \(-4\)}, {1, 4}}]}, 
                  Line[{{\[Pi]/2, \(-3\)}, {\[Pi]/2, 3}}], 
                  Line[{{\(-\[Pi]\)/2, \(-3\)}, {\(-\[Pi]\)/2, 3}}]}], 
              Graphics[{Text["\<tg(\>" <> 
                      ToString[N[#[\([1]\)]]/Degree] <> "\<\[Degree]) = \>" <> 
                      ToString[N[#[\([2]\)]]], {1.8, 3}, {\(-1\), 1}, 
                    TextStyle \[Rule] 
                      stileTesto]}], \
\[IndentingNewLine]Graphics[{AbsolutePointSize[5], Point[#], 
                  Point[{Cos[#[\([1]\)]], Sin[#[\([1]\)]]}], {colVerde, 
                    Point[{1, 
                        Tan[#[\([1]\)]]}]}}], \
\[IndentingNewLine]DisplayFunction \[Rule] Identity] &\) /@ 
          coordinateTan;\)\), "\n", 
    \(\(listaTan2 = \(If[#[\([1]\)] \[Equal] \(-angoloMax\), 
              Show[Graphics[{AbsolutePointSize[5], 
                    Point[{#[\([1]\)], Tan[#[\([1]\)]]}]}], 
                DisplayFunction \[Rule] Identity], 
              Plot[Tan[x], {x, \(-angoloMax\), #[\([1]\)]}, Axes -> False, 
                PlotStyle \[Rule] {AbsoluteThickness[2], colRosso}, 
                DisplayFunction \[Rule] Identity]] &\) /@ 
          coordinateTan;\)\), "\n", 
    \(\(\(Show[#, DisplayFunction \[Rule] $DisplayFunction, 
            AspectRatio \[Rule] Automatic, ImageSize \[Rule] {500, 320}, 
            PlotRange \[Rule] {\(-4\), 4}] &\) /@ 
        Thread[{listaTan1, listaTan2}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Animazione", "Subsubsection"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6063 
%%ImageSize: 500 320 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.303152 0.0757881 [
[.02381 .29065 -9.84375 -10.9375 ]
[.02381 .29065 9.84375 0 ]
[.14286 .29065 -11.7188 -20 ]
[.14286 .29065 11.7188 0 ]
[.2619 .29065 -6.84375 -10.9375 ]
[.2619 .29065 6.84375 0 ]
[.38095 .29065 -8.84375 -17.8125 ]
[.38095 .29065 8.84375 0 ]
[.61905 .29065 -6.09375 -17.8125 ]
[.61905 .29065 6.09375 0 ]
[.7381 .29065 -4.09375 -10.9375 ]
[.7381 .29065 4.09375 0 ]
[.85714 .29065 -8.96875 -20 ]
[.85714 .29065 8.96875 0 ]
[.97619 .29065 -7.09375 -10.9375 ]
[.97619 .29065 7.09375 0 ]
[.4875 0 -13.9375 -5.46875 ]
[.4875 0 0 5.46875 ]
[.4875 .07579 -13.9375 -5.46875 ]
[.4875 .07579 0 5.46875 ]
[.4875 .15158 -13.9375 -5.46875 ]
[.4875 .15158 0 5.46875 ]
[.4875 .22736 -13.9375 -5.46875 ]
[.4875 .22736 0 5.46875 ]
[.4875 .37894 -8.4375 -5.46875 ]
[.4875 .37894 0 5.46875 ]
[.4875 .45473 -8.4375 -5.46875 ]
[.4875 .45473 0 5.46875 ]
[.4875 .53052 -8.4375 -5.46875 ]
[.4875 .53052 0 5.46875 ]
[.4875 .6063 -8.4375 -5.46875 ]
[.4875 .6063 0 5.46875 ]
[ 0 0 0 0 ]
[ 1 .6063 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30315 m
.02381 .3094 L
s
gsave
.02381 .29065 -70.8438 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
74.500 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.14286 .30315 m
.14286 .3094 L
s
gsave
.14286 .29065 -72.7188 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 16.688 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.375 10.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
76.375 10.750 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.563 16.688 moveto
(\\200\\200\\200\\200) show
73.813 16.688 moveto
(\\200\\200\\200\\200) show
78.063 16.688 moveto
(\\200\\200) show
80.063 16.688 moveto
(\\200) show
73.250 23.000 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.2619 .30315 m
.2619 .3094 L
s
gsave
.2619 .29065 -67.8438 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.38095 .30315 m
.38095 .3094 L
s
gsave
.38095 .29065 -69.8438 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 14.500 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
70.500 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.563 14.500 moveto
(\\200\\200) show
71.688 14.500 moveto
(\\200\\200) show
73.813 14.500 moveto
(\\200) show
74.313 14.500 moveto
(\\200) show
70.375 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.61905 .30315 m
.61905 .3094 L
s
gsave
.61905 .29065 -67.0938 -21.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 25.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

65.000 8.563 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 14.500 moveto
(\\200\\200) show
66.188 14.500 moveto
(\\200\\200) show
68.313 14.500 moveto
(\\200) show
68.813 14.500 moveto
(\\200) show
64.875 20.813 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7381 .30315 m
.7381 .3094 L
s
gsave
.7381 .29065 -65.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
.85714 .30315 m
.85714 .3094 L
s
gsave
.85714 .29065 -69.9688 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

64.875 10.750 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
70.875 10.750 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
64.063 16.688 moveto
(\\200\\200\\200\\200) show
68.313 16.688 moveto
(\\200\\200\\200\\200) show
72.563 16.688 moveto
(\\200\\200) show
74.563 16.688 moveto
(\\200) show
67.750 23.000 moveto
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.97619 .30315 m
.97619 .3094 L
s
gsave
.97619 .29065 -68.0938 -14.9375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
%%BeginResource: font Helvetica-MISO
%%BeginFont: Helvetica-MISO
/Helvetica /Helvetica-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-MISO
%%IncludeFont: Helvetica-MISO
/Helvetica-MISO findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
1.000 setlinewidth
grestore
0 .30315 m
1 .30315 L
s
.5 0 m
.50625 0 L
s
gsave
.4875 0 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5 .07579 m
.50625 .07579 L
s
gsave
.4875 .07579 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 .15158 m
.50625 .15158 L
s
gsave
.4875 .15158 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .22736 m
.50625 .22736 L
s
gsave
.4875 .22736 -74.9375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
68.500 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .37894 m
.50625 .37894 L
s
gsave
.4875 .37894 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .45473 m
.50625 .45473 L
s
gsave
.4875 .45473 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .53052 m
.50625 .53052 L
s
gsave
.4875 .53052 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 .6063 m
.50625 .6063 L
s
gsave
.4875 .6063 -69.4375 -9.46875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.188 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 8.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .01516 m
.50375 .01516 L
s
.5 .03032 m
.50375 .03032 L
s
.5 .04547 m
.50375 .04547 L
s
.5 .06063 m
.50375 .06063 L
s
.5 .09095 m
.50375 .09095 L
s
.5 .1061 m
.50375 .1061 L
s
.5 .12126 m
.50375 .12126 L
s
.5 .13642 m
.50375 .13642 L
s
.5 .16673 m
.50375 .16673 L
s
.5 .18189 m
.50375 .18189 L
s
.5 .19705 m
.50375 .19705 L
s
.5 .21221 m
.50375 .21221 L
s
.5 .24252 m
.50375 .24252 L
s
.5 .25768 m
.50375 .25768 L
s
.5 .27284 m
.50375 .27284 L
s
.5 .28799 m
.50375 .28799 L
s
.5 .31831 m
.50375 .31831 L
s
.5 .33347 m
.50375 .33347 L
s
.5 .34863 m
.50375 .34863 L
s
.5 .36378 m
.50375 .36378 L
s
.5 .3941 m
.50375 .3941 L
s
.5 .40926 m
.50375 .40926 L
s
.5 .42441 m
.50375 .42441 L
s
.5 .43957 m
.50375 .43957 L
s
.5 .46989 m
.50375 .46989 L
s
.5 .48504 m
.50375 .48504 L
s
.5 .5002 m
.50375 .5002 L
s
.5 .51536 m
.50375 .51536 L
s
.5 .54567 m
.50375 .54567 L
s
.5 .56083 m
.50375 .56083 L
s
.5 .57599 m
.50375 .57599 L
s
.5 .59115 m
.50375 .59115 L
s
.25 Mabswid
.5 0 m
.5 .6063 L
s
0 0 m
1 0 L
1 .6063 L
0 .6063 L
closepath
clip
newpath
.5 Mabswid
.02381 .30315 m
.04262 .32236 L
.06244 .34552 L
.07216 .35934 L
.08255 .3774 L
.08852 .3901 L
.09396 .40384 L
.09911 .41954 L
.10458 .44023 L
.10932 .46308 L
.11454 .49643 L
.11682 .51502 L
.11928 .53887 L
.12373 .59699 L
s
.12373 .59699 m
.12423 .6063 L
s
.14244 .6063 m
.14248 0 L
s
.16145 0 m
.16166 .00403 L
.16442 .04399 L
.16907 .09287 L
.17142 .11168 L
.174 .12923 L
.18284 .17307 L
.18805 .1915 L
.193 .20583 L
.20229 .22718 L
.21228 .24497 L
.22318 .26066 L
.26388 .30512 L
.28271 .3245 L
.30306 .34889 L
.31424 .36577 L
.32451 .38537 L
.33433 .41041 L
.33927 .42679 L
.34469 .44929 L
.34995 .47797 L
.35492 .51509 L
.35939 .56231 L
.36191 .59843 L
s
.36191 .59843 m
.36234 .6063 L
s
.38024 .6063 m
.38024 0 L
s
.39954 0 m
.40423 .06422 L
.40693 .09079 L
.40948 .11143 L
.41426 .14195 L
.4194 .16681 L
.42498 .18772 L
.43443 .2142 L
.44483 .23562 L
.46587 .26651 L
.50618 .30934 L
.52473 .3288 L
.54497 .35426 L
.55594 .37209 L
.56612 .39343 L
.57585 .42139 L
.58128 .44245 L
.58621 .467 L
.59109 .49922 L
.59376 .52179 L
.59625 .54742 L
s
.59625 .54742 m
.60044 .6063 L
s
.61979 .6063 m
.61982 0 L
s
.6377 0 m
.63849 .01422 L
.64107 .04971 L
.64589 .09818 L
.65048 .13101 L
.6547 .15409 L
.66421 .19138 L
.66893 .20512 L
.67398 .21757 L
.68308 .23589 L
.70377 .26626 L
.7452 .31028 L
.76595 .33233 L
.77507 .34337 L
.78512 .35731 L
.79409 .3722 L
.80375 .39232 L
.80908 .4062 L
.81396 .42144 L
.81897 .44068 L
.82352 .46262 L
.82828 .49244 L
.83072 .51164 L
.83336 .53665 L
.83581 .56521 L
.83806 .59778 L
s
.83806 .59778 m
.83853 .6063 L
s
.85737 .6063 m
.85738 0 L
s
.87576 0 m
.87807 .03574 L
.88308 .09043 L
.88581 .11247 L
.88877 .1322 L
.89412 .16035 L
.89933 .18137 L
.90412 .19696 L
.91388 .22157 L
.92297 .23904 L
.94365 .26845 L
.97619 .30315 L
s
0 0 1 r
2 Mabswid
.50748 .30315 m
.50751 .30333 L
.50753 .30353 L
.50755 .30373 L
.50756 .30383 L
.50756 .30393 L
.50756 .30398 L
.50757 .30404 L
.50757 .30409 L
.50757 .30414 L
.50757 .30417 L
.50757 .30419 L
.50757 .30421 L
.50757 .30424 L
.50757 .30425 L
.50757 .30427 L
.50757 .30429 L
.50757 .30432 L
.50757 .30434 L
.50757 .30436 L
.50757 .30437 L
.50757 .30438 L
.50757 .3044 L
.50757 .30443 L
.50757 .30446 L
.50757 .30452 L
.50757 .30458 L
.50756 .30469 L
.50756 .30479 L
.50754 .30499 L
.50752 .30518 L
.50746 .30561 L
.50739 .306 L
.50728 .30642 L
.507 .30724 L
.50665 .308 L
.50618 .30878 L
.50564 .30949 L
.50505 .31012 L
.50434 .31073 L
.50359 .31125 L
.50272 .31172 L
.50183 .31208 L
.50093 .31234 L
.50045 .31243 L
.5002 .31247 L
.49993 .31251 L
.49968 .31254 L
.49944 .31256 L
.49933 .31256 L
Mistroke
.49921 .31257 L
.49915 .31257 L
.49909 .31257 L
.49904 .31257 L
.49898 .31258 L
.49895 .31258 L
.49892 .31258 L
.4989 .31258 L
.49888 .31258 L
.49886 .31258 L
.49885 .31258 L
.49882 .31258 L
.49879 .31258 L
.49876 .31258 L
.49874 .31258 L
.49872 .31258 L
.49869 .31258 L
.49865 .31258 L
.49858 .31257 L
.49851 .31257 L
.49844 .31257 L
.49831 .31256 L
.49819 .31256 L
.49793 .31253 L
.49766 .31251 L
.49741 .31247 L
.49693 .31239 L
.49643 .31227 L
.49596 .31214 L
.49499 .31178 L
.49408 .31133 L
.49316 .31075 L
.49233 .31009 L
.49153 .30931 L
Mfstroke
0 g
.5 Mabswid
newpath
.5 .30315 .07579 0 365.73 arc
s
.5 .30315 m
.57579 .24809 L
.69048 .24809 L
.69048 .30315 L
s
.5 .30315 m
.43869 .3477 L
.43869 .30315 L
s
0 0 1 r
2 Mabswid
.5 .30315 m
.69048 .30315 L
s
0 g
.5 Mabswid
[ .025 .025 ] 0 setdash
.57579 0 m
.57579 .6063 L
s
[ ] 0 setdash
.61905 .07579 m
.61905 .53052 L
s
.38095 .07579 m
.38095 .53052 L
s
gsave
.63642 .53052 -61 -16.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(tg) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
71.500 13.375 moveto
(H) show
74.625 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(144.) show
92.125 13.375 moveto
(\\260) show
%%IncludeResource: font Mathematica2-Bold
%%IncludeFont: Mathematica2-Bold
/Mathematica2-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.688 13.375 moveto
(L) show
101.313 13.375 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
109.938 13.375 moveto
(-) show
116.063 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.726543) show
153.563 13.375 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
5 Mabswid
.69048 .24809 Mdot
.43869 .3477 Mdot
0 1 0 r
.57579 .24809 Mdot
1 0 0 r
2 Mabswid
.02381 .30315 m
.05085 .33141 L
.06493 .34885 L
.07238 .35968 L
.08035 .37319 L
.08786 .38858 L
.09469 .40589 L
.10156 .42818 L
.10805 .4564 L
.11128 .47439 L
.11484 .49871 L
.11855 .5313 L
.12203 .57197 L
s
.12203 .57197 m
.12417 .6063 L
s
.14263 .6063 m
.14265 0 L
s
.16147 0 m
.16233 .0147 L
.16598 .06249 L
.16944 .09604 L
.17594 .14072 L
.17957 .15915 L
.18294 .17347 L
.19057 .1991 L
.19798 .21802 L
.20496 .23236 L
.21799 .25357 L
.24502 .28598 L
.27376 .3151 L
.28808 .33042 L
.30143 .3467 L
.31429 .36585 L
.32805 .39349 L
.33519 .41303 L
.33895 .42562 L
.34295 .4414 L
.34643 .45787 L
.35027 .48002 L
.35351 .5032 L
.35704 .53533 L
.36049 .57704 L
.36225 .604 L
s
.36225 .604 m
.36237 .6063 L
s
.38047 .6063 m
.38047 0 L
s
.39957 0 m
.40014 .01027 L
.40395 .06114 L
.40754 .09606 L
.41076 .12051 L
.41424 .14186 L
.4209 .17296 L
.42821 .19779 L
.43584 .21748 L
.44296 .23218 L
.45722 .25516 L
.47021 .27173 L
.49812 .30127 L
.52496 .32906 L
.53854 .3454 L
.55352 .3678 L
.56035 .38061 L
.56771 .39738 L
.57466 .4174 L
.58102 .44131 L
.58434 .45693 L
.58789 .47701 L
.59096 .49818 L
.59428 .52674 L
.59631 .54818 L
.59819 .57151 L
.59994 .59742 L
s
.59994 .59742 m
.60044 .6063 L
s
.6188 .6063 m
.6188 0 L
s
.63763 0 m
.63768 .00113 L
.63946 .02862 L
.64115 .05067 L
.64431 .08428 L
.64772 .11245 L
.65142 .13665 L
.65809 .16926 L
.66425 .19153 L
.67672 .22356 L
.68381 .23718 L
.69048 .24809 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 320},
  Magnification->0.7,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009a0001T2000`400?l00000o`00003oo`3ooooo
0?ooog<0oooo003o0?ooool0ooooL`3oool00?l0ooooo`3ooomc0?ooo`00o`3ooooo0?ooog<0oooo
003o0?ooool0ooooL`3oool00?l0ooooo`3ooomc0?ooo`00o`3ooooo0?ooog<0oooo003o0?ooool0
ooooL`3oool00?l0oooo;03oool00`3o_g@0B9cO0?ooo`3o0?oood@0oooo003o0?ooob`0oooo00<0
okmd04RLg`3oool0o`3ooom40?ooo`00o`3ooolR0?ooo`030?noM000000000000080000000<004RL
0=ooo`3OW4P0100000000`18W=l0oooo0?ooo`3o0?oood80oooo003o0?ooobT0oooo00D0oono07@0
M02oool0okmd04RLg`0;0?ooo`@00000o`3ooolf0?ooo`00F03oool20?l000X0oooo0P3o00260?oo
o`80o`002P3oool20?l002l0oooo00@0omnL04Q8W03O_g@0B9cO2`3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo01L0oooo0P3o00090?ooo`80o`00R@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo04`0oooo001H0?ooo`80o`002P3oool20?l008H0oooo0P3o000:0?oo
o`80o`00<03oool00`3o_g@0000004RLg`0;0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool05`3oool20?l000X0oooo0P3o00280?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0C03oool005P0oooo0P3o000:0?ooo`80o`00QP3oool20?l000X0oooo0P3o000a0?ooo`03
0=nLB018W=l0oooo00X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80
o`002P3oool20?l008P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1<0?ooo`00
F03oool20?l000X0oooo0P3o00260?ooo`80o`002P3oool20?l003h0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0G0?ooo`80o`002P3oool20?l008P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`1<0?ooo`00F03oool20?l000X0oooo0P3o00260?ooo`80o`002P3o
ool20?l003h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`002P3o
ool20?l008P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1<0?ooo`00F03oool2
0?l000X0oooo0P3o00260?ooo`80o`002P3oool20?l003h0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0G0?ooo`80o`002P3oool20?l008P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`1<0?ooo`00F03oool20?l000X0oooo0P3o00260?ooo`80o`002`3oool20?l0
03d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`002P3oool20?l0
08P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1<0?ooo`00F03oool20?l000X0
oooo0P3o00260?ooo`80o`002`3oool20?l003d0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0G0?ooo`80o`002P3oool20?l008P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`1<0?ooo`00F03oool20?l000X0oooo0P3o00260?ooo`80o`002`3oool20?l003d0oooo
0`00000/0?ooo`030000003oool0oooo01L0oooo0P3o000:0?ooo`80o`00R03oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo04`0oooo001H0?ooo`80o`002`3oool20?l008D0oooo0P3o
000;0?ooo`80o`00?@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o
000;0?ooo`80o`00Q`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04`0oooo001H
0?ooo`80o`002`3oool20?l008D0oooo0P3o000;0?ooo`80o`00?@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo01L0oooo0P3o000;0?ooo`80o`00Q`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo04`0oooo001H0?ooo`80o`002`3oool20?l008D0oooo0P3o000;0?oo
o`80o`00?@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o000;0?oo
o`80o`00Q`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo001H0?ooo`80
o`002`3oool20?l008D0oooo0P3o000;0?ooo`80o`00?@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo01L0oooo0P3o000;0?ooo`80o`00Q`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo04/0oooo001H0?ooo`80o`002`3oool20?l008D0oooo0P3o000;0?ooo`80o`00
?@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o000;0?ooo`80o`00
Q`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo001H0?ooo`80o`002`3o
ool20?l008D0oooo0P3o000;0?ooo`80o`00?@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo01L0oooo0P3o000;0?ooo`80o`00Q`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo04/0oooo001H0?ooo`80o`002`3oool20?l008D0oooo0P3o000;0?ooo`80o`00?@3oool0
0`000000oooo0?ooo`160?ooo`80o`002`3oool20?l008L0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`1;0?ooo`00F03oool20?l000/0oooo0P3o00250?ooo`80o`00303oool20?l0
03`0oooo00<000000?ooo`3oool0AP3oool20?l000/0oooo0P3o00270?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0B`3oool005P0oooo0P3o000;0?ooo`80o`00Q@3oool20?l000`0
oooo0P3o000l0?ooo`030000003oool0oooo04H0oooo0P3o000;0?ooo`80o`00Q`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo001H0?ooo`80o`002`3oool20?l008D0oooo
0P3o000<0?ooo`80o`00?03oool3000004H0oooo0P3o000<0?ooo`80o`00QP3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo04/0oooo001H0?ooo`80o`002`3oool20?l008D0oooo0P3o
000<0?ooo`80o`00?03oool00`000000oooo0?ooo`160?ooo`80o`00303oool20?l008H0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`1;0?ooo`00F03oool20?l000/0oooo0P3o0025
0?ooo`80o`00303oool20?l003`0oooo00<000000?ooo`3oool0AP3oool20?l000`0oooo0P3o0026
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0B`3oool005P0oooo0P3o000;0?oo
o`80o`00Q@3oool20?l000`0oooo0P3o000l0?ooo`030000003oool0oooo04H0oooo0P3o000<0?oo
o`80o`00QP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo001H0?ooo`80
o`002`3oool20?l008D0oooo0P3o000<0?ooo`80o`00?03oool00`000000oooo0?ooo`160?ooo`80
o`00303oool20?l008H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1;0?ooo`00
F03oool20?l000/0oooo0P3o00250?ooo`80o`00303oool20?l003`0oooo00<000000?ooo`3oool0
AP3oool20?l000`0oooo0P3o00260?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
B`3oool005P0oooo0P3o000<0?ooo`80o`00Q03oool20?l000`0oooo0P3o000l0?ooo`030000003o
ool0oooo04H0oooo0P3o000<0?ooo`80o`00QP3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo04/0oooo001H0?ooo`80o`00303oool20?l008@0oooo0P3o000<0?ooo`80o`00?03oool0
0`000000oooo0?ooo`160?ooo`80o`00303oool20?l008H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`1;0?ooo`00F03oool20?l000`0oooo0P3o00240?ooo`80o`00303oool20?l0
03`0oooo00<000000?ooo`3oool0AP3oool20?l000`0oooo0P3o00260?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0BP3oool005P0oooo0P3o000<0?ooo`80o`00Q03oool20?l000d0
oooo0P3o000k0?ooo`<00000AP3oool20?l000`0oooo0P3o00260?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0BP3oool005P0oooo0P3o000<0?ooo`80o`00Q03oool20?l000d0oooo
0P3o000k0?ooo`030000003oool0oooo04H0oooo0P3o000<0?ooo`80o`00QP3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo04X0oooo001H0?ooo`80o`00303oool20?l008@0oooo0P3o
000=0?ooo`80o`00>`3oool00`000000oooo0?ooo`160?ooo`80o`00303oool20?l008H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1:0?ooo`00F03oool20?l000`0oooo0P3o0024
0?ooo`80o`003@3oool20?l003/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G
0?ooo`80o`00303oool20?l008H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1:
0?ooo`00F03oool20?l000`0oooo0P3o00240?ooo`80o`003@3oool20?l003/0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`003@3oool20?l008D0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1:0?ooo`00F03oool20?l000`0oooo0P3o00240?ooo`80
o`003@3oool20?l003/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80
o`003@3oool20?l008D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1:0?ooo`00
F03oool20?l000`0oooo0P3o00240?ooo`80o`003@3oool20?l003/0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0G0?ooo`80o`003@3oool20?l008D0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1:0?ooo`00F03oool20?l000`0oooo0P3o00240?ooo`80o`003@3o
ool20?l003/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`003@3o
ool20?l008D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`190?ooo`00F03oool2
0?l000`0oooo0P3o00240?ooo`80o`003@3oool20?l003/0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0G0?ooo`80o`003@3oool20?l008D0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`190?ooo`00F03oool20?l000`0oooo0P3o00240?ooo`80o`003@3oool20?l0
03/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`003@3oool20?l0
08D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`190?ooo`00F03oool20?l000`0
oooo0P3o00240?ooo`80o`003@3oool20?l003/0oooo0`00000/0?ooo`030000003oool0oooo01L0
oooo0P3o000=0?ooo`80o`00Q@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04T0
oooo001H0?ooo`80o`00303oool20?l008@0oooo0P3o000>0?ooo`80o`00>P3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o000=0?ooo`80o`00Q@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo04T0oooo001H0?ooo`80o`003@3oool20?l008<0oooo0P3o
000>0?ooo`80o`00>P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o
000=0?ooo`80o`00Q@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04T0oooo001H
0?ooo`80o`003@3oool20?l008<0oooo0P3o000>0?ooo`80o`00>P3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo01L0oooo0P3o000=0?ooo`80o`00Q@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo04T0oooo001H0?ooo`80o`003@3oool20?l008<0oooo0P3o000>0?oo
o`80o`00>P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o000>0?oo
o`80o`00Q03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo04T0oooo001H0?ooo`80
o`003@3oool20?l008<0oooo0P3o000>0?ooo`80o`00>P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo01L0oooo0P3o000>0?ooo`80o`00Q03oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo04T0oooo001H0?ooo`80o`003@3oool20?l008<0oooo0P3o000>0?ooo`80o`00
>P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o000>0?ooo`80o`00
Q03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04P0oooo001H0?ooo`80o`003@3o
ool20?l008<0oooo0P3o000>0?ooo`80o`00:`3oool0102oM000000000000000M;l;0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool05`3oool20?l000h0oooo0P3o00240?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0B03oool005P0oooo0P3o000=0?ooo`80o`00P`3o
ool20?l000h0oooo0P3o000Z0?ooo`060?noM018W=l0oooo0?ooo`3OW4P0B9cO2P3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o000>0?ooo`80o`00Q03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo04P0oooo001H0?ooo`80o`003@3oool20?l008<0oooo
0P3o000>0?ooo`80o`008`3oool00`3o_g@0000000000002000000030018W03Oool0oooo00<0oooo
00<0gia804RLg`3oool02@3oool4000002/0oooo00<000000?ooo`3oool05`3oool20?l000h0oooo
0P3o00240?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0B03oool005P0oooo0P3o
000=0?ooo`80o`00P`3oool20?l000h0oooo0P3o000/0?ooo`030;md00000000B9cO00/0oooo00<0
00000?ooo`3oool0AP3oool20?l000h0oooo0P3o00240?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0B03oool005P0oooo0P3o000=0?ooo`80o`00P`3oool20?l000h0oooo0P3o000]
0?ooo`030?oo_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0AP3oool20?l000h0oooo0P3o0024
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0B03oool005P0oooo0P3o000>0?oo
o`80o`00PP3oool20?l000l0oooo0P3o000Y0?ooo`060?noM000M;l0oooo0?oo_`1d07@0_ooo2P3o
ool00`000000oooo0?ooo`160?ooo`80o`003P3oool20?l008@0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`180?ooo`00F03oool20?l000h0oooo0P3o00220?ooo`80o`003`3oool2
0?l002X0oooo00@0_g@0000000000000M;oo2`3oool00`000000oooo0?ooo`160?ooo`80o`003P3o
ool20?l008@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`180?ooo`00F03oool2
0?l000h0oooo0P3o00220?ooo`80o`003`3oool20?l003T0oooo00<000000?ooo`3oool0AP3oool2
0?l000h0oooo0P3o00240?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0A`3oool0
05P0oooo0P3o000>0?ooo`80o`00PP3oool20?l000l0oooo0P3o000i0?ooo`030000003oool0oooo
04H0oooo0P3o000?0?ooo`80o`00P`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
04L0oooo001H0?ooo`80o`003P3oool20?l00880oooo0P3o000?0?ooo`80o`00>@3oool00`000000
oooo0?ooo`160?ooo`80o`003`3oool20?l008<0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`170?ooo`00F03oool20?l000h0oooo0P3o00220?ooo`80o`003`3oool20?l003T0oooo
00<000000?ooo`3oool0AP3oool20?l000l0oooo0P3o00230?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0A`3oool005P0oooo0P3o000>0?ooo`80o`00PP3oool20?l000l0oooo0P3o
000i0?ooo`030000003oool0oooo04H0oooo0P3o000?0?ooo`80o`00P`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo04L0oooo001H0?ooo`80o`003P3oool20?l00880oooo0P3o000?
0?ooo`80o`00>@3oool3000004H0oooo0P3o000?0?ooo`80o`00P`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo04L0oooo001H0?ooo`80o`003P3oool20?l00880oooo0P3o000?0?oo
o`80o`00>@3oool00`000000oooo0?ooo`160?ooo`80o`003`3oool20?l008<0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`170?ooo`00F03oool20?l000h0oooo0P3o00220?ooo`80
o`003`3oool20?l003T0oooo00<000000?ooo`3oool0AP3oool20?l000l0oooo0P3o00230?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0A`3oool005P0oooo0P3o000>0?ooo`80o`00
PP3oool20?l000l0oooo0P3o000i0?ooo`030000003oool0oooo04H0oooo0P3o000?0?ooo`80o`00
P`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04L0oooo001H0?ooo`80o`003`3o
ool20?l00840oooo0P3o000@0?ooo`80o`00>03oool00`000000oooo0?ooo`160?ooo`80o`003`3o
ool20?l008<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`170?ooo`00F03oool2
0?l000l0oooo0P3o00210?ooo`80o`00403oool20?l003P0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0G0?ooo`80o`00403oool20?l00880oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`170?ooo`00F03oool20?l000l0oooo0P3o00210?ooo`80o`00403oool20?l0
03P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`00403oool20?l0
0880oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`170?ooo`00F03oool20?l000l0
oooo0P3o00210?ooo`80o`00403oool20?l003P0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0G0?ooo`80o`00403oool20?l00880oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`160?ooo`00F03oool20?l000l0oooo0P3o00210?ooo`80o`00403oool20?l003P0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`00403oool20?l00880oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`160?ooo`00F03oool20?l000l0oooo0P3o
00210?ooo`80o`00403oool20?l003P0oooo0`00000/0?ooo`030000003oool0oooo01L0oooo0P3o
000@0?ooo`80o`00PP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04H0oooo001H
0?ooo`80o`003`3oool20?l00840oooo0P3o000@0?ooo`80o`00>03oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo01L0oooo0P3o000@0?ooo`80o`00PP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo04H0oooo001H0?ooo`80o`00403oool20?l00800oooo0P3o000A0?oo
o`80o`00=`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o000@0?oo
o`80o`00PP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04H0oooo001H0?ooo`80
o`00403oool20?l00800oooo0P3o000A0?ooo`80o`00=`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo01L0oooo0P3o000@0?ooo`80o`00PP3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo04H0oooo001H0?ooo`80o`00403oool20?l00800oooo0P3o000A0?ooo`80o`00
=`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o000@0?ooo`80o`00
PP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04H0oooo001H0?ooo`80o`00403o
ool20?l00800oooo0P3o000A0?ooo`80o`00=`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo01L0oooo0P3o000A0?ooo`80o`00P@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo04H0oooo001H0?ooo`80o`00403oool20?l00800oooo0P3o000A0?ooo`80o`00=`3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o000A0?ooo`80o`00P@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo04H0oooo001H0?ooo`80o`00403oool20?l0
0800oooo0P3o000A0?ooo`80o`00=`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
01L0oooo0P3o000A0?ooo`80o`00P@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
04H0oooo001H0?ooo`80o`00403oool20?l00800oooo0P3o000A0?ooo`80o`00=`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o000A0?ooo`80o`00P@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo04D0oooo001H0?ooo`80o`004@3oool20?l007l0oooo
0P3o000A0?ooo`80o`00=`3oool3000002`0oooo00<000000?ooo`3oool05`3oool20?l00140oooo
0P3o00210?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0A@3oool005P0oooo0P3o
000A0?ooo`80o`00O`3oool20?l00180oooo0P3o000f0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool05`3oool20?l00140oooo0P3o00210?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0A@3oool005P0oooo0P3o000A0?ooo`80o`00O`3oool20?l00180oooo0P3o000f
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05`3oool20?l00140oooo0P3o0021
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0A@3oool005P0oooo0P3o000A0?oo
o`80o`00O`3oool20?l00180oooo0P3o000f0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool05`3oool20?l00180oooo0P3o00200?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0A@3oool005P0oooo0P3o000A0?ooo`80o`00O`3oool20?l00180oooo0P3o000f0?ooo`03
0000003oool0oooo04H0oooo0P3o000B0?ooo`80o`00P03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04D0oooo001H0?ooo`80o`004@3oool20?l007l0oooo0P3o000B0?ooo`80o`00
=P3oool00`000000oooo0?ooo`160?ooo`80o`004P3oool20?l00800oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`140?ooo`00F03oool20?l00140oooo0P3o001o0?ooo`80o`004P3o
ool20?l003H0oooo00<000000?ooo`3oool0AP3oool20?l00180oooo0P3o00200?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0A03oool005P0oooo0P3o000B0?ooo`80o`00OP3oool2
0?l001<0oooo0P3o000e0?ooo`030000003oool0oooo04H0oooo0P3o000B0?ooo`80o`00P03oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04@0oooo001H0?ooo`80o`004P3oool20?l0
07h0oooo0P3o000C0?ooo`80o`00=@3oool00`000000oooo0?ooo`160?ooo`80o`004P3oool20?l0
0800oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`140?ooo`00F03oool20?l00180
oooo0P3o001n0?ooo`80o`004`3oool20?l003D0oooo00<000000?ooo`3oool0AP3oool20?l00180
oooo0P3o00200?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool005P0oooo
0P3o000B0?ooo`80o`00OP3oool20?l001<0oooo0P3o000e0?ooo`<00000AP3oool20?l00180oooo
0P3o00200?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool005P0oooo0P3o
000B0?ooo`80o`00OP3oool20?l001<0oooo0P3o000e0?ooo`030000003oool0oooo04H0oooo0P3o
000C0?ooo`80o`00O`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04<0oooo001H
0?ooo`80o`004P3oool20?l007h0oooo0P3o000C0?ooo`80o`00=@3oool00`000000oooo0?ooo`16
0?ooo`80o`004`3oool20?l007l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`13
0?ooo`00F03oool20?l00180oooo0`3o001m0?ooo`80o`004`3oool20?l003D0oooo00<000000?oo
o`3oool0AP3oool20?l001<0oooo0P3o001o0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0@`3oool005P0oooo0P3o000C0?ooo`80o`00O@3oool20?l001@0oooo0P3o000d0?ooo`03
0000003oool0oooo04H0oooo0P3o000C0?ooo`80o`00O`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo04<0oooo001H0?ooo`80o`004`3oool20?l007d0oooo0P3o000D0?ooo`80o`00
=03oool00`000000oooo0?ooo`160?ooo`80o`004`3oool20?l007l0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`130?ooo`00F03oool20?l001<0oooo0P3o001m0?ooo`80o`00503o
ool20?l003@0oooo00<000000?ooo`3oool0AP3oool20?l001@0oooo0P3o001n0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0@`3oool005P0oooo0P3o000C0?ooo`<0o`00O03oool2
0?l001@0oooo0P3o000T0?ooo`030;md0000000000000080000000<0B9cO0?ooo`3oool0203oool0
0`000000oooo0?ooo`160?ooo`80o`00503oool20?l007h0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`120?ooo`00F03oool20?l001@0oooo0P3o001l0?ooo`80o`00503oool20?l0
02@0oooo00<0oooO09a8001d_ol03@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
01L0oooo0P3o000D0?ooo`80o`00OP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0480oooo001H0?ooo`80o`00503oool20?l007`0oooo0P3o000E0?ooo`80o`00703oool00`3o_g@0
000000000002000000060018W03Oool0oooo0?ooo`2oM00007Bo303oool4000002/0oooo00<00000
0?ooo`3oool05`3oool20?l001@0oooo0P3o001n0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0@P3oool005P0oooo0P3o000D0?ooo`<0o`00N`3oool20?l001D0oooo0P3o000V0?oo
o`030?noM000M;l0oooo00X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?oo
o`80o`00503oool20?l007h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`120?oo
o`00F03oool20?l001D0oooo0P3o001k0?ooo`80o`005@3oool20?l002L0oooo00<0gia807Boo`3o
ool02@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo0P3o000E0?ooo`80
o`00O@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0480oooo001H0?ooo`80o`00
5@3oool20?l007/0oooo0P3o000E0?ooo`80o`008`3oool01P3o_g@007Bo0?ooo`3oool0_g@007Bo
o`X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`005@3oool20?l0
07d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`120?ooo`00F03oool20?l001D0
oooo0P3o001k0?ooo`80o`005@3oool20?l002<0oooo00H0oooO09a80000000000000018W03Oool:
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05`3oool20?l001D0oooo0P3o001m
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool005P0oooo0P3o000E0?oo
o`<0o`00NP3oool20?l001H0oooo0P3o000b0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool05`3oool20?l001D0oooo0P3o001m0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0@@3oool005P0oooo0P3o000F0?ooo`80o`00NP3oool20?l001H0oooo0P3o000b0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool05`3oool20?l001D0oooo0P3o001m0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool005P0oooo0P3o000F0?ooo`80o`00
NP3oool20?l001H0oooo0P3o000b0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
5`3oool20?l001H0oooo0P3o001l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
@@3oool005P0oooo0P3o000F0?ooo`80o`00NP3oool20?l001H0oooo0P3o000b0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool05`3oool20?l001H0oooo0P3o001l0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0@03oool005P0oooo0P3o000F0?ooo`80o`00NP3oool2
0?l001H0oooo0P3o000b0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05`3oool2
0?l001H0oooo0P3o001l0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0@03oool0
05P0oooo0P3o000F0?ooo`<0o`00N@3oool20?l001L0oooo0P3o000a0?ooo`<00000;03oool00`00
0000oooo0?ooo`0G0?ooo`80o`005P3oool20?l007`0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`100?ooo`00F03oool20?l001L0oooo0P3o001i0?ooo`80o`005`3oool20?l00340
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`005P3oool30?l007/0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0o0?ooo`00F03oool20?l001L0oooo
0P3o001i0?ooo`80o`005`3oool20?l00340oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0G0?ooo`80o`005`3oool20?l007/0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0o0?ooo`00F03oool20?l001L0oooo0P3o001i0?ooo`80o`005`3oool20?l00340oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`005`3oool20?l007/0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0o0?ooo`00F03oool20?l001L0oooo0`3o001h
0?ooo`80o`005`3oool30?l00300oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G
0?ooo`80o`005`3oool20?l007/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0o
0?ooo`00F03oool20?l001P0oooo0P3o001h0?ooo`80o`00603oool20?l00300oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`005`3oool30?l007X0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0n0?ooo`00F03oool20?l001P0oooo0P3o001h0?ooo`80
o`00603oool20?l00300oooo00<000000?ooo`3oool0AP3oool20?l001P0oooo0P3o001j0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0?P3oool005P0oooo0P3o000H0?ooo`80o`00
N03oool20?l001P0oooo0`3o000_0?ooo`030000003oool0oooo04H0oooo0P3o000H0?ooo`80o`00
NP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03h0oooo001H0?ooo`80o`00603o
ool30?l007L0oooo0P3o000I0?ooo`80o`00;`3oool00`000000oooo0?ooo`160?ooo`80o`00603o
ool30?l007T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0m0?ooo`00F03oool2
0?l001T0oooo0P3o001g0?ooo`80o`006@3oool20?l002l0oooo0`0000160?ooo`80o`006@3oool2
0?l007T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0m0?ooo`00F03oool20?l0
01T0oooo0P3o001g0?ooo`80o`006@3oool30?l002h0oooo00<000000?ooo`3oool0AP3oool20?l0
01T0oooo0P3o001i0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0?@3oool005P0
oooo0P3o000I0?ooo`80o`00M`3oool20?l001X0oooo0P3o000^0?ooo`030000003oool0oooo04H0
oooo0P3o000I0?ooo`80o`00N@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03`0
oooo001H0?ooo`80o`006@3oool30?l007H0oooo0P3o000J0?ooo`80o`00;P3oool00`000000oooo
0?ooo`160?ooo`80o`006@3oool30?l007P0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0l0?ooo`00F03oool20?l001X0oooo0P3o001f0?ooo`80o`006P3oool30?l002d0oooo00<0
00000?ooo`3oool0AP3oool20?l001X0oooo0P3o001h0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0?03oool005P0oooo0P3o000J0?ooo`80o`00MP3oool20?l001/0oooo0P3o000]
0?ooo`030000003oool0oooo04H0oooo0P3o000J0?ooo`80o`00N03oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo03`0oooo001H0?ooo`80o`006P3oool20?l007H0oooo0P3o000K0?oo
o`80o`00;@3oool00`000000oooo0?ooo`160?ooo`80o`006P3oool30?l007L0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0k0?ooo`00F03oool20?l001X0oooo0`3o001e0?ooo`80
o`006`3oool30?l002`0oooo00<000000?ooo`3oool0AP3oool20?l001/0oooo0P3o001g0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0>`3oool005P0oooo0P3o000K0?ooo`80o`00
M@3oool20?l001`0oooo0P3o000/0?ooo`030000003oool0oooo04H0oooo0P3o000K0?ooo`80o`00
M`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03/0oooo001H0?ooo`80o`006`3o
ool20?l007D0oooo0P3o000L0?ooo`80o`00;03oool00`000000oooo0?ooo`160?ooo`80o`006`3o
ool30?l007H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0j0?ooo`00F03oool2
0?l001/0oooo0P3o001e0?ooo`80o`00703oool30?l002/0oooo0`0000160?ooo`80o`00703oool2
0?l007H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0j0?ooo`00F03oool20?l0
01/0oooo0`3o001d0?ooo`80o`007@3oool20?l002/0oooo00<000000?ooo`3oool0AP3oool20?l0
01`0oooo0`3o001e0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0>P3oool005P0
oooo0P3o000L0?ooo`80o`00M03oool20?l001d0oooo0P3o000[0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool05`3oool20?l001d0oooo0P3o001e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0>@3oool005P0oooo0P3o000L0?ooo`<0o`00L`3oool20?l001d0oooo
0`3o000Z0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05`3oool20?l001d0oooo
0P3o001e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0>@3oool005P0oooo0P3o
000M0?ooo`80o`00L`3oool20?l001h0oooo0P3o000Z0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool05`3oool20?l001d0oooo0`3o001d0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0>03oool005P0oooo0P3o000M0?ooo`80o`00L`3oool20?l001h0oooo0P3o000Z
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05`3oool20?l001h0oooo0P3o001d
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0>03oool005P0oooo0P3o000M0?oo
o`<0o`00LP3oool20?l001h0oooo0P3o000Z0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool05`3oool20?l001h0oooo0`3o001c0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0>03oool005P0oooo0P3o000N0?ooo`80o`00LP3oool20?l001h0oooo0`3o000Y0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool05`3oool20?l001l0oooo0P3o001c0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0=`3oool005P0oooo0P3o000N0?ooo`<0o`00
L@3oool20?l001l0oooo0P3o000Y0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
5`3oool20?l001l0oooo0P3o001c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
=`3oool005P0oooo0P3o000O0?ooo`80o`00L@3oool20?l001l0oooo0P3o00000`000000oooo0?oo
o`0V0?ooo`<00000;03oool00`000000oooo0?ooo`0G0?ooo`80o`007`3oool30?l00780oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00F03oool20?l001l0oooo0P3o001a
0?ooo`80o`007`3oool30?l002P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G
0?ooo`80o`00803oool20?l00780oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0f
0?ooo`00F03oool20?l001l0oooo0`3o001`0?ooo`80o`00803oool20?l002P0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`00803oool30?l00740oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0f0?ooo`00F03oool20?l00200oooo0P3o001`0?ooo`80
o`00803oool20?l000030000003oool0oooo02D0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0G0?ooo`80o`008@3oool20?l00740oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0e0?ooo`00F03oool20?l00200oooo0P3o001`0?ooo`80o`008@3oool00`3o00000000
0?ooo`0V0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05`3oool20?l00240oooo
0P3o001a0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0=@3oool005P0oooo0P3o
000Q0?ooo`80o`00K`3oool20?l00240oooo0P3o00000`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool05`3oool20?l00240oooo0`3o001`0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0=03oool005P0oooo0P3o000R0?ooo`030?l0003oool0
oooo06d0oooo0P3o000R0?ooo`030?l000000000oooo02D0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0G0?ooo`80o`008P3oool20?l00700oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0d0?ooo`00F03oool20?l00280oooo0P3o001^0?ooo`80o`008P3oool20?l0
00030000003oool0oooo01D0oooo00<0oooO09a8M02oool02`3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo01L0oooo0P3o000R0?ooo`80o`00L03oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo03@0oooo001H0?ooo`80o`008`3oool00`3o0000oooo0?ooo`1/0?ooo`80
o`008`3oool00`3o000000000?ooo`0F0?ooo`030?oog`2LB7@0_ooo00/0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0G0?ooo`80o`008`3oool20?l006l0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0c0?ooo`00F03oool20?l002<0oooo00<0o`000000003oool0
K03oool20?l002<0oooo0P3o000>0?ooo`030?noM000000000000080000000L004RL0=ooo`3oool0
oooo0?oog`2LB7@0_ooo00/0oooo00<000000?ooo`3oool0AP3oool20?l002@0oooo00<0o`000?oo
o`3oool0K@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03<0oooo001H0?ooo`80
o`008`3oool20?l006d0oooo0P3o000T0?ooo`80o`005P3oool00`3ooml0W4Qd0;ooo`020?oooa80
0000@03oool20?l002@0oooo0P3o001^0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0<P3oool005P0oooo0P3o000T0?ooo`030?l000000000oooo06/0oooo0P3o000U0?ooo`030?l0
003oool0oooo0180oooo00<0oooO09bL_`000000100000090?ooo`030000003oool0oooo00H0oooo
1@00000k0?ooo`80o`009@3oool00`3o0000oooo0?ooo`1/0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0<P3oool005P0oooo0P3o000T0?ooo`80o`00K03oool20?l002D0oooo0P3o
000C0?ooo`<0000000<0001d0;ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`800000>@3o
ool20?l002D0oooo00<0o`000?ooo`3oool0K03oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo0340oooo001H0?ooo`80o`009@3oool00`3o000000000?ooo`1Z0?ooo`80o`009P3oool0
0`3o0000oooo0?ooo`0?0?ooo`8000000P3oool00`3ookl0M01d0;ooo`0;0?ooo`030000003oool0
oooo00d0oooo0P00000g0?ooo`80o`009@3oool20?l006d0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0a0?ooo`00F03oool20?l002D0oooo0P3o001[0?ooo`80o`009P3oool20?l0
00h0oooo0P00000B0?ooo`030000003oool0oooo00l0oooo0P00000e0?ooo`80o`009P3oool00`3o
0000oooo0?ooo`1[0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<03oool005P0
oooo0P3o000V0?ooo`80o`00JP3oool20?l002L0oooo0P3o000;0?ooo`800000503oool00`000000
oooo0?ooo`0A0?ooo`800000<`3oool20?l002H0oooo0P3o001/0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0<03oool005P0oooo0P3o000W0?ooo`030?l0003oool0oooo06P0oooo
0P3o000X0?ooo`030?l0003oool0oooo00L0oooo0P00000F0?ooo`030000003oool0oooo01<0oooo
0P00000a0?ooo`80o`009`3oool00`3o000000000?ooo`1Z0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0;`3oool005P0oooo0P3o000W0?ooo`80o`00J@3oool20?l002P0oooo0P3o
00060?ooo`800000603oool00`000000oooo0?ooo`0E0?ooo`800000;`3oool20?l002L0oooo0P3o
001[0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0;`3oool005P0oooo0P3o000X
0?ooo`80o`00J03oool20?l002T0oooo0P3o00040?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0/0?ooo`80o`00:03oool00`3o000000000?ooo`1Y
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0;P3oool005P0oooo0P3o000Y0?oo
o`030?l0003oool0oooo06H0oooo0P3o000Z0?ooo`050?l0003oool0oooo0?ooo`0000006`3oool3
000001P0oooo00<000000?ooo`3oool0:`3oool20?l002P0oooo0P3o00000`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0;P3oool005P0oooo0P3o000Y0?oo
o`80o`00I`3oool20?l002X0oooo0P3o0002000001`0oooo00<000000?ooo`3oool06@3oool20000
0100oooo0P00o`0I0?ooo`80o`00:@3oool20?l000800000I`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo02d0oooo001H0?ooo`80o`00:P3oool20?l006H0oooo0P3o000[0?ooo`03
0?l0003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`@0
0?l0603oool20?l002X0oooo00@0o`000000000000000000IP3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo02`0oooo001H0?ooo`80o`00:`3oool20?l006D0oooo0P3o000Z0?ooo`03
0000003o0000o`0001d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:0?ooo`H0
0?l05`3oool20?l002T0oooo00<000000?l0003o00000`00001U0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0:`3oool005P0oooo0P3o000/0?ooo`030?l0003oool0oooo06<0oooo
0P3o000X0?ooo`8000000P3oool20?l001`0oooo00<000000?ooo`3oool07@3oool2000000X0oooo
1P00o`0G00000080o`00:`000000103o0000000000000000001U0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0:`3oool005P0oooo0P3o000/0?ooo`80o`00I03oool20?l002L0oooo
00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool02@3oool4003o01P0oooo0P3o000Z0?ooo`040000003o00000000000006H0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0Z0?ooo`00F03oool20?l002d0oooo
0P3o001S0?ooo`80o`009`3oool00`000000oooo0?ooo`030?ooo`80o`006`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`00o`000?l06@3oool20?l002/0
oooo0P0000000`3oool000000?ooo`1T0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0:@3oool005P0oooo0P3o00040000000304RLg`3oool0oooo02L0oooo0P3o001R0?ooo`80o`00
9P3oool00`000000oooo0?ooo`050?ooo`80o`006P3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`80o`00:`3oool01@000000
oooo0?ooo`3oool000000640oooo00<0_g@00000000000000P0000000`18W=l0oooo0?ooo`0Y0?oo
o`030000003oool0oooo02T0oooo001H0?ooo`80o`0000<0W4P007Boo`3oool0:`3oool30?l00640
oooo0P3o000U0?ooo`030000003oool0oooo00L0oooo0P3o000I0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool05`3oool20?l002/0
oooo00D000000?ooo`3oool0oooo0000001Q0?ooo`040?oog`2LB000M;oo000002h0oooo00<00000
0?ooo`3oool0:03oool005P0oooo0P3o00000`3oool0_g@0001d_`0/0?ooo`80o`00H@3oool20?l0
02@0oooo00<000000?ooo`3oool0203oool30?l001P0oooo00<000000?ooo`3oool08P3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo01L0oooo0P3o000[0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0H03oool00`2oM00000000?ooo`0^0?ooo`030000003oool0
oooo02L0oooo001H0?ooo`80o`000P3oool00`3o_g@007Bo0?ooo`0[0?ooo`80o`00H03oool20?l0
00030;md0000000000000080000000<0B9cO0?ooo`3oool06`3oool00`000000oooo0?ooo`0:0?oo
o`80o`00603oool3000002<0oooo0P0000070?ooo`030000003oool0oooo01D0oooo00H0_g@00000
003o0000o`0000000018W=lY0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0H03o
ool00`00000007Bo0?ooo`0^0?ooo`030000003oool0oooo02H0oooo001H0?ooo`80o`000`3oool0
0`3OW4P0M;oo0?ooo`0Z0?ooo`<0o`00G`3oool20?l000030?oog`2LB000M;oo01l0oooo00<00000
0?ooo`3oool0303oool20?l001L0oooo00<000000?ooo`3oool08P3oool3000000L0oooo00<00000
0?ooo`3oool05@3oool0103ooml0W4P00?l0003o000[0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0H03oool00`000000gia807Boo`0^0?ooo`030000003oool0oooo02H0oooo001H
0?ooo`80o`0000D007Bo0?ooo`3oool0_g@007Boo`0/0?ooo`<0o`00GP3oool20?l00080oooo00<0
_g@0001d_`3oool0703oool00`000000oooo0?ooo`0=0?ooo`<0o`005P3oool00`000000oooo0?oo
o`0Q0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool05`3oool20?l002/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`1L0?ooo`060?noM000M;l0oooo0000002o
M000M;oo;`3oool00`000000oooo0?ooo`0U0?ooo`00F03oool20?l0000509a80000000000000018
W03Oool0;@3oool30?l005d0oooo0P3o00030?ooo`030?noM000M;l0oooo01/0oooo00<000000?oo
o`3oool03P3oool30?l001D0oooo00<000000?ooo`3oool07`3oool2000000@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0G0?ooo`80o`0000<007Bo0?ooo`3oool0:03oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo05/0oooo00H0oooO09a80000000000000018W03O
ool`0?ooo`030000003oool0oooo02@0oooo001H0?ooo`80o`00<`3oool20?l005d0oooo0P3o0004
0?ooo`030=nLB01d_ol0oooo01T0oooo00<000000?ooo`3oool0403oool30?l001@0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool05`3oool20?l000030=nLB01d_ol0oooo02P0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool08`3oool0
05P0oooo0P3o000d0?ooo`80o`00G03oool20?l000060?noM000M;l0oooo0?ooo`2oM000M;oo6P3o
ool00`000000oooo0?ooo`0A0?ooo`80o`00503oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`060?noM000
M;l0o`000?l0002oM000M;oo:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05d0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0S0?ooo`00F03oool20?l003@0oooo
0`3o001K0?ooo`80o`0000H0oooO09a80000000000000018W03OoolI0?ooo`030000003oool0oooo
01<0oooo0P3o000C0?ooo`030000003oool0oooo01/0oooo0P0000090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool05@3oool01P3ooml0W4P00?l0003o000004RL0=ooobT0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool08P3oool004d0oooo00<0okmd0000000000000P0000001P00B9`0gooo0?oo_`1d
000007Ad07@00080o`000`0000000`00M7@0M0000000000300000003001d_`3oool0oooo02T0oooo
0`3o001J0?ooo`80o`007`3oool00`000000oooo0?ooo`0C0?ooo`<0o`004P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0G0?ooo`80o`00:`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0580oooo
00H0oono07@00000M7@0M000001dM01d00040000000607@00000M5L0=@00000e@@0e000003F?;`3o
ool00`000000oooo0?ooo`0Q0?ooo`00F03oool20?l003H0oooo0`3o001I0?ooo`80o`007`3oool0
0`000000oooo0?ooo`0D0?ooo`<0o`004@3oool00`000000oooo0?ooo`0H0?ooo`8000003@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo0P3o000[0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo0200oooo001H0?ooo`80o`00=`3oool20?l005T0oooo0P3o000N0?ooo`030000003oool0oooo
01H0oooo0`3o000@0?ooo`<000005`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo
0?ooo`0000006@3oool20?l002/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool07`3oool005P0oooo0P3o000h0?oo
o`80o`00D@3oool00`3o_g@0000000000002000000080018W03Oool0o`000?l00000M5L0=@00000e
E`1d000200000003001d_`3oool0oooo01D0oooo00<000000?ooo`3oool05`3oool30?l000l0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`00
00005@3oool0103ookl0M000001dM01d00020?l0000303D00000000007Bo02P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool07P3oool000/0oooo00<0_g@00000000000000P0000002018W=l0oooo0?oo_`1d04P0W=oo
0?oOW01807@0_ooo@03oool20?l003P0oooo0`3o000>0?ooo`060?oo_`1d04P0W=oo0?oOW01807@0
_ooo@`3oool20?l001d0oooo00<000000?ooo`3oool06@3oool30?l000h0oooo00<000000?ooo`3o
ool0503oool200000180oooo00<000000?ooo`3oool06`3oool20?l002/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`080?ooo`060?oo_`1d04P0W=oo0?oOW01807@0_oooB@3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00H0oooo00<0_g@00000000000000P000000
2018W=l0oooo0?oo_`1d04P0W=oo0?oOW01807@0_ooo2P3oool000/0oooo00<0oooO09a8001d_ol0
1@3oool0103ookl0M7Bo0?oOW01dW=m10?ooo`80o`00>@3oool30?l000h0oooo00@0oono07Ad_`3o
gi`0M9cOA03oool20?l001d0oooo00<000000?ooo`3oool06P3oool20?l000h0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01X0oooo0P3o000[0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool0103ookl0M7Bo0?oOW01dW=m:
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01@3oool00`3ooml0W4P007Boo`05
0?ooo`040?oo_`1dM;l0omnL07BLg`/0oooo00050?ooo`030?noM000000000000080000000D004RL
0=ooo`3oool0_g@0001d_`050?ooo`030;mdM02ooml0W9bo0400oooo00/0_g@00?l0003o000007Bo
0?ooo`3ookl0M01809cOo`3ogi`0B01d0;ooo`0b0?ooo`<0o`001P3oool00`3o_g@0000000000002
000000060018W03Oool0oooo0;mdM02ooml0W9boA03oool20?l001`0oooo00<000000?ooo`3oool0
703oool20?l000d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo01X0oooo0P3o000[0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
203oool00`2oM7@0_ooO09bL_`140?ooo`0;0;md000000000000001d_`3oool0oono0000002Lgol0
omnL04P0M02oool0=`3oool00`000000oooo0?ooo`060?ooo`030;md0000M;l0oooo00@0oooo00<0
_gAd0;oog`2LW;l02`3oool000h0oooo00<0okmd001d_`3oool00P3oool01@2oW9`0gkmd07Boo`2o
W9`0gooo03h0oooo00/0okmd04RLg`3o0000o`000=nLB018W=l0oooo0?oo_`1dM;l0omnL07BLg`0d
0?ooo`80o`0000<000000?ooo`3oool02P3oool01@2oW9`0gkmd07Boo`2oW9`0gooo04<0oooo0P3o
000L0?ooo`030000003oool0oooo01`0oooo0`3o000<0?ooo`030000003oool0oooo0100oooo0P00
000H0?ooo`030000003oool0oooo01T0oooo0P3o000[0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool01P3oool01@2oW9`0gkmd07Boo`2oW9`0gooo0480oooo00/0okmd04RLg`3oool0
oooo0=nLB018W=l0oooo0000001dM;l0omnL07BLg`0i0?ooo`030000003oool0oooo00H0oooo00<0
okmd001d_`3oool00P3oool01@2oW9`0gkmd07Boo`2oW9`0gooo00X0oooo000?0?ooo`060=nLB01d
_ol0oooo0?ooo`3ogi`0B0000P0000000`0004P0W=oo0?ooo`0n0?ooo`80o`0000L0gia804RLg`3o
ool0oooo0;mdM02ooml0W9bo03D0oooo0P3o000<0?ooo`060?oOW018000000000000000004P0W=oo
@P3oool20?l0000507@0B02Lgol0omnL04P0M02oool05`3oool00`000000oooo0?ooo`0M0?ooo`<0
o`002`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool05P3oool00`3ookl0M01809cOo`020?l000030;ooo`3oool0oooo02P0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`050?ooo`060?oOW018000000000000000004P0W=ooA@3oool0
1`3OW4P0B9cO0?ooo`000000_gAd0;oog`2LW;l0>P3oool00`000000oooo0?ooo`060?ooo`060=nL
B01d_ol0oooo0?ooo`3ogi`0B0000P0000000`0004P0W=oo0?ooo`080?ooo`002`3oool01P3o_g@0
07Bo0?ooo`3oool0_g@007BoodL0oooo0P3o00002018W=l0oooo0?ooo`2oW9`0gkmd07Boo`2oW9`0
gooo=03oool30?l005<0oooo0P3o0000103ookl0M7Bo0?oOW01dW=lH0?ooo`030000003oool0oooo
01h0oooo0`3o000:0?ooo`030000003oool0oooo00d0oooo0P00000K0?ooo`030000003oool0oooo
01L0oooo00@0oono07Ad_`3o0000o`00:`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo04d0oooo00<0_g@000000018W=l00P3oool01@000000gkmd07Boo`2oW9`0gooo03X0oooo00H0
00000?ooo`3oool0oooo0?noM000M;l20?ooo`030;md001d_ol0oooo0100oooo000;0?ooo`060?oo
g`2LB000000000000000B9`0goooA`3oool20?l0000507@0M02oool0oooo0?oOW01800000P000000
0`0004P0W=oo0?ooo`0c0?ooo`<0o`00DP3oool20?l000040?ooo`2oM7@0_ooO09bL_aP0oooo00<0
00000?ooo`3oool07`3oool30?l000T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01P0oooo00<0_gAd0?l0003o0000:`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo04d0oooo00H0oono07@0M02oool0oooo00000018000200000003
0000B02Lgol0oooo03P0oooo00H000000?ooo`3oool0oooo0?oog`2LB002000000030018W03Oool0
oooo0100oooo001F0?ooo`060?noM000M;l0o`000?l0001d07@0_ooo?03oool30?l00540oooo0P3o
00001@2oW9`0gkmd07Boo`2oW9`0gooo01H0oooo00<000000?ooo`3oool08@3oool30?l000P0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01H0oooo
00D0_ibL0=noM03o0000o`000=ooo`0Z0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0B@3oool0203o_g@007Bo0?ooo`3ookl0M01d0;ooo`3oool00000?`3oool00`000000oooo0?oo
o`0G0?ooo`00E`3oool0102oM000o`000?l0001d_oln0?ooo`<0o`00D03oool20?l000060?oOW018
000000000000000004P0W=oo5@3oool00`000000oooo0?ooo`0R0?ooo`<0o`001`3oool3000000T0
oooo0P00000P0?ooo`030000003oool0oooo01H0oooo00H0omnL04P0003o0000o`000000B02LgolY
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0BP3oool0102oM00000000000001d
_ol20?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool05P3oool005P0oooo0P3o0010
0?ooo`<0o`00C`3oool20?l001/0oooo00<000000?ooo`3oool08`3oool30?l000H0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01P0oooo0P3o000[
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo01D0oooo001H0?ooo`80o`00@@3oool30?l004h0oooo0P3o000K0?oo
o`030000003oool0oooo02@0oooo0`3o00050?ooo`030000003oool0oooo00H0oooo0P00000S0?oo
o`030000003oool0oooo01P0oooo0P3o000[0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01@0oooo001H0?ooo`80
o`00@P3oool30?l004d0oooo0P3o000J0?ooo`030000003oool0oooo02H0oooo0P3o00050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?ooo`80
o`00:`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0C0?ooo`00F03oool20?l004<0oooo0`3o001<0?ooo`80o`00
6P3oool00`000000oooo0?ooo`0W0?ooo`80o`00103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool05`3oool20?l002/0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
4P3oool005P0oooo0P3o00140?ooo`<0o`00B`3oool20?l001X0oooo00<000000?ooo`3oool09`3o
ool30?l000<0oooo00<000000?ooo`3oool00P3oool2000002P0oooo00<000000?ooo`3oool05`3o
ool20?l002/0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool04@3oool005P0oooo0P3o00150?ooo`<0o`00BP3oool2
0?l001X0oooo00<000000?ooo`3oool0:03oool30?l00080oooo00D000000?ooo`3oool0oooo0000
000Z0?ooo`030000003oool0oooo01L0oooo0P3o000[0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0100oooo001H
0?ooo`80o`00AP3oool30?l004T0oooo0P3o000J0?ooo`030000003oool0oooo02T0oooo0`3o0000
1@3oool000000?ooo`3oool0000002/0oooo00<000000?ooo`3oool05`3oool20?l002/0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03`3oool000h0oooo00<0o`000?ooo`3oool0A`3oool20?l004L0oooo0`3o0018
0?ooo`80o`006P3oool00`000000oooo0?ooo`0Z0?ooo`<0o`000`00000/0?ooo`030000003oool0
oooo01L0oooo0P3o000[0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo00h0oooo000=000000<0o`00B00000020?l0
04P000000`3o001700000080o`00B00000030?l002h0003o00<000000000o`000?l05`000?l20?l0
02`0003o`@0000010?ooo`003P3oool30?l004L0oooo0P3o00190?ooo`<0o`00AP3oool20?l001X0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`040000003o0000o`000?l0
02d0003o00<000000000o`000?l05`000?l20?l002`0003o7@3oool00`000000oooo000000170?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool03@3oool000h0oooo00@000000?l0003o
0000o`00AP3oool20?l004T0oooo00@000000?l0003o0000o`00A@3oool20?l001X0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0o`000P000?lZ
0?ooo`030000003oool0oooo01L0oooo0P3o00190?ooo`040000003oool0oooo000004H0oooo00<0
00000?ooo`3oool0B03oool00`000000oooo0?ooo`0=0?ooo`003P3oool00`000000oooo0?l00002
0?l004D0oooo0P3o00190?ooo`030000003oool0o`000080o`00A03oool20?l001X0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0P0?ooo`050000003oool0oooo0?ooo`0000000`3o
00000`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo01L0oooo0P3o00190?ooo`050000003o
ool0oooo0?ooo`000000A@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00d0oooo
000>0?ooo`030000003oool0oooo00<0o`00A03oool20?l004T0oooo00<000000?ooo`3oool00`3o
00130?ooo`80o`006P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01d0oooo00<0
003o000000000000103oool00`000000oooo0?l000020?l002X0oooo00<000000?ooo`3oool05`3o
ool20?l004T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool03@3oool00180oooo0`3o00130?ooo`80o`00C@3oool3
0?l00480oooo0P3o000J0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool0
0`000000003o0000o`020000o`80oooo0`000?l30?l002T0oooo00<000000?ooo`3oool05`3oool2
0?l004l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1H0?ooo`004`3oool30?l0
0480oooo0P3o001>0?ooo`<0o`00@@3oool20?l001X0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0K0?ooo`80000000<0oooo0000o`000?l01`000?l0103oool0o`000?l0003o000W
0?ooo`8000006@3oool20?l00500oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1H
0?ooo`00503oool30?l00440oooo0P3o001?0?ooo`<0o`00@03oool20?l001/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00@0oooo1@000?l30?oo
o`<0o`009P3oool2000001T0oooo0P3o001A0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0F03oool001D0oooo0`3o00100?ooo`80o`00D03oool30?l003l0oooo0P3o000K0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00<0oooo0`3o000U0?ooo`8000006@3oool20?l00540oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`1H0?ooo`005P3oool20?l00400oooo0P3o001A0?ooo`<0o`00
?P3oool20?l001/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`800000
2`3oool3000000@0oooo0`3o000T0?ooo`8000006@3oool20?l00580oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`1H0?ooo`005`3oool20?l003l0oooo0P3o001B0?ooo`<0o`00?@3o
ool20?l001/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool01@3oool30?l002<0oooo0P00000I0?ooo`80o`00D`3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo05P0oooo000G0?ooo`<0o`00?P3oool2
0?l005<0oooo0P3o000m0?ooo`80o`00703oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01@0oooo0P00000>0?ooo`030000003oool0oooo00H0oooo0`3o000Q0?ooo`030000003oool0
000001T0oooo0P3o001D0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0F03oool0
01P0oooo0`3o000m0?ooo`80o`00E03oool20?l003`0oooo0P3o000L0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00L0oooo0`3o000P0?ooo`030000003oool0000001T0oooo0P3o001E0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0F03oool001T0oooo0`3o000l0?ooo`80o`00E03oool30?l003/0
oooo0P3o000L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo0`3o000O0?ooo`030000003oool0000001T0
oooo0P3o001F0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0F03oool001X0oooo
0`3o000k0?ooo`80o`00E@3oool30?l003X0oooo0P3o000L0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0403oool200000180oooo00<000000?ooo`3oool02@3oool30?l001h0oooo
00<000000?ooo`0000006@3oool20?l005L0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`1H0?ooo`006`3oool30?l003X0oooo0P3o001F0?ooo`<0o`00>@3oool20?l001`0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool02P3oool30?l001`0oooo00<000000?ooo`3oool06P3oool20?l005L0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`1H0?ooo`00703oool30?l003T0oooo0P3o001G
0?ooo`<0o`00>03oool20?l001d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool30?l001/0oooo00<00000
0?ooo`3oool06P3oool20?l005P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1H
0?ooo`007@3oool30?l003P0oooo0P3o001H0?ooo`<0o`00=`3oool20?l001d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`8000005P3oool00`000000oooo0?ooo`0<0?oo
o`<0o`006@3oool00`000000oooo0?ooo`0K0?ooo`80o`00F@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo05P0oooo000N0?ooo`<0o`00=`3oool20?l005T0oooo0`3o000f0?ooo`80
o`007P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`0=0?ooo`<0o`00603oool00`000000oooo0?ooo`0K0?ooo`80
o`00FP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo05P0oooo000O0?ooo`<0o`00
=P3oool20?l005X0oooo0`3o000e0?ooo`80o`007P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo0P00000I0?ooo`<000003P3oool30?l001L0oooo00<000000?ooo`3oool0
6`3oool20?l005/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1H0?ooo`00803o
ool20?l003H0oooo0P3o001K0?ooo`<0o`00=03oool20?l001l0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool20?l001H0oooo
00<000000?ooo`3oool0703oool20?l005`0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`1H0?ooo`008@3oool20?l003D0oooo0P3o001L0?ooo`80o`00=03oool20?l001l0oooo00D0
00000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
403oool20?l001D0oooo00<000000?ooo`3oool0703oool20?l005d0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`1H0?ooo`008@3oool30?l003@0oooo0P3o001M0?ooo`80o`00<`3o
ool20?l001l0oooo00D000000?ooo`3oool0oooo000000070?ooo`8000007@3oool00`000000oooo
0?ooo`0@0?ooo`<0o`004`3oool00`000000oooo0?ooo`0M0?ooo`80o`00G@3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo05P0oooo000R0?ooo`<0o`00<`3oool20?l005d0oooo0`3o
000b0?ooo`80o`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool04@3oool30?l00180oooo00<000000?ooo`3oool07@3oool20?l005h0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`1H0?ooo`008`3oool30?l00380oooo0P3o
001N0?ooo`<0o`00<@3oool20?l00200oooo00@000000?ooo`3oool00000103oool200000200oooo
00<000000?ooo`3oool04P3oool30?l00100oooo00<000000?ooo`3oool07P3oool20?l005l0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1H0?ooo`00903oool30?l00340oooo0P3o
001O0?ooo`<0o`00<03oool20?l00240oooo00@000000?ooo`00000000000P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo01<0oooo0`3o000?0?ooo`030000003oool0oooo01h0oooo
0P3o001P0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0F03oool002D0oooo0P3o
000a0?ooo`80o`00H03oool30?l002l0oooo0P3o000Q0?ooo`H000008`3oool00`000000oooo0?oo
o`0D0?ooo`80o`003P3oool00`000000oooo0?ooo`0O0?ooo`80o`00H@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo05P0oooo000V0?ooo`80o`00<03oool20?l00640oooo0P3o000_
0?ooo`80o`008@3oool6000002<0oooo00<000000?ooo`3oool05@3oool20?l000d0oooo00<00000
0?ooo`3oool07`3oool20?l00640oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`1H
0?ooo`009P3oool30?l002l0oooo0P3o001R0?ooo`80o`00;P3oool20?l00240oooo1P00000S0?oo
o`<000005P3oool20?l000/0oooo00<000000?ooo`3oool0803oool20?l00680oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`1H0?ooo`009`3oool30?l002h0oooo0P3o001S0?ooo`80
o`00;@3oool20?l00280oooo1000000T0?ooo`030000003oool0oooo01L0oooo00<0o`000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo0P3o001S0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0F03oool002P0oooo0`3o000]0?ooo`80o`00
I03oool00`3o0000oooo0?ooo`0[0?ooo`80o`008`3oool3000002@0oooo00<000000?ooo`3oool0
5`3oool20?l000P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`80o`00
H`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo05P0oooo000Y0?ooo`80o`00;@3o
ool20?l006@0oooo0P3o000/0?ooo`80o`009P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo01P0oooo0P3o00060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3o
ool20?l006@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`1H0?ooo`00:P3oool2
0?l002`0oooo0P3o001U0?ooo`80o`00:`3oool20?l002L0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0I0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0G0?ooo`80o`00I@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo05P0oooo000Z0?ooo`<0o`00:`3oool20?l006H0oooo00<0o`000?ooo`3oool0:@3oool20?l0
02L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0I0?ooo`80o`000`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo0P3o001U0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool0F03oool002/0oooo0`3o000Z0?ooo`80o`00IP3oool20?l002X0
oooo0P3o000X0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool06P3oool01@3o0000
oooo0?ooo`3oool0000000d0oooo00<000000?ooo`3oool05`3oool20?l006H0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`1H0?ooo`00;03oool20?l002X0oooo0P3o001W0?ooo`80
o`00:@3oool20?l002T0oooo0P00000O0?ooo`030000003oool0oooo01X0oooo0P3o0002000000h0
oooo00<000000?ooo`3oool05`3oool20?l006L0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`1H0?ooo`00;@3oool20?l002T0oooo0P3o001X0?ooo`030?l0003oool0oooo02L0oooo
0P3o000[0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool20?l000l0oooo
00<000000?ooo`3oool05`3oool20?l006L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`1H0?ooo`00;P3oool00`3o0000oooo0?ooo`0W0?ooo`80o`00J03oool20?l002P0oooo0P3o
000/0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?l0
000?0?ooo`030000003oool0oooo01L0oooo0P3o001X0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0F03oool002h0oooo0P3o000X0?ooo`80o`00J@3oool20?l002L0oooo0P3o000]
0?ooo`8000006`3oool3000001P0oooo0P0000020?ooo`80o`003P3oool00`000000oooo0?ooo`0G
0?ooo`80o`00J@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo05P0oooo000_0?oo
o`030?l0003oool0oooo02H0oooo0P3o001Z0?ooo`030?l0003oool0oooo02D0oooo0P3o000_0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030?oo
o`80o`003@3oool00`000000oooo0?ooo`0G0?ooo`80o`00J@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo05P0oooo000_0?ooo`80o`009`3oool20?l006X0oooo0P3o000V0?ooo`80
o`00<03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0103oool00`000000o`000?ooo`0<0?ooo`030000003oool0oooo01L0oooo0P3o001Z0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0F03oool00300oooo0P3o000V0?ooo`80o`00
J`3oool00`3o0000oooo0?ooo`0T0?ooo`80o`00<@3oool2000001L0oooo00<000000?ooo`3oool0
503oool2000000P0oooo0P3o000<0?ooo`030000003oool0oooo01L0oooo0P3o001[0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0F03oool00340oooo00<0o`000?ooo`3oool0903o
ool20?l006/0oooo0P3o000U0?ooo`80o`00<`3oool2000001D0oooo00<000000?ooo`3oool04P3o
ool2000000X0oooo00<000000?l0003oool02`3oool00`000000oooo0?ooo`0G0?ooo`80o`00J`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo05P0oooo000a0?ooo`80o`009@3oool2
0?l006`0oooo00<0o`000?ooo`3oool08`3oool20?l003D0oooo0P00000C0?ooo`030000003oool0
oooo0100oooo0P00000=0?ooo`80o`002`3oool00`000000oooo0?ooo`0G0?ooo`80o`00K03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05P0oooo000b0?ooo`030?l0003oool0oooo
02<0oooo0P3o001/0?ooo`80o`00903oool20?l003L0oooo0P00000A0?ooo`030000003oool0oooo
00h0oooo0P00000@0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool20?l0
06`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`1H0?ooo`00<P3oool20?l002@0
oooo0P3o001]0?ooo`030?l0003oool0oooo0280oooo0P3o000i0?ooo`<0000000<0oooO09a8M02o
ool02`3oool00`000000oooo0?ooo`0;0?ooo`<000004P3oool20?l000X0oooo00<000000?ooo`3o
ool05`3oool20?l006d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1H0?ooo`00
<`3oool00`3o0000oooo0?ooo`0R0?ooo`80o`00K@3oool20?l002<0oooo0P3o000l0?ooo`@00000
2P3oool00`000000oooo0?ooo`070?ooo`@000005P3oool00`3o0000oooo0?ooo`0R0?ooo`80o`00
K@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo05P0oooo000c0?ooo`80o`008`3o
ool20?l006h0oooo00<0o`000?ooo`3oool08@3oool20?l003`0oooo00@0oooO09a8M02oool0oooo
5000000J0?ooo`80o`008`3oool20?l006h0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`1H0?ooo`00=03oool00`3o0000oooo0?ooo`0Q0?ooo`80o`00KP3oool00`3o0000oooo0?oo
o`0Q0?ooo`80o`00?03oool00`3ooml0W4Qd0;ooo`0;0?ooo`030000003oool0oooo0280oooo00<0
o`000?ooo`3oool08@3oool20?l006h0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`1H0?ooo`00=03oool00`3o0000oooo0?ooo`0Q0?ooo`80o`00KP3oool20?l00280oooo0P3o000j
0?ooo`050?oog`2LW;l0oooO09a8M02oool02`3oool00`000000oooo0?ooo`0R0?ooo`80o`008P3o
ool20?l006l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1H0?ooo`00=03oool2
0?l00280oooo0P3o001_0?ooo`030?l0003oool0oooo0200oooo0P3o000k0?ooo`040?noM0000000
001d0;ooo`/0oooo00<000000?ooo`3oool08`3oool00`3o0000oooo0?ooo`0P0?ooo`80o`00K`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo05P0oooo000e0?ooo`030?l0003oool0
oooo0200oooo0P3o001_0?ooo`80o`008@3oool20?l003`0oooo00<0oono07@0M02oool02`3oool0
0`000000oooo0?ooo`0S0?ooo`80o`008@3oool20?l00700oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`1H0?ooo`00=@3oool20?l00240oooo0P3o001`0?ooo`030?l0003oool0oooo
01l0oooo0P3o001:0?ooo`030000003oool0oooo02@0oooo00<0o`000?ooo`3oool07`3oool20?l0
0700oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1H0?ooo`00=P3oool00`3o0000
oooo0?ooo`0O0?ooo`80o`00L03oool20?l00200oooo0P3o001:0?ooo`030000003oool0oooo02@0
oooo00<0o`000?ooo`3oool07`3oool20?l00740oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`1H0?ooo`00=P3oool20?l00200oooo0P3o001a0?ooo`030?l0003oool0oooo01h0oooo
0P3o001:0?ooo`030000003oool0oooo02@0oooo0P3o000P0?ooo`80o`00L@3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo05P0oooo000g0?ooo`030?l0003oool0oooo01h0oooo0P3o
001a0?ooo`80o`007`3oool20?l004X0oooo00<000000?ooo`3oool09@3oool00`3o0000oooo0?oo
o`0N0?ooo`80o`00LP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05P0oooo000g
0?ooo`80o`007`3oool20?l00780oooo00<0o`000?ooo`3oool07@3oool20?l004X0oooo00<00000
0?ooo`3oool09@3oool20?l001l0oooo0P3o001b0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0F03oool003P0oooo00<0o`000?ooo`3oool07@3oool20?l00780oooo0P3o000N0?oo
o`80o`00BP3oool3000002H0oooo00<0o`000?ooo`3oool07@3oool20?l00780oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`1H0?ooo`00>03oool00`3o0000oooo0?ooo`0M0?ooo`80
o`00LP3oool20?l001h0oooo0P3o001:0?ooo`030000003oool0oooo02H0oooo0P3o000N0?ooo`80
o`00L`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05P0oooo000h0?ooo`80o`00
7P3oool20?l00780oooo0`3o000M0?ooo`80o`00BP3oool00`000000oooo0?ooo`0W0?ooo`030?l0
003oool0oooo01`0oooo0P3o001c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
F03oool003T0oooo00<0o`000?ooo`3oool0703oool20?l007<0oooo0P3o000M0?ooo`80o`00BP3o
ool00`000000oooo0?ooo`0W0?ooo`80o`000`3oool00`000000oooo0?ooo`0G0?ooo`80o`00L`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05P0oooo000i0?ooo`80o`007@3oool2
0?l007<0oooo0`3o000L0?ooo`80o`00BP3oool00`000000oooo0?ooo`0W0?ooo`80o`000`3oool0
0`000000oooo0?ooo`0G0?ooo`80o`00M03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo05P0oooo000j0?ooo`030?l0003oool0oooo01/0oooo0P3o001d0?ooo`80o`00703oool20?l0
04X0oooo00<000000?ooo`3oool09`3oool30?l00080oooo00<000000?ooo`3oool05`3oool20?l0
07@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00>P3oool20?l001`0
oooo0P3o001d0?ooo`80o`00703oool20?l004X0oooo00<000000?ooo`3oool0:03oool20?l00080
oooo00<000000?ooo`3oool05`3oool20?l007D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`1H0?ooo`00>P3oool00`000000o`000?ooo`0K0?ooo`80o`00M03oool30?l001/0oooo
0P3o001:0?ooo`030000003oool0oooo02P0oooo0P3o00020?ooo`030000003oool0oooo01L0oooo
0P3o001e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0F03oool003/0oooo0P3o
000K0?ooo`80o`00M@3oool20?l001/0oooo0P3o001:0?ooo`030000003oool0oooo02P0oooo0`3o
00000`3oool000000?ooo`0H0?ooo`80o`00M@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo05P0oooo000k0?ooo`80o`006`3oool20?l007D0oooo0`3o000J0?ooo`80o`00BP3oool3
000002T0oooo0P3o00000`3oool000000?ooo`0H0?ooo`80o`00MP3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo05P0oooo000k0?ooo`80o`006`3oool20?l007H0oooo0P3o000J0?oo
o`80o`00BP3oool00`000000oooo0?ooo`0Y0?ooo`80o`0000<0oooo0000003oool0603oool20?l0
07H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1H0?ooo`00>`3oool30?l001X0
oooo0P3o001f0?ooo`80o`006P3oool20?l004X0oooo00<000000?ooo`3oool0:@3oool30?l00003
0000003oool0oooo01L0oooo0P3o001f0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0F03oool003`0oooo0P3o000J0?ooo`80o`00MP3oool30?l001T0oooo0P3o001:0?ooo`030000
003oool0oooo02X0oooo0P3o00000`000000oooo0?ooo`0G0?ooo`80o`00MP3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo05P0oooo000l0?ooo`80o`006P3oool20?l007L0oooo0P3o
000I0?ooo`80o`00BP3oool00`000000oooo0?ooo`0Z0?ooo`80o`0000<000000?ooo`3oool05`3o
ool20?l007L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1H0?ooo`00?03oool3
0?l001T0oooo0P3o001g0?ooo`80o`006@3oool20?l004X0oooo00<000000?ooo`3oool0:P3oool3
0?l001T0oooo0P3o001g0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0F03oool0
03d0oooo0P3o000I0?ooo`80o`00M`3oool20?l001T0oooo0P3o001:0?ooo`030000003oool0oooo
02/0oooo0P3o000I0?ooo`80o`00M`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
05P0oooo000m0?ooo`80o`006@3oool20?l007L0oooo0`3o000H0?ooo`80o`00BP3oool00`000000
oooo0?ooo`0[0?ooo`80o`006@3oool20?l007P0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`1H0?ooo`00?@3oool20?l001T0oooo0P3o001h0?ooo`80o`00603oool20?l004X0oooo
00<000000?ooo`3oool0:`3oool20?l001T0oooo0P3o001h0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0F03oool003d0oooo0`3o000H0?ooo`80o`00N03oool20?l001P0oooo0P3o
001:0?ooo`030000003oool0oooo02/0oooo0`3o000H0?ooo`80o`00N03oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo05P0oooo000n0?ooo`80o`00603oool20?l007P0oooo0`3o000G
0?ooo`80o`00BP3oool3000002`0oooo0P3o000H0?ooo`80o`00N@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo05P0oooo000n0?ooo`80o`00603oool20?l007T0oooo0P3o000G0?oo
o`80o`00BP3oool00`000000oooo0?ooo`0/0?ooo`80o`00603oool20?l007T0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`1H0?ooo`00?P3oool30?l001L0oooo0P3o001i0?ooo`80
o`005`3oool20?l004X0oooo00<000000?ooo`3oool0;03oool20?l001P0oooo0P3o001i0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0F03oool003l0oooo0P3o000G0?ooo`80o`00
N@3oool30?l001H0oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo0`3o000G0?ooo`80o`00
NP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05P0oooo000o0?ooo`80o`005`3o
ool20?l007X0oooo0P3o000F0?ooo`80o`00BP3oool00`000000oooo0?ooo`0]0?ooo`80o`005`3o
ool20?l007X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1H0?ooo`00?`3oool2
0?l001L0oooo0P3o001j0?ooo`80o`005P3oool20?l004X0oooo00<000000?ooo`3oool0;@3oool2
0?l001L0oooo0P3o001j0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0F03oool0
03l0oooo0P3o000G0?ooo`80o`00NP3oool20?l001H0oooo0P3o001:0?ooo`030000003oool0oooo
02d0oooo0`3o000F0?ooo`80o`00N`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
05P0oooo000o0?ooo`<0o`005P3oool20?l007X0oooo0`3o000E0?ooo`80o`00BP3oool00`000000
oooo0?ooo`0^0?ooo`80o`005P3oool20?l007/0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`1H0?ooo`00@03oool20?l001H0oooo0P3o001k0?ooo`80o`005@3oool20?l004X0oooo
00<000000?ooo`3oool0;P3oool20?l001H0oooo0P3o001k0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0F03oool00400oooo0P3o000F0?ooo`80o`00N`3oool20?l001D0oooo0P3o
001:0?ooo`<00000;P3oool20?l001H0oooo0P3o001l0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0F03oool00400oooo0P3o000F0?ooo`80o`00N`3oool20?l001D0oooo0P3o001:
0?ooo`030000003oool0oooo02h0oooo0P3o000F0?ooo`80o`00O03oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo05P0oooo00100?ooo`<0o`005@3oool20?l007`0oooo0P3o000D0?oo
o`80o`00BP3oool00`000000oooo0?ooo`0_0?ooo`80o`005@3oool20?l007`0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`1H0?ooo`00@@3oool20?l001D0oooo0P3o001l0?ooo`80
o`00503oool20?l004X0oooo00<000000?ooo`3oool0;`3oool20?l001D0oooo0P3o001l0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0F03oool00440oooo0P3o000E0?ooo`80o`00
O03oool20?l001@0oooo0P3o001:0?ooo`030000003oool0oooo02l0oooo0P3o000E0?ooo`80o`00
O03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05P0oooo00110?ooo`80o`005@3o
ool20?l007`0oooo0P3o000D0?ooo`80o`00BP3oool00`000000oooo0?ooo`0_0?ooo`80o`005@3o
ool20?l007d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1H0?ooo`00@@3oool2
0?l001D0oooo0P3o001l0?ooo`80o`00503oool20?l004X0oooo00<000000?ooo`3oool0;`3oool2
0?l001D0oooo0P3o001m0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0F03oool0
0440oooo0`3o000D0?ooo`80o`00O@3oool20?l001<0oooo0P3o000j0?ooo`030;md000000000000
0080000000<0B9cO0?ooo`3oool0203oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo
0?ooo`80o`00503oool20?l007d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1H
0?ooo`00@P3oool20?l001@0oooo0P3o001m0?ooo`80o`004`3oool20?l003X0oooo00<0oooO09a8
001d_ol03@3oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo0?ooo`80o`00503oool2
0?l007d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1H0?ooo`00@P3oool20?l0
01@0oooo0P3o001m0?ooo`80o`004`3oool20?l003`0oooo00<0_g@0001d_`3oool02`3oool00`00
0000oooo0?ooo`0/0?ooo`040000003oool0oooo0?ooo`80o`00503oool20?l007d0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`1H0?ooo`00@P3oool20?l001@0oooo0P3o001m0?oo
o`80o`004`3oool20?l003d0oooo00<0okmd001d_`3oool02P3oool4000002/0oooo00@000000?oo
o`3oool0oooo0P3o000D0?ooo`80o`00O@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo05P0oooo00120?ooo`80o`00503oool20?l007d0oooo0P3o000C0?ooo`80o`00?P3oool00`3O
W4P0M;oo0?ooo`090?ooo`030000003oool0oooo02`0oooo00@000000?ooo`3oool0oooo0P3o000D
0?ooo`80o`00O@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05P0oooo00130?oo
o`80o`004`3oool20?l007d0oooo0P3o000C0?ooo`80o`00>P3oool01P3o_g@007Bo0?ooo`3oool0
_g@007Boo`X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`020?ooo`80o`004`3o
ool20?l007h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1H0?ooo`00@`3oool2
0?l001<0oooo0P3o001n0?ooo`80o`004P3oool20?l003X0oooo00H0oooO09a80000000000000018
W03Oool:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00P3oool20?l001<0oooo
0P3o001n0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F03oool004<0oooo0P3o
000C0?ooo`80o`00OP3oool20?l00180oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool00P3oool20?l001<0oooo0P3o001n0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0F03oool004<0oooo0P3o000C0?ooo`80o`00OP3oool20?l00180oooo0P3o001:
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00P3oool20?l001<0oooo0P3o001n
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F03oool004<0oooo0P3o000C0?oo
o`80o`00OP3oool20?l00180oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool00P3oool20?l001<0oooo0P3o001n0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0F03oool004@0oooo0P3o000B0?ooo`80o`00OP3oool20?l00180oooo0P3o001:0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool00P3oool20?l001<0oooo0P3o001n0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0F03oool004@0oooo0P3o000B0?ooo`80o`00
OP3oool20?l00180oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
0`3oool20?l00180oooo0P3o001n0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
F03oool004@0oooo0P3o000B0?ooo`80o`00O`3oool20?l00140oooo0P3o001:0?ooo`<00000;03o
ool00`000000oooo0?ooo`030?ooo`80o`004P3oool20?l007l0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1H0?ooo`00A03oool20?l00180oooo0P3o001o0?ooo`80o`004@3oool2
0?l004X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`030?ooo`80o`004P3oool2
0?l007l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1H0?ooo`00A03oool20?l0
0180oooo0P3o001o0?ooo`80o`004@3oool20?l004X0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`030?ooo`80o`004P3oool20?l007l0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1H0?ooo`00A03oool20?l00180oooo0P3o001o0?ooo`80o`004@3oool20?l004X0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`030?ooo`80o`004P3oool20?l007l0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1H0?ooo`00A@3oool20?l00140oooo
0P3o001o0?ooo`80o`004@3oool20?l004X0oooo00<000000?ooo`3oool0<P3oool20?l00180oooo
0P3o001o0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0F03oool004D0oooo0P3o
000A0?ooo`80o`00O`3oool20?l00140oooo0P3o001:0?ooo`030000003oool0oooo03<0oooo0P3o
000A0?ooo`80o`00O`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05P0oooo0015
0?ooo`80o`004@3oool20?l007l0oooo0P3o000A0?ooo`80o`00BP3oool00`000000oooo0?ooo`0c
0?ooo`80o`004@3oool20?l00800oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1H
0?ooo`00A@3oool20?l00140oooo0P3o00200?ooo`80o`00403oool20?l004X0oooo00<000000?oo
o`3oool0<`3oool20?l00140oooo0P3o00200?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0F03oool004D0oooo0P3o000A0?ooo`80o`00P03oool20?l00100oooo0P3o001:0?ooo`03
0000003oool0oooo03<0oooo0P3o000A0?ooo`80o`00P03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo05P0oooo00150?ooo`80o`004@3oool20?l00800oooo0P3o000@0?ooo`80o`00
BP3oool3000003<0oooo0P3o000A0?ooo`80o`00P03oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo05P0oooo00150?ooo`80o`004@3oool20?l00800oooo0P3o000@0?ooo`80o`00BP3o
ool00`000000oooo0?ooo`0c0?ooo`80o`004@3oool20?l00800oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`1H0?ooo`00AP3oool20?l00100oooo0P3o00200?ooo`80o`00403oool2
0?l004X0oooo00<000000?ooo`3oool0<`3oool20?l00140oooo0P3o00200?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0F03oool004H0oooo0P3o000@0?ooo`80o`00P03oool20?l0
0100oooo0P3o001:0?ooo`030000003oool0oooo03@0oooo0P3o000@0?ooo`80o`00P@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo05P0oooo00160?ooo`80o`00403oool20?l00800
oooo0P3o000@0?ooo`80o`00BP3oool00`000000oooo0?ooo`0d0?ooo`80o`00403oool20?l00840
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1H0?ooo`00AP3oool20?l00100oooo
0P3o00210?ooo`80o`003`3oool20?l004X0oooo00<000000?ooo`3oool0=03oool20?l00100oooo
0P3o00210?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0F03oool004H0oooo0P3o
000@0?ooo`80o`00P@3oool20?l000l0oooo0P3o001:0?ooo`030000003oool0oooo03@0oooo0P3o
000@0?ooo`80o`00P@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05P0oooo0016
0?ooo`80o`00403oool20?l00840oooo0P3o000?0?ooo`80o`00BP3oool00`000000oooo0?ooo`0d
0?ooo`80o`00403oool20?l00840oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1H
0?ooo`00AP3oool20?l00100oooo0P3o00210?ooo`80o`003`3oool20?l004X0oooo00<000000?oo
o`3oool0=03oool20?l00100oooo0P3o00210?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0F03oool004H0oooo0P3o000@0?ooo`80o`00P@3oool20?l000l0oooo0P3o001:0?ooo`03
0000003oool0oooo03@0oooo0P3o000@0?ooo`80o`00PP3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo05P0oooo00170?ooo`80o`003`3oool20?l00840oooo0P3o000?0?ooo`80o`00
BP3oool3000002`0oooo00<000000?ooo`3oool01P3oool20?l000l0oooo0P3o00220?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0F03oool004L0oooo0P3o000?0?ooo`80o`00P@3o
ool20?l000l0oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01P3o
ool20?l000l0oooo0P3o00220?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0F03o
ool004L0oooo0P3o000?0?ooo`80o`00P@3oool20?l000l0oooo0P3o001:0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool01P3oool20?l000l0oooo0P3o00220?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0F03oool004L0oooo0P3o000?0?ooo`80o`00PP3oool20?l0
00h0oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01P3oool20?l0
00l0oooo0P3o00220?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0F03oool004L0
oooo0P3o000?0?ooo`80o`00PP3oool20?l000h0oooo0P3o001:0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool01P3oool20?l000l0oooo0P3o00220?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0F03oool004L0oooo0P3o000?0?ooo`80o`00PP3oool20?l000h0oooo
0P3o001:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01P3oool20?l000l0oooo
0P3o00230?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0F03oool004L0oooo0P3o
000?0?ooo`80o`00PP3oool20?l000h0oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool01P3oool20?l000l0oooo0P3o000@0?ooo`030?oOW018000000000080000000H0
B9cO0?ooo`3oool0oooo0=nLB01d_olJ0?ooo`030?noM018W=l0oooo04/0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`1H0?ooo`00A`3oool20?l000l0oooo0P3o00220?ooo`80o`00
3P3oool20?l004X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`060?ooo`80o`00
3`3oool20?l001@0oooo00H0okmd0000B02Lgol0oooo0?oOW01dW=lL0?ooo`030=nLB01d_ol0oooo
04X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1H0?ooo`00A`3oool20?l000l0
oooo0P3o00220?ooo`80o`003P3oool20?l004X0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`060?ooo`80o`003`3oool20?l000d0oooo00D0_g@000000000B9`0gooo0=nLB0020000
000607BLW0180000M;oo0?oog`2LB4P0W=oo0`3oool00`3o_g@0000007Boo`030?ooo`040?oog`2L
B00004RL0=ooo`80oooo00L0oooO09a80000B9`0gooo0?oOW0180000M;oo00H0oooo00<0omnL04Q8
W03Oool05P3oool0303OW4P000000000001d_ol0oooo0?oOW0180000M;oo0?ooo`2oM000001d0;oo
o`80oooo00<0gia80000000000000P0000000`18W=l0oooo0?noM00200000004001d_`3oool0oooO
09a80080000000X007Bo0?ooo`3oool0oooo0?oog`2LB00004RL0=ooo`3ooml0W4P00P0000000`18
W=l0oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0F03oool004L0
oooo0P3o000?0?ooo`80o`00PP3oool20?l000h0oooo0P3o001:0?ooo`<00000;03oool00`000000
oooo0?ooo`070?ooo`80o`003P3oool20?l000`0oooo00h0oooO09a80000M;l0oooo0?noM0000000
M;oo0?ooo`2oM000000007Boo`3ogi`0B01d0;ooo`<0oooo00<0okmd0000001d_ol00`3oool0103o
oml0W4P00018W03Oool20?ooo`070?oog`2LB00004RL0=ooo`3ogi`0B00007Boo`060?ooo`030?oo
_`1d0000M;oo00<0oooo00<0okmd0000000000000`0000000`00B9`0gooo0?ooo`090?ooo`0=0?oO
W0180000M;oo0?noM00004P0W=oo0?oOW0180000M;oo0?ooo`3OW4P0001d0;ooo`020?ooo`040?oo
_`1d000004RL0=ooo`80oooo00`0omnL04P0B02Lgol0omnL04P0001d_ol0gia80000B02Lgol0omnL
04P00018W=l20?ooo`0:0?oog`2LB00004RL0=ooo`3OW4P0001809cOo`3o_g@0000007Boo`P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1H0?ooo`00B03oool20?l000h0oooo0P3o
00220?ooo`80o`003P3oool20?l004X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`070?ooo`80o`003P3oool20?l000`0oooo00h0oooO09a80000M;l0oooo0=nLB00007@0_ooo0?oo
o`3ogi`0B00007Boo`3o_g@0001d0;ooo`<0oooo00D0okmd0000001d_ol0oooO09a8000400000003
0018M01dB000000000<0000000<004RL0=ooo`3oool01`3oool00`3ooml0W4P007Boo`0>0?ooo`03
0?noM0000000000000<0000000L004RL0<BLB00007@0_ooo0?oOW0180000M;oo00@0oooo00<0okmd
0000001d_ol00`3oool00`3ogi`0B000001d_`020?ooo`060=nLB00007@0_ooo0?oo_`1d000007Bo
0`3oool0103ooml0W4P0001dW02LB004000000070018W03Oool0oooo0?ooo`3ookl0M00004RLg`08
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0F03oool004P0oooo0P3o000>0?oo
o`80o`00PP3oool20?l000h0oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool01`3oool20?l000h0oooo0P3o000<0?ooo`0>0?oog`2LB00007Bo0?ooo`3OW4P0001d0;oo
o`3oool0omnL04P0001d_ol0okmd0000M02oool30?ooo`0@0?noM0000000M;oo0?ooo`3OW4P004RL
0=oog`2LB00004RL0=ooo`3OW4P004RL0=oog`2LB00004RL0=ooo`T0oooo00<0oooO09a8001d_ol0
5@3oool01P2oM000001d0;ooo`3ogi`0B00004RLg`@0oooo00<0oono07@00018W=l0103oool05P3o
_g@0000004RLg`3oool0_g@00000B02Lgol0omnL04P00018W=l0okmd0000B02Lgol0omnL04P00018
W=l0gia80018W03Ooml0W4P00018W03Oool30?ooo`030?oOW0180000M;oo00P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`1H0?ooo`00B03oool20?l000h0oooo0P3o00220?ooo`80
o`003P3oool20?l004X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`070?ooo`80
o`003P3oool20?l000`0oooo0240oooO09a80000M;l0oooo0?noM0000000M;oo0?ooo`2oM0000000
07Boo`3ogi`0B01d0;ooo`3oool0omnL04Qd_`3o_g@0000007Boo`3oool0oooO09a8001d_ml0W4P0
0018W03Oool0oooO09a8001d_ml0W4P00018W03Oool0103oool0203ogi`0B0000000M02oool0oooo
0?oo_`1d0000M;oo0`3oool00`3o_g@0000000000003000000030018W03Oool0oooo00T0oooo00H0
_g@00000M02oool0omnL04P00018W=l50?ooo`030;md000007@0_ooo00@0oooo00/0gia80000B02L
gol0gia80018B01800000000001d_`3oool0omnL04P00002000000080018W03Oool0oooO09a8001d
_ml0W4P00018W03Oool20?ooo`030?noM00007@0_ooo00X0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1H0?ooo`00B03oool20?l000h0oooo0P3o00230?ooo`80o`003@3oool20?l0
04X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`070?ooo`80o`003P3oool20?l0
00/0oooo00L0oooO09a80000000000000018W03Oool0gia80080000000T0B7Ad04P0001d_ol0oooO
09a8B02Lgol0oooo0?oOW01800000P0000003P1d_ol0oooo0?ooo`3ogi`0B4Qd07A80000B9`0gooo
0?ooo`3ogi`0B4Qd07A80000B9`0gooo103oool0202oM000M;oo0?noM018W=l0oooo0?oOW018B9`0
gooo5@3oool01P3OW4P0001d0;ooo`3ogi`0B00007Boo`D0oooo00<0omnL04P00018W=l0103oool0
1P3ogi`0B00004RLg`3OW4P0001d0;ooo`<0oooo00<0oono07@0001d_ol0103oool01@3ogi`0B4Qd
07A80000B9`0gooo00<0oooo00<0gia80000M02oool02@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo05P0oooo00180?ooo`80o`003P3oool20?l008<0oooo0P3o000=0?ooo`80o`00
BP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00L0oooo0P3o000>0?ooo`80o`00
303oool00`3ooml0W4P0001d_`090?ooo`080?oOW018B9`0gooo0?ooo`3ogi`0B0000000001d_ol3
0?ooo`040=nLB000000004RL0=ooo`80oooo00@0gia800000000B9`0gooo103oool01`2oM000M;oo
0?noM018W=l0oooo0;md001d_ol05P3oool01P3ogi`0B01809cOo`3o_g@0001809cOo`H0oooo0180
gia80000B02Lgol0okmd0000001d_ol0omnL04P0001d_ol0omnL04P0001d_ol0okmd0000001d_ol0
oooO09a80000M;l50?ooo`0:0=nLB000000004RL0=ooo`3o_g@0000007Boo`3OW4P0001809cOo`T0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1H0?ooo`00B03oool20?l000h0oooo
0P3o00230?ooo`80o`003@3oool20?l004X0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`070?ooo`80o`003P3oool20?l000d0oooo00<0omnL04Qd_`3oool02@3oool01`3ogi`0W;oo
0?ooo`3oool0omnL04P0001d_ol00`3oool0103ooml0W4P00018W03Oool20?ooo`040?oog`2LB000
04RL0=ooo`@0oooo00H0omnL04P0000007@0_ooo0?noM01d_olH0?ooo`040=nLB0000000000007Bo
o`@0oooo00<0gia80000000000000P0000000`18W=l0oooo0;md000200000004001d_`3oool0oooo
0?noM080000000@007Bo0?ooo`3oool0_g@00`0000002@1d_ol0oooo0?ooo`3ooml0W4P00018W03O
ool0oooo0;md00020000000304RLg`3oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`1H0?ooo`00B03oool20?l000h0oooo0P3o00230?ooo`80o`003@3oool20?l003/0
oooo00@0_g@000000000000007Bo2`3oool00`000000oooo0?ooo`0f0?ooo`80o`003P3oool20?l0
08@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1H0?ooo`00B03oool20?l000h0
oooo0P3o00230?ooo`80o`003@3oool20?l003X0oooo00H0okmd04RLg`3oool0oooo0=nLB018W=l:
0?ooo`030000003oool0oooo03H0oooo0P3o000>0?ooo`80o`00Q03oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo05P0oooo00180?ooo`80o`003P3oool20?l008<0oooo0P3o000=0?oo
o`80o`00?P3oool00`3OW4P0B9cO0?ooo`090?ooo`030000003oool0oooo03L0oooo0P3o000=0?oo
o`80o`00Q03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05P0oooo00180?ooo`80
o`003P3oool20?l008<0oooo0P3o000=0?ooo`80o`00?03oool00`2oM000000004RLg`0;0?ooo`@0
0000=P3oool20?l000d0oooo0P3o00240?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0F03oool004T0oooo0P3o000=0?ooo`80o`00P`3oool20?l000d0oooo0P3o000m0?ooo`030?oo
_`1d07@0_ooo00X0oooo00<000000?ooo`3oool0=`3oool20?l000d0oooo0P3o00250?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0F03oool004T0oooo0P3o000=0?ooo`80o`00P`3o
ool20?l000d0oooo0P3o000j0?ooo`060?noM000M;l0oooo0?oo_`1d07@0_ooo2P3oool00`000000
oooo0?ooo`0g0?ooo`80o`003@3oool20?l008D0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1H0?ooo`00B@3oool20?l000d0oooo0P3o00230?ooo`80o`003@3oool20?l003/0oooo
00@0_g@0000000000000M;oo2`3oool00`000000oooo0?ooo`0g0?ooo`80o`003@3oool20?l008D0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1H0?ooo`00B@3oool20?l000d0oooo
0P3o00240?ooo`80o`00303oool20?l004X0oooo00<000000?ooo`3oool0=`3oool20?l000d0oooo
0P3o00250?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0F03oool004T0oooo0P3o
000=0?ooo`80o`00Q03oool20?l000`0oooo0P3o001:0?ooo`030000003oool0oooo03P0oooo0P3o
000<0?ooo`80o`00Q@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05P0oooo0019
0?ooo`80o`003@3oool20?l008@0oooo0P3o000<0?ooo`80o`00BP3oool00`000000oooo0?ooo`0h
0?ooo`80o`00303oool20?l008D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1H
0?ooo`00B@3oool20?l000d0oooo0P3o00240?ooo`80o`00303oool20?l004X0oooo00<000000?oo
o`3oool0>03oool20?l000`0oooo0P3o00250?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0F03oool004T0oooo0P3o000=0?ooo`80o`00Q03oool20?l000`0oooo0P3o001:0?ooo`03
0000003oool0oooo03P0oooo0P3o000<0?ooo`80o`00Q@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo05P0oooo001:0?ooo`80o`00303oool20?l008@0oooo0P3o000<0?ooo`80o`00
BP3oool3000003P0oooo0P3o000<0?ooo`80o`00Q@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo05P0oooo001:0?ooo`80o`00303oool20?l008@0oooo0P3o000<0?ooo`80o`00BP3o
ool00`000000oooo0?ooo`0h0?ooo`80o`00303oool20?l008D0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1H0?ooo`00BP3oool20?l000`0oooo0P3o00240?ooo`80o`00303oool2
0?l004X0oooo00<000000?ooo`3oool0>03oool20?l000`0oooo0P3o00250?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0F03oool004X0oooo0P3o000<0?ooo`80o`00Q03oool20?l0
00`0oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool20?l0
00/0oooo0P3o00250?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0F03oool004X0
oooo0P3o000<0?ooo`80o`00Q03oool20?l000`0oooo0P3o001:0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02P3oool20?l000/0oooo0P3o00250?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0F03oool004X0oooo0P3o000<0?ooo`80o`00Q03oool20?l000`0oooo
0P3o001:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool20?l000/0oooo
0P3o00260?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0F03oool004X0oooo0P3o
000<0?ooo`80o`00Q03oool20?l000`0oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02P3oool20?l000/0oooo0P3o00260?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0F03oool004X0oooo0P3o000<0?ooo`80o`00Q03oool20?l000030000003oool0
oooo00T0oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool2
0?l000/0oooo0P3o00260?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0F03oool0
04X0oooo0P3o000<0?ooo`80o`00Q@3oool20?l000/0oooo0P3o001:0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02P3oool20?l000/0oooo0P3o00260?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0F03oool004/0oooo0P3o000;0?ooo`80o`00Q@3oool20?l000/0
oooo0P3o001:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool20?l000/0
oooo0P3o00260?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0F03oool004/0oooo
0P3o000;0?ooo`80o`00Q@3oool20?l000/0oooo0P3o001:0?ooo`<00000;03oool00`000000oooo
0?ooo`0:0?ooo`80o`002`3oool20?l008H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1H0?ooo`00B`3oool20?l000/0oooo0P3o00250?ooo`80o`002`3oool20?l004X0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`80o`002`3oool20?l008H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`1H0?ooo`00B`3oool20?l000/0oooo0P3o0025
0?ooo`80o`002`3oool20?l004X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:
0?ooo`80o`002`3oool20?l008H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1H
0?ooo`00B`3oool20?l000/0oooo0P3o00250?ooo`80o`002`3oool20?l004X0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`80o`002`3oool20?l008H0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1H0?ooo`00B`3oool20?l000/0oooo0P3o00250?ooo`80
o`002`3oool20?l004X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`80
o`002`3oool20?l008H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1H0?ooo`00
B`3oool20?l000/0oooo0P3o00250?ooo`80o`002`3oool20?l004X0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0:0?ooo`80o`002`3oool20?l008H0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1H0?ooo`00B`3oool20?l000/0oooo0P3o00250?ooo`80o`002`3o
ool20?l004X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`80o`002`3o
ool20?l008H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1H0?ooo`00B`3oool3
0?l000X0oooo0P3o00250?ooo`80o`002`3oool20?l004X0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0;0?ooo`80o`002P3oool20?l008H0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`1H0?ooo`00C03oool20?l000X0oooo0P3o00250?ooo`80o`002`3oool20?l0
04X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0;0?ooo`80o`002P3oool20?l0
08H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1H0?ooo`00C03oool20?l000X0
oooo0P3o00250?ooo`80o`002`3oool20?l004X0oooo0`00000/0?ooo`030000003oool0oooo00/0
oooo0P3o000:0?ooo`80o`00QP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05P0
oooo001<0?ooo`80o`002P3oool20?l008D0oooo0P3o000;0?ooo`80o`00BP3oool00`000000oooo
0?ooo`0j0?ooo`80o`002P3oool20?l008H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1H0?ooo`00C03oool20?l000X0oooo0P3o00260?ooo`80o`002P3oool20?l004X0oooo00<0
00000?ooo`3oool0>P3oool20?l000X0oooo0P3o00260?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0F03oool004`0oooo0P3o000:0?ooo`80o`00QP3oool20?l000X0oooo0P3o001:
0?ooo`030000003oool0oooo03X0oooo0P3o000:0?ooo`80o`00QP3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo05P0oooo001<0?ooo`80o`002P3oool20?l008H0oooo0P3o000:0?oo
o`80o`00BP3oool00`000000oooo0?ooo`0j0?ooo`80o`002P3oool20?l008H0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1H0?ooo`00C03oool20?l000X0oooo0P3o00260?ooo`80
o`002P3oool20?l004X0oooo00<000000?ooo`3oool0>P3oool20?l000X0oooo0P3o00270?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0F03oool004`0oooo0P3o000:0?ooo`80o`00
QP3oool20?l000X0oooo0P3o001:0?ooo`030000003oool0oooo03X0oooo0P3o000:0?ooo`80o`00
Q`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05P0oooo001<0?ooo`80o`002P3o
ool20?l008H0oooo0P3o000:0?ooo`80o`00BP3oool00`000000oooo0?ooo`0j0?ooo`80o`002P3o
ool20?l008L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1H0?ooo`00C03oool2
0?l000X0oooo0P3o00260?ooo`80o`002P3oool20?l004X0oooo00<000000?ooo`3oool0>P3oool2
0?l000X0oooo0P3o00270?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0F03oool0
04`0oooo0P3o000:0?ooo`80o`00QP3oool20?l000X0oooo0P3o001:0?ooo`030000003oool0oooo
03X0oooo0P3o000:0?ooo`80o`00Q`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
05P0oooo001<0?ooo`80o`002P3oool20?l008L0oooo0P3o00090?ooo`80o`00BP3oool3000003X0
oooo0P3o000:0?ooo`80o`00Q`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05P0
oooo001<0?ooo`80o`002P3oool20?l008L0oooo0P3o00090?ooo`80o`00BP3oool00`000000oooo
0?ooo`0j0?ooo`80o`002P3oool20?l008L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1H0?ooo`00C03oool20?l000X0oooo0P3o00270?ooo`80o`002@3oool20?l004X0oooo00<0
00000?ooo`3oool0>P3oool20?l000X0oooo0P3o00270?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0F03oool004`0oooo0P3o000:0?ooo`80o`00Q`3oool20?l000T0oooo0P3o001:
0?ooo`030000003oool0oooo03X0oooo0P3o000:0?ooo`80o`00Q`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo05P0oooo001<0?ooo`80o`002P3oool20?l008L0oooo0P3o00090?oo
o`80o`00BP3oool00`000000oooo0?ooo`0j0?ooo`<0o`002@3oool20?l008L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1H0?ooo`00C03oool20?l000X0oooo0P3o00270?ooo`80
o`002@3oool20?l004X0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0;0?ooo`<0
o`002@3oool20?l008L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1H0?ooo`00
C03oool20?l000X0oooo0P3o00270?ooo`80o`002@3oool20?l004X0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0;0?ooo`80o`002P3oool20?l008L0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`1H0?ooo`00C03oool20?l000X0oooo0P3o00270?ooo`80o`002@3o
ool20?l003d0oooo00<0okmd04RLg`3oool02P3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00/0oooo0P3o000:0?ooo`80o`00R03oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo05P0oooo001<0?ooo`80o`002P3oool20?l008L0oooo0`3o00080?ooo`80o`00?@3oool0
0`3o_g@0B9cO0?ooo`0:0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02`3oool2
0?l000X0oooo0P3o00280?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0F03oool0
04d0oooo0P3o00090?ooo`80o`00Q`3oool30?l000P0oooo0P3o000j0?ooo`030=nLB00000000000
0080000000<0B9cO0?ooo`3oool0203oool4000002/0oooo00<000000?ooo`3oool02`3oool20?l0
00X0oooo0P3o00280?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0F03oool00?l0
oooo:@3oool01@3ookl0M01d0;ooo`3o_g@0B9cO0?l0ooooA@3oool00?l0oooo:P3oool0103ogi`0
B4RL0=noM018W=oo0?ooodD0oooo003o0?ooob/0oooo00<0okmd00000018W=l0o`3ooom50?ooo`00
o`3oool/0?ooo`030=nLB018W=l0oooo0?l0ooooA03oool00?l0ooooo`3ooomc0?ooo`00o`3ooooo
0?ooog<0oooo003o0?ooool0ooooL`3oool00?l0ooooo`3ooomc0?ooo`00o`3ooooo0?ooog<0oooo
003o0?ooool0ooooL`3oool00001\
\>"],
  ImageRangeCache->{{{94.4375, 443.375}, {641.188, 418.25}} -> {-10.1685, \
11.6007, 0.02647, 0.02647}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 941}},
PrintingStyleEnvironment->"OutputPDF",
WindowSize->{831, 629},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{56.6875, 56.6875}, {70.8125, \
70.8125}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->False},
ShowSelection->True,
CellLabelAutoDelete->True,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "OutputPDF"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ ""]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ ""]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Angoli e funzioni goniometriche"}], "Footer"], None, 
          Cell[ 
            TextData[ {"Lorenzo Roi 2006"}], "Footer"]}, {Cell[ 
            TextData[ {"Angoli e funzioni goniometriche"}], "Footer"], None, 
          Cell[ 
            TextData[ {"Lorenzo Roi 2006"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellFrame->False,
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 0.8, 0.4]],
  
  Cell[StyleData["Title", "OutputPDF"],
    CellFrame->False,
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 0.8, 0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 10}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Subtitle", "OutputPDF"],
    CellMargins->{{0, 0}, {0, 10}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "OutputPDF"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 25}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Section", "OutputPDF"],
    CellMargins->{{9, 0}, {2, 25}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 20}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "OutputPDF"],
    CellMargins->{{9, 0}, {4, 20}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{21, 0}, {4, 10}},
    FontSize->14],
  
  Cell[StyleData["Subsubsection", "OutputPDF"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{21, 0}, {4, 10}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6},
    FontSize->14],
  
  Cell[StyleData["Text", "OutputPDF"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.360784, 0.678431, 0.870588],
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0.705882, 0.85098, 0.937255]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{25, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Courier",
    FontSize->9,
    Background->None],
  
  Cell[StyleData["Input", "OutputPDF"],
    CellFrame->{{2, 0}, {0, 0}},
    CellMargins->{{25, 0}, {6, 6}},
    CellFrameColor->GrayLevel[0],
    FontFamily->"Courier",
    FontSize->8,
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[1, 0.623529, 0.623529],
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontSize->12,
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellFrameColor->GrayLevel[0],
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Output", "OutputPDF"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellFrameColor->GrayLevel[0],
    FontSize->8,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "OutputPDF"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "OutputPDF"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}],
  
  Cell[StyleData["Graphics", "OutputPDF"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "OutputPDF"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{0, 4}, {2, 10}},
    TextAlignment->Left,
    FontFamily->"Helvetica",
    FontSize->12,
    FontSlant->"Italic",
    Background->RGBColor[1, 0.8, 0.4]],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{0, 10}, {2, 12}},
    TextAlignment->Left,
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{0, 10}, {1, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellFrame->False,
    CellMargins->{{0, 0}, {4, 12}},
    TextAlignment->Left,
    ParagraphSpacing->{0, 6},
    FontFamily->"Helvetica",
    Background->GrayLevel[1]],
  
  Cell[StyleData["Author", "OutputPDF"],
    CellFrame->False,
    CellMargins->{{0, 0}, {4, 12}},
    TextAlignment->Left,
    ParagraphSpacing->{0, 6},
    FontFamily->"Helvetica",
    FontSize->11,
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    TextAlignment->Right,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    TextAlignment->Right,
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    TextAlignment->Right,
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    TextAlignment->Right,
    FontSize->7],
  
  Cell[StyleData["Copyright", "OutputPDF"],
    CellMargins->{{9, 0}, {72, 4}},
    TextAlignment->Right,
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10],
  
  Cell[StyleData["Abstract", "OutputPDF"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Example", "OutputPDF"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->True,
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.34902, 0.807843, 0.807843],
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Normal",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.639216, 0.894118, 0.894118]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellFrame->True,
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellFrame->True,
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->14,
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Definition", "OutputPDF"],
    CellMargins->{{44, 44}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8,
    FontWeight->"Normal",
    Background->RGBColor[0.823529, 0.94902, 0.94902]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->True,
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.647059, 0.219608, 0.647059],
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Normal",
    FontColor->RGBColor[0.25098, 0, 0.25098],
    Background->RGBColor[0.858824, 0.584314, 0.858824]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Theorem", "OutputPDF"],
    CellMargins->{{44, 44}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->9,
    FontWeight->"Normal",
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->True,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 0.443137, 0.443137],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->True,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->True,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->True,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Caution", "OutputPDF"],
    CellFrame->True,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->True,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.682353, 1, 0.682353],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->True,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->True,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->True,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.900008]],
  
  Cell[StyleData["Advice", "OutputPDF"],
    CellFrame->True,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Exercise", "OutputPDF"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["ExerciseMain", "OutputPDF"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["ExerciseTitle", "OutputPDF"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "OutputPDF"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "OutputPDF"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{50, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    CellMargins->{{50, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["BulletedList", "Printout"],
    CellMargins->{{50, 10}, {2, Inherited}},
    LineSpacing->{0, 12},
    FontSize->10],
  
  Cell[StyleData["BulletedList", "OutputPDF"],
    CellMargins->{{50, 10}, {2, Inherited}},
    LineSpacing->{0, 12},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "OutputPDF"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "OutputPDF"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "OutputPDF"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "OutputPDF"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figura ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]],
  
  Cell[StyleData["NumberedFigure", "OutputPDF"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]],
  
  Cell[StyleData["NumberedTable", "OutputPDF"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->11,
    FontWeight->"Normal",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->14,
    FontWeight->"Normal",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["Hyperlink", "OutputPDF"],
    FontSize->10,
    FontWeight->"Normal",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["MainBookLink", "OutputPDF"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["AddOnLink", "OutputPDF"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["RefGuideLink", "OutputPDF"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["GettingStartedLink", "OutputPDF"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}],
  
  Cell[StyleData["OtherInformationLink", "OutputPDF"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "intervalli"->{
    Cell[3621, 109, 1542, 31, 204, "Text",
      CellTags->"intervalli"]},
  "figura1"->{
    Cell[6393, 171, 35925, 1012, 231, 16742, 769, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura1"]},
  "figura2"->{
    Cell[44269, 1239, 37891, 1117, 231, 18291, 869, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura2"]},
  "figura3"->{
    Cell[219508, 5715, 53269, 1202, 223, 15935, 735, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura3"]},
  "figura4"->{
    Cell[449914, 11793, 45851, 1585, 126, 33744, 1430, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura4"]},
  "definizionecoseno"->{
    Cell[497210, 13429, 188, 5, 101, "Definition",
      CellTags->"definizionecoseno"]},
  "figura5"->{
    Cell[499227, 13495, 53268, 1202, 223, 15935, 735, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura5"]},
  "figura6"->{
    Cell[691789, 18918, 46001, 1580, 126, 33614, 1421, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura6"]},
  "deftangente"->{
    Cell[738892, 20542, 238, 8, 101, "Definition",
      CellTags->"deftangente"]},
  "figura7"->{
    Cell[740451, 20589, 35861, 987, 223, 15935, 735, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura7"]},
  "figura8"->{
    Cell[780615, 21701, 62502, 1397, 223, 18974, 852, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura8"]},
  "dimpertan"->{
    Cell[844881, 23164, 175, 3, 52, "DisplayFormula",
      CellTags->"dimpertan"]},
  "figura9"->{
    Cell[850620, 23333, 69557, 1489, 257, 19298, 863, "GraphicsData", 
    "PostScript", "NumberedFigure",
      CellTags->"figura9"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"intervalli", 1293120, 32967},
  {"figura1", 1293210, 32970},
  {"figura2", 1293357, 32974},
  {"figura3", 1293506, 32978},
  {"figura4", 1293656, 32982},
  {"definizionecoseno", 1293818, 32986},
  {"figura5", 1293923, 32989},
  {"figura6", 1294074, 32993},
  {"deftangente", 1294230, 32997},
  {"figura7", 1294329, 33000},
  {"figura8", 1294479, 33004},
  {"dimpertan", 1294632, 33008},
  {"figura9", 1294732, 33011}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 76, 0, 118, "Title"],
Cell[1855, 55, 29, 0, 54, "Author"],
Cell[1887, 57, 265, 8, 33, "Copyright"],

Cell[CellGroupData[{
Cell[2177, 69, 35, 0, 56, "Subsection"],
Cell[2215, 71, 277, 5, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2529, 81, 51, 0, 35, "Subsection"],
Cell[2583, 83, 134, 3, 32, "Text"],
Cell[2720, 88, 804, 14, 220, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3561, 107, 57, 0, 43, "Section"],
Cell[3621, 109, 1542, 31, 204, "Text",
  CellTags->"intervalli"],

Cell[CellGroupData[{
Cell[5188, 144, 44, 0, 46, "Subsubsection"],
Cell[5235, 146, 1086, 18, 240, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[6358, 169, 32, 0, 46, "Subsubsection"],
Cell[6393, 171, 35925, 1012, 231, 16742, 769, "GraphicsData", "PostScript", \
"NumberedFigure",
  CellTags->"figura1"],
Cell[42321, 1185, 686, 21, 72, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[43044, 1211, 44, 0, 46, "Subsubsection"],
Cell[43091, 1213, 1106, 19, 240, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[44234, 1237, 32, 0, 46, "Subsubsection"],
Cell[44269, 1239, 37891, 1117, 231, 18291, 869, "GraphicsData", "PostScript", \
"NumberedFigure",
  CellTags->"figura2"],
Cell[82163, 2358, 1209, 25, 152, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[83409, 2388, 44, 0, 46, "Subsubsection"],
Cell[83456, 2390, 1259, 21, 260, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[84752, 2416, 35, 0, 46, "Subsubsection"],
Cell[84790, 2418, 62619, 1491, 215, 19684, 957, "GraphicsData", "PostScript", \
"Graphics"],
Cell[147412, 3911, 110, 5, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[147559, 3921, 44, 0, 46, "Subsubsection"],
Cell[147606, 3923, 1305, 23, 260, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[148948, 3951, 35, 0, 46, "Subsubsection"],
Cell[148986, 3953, 62498, 1500, 215, 19888, 970, "GraphicsData", \
"PostScript", "Graphics"],
Cell[211487, 5455, 615, 11, 92, "Text"],
Cell[212105, 5468, 151, 2, 56, "Theorem"],
Cell[212259, 5472, 710, 20, 72, "Text"],
Cell[212972, 5494, 223, 3, 56, "Theorem"],
Cell[213198, 5499, 1548, 44, 132, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[214795, 5549, 63, 0, 43, "Section"],
Cell[214861, 5551, 1322, 47, 124, "Text"],
Cell[216186, 5600, 153, 4, 101, "Definition"],
Cell[216342, 5606, 2111, 80, 92, "Text"],

Cell[CellGroupData[{
Cell[218478, 5690, 44, 0, 46, "Subsubsection"],
Cell[218525, 5692, 911, 16, 220, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[219473, 5713, 32, 0, 46, "Subsubsection"],
Cell[219508, 5715, 53269, 1202, 223, 15935, 735, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura3"]
}, Closed]],

Cell[CellGroupData[{
Cell[272814, 6922, 52, 0, 56, "Subsection"],
Cell[272869, 6924, 870, 29, 72, "Text"],
Cell[273742, 6955, 219, 3, 56, "Theorem"],
Cell[273964, 6960, 666, 20, 72, "Text"],

Cell[CellGroupData[{
Cell[274655, 6984, 44, 0, 46, "Subsubsection"],
Cell[274702, 6986, 1402, 24, 320, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[276141, 7015, 35, 0, 46, "Subsubsection"],
Cell[276179, 7017, 62689, 1441, 215, 21054, 923, "GraphicsData", \
"PostScript", "Graphics"],
Cell[338871, 8460, 1165, 36, 104, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[340097, 8503, 68, 0, 43, "Section"],
Cell[340168, 8505, 1450, 37, 112, "Text"],

Cell[CellGroupData[{
Cell[341643, 8546, 44, 0, 46, "Subsubsection"],
Cell[341690, 8548, 2490, 44, 460, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[344217, 8597, 35, 0, 46, "Subsubsection"],
Cell[344255, 8599, 37637, 1163, 145, 20136, 942, "GraphicsData", \
"PostScript", "Graphics"],
Cell[381895, 9764, 863, 24, 80, "Text"],
Cell[382761, 9790, 1072, 30, 92, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[383870, 9825, 44, 0, 46, "Subsubsection"],
Cell[383917, 9827, 2455, 43, 460, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[386409, 9875, 35, 0, 46, "Subsubsection"],
Cell[386447, 9877, 60557, 1833, 110, 31144, 1466, "GraphicsData", \
"PostScript", "Graphics"],
Cell[447007, 11712, 527, 13, 72, "Text"],
Cell[447537, 11727, 1033, 30, 92, "Definition"]
}, Closed]],

Cell[CellGroupData[{
Cell[448607, 11762, 44, 0, 46, "Subsubsection"],
Cell[448654, 11764, 1188, 22, 220, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[449879, 11791, 32, 0, 46, "Subsubsection"],
Cell[449914, 11793, 45851, 1585, 126, 33744, 1430, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura4"],
Cell[495768, 13380, 315, 10, 32, "Text"],
Cell[496086, 13392, 179, 3, 35, "DisplayFormula"],
Cell[496268, 13397, 118, 3, 32, "Text"],
Cell[496389, 13402, 247, 5, 35, "DisplayFormula"],
Cell[496639, 13409, 234, 6, 32, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[496922, 13421, 65, 0, 43, "Section"],
Cell[496990, 13423, 217, 4, 52, "Text"],
Cell[497210, 13429, 188, 5, 101, "Definition",
  CellTags->"definizionecoseno"],
Cell[497401, 13436, 770, 30, 52, "Text"],

Cell[CellGroupData[{
Cell[498196, 13470, 44, 0, 46, "Subsubsection"],
Cell[498243, 13472, 912, 16, 220, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[499192, 13493, 32, 0, 46, "Subsubsection"],
Cell[499227, 13495, 53268, 1202, 223, 15935, 735, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura5"]
}, Closed]],

Cell[CellGroupData[{
Cell[552532, 14702, 46, 0, 46, "Subsubsection"],
Cell[552581, 14704, 283, 8, 32, "Text"],
Cell[552867, 14714, 203, 3, 59, "Theorem"],
Cell[553073, 14719, 96, 2, 32, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[553206, 14726, 44, 0, 46, "Subsubsection"],
Cell[553253, 14728, 1442, 25, 320, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[554732, 14758, 35, 0, 46, "Subsubsection"],
Cell[554770, 14760, 39017, 1037, 215, 17406, 765, "GraphicsData", \
"PostScript", ""],
Cell[593790, 15799, 1086, 31, 100, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[594925, 15836, 70, 0, 43, "Section"],
Cell[594998, 15838, 1907, 47, 172, "Text"],

Cell[CellGroupData[{
Cell[596930, 15889, 44, 0, 46, "Subsubsection"],
Cell[596977, 15891, 2711, 47, 520, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[599725, 15943, 35, 0, 46, "Subsubsection"],
Cell[599763, 15945, 40381, 1219, 145, 20535, 969, "GraphicsData", \
"PostScript", "Graphics"],
Cell[640147, 17166, 266, 6, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[640450, 17177, 44, 0, 46, "Subsubsection"],
Cell[640497, 17179, 2826, 49, 520, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[643360, 17233, 35, 0, 46, "Subsubsection"],
Cell[643398, 17235, 46690, 1634, 110, 30552, 1430, "GraphicsData", \
"PostScript", ""],
Cell[690091, 18871, 172, 6, 32, "Text"],
Cell[690266, 18879, 179, 3, 35, "DisplayFormula"]
}, Closed]],

Cell[CellGroupData[{
Cell[690482, 18887, 44, 0, 46, "Subsubsection"],
Cell[690529, 18889, 1188, 22, 220, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[691754, 18916, 32, 0, 46, "Subsubsection"],
Cell[691789, 18918, 46001, 1580, 126, 33614, 1421, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura6"],
Cell[737793, 20500, 87, 1, 32, "Text"],
Cell[737883, 20503, 247, 5, 35, "DisplayFormula"],
Cell[738133, 20510, 168, 5, 32, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[738350, 20521, 97, 2, 43, "Section"],
Cell[738450, 20525, 439, 15, 52, "Text"],
Cell[738892, 20542, 238, 8, 101, "Definition",
  CellTags->"deftangente"],
Cell[739133, 20552, 261, 8, 32, "Text"],

Cell[CellGroupData[{
Cell[739419, 20564, 44, 0, 46, "Subsubsection"],
Cell[739466, 20566, 913, 16, 220, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[740416, 20587, 32, 0, 46, "Subsubsection"],
Cell[740451, 20589, 35861, 987, 223, 15935, 735, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura7"],
Cell[776315, 21578, 813, 23, 76, "Text"],
Cell[777131, 21603, 322, 5, 65, "Theorem"],
Cell[777456, 21610, 402, 12, 52, "Text"],
Cell[777861, 21624, 156, 2, 69, "DisplayFormula"],
Cell[778020, 21628, 381, 12, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[778438, 21645, 41, 0, 56, "Subsection"],
Cell[778482, 21647, 634, 17, 72, "Text"],

Cell[CellGroupData[{
Cell[779141, 21668, 44, 0, 46, "Subsubsection"],
Cell[779188, 21670, 1355, 24, 320, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[780580, 21699, 32, 0, 46, "Subsubsection"],
Cell[780615, 21701, 62502, 1397, 223, 18974, 852, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura8"],
Cell[843120, 23100, 1630, 57, 52, "Text"],
Cell[844753, 23159, 76, 1, 48, "DisplayFormula"],
Cell[844832, 23162, 46, 0, 32, "Text"],
Cell[844881, 23164, 175, 3, 52, "DisplayFormula",
  CellTags->"dimpertan"],
Cell[845059, 23169, 556, 14, 56, "Text"],
Cell[845618, 23185, 757, 21, 72, "Text"],
Cell[846378, 23208, 1009, 31, 72, "Text"],
Cell[847390, 23241, 336, 11, 32, "Text"],
Cell[847729, 23254, 277, 5, 46, "DisplayFormula"],
Cell[848009, 23261, 254, 7, 52, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[848324, 23275, 50, 0, 43, "Section"],
Cell[848377, 23277, 789, 21, 72, "Text"],

Cell[CellGroupData[{
Cell[849191, 23302, 44, 0, 46, "Subsubsection"],
Cell[849238, 23304, 1310, 22, 300, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[850585, 23331, 32, 0, 46, "Subsubsection"],
Cell[850620, 23333, 69557, 1489, 257, 19298, 863, "GraphicsData", \
"PostScript", "NumberedFigure",
  CellTags->"figura9"],
Cell[920180, 24824, 914, 34, 32, "Text"],
Cell[921097, 24860, 115, 2, 50, "DisplayFormula"],
Cell[921215, 24864, 1534, 43, 124, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[922786, 24912, 44, 0, 46, "Subsubsection"],
Cell[922833, 24914, 1920, 34, 420, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[924790, 24953, 35, 0, 46, "Subsubsection"],
Cell[924828, 24955, 76583, 1638, 285, 22367, 965, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1001414, 26595, 887, 22, 92, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1002338, 26622, 44, 0, 46, "Subsubsection"],
Cell[1002385, 26624, 2502, 45, 500, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1004924, 26674, 35, 0, 46, "Subsubsection"],
Cell[1004962, 26676, 120557, 2043, 355, 16742, 757, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1125522, 28721, 701, 18, 80, "Text"],
Cell[1126226, 28741, 144, 2, 46, "DisplayFormula"],
Cell[1126373, 28745, 370, 10, 56, "Text"],
Cell[1126746, 28757, 149, 2, 46, "DisplayFormula"],
Cell[1126898, 28761, 1181, 27, 156, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1128116, 28793, 44, 0, 46, "Subsubsection"],
Cell[1128163, 28795, 2838, 50, 560, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1131038, 28850, 35, 0, 46, "Subsubsection"],
Cell[1131076, 28852, 120166, 2615, 229, 33185, 1537, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

